@@ -1,8 +1,6 @@
 /* display.c -- How to display Info windows.
-   $Id: display.c 7709 2017-04-09 09:27:24Z gavin $
 
-   Copyright 1993, 1997, 2003, 2004, 2006, 2007, 2008, 2012, 2013,
-   2014, 2015, 2016, 2017 Free Software Foundation, Inc.
+   Copyright 1993-2019 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -315,7 +313,7 @@ static int ref_highlighted;
 static int pl_num; /* Number of printed lines done so far. */
 
 RENDITION ref_rendition = {UNDERLINE_MASK, UNDERLINE_MASK};
-RENDITION hl_ref_rendition = {UNDERLINE_MASK, 0};
+RENDITION hl_ref_rendition = {BOLD_MASK, BOLD_MASK};
 RENDITION match_rendition = {STANDOUT_MASK, STANDOUT_MASK};
 
 
@@ -357,7 +355,7 @@ display_process_line (WINDOW *win,
         break;
       cur_ptr = mbi_cur_ptr (iter);
 
-      if (matches_ready (matches)
+      if (matches && matches_ready (matches)
           && !at_end_of_matches (matches, match_index))
         {
           int was_in_match = in_match;
