@@ -997,7 +997,12 @@ copy_input_to_output (long n)
                   else if (first_anchor < (inptr-input_start) + bytes_left)
                     {
                       /* Convert enough to pass the first anchor in input. */
-                      bytes_to_convert = first_anchor - (inptr-input_start) + 1;
+                      bytes_to_convert = first_anchor - (inptr-input_start)+1;
+                      if (bytes_to_convert < 0)
+                        {
+                          bytes_to_convert = bytes_left;
+                          anchor_to_adjust = 0;
+                        }
                     }
                 }
 
@@ -1319,7 +1324,8 @@ scan_reference_label (REFERENCE *entry, int in_index)
     entry->end = inptr - input_start;
 
   /* Colon after label. */
-  skip_input (1);
+  if (*inptr)
+    skip_input (1);
   /* Don't mess up the margin of a menu description. */
   if (entry->type == REFERENCE_MENU_ITEM)
     write_extra_bytes_to_output (" ", 1);
