@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright (C) 2014, 2015, 2017 Free Software Foundation, Inc.
+# Copyright (C) 2014-2019 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,7 +16,6 @@
 
 srcdir=${srcdir:-.}
 . $srcdir/t/Init-test.inc
-. $t/Init-inter.inc
 
 run_ginfo
 
@@ -24,9 +23,7 @@ run_ginfo
 # result. Then type "i" followed by <TAB> to check the indices in the
 # file are still there.
 
-printf '\033xindex-apropos\rlink\r\t\ri\txxxx\rqq' >$PTY_TYPE
-# We exited the "i" prompt with "xxx\r" instead of "\007" because
-# C-g leads typeahead to be discarded so it would not be reliable.
+printf '\033xindex-apropos\rlink\r\t\ri\t\030qq' >&7
 
 timeout_test
 
