@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright (C) 2014, 2015, 2017 Free Software Foundation, Inc.
+# Copyright (C) 2014-2019 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,20 +16,19 @@
 
 srcdir=${srcdir:-.}
 . $srcdir/t/Init-test.inc
-. $t/Init-inter.inc 
 
 # Follow an index entry in a split file
 
 run_ginfo -f split
-printf 'ientry text\r\rDq' >$PTY_TYPE
+printf 'ientry text\r\rDq' >&7
 timeout_test
 
-if test ! -f $GINFO_OUTPUT; then
-  RETVAL=1
+if test ! -f $ginfo_output; then
+  retval=1
 else
   # Return non-zero (test failure) if files differ
-  diff $GINFO_OUTPUT $t/node-target
-  RETVAL=$?
+  diff $ginfo_output $t/node-target
+  retval=$?
 fi
 
 cleanup
