@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright (C) 2014 Free Software Foundation, Inc.
+# Copyright (C) 2014-2019 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,15 +16,14 @@
 
 srcdir=${srcdir:-.}
 . $srcdir/t/Init-test.inc
-. $t/Init-inter.inc
 
 # Load dir node
 run_ginfo
 # Split it in two, go to the new window, and make it the only window.
-printf '\0302\030o\0301Dq' >$PTY_TYPE
-. $t/Timeout-test.inc
+printf '\0302\030o\0301Dq' >&7
+timeout_test
 
-grep '^File: dir' $GINFO_OUTPUT
-RETVAL=$?
+grep '^File: dir' $ginfo_output
+retval=$?
 
 cleanup
