@@ -1,6 +1,6 @@
 # Report.pm: prepare error messages and translate strings.
 #
-# Copyright 2010, 2011, 2012, 2014 Free Software Foundation, Inc.
+# Copyright 2010-2020 Free Software Foundation, Inc.
 # 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,13 +21,6 @@ require Exporter;
 use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 @ISA = qw(Exporter);
 
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-
-# This allows declaration      use Texinfo::Parser ':all';
-# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
-# will save memory.
 %EXPORT_TAGS = ( 'all' => [ qw(
   errors
   gdt
@@ -46,6 +39,7 @@ use strict;
 # for fileparse
 use File::Basename;
 
+use POSIX qw(setlocale LC_ALL);
 use Locale::Messages;
 # to be able to load a parser if none was given to gdt.
 use Texinfo::Parser;
@@ -54,30 +48,15 @@ use Texinfo::Parser;
 sub errors($)
 {
   my $self = shift;
-  #print STDERR "REPORT ERRORS $self $self->{'errors_warnings'}\n";
   return ($self->{'errors_warnings'}, $self->{'error_nrs'});
 }
 
-sub __($$)
-{
-  my $self = shift;
-  return &{$self->{'gettext'}}(@_);
-}
-
-sub __p($$$)
-{
-  my $self = shift;
-  return &{$self->{'pgettext'}}(@_);
-}
-
 sub new($)
 {
   my $self = shift;
   $self->{'errors_warnings'} = [];
   #print STDERR "REPORT NEW $self $self->{'errors_warnings'}\n";
   $self->{'errors_nrs'} = 0;
-  $self->{'gettext'} = sub {return $_[0];} if (!defined($self->{'gettext'}));
-  $self->{'pgettext'} = sub {return $_[1];} if (!defined($self->{'pgettext'}));
   return $self;
 }
 
@@ -96,11 +75,11 @@ sub line_warn($$$)
     if ($self->get_conf('TEST'));
   my $warn_line;
   if ($line_number->{'macro'} ne '') {
-    $warn_line = sprintf($self->__p("Texinfo source file warning",
+    $warn_line = sprintf(__p("Texinfo source file warning",
                              "%s:%d: warning: %s (possibly involving \@%s)\n"),
              $file, $line_number->{'line_nr'}, $text, $line_number->{'macro'});
   } else {
-    $warn_line = sprintf($self->__p("Texinfo source file warning", 
+    $warn_line = sprintf(__p("Texinfo source file warning", 
                                     "%s:%d: warning: %s\n"),
                          $file, $line_number->{'line_nr'}, $text);
   }
@@ -111,13 +90,12 @@ sub line_warn($$$)
 }
 
 # format a line error
-sub line_error($$$;$)
+sub line_error($$$)
 {
   my $self = shift;
   my $text = shift;
   chomp ($text);
   my $line_number = shift;
-  my $continuation = shift;
   return if ($self->{'ignore_notice'});
   if (defined($line_number)) {
     my $file = $line_number->{'file_name'};
@@ -129,13 +107,11 @@ sub line_error($$$;$)
        if ($line_number->{'macro'} ne '');
     my $error_text = "$file:$line_number->{'line_nr'}: $text$macro_text\n";
     warn "$error_text" if ($self->get_conf('DEBUG'));
-    my $type = 'error';
-    $type = 'error continuation' if ($continuation);
     push @{$self->{'errors_warnings'}},
-         { 'type' => $type, 'text' => $text, 'error_line' => $error_text,
+         { 'type' => 'error', 'text' => $text, 'error_line' => $error_text,
            %{$line_number} };
   }
-  $self->{'error_nrs'}++ unless ($continuation);
+  $self->{'error_nrs'}++;
 }
 
 sub document_warn($$)
@@ -147,10 +123,10 @@ sub document_warn($$)
 
   my $warn_line;
   if (defined($self->get_conf('PROGRAM')) and $self->get_conf('PROGRAM') ne '') {
-    $warn_line = sprintf($self->__p("whole document warning", "%s: warning: %s\n"), 
+    $warn_line = sprintf(__p("whole document warning", "%s: warning: %s\n"), 
                          $self->get_conf('PROGRAM'), $text);
   } else {
-    $warn_line = sprintf($self->__p("whole document warning", "warning: %s\n"), 
+    $warn_line = sprintf(__p("whole document warning", "warning: %s\n"), 
                          $text);
   }
   push @{$self->{'errors_warnings'}},
@@ -185,12 +161,12 @@ sub file_line_warn($$$;$)
 
   my $warn_line;
   if (!defined($file)) {
-    $warn_line = sprintf($self->__p("file warning", "warning: %s\n"), $text);
+    $warn_line = sprintf(__p("file warning", "warning: %s\n"), $text);
   } elsif (!defined($line_nr)) {
-    $warn_line = sprintf($self->__p("file warning", "%s: warning: %s\n"), 
+    $warn_line = sprintf(__p("file warning", "%s: warning: %s\n"), 
                          $file, $text);
   } else {
-    $warn_line = sprintf($self->__p("file warning", "%s:%d: warning: %s\n"), 
+    $warn_line = sprintf(__p("file warning", "%s:%d: warning: %s\n"), 
                          $file, $line_nr, $text);
   }
   #print STDERR "REPORT FILE_LINE_WARN $self $self->{'errors_warnings'}\n";
@@ -230,10 +206,22 @@ my $DEFAULT_LANGUAGE = 'en';
 # gettext.
 Locale::Messages->select_package ('gettext_pp');
 
-# FIXME make those configurable?  Set them with call to new?
 my $strings_textdomain = 'texinfo_document';
 my $messages_textdomain = 'texinfo';
 
+sub __($) {
+  my $msgid = shift;
+  return Locale::Messages::dgettext($messages_textdomain, $msgid);
+}
+  
+sub __p($$) {
+  my $context = shift;
+  my $msgid = shift;
+  return Locale::Messages::dpgettext($messages_textdomain, $context, $msgid);
+}
+
+
+
 # libintl converts between encodings but doesn't decode them into the
 # perl internal format.  This is only called if the encoding is a proper
 # perl encoding.
@@ -248,30 +236,33 @@ sub _encode_i18n_string($$)
 # Return a parsed Texinfo tree
 sub gdt($$;$$)
 {
-  my $self = shift;
-  my $message = shift;
-  my $context = shift;
-  my $type = shift;
+  my ($self, $message, $context, $type) = @_;
 
   my $re = join '|', map { quotemeta $_ } keys %$context
       if (defined($context) and ref($context));
 
-  my $saved_env_LC_ALL = $ENV{'LC_ALL'};
+  my $saved_LC_ALL = POSIX::setlocale(LC_ALL);
   my $saved_LANGUAGE = $ENV{'LANGUAGE'};
-#  my $saved_LANG = $ENV{'LANG'};
-#  my $saved_LC_ALL = POSIX::setlocale (LC_ALL);
-#  my $saved_LC_CTYPE = POSIX::setlocale (LC_CTYPE);
-#  my $saved_LC_MESSAGES = POSIX::setlocale (LC_MESSAGES);
+
+  # The following is necessary when the locale is "C" (as is the case
+  # when the tests are run), due to the fix for
+  #   https://rt.cpan.org/Public/Bug/Display.html?id=81315
+  # Translation is not done if LC_MESSAGES is "C" or "POSIX".
+  # This may not work if a locale named here doesn't exist on the system.
+  # Set LC_ALL rather than LC_MESSAGES as LC_MESSAGES may not be supported
+  # on Perl for MS-Windows.
+  for my $try ('en_US.UTF-8', 'en_US') {
+    my $locale = POSIX::setlocale(LC_ALL, $try);
+    last if $locale;
+  }
 
   Locale::Messages::textdomain($strings_textdomain);
 
-  # FIXME do that only once when encoding is seen (or at beginning)
+  # FIXME do this only once when encoding is seen (or at beginning)
   # instead of here, each time that gdt is called?
   my $encoding;
   if ($self->get_conf('OUTPUT_ENCODING_NAME')) {
     $encoding = $self->get_conf('OUTPUT_ENCODING_NAME');
-  } elsif ($self->get_conf('INPUT_ENCODING_NAME')) {
-    $encoding = $self->get_conf('INPUT_ENCODING_NAME');
   }
   Locale::Messages::bind_textdomain_codeset($strings_textdomain, $encoding)
     if ($encoding and $encoding ne 'us-ascii');
@@ -279,8 +270,6 @@ sub gdt($$;$$)
     my $perl_encoding;
     if ($self->get_conf('OUTPUT_PERL_ENCODING')) {
       $perl_encoding = $self->get_conf('OUTPUT_PERL_ENCODING');
-    } elsif ($self->get_conf('INPUT_PERL_ENCODING')) {
-      $perl_encoding = $self->get_conf('INPUT_PERL_ENCODING');
     }
     if ($perl_encoding) {
       Locale::Messages::bind_textdomain_filter($strings_textdomain,
@@ -288,7 +277,7 @@ sub gdt($$;$$)
     }
   }
 
-  # FIXME do that once when @documentlanguage changes (or at beginning)
+  # FIXME do this once when @documentlanguage changes (or at beginning)
   # instead of here, each time that gdt is called?
   my $lang = $self->get_conf('documentlanguage');
   $lang = $DEFAULT_LANGUAGE if (!defined($lang));
@@ -315,49 +304,23 @@ sub gdt($$;$$)
     }
   }
   $locales =~ s/:$//;
-  # print STDERR "$locales $message\n";
   # END FIXME
 
   Locale::Messages::nl_putenv("LANGUAGE=$locales");
 
-  my $translation_result;
-  if (!defined($context) or ref($context)) {
-    $translation_result = Locale::Messages::gettext($message);
-  } else {
-    # In practice this is not used anywhere, context is always a HASH.
-    # for strings substitution not a context for translation.
-    $translation_result = Locale::Messages::pgettext($context, $message);
-  }
-  #print STDERR "$locales $message ----> $translation_result\n";
+  my $translation_result = Locale::Messages::gettext($message);
 
   Locale::Messages::textdomain($messages_textdomain);
-  # old perl complains 'Use of uninitialized value in scalar assignment'
   if (!defined($saved_LANGUAGE)) {
     delete ($ENV{'LANGUAGE'});
   } else {
     $ENV{'LANGUAGE'} = $saved_LANGUAGE;
   }
-  if (!defined($saved_env_LC_ALL)) {
-    delete ($ENV{'LC_ALL'});
+  if (defined($saved_LC_ALL)) {
+    POSIX::setlocale(LC_ALL, $saved_LC_ALL);
   } else {
-    $ENV{'LC_ALL'} = $saved_env_LC_ALL;
+    POSIX::setlocale(LC_ALL, '');
   }
-#  my $new_LC_ALL = POSIX::setlocale (LC_ALL);
-#  my $new_LC_CTYPE = POSIX::setlocale (LC_CTYPE);
-#  my $new_LC_MESSAGES = POSIX::setlocale (LC_MESSAGES);
-#  my $new_env_LC_ALL = 'UNDEF';
-#  $new_env_LC_ALL = $ENV{'LC_ALL'} if defined($ENV{'LC_ALL'});
-#  my $saved_str_env_LC_ALL = $saved_env_LC_ALL;
-#  $saved_str_env_LC_ALL = 'UNDEF' if (!defined($saved_str_env_LC_ALL));
-
-#  print STDERR "  LC_ALL $saved_LC_ALL $new_LC_ALL ENV: $saved_str_env_LC_ALL $new_env_LC_ALL\n";
-#  print STDERR "  LC_CTYPE $saved_LC_CTYPE $new_LC_CTYPE\n";
-#  print STDERR "  LC_MESSAGES $saved_LC_MESSAGES $new_LC_MESSAGES\n";
-#  my $new_LANG = 'UNDEF';
-#  $new_LANG = $ENV{'LANG'} if defined($ENV{'LANG'});
-#  my $saved_str_LANG = $saved_LANG;
-#  $saved_str_LANG = 'UNDEF' if (!defined($saved_str_LANG));
-#  print STDERR "  LANG $saved_str_LANG $new_LANG\n";
 
   if ($type and $type eq 'translated_text') {
     if (defined($re)) {
@@ -376,7 +339,6 @@ sub gdt($$;$$)
     # next line taken from libintl perl, copyright Guido. sub __expand
     $translation_result =~ s/\{($re)\}/\@value\{_$1\}/g;
     foreach my $substitution(keys %$context) {
-      #print STDERR "$translation_result $substitution $context->{$substitution}\n";
       # Only pass simple string @values to parser.
       if (!ref($context->{$substitution})) {
         $parser_conf->{'values'}->{'_'.$substitution}
@@ -403,19 +365,14 @@ sub gdt($$;$$)
         if (defined($current_parser->{$duplicated_conf}));
     }
   }
+  $parser_conf->{'in_gdt'} = 1;
   #my $parser = Texinfo::Parser::parser($parser_conf);
   my $parser = Texinfo::Parser::simple_parser($parser_conf);
   if ($parser->{'DEBUG'}) {
     print STDERR "GDT $translation_result\n";
   }
 
-  my $tree;
-  # Right now this is not used anywhere.
-  if ($type and $type eq 'translated_paragraph') {
-    $tree = $parser->parse_texi_text($translation_result);
-  } else {
-    $tree = $parser->parse_texi_line($translation_result);
-  }
+  my $tree = $parser->parse_texi_line($translation_result);
   $tree = _substitute ($tree, $context);
   return $tree;
 }
@@ -429,9 +386,11 @@ sub _substitute_element_array ($$) {
       my $name = $_->{'type'};
       $name =~ s/^_//;
       if (ref($context->{$name}) eq 'HASH') {
-        ( $context->{$name} );
+        $context->{$name};
       } elsif (ref($context->{$name}) eq 'ARRAY') {
         @{$context->{$name}};
+      } else {
+        (); # undefined - shouldn't happen?
       }
     } else {
       _substitute($_, $context);
@@ -454,15 +413,6 @@ sub _substitute ($$) {
     _substitute_element_array ($tree->{'args'}, $context);
   }
 
-  # Used for @email and @url
-  if ($tree->{'extra'} and $tree->{'extra'}{'brace_command_contents'}) {
-    for my $arg (@{$tree->{'extra'}{'brace_command_contents'}}) {
-      if ($arg) {
-        _substitute_element_array ($arg, $context);
-      }
-    }
-  }
-
   return $tree;
 }
 
@@ -550,11 +500,6 @@ In that case the string is not considered to be Texinfo, a plain string
 that is returned after translation and substitution.  The substitutions
 may only be strings in that case.
 
-=item translated_paragraph
-
-In that case, the parsing of the Texinfo string is done in a 
-context of a paragraph, not in the context of an inline text.
-
 =back
 
 For example in the following call, the string 
@@ -593,8 +538,7 @@ the following keys:
 
 =item type
 
-May be C<warning>, C<error>, or C<error continuation> (for a continuation of
-an error line).
+May be C<warning>, or C<error>.
 
 =item text
 
@@ -622,15 +566,14 @@ the error or warning.
 
 =item $converter->line_warn($text, $line_nr)
 
-=item $converter->line_error($text, $line_nr, $continuation)
+=item $converter->line_error($text, $line_nr)
 
 Register a warning or an error.  The I<$text> is the text of the
 error or warning.  The optional I<$line_nr> holds the information
 on the error or warning location.  It is associated with the I<line_nr> 
 key of Texinfo tree elements as described in L<Texinfo::Parser/line_nr>
 for the @-commands.  The I<$line_nr> structure is described in L<errors|($error_warnings_list, $error_count) = errors ($converter)>
-above.  If I<$continuation> is set, the line is an error message continuation
-line and not a new error.
+above.
 
 =item $converter->document_warn($text)
 
@@ -655,13 +598,4 @@ the line I<$line_nr> in the file.
 
 Patrice Dumas, E<lt>pertusus@free.frE<gt>
 
-=head1 COPYRIGHT AND LICENSE
-
-Copyright 2010, 2011, 2012 Free Software Foundation, Inc.
-
-This library is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 3 of the License,
-or (at your option) any later version.
-
 =cut
