@@ -1,4 +1,4 @@
-/* Copyright 2010-2020 Free Software Foundation, Inc.
+/* Copyright 2010-2021 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -40,6 +40,7 @@
 
 ELEMENT *Root;
 
+#ifdef ENABLE_NLS
 
 #define LOCALEDIR DATADIR "/locale"
 
@@ -57,7 +58,7 @@ find_locales_dir (char *builddir)
   dTHX;
 
   /* Can't use asprintf here, because it might come from Gnulib, and
-     will then use malloc that is different from Perl's malloc, wheres
+     will then use malloc that is different from Perl's malloc, whereas
      free below is redirected to Perl's implementation.  This could
      cause crashes if the two malloc/free implementations were different.  */
   s = malloc (strlen (builddir) + strlen ("/LocaleData") + 1);
@@ -93,6 +94,16 @@ init (int texinfo_uninstalled, char *builddir)
   return 1;
 }
 
+#else
+
+int
+init (int texinfo_uninstalled, char *builddir)
+{
+  return 1;
+}
+
+#endif
+
 static void
 reset_floats ()
 {
@@ -427,8 +438,10 @@ element_to_perl_hash (ELEMENT *e)
               break;
               }
             case extra_integer:
-              { /* A simple integer. */
-              IV value = (IV) f;
+              { /* A simple integer.  The intptr_t cast here prevents
+                   a warning on MinGW ("cast from pointer to integer of
+                   different size"). */
+              IV value = (IV) (intptr_t) f;
               STORE(newSViv (value));
               break;
               }
