@@ -1,4 +1,6 @@
 /* api.h - declarations for api.c */
+#ifndef API_H
+#define API_H
 extern ELEMENT *Root;
 
 int init (int texinfo_uninstalled, char *srcdir_in);
@@ -21,3 +23,4 @@ HV *build_global_info (void);
 HV *build_global_info2 (void);
 
 
+#endif
