@@ -53,13 +53,14 @@ COMMAND builtin_command_data[] = {
 "author", CF_line | CF_global, LINE_line,
 "b", CF_brace, BRACE_style,
 "backslashchar", CF_brace, 0,
+"bsixpaper", CF_line, LINE_skipline,
 "bullet", CF_brace, 0,
 "bye", CF_line, LINE_skipline,
 "c", CF_line, LINE_lineraw,
 "caption", CF_brace, BRACE_context,
 "cartouche", CF_block, 0,
 "center", CF_line, LINE_line,
-"centerchap", CF_root | CF_line | CF_sectioning, LINE_line,
+"centerchap", CF_root | CF_line | CF_sectioning | CF_deprecated, LINE_line,
 "chapheading", CF_line | CF_sectioning, LINE_line,
 "chapter", CF_root | CF_line | CF_sectioning, LINE_line,
 "cite", CF_brace, BRACE_style,
@@ -83,7 +84,7 @@ COMMAND builtin_command_data[] = {
 "deffn", CF_block | CF_def, 0,
 "deffnx", CF_line | CF_def, LINE_line,
 "defindex", CF_line, 1,
-"definfoenclose", CF_line, 3,
+"definfoenclose", CF_line | CF_deprecated, 3,
 "defivar", CF_block | CF_def | CF_def_alias, 0,
 "defivarx", CF_line | CF_def | CF_def_alias, LINE_line,
 "defmac", CF_block | CF_def | CF_def_alias, 0,
@@ -127,6 +128,7 @@ COMMAND builtin_command_data[] = {
 "dircategory", CF_line, LINE_line,
 "direntry", CF_block | CF_menu, 0,
 "display", CF_block | CF_preformatted, 0,
+"displaymath", CF_block, 0,
 "dmn", CF_brace, 1,
 "docbook", CF_block | CF_format_raw, 0,
 "documentdescription", CF_block | CF_global_unique, BLOCK_region,
@@ -153,7 +155,7 @@ COMMAND builtin_command_data[] = {
 "everyfootingmarks", CF_line | CF_global_unique, 1,
 "everyheading", CF_line | CF_global_unique, LINE_lineraw,
 "everyheadingmarks", CF_line | CF_global_unique, 1,
-"example", CF_block | CF_preformatted | CF_preformatted_code, 0,
+"example", CF_block | CF_preformatted | CF_preformatted_code, BLOCK_variadic,
 "exampleindent", CF_line | CF_global, 1,
 "exclamdown", CF_brace, 0,
 "exdent", CF_line, LINE_line,
@@ -208,7 +210,7 @@ COMMAND builtin_command_data[] = {
 "indent", CF_other, OTHER_skipspace,
 "indentedblock", CF_block, 0,
 "indicateurl", CF_brace | CF_code_style, 1,
-"inforef", CF_brace | CF_ref, 3,
+"inforef", CF_brace | CF_ref | CF_deprecated, 3,
 "inlinefmt", CF_brace | CF_inline, 2,
 "inlinefmtifelse", CF_brace | CF_inline, 3,
 "inlineifclear", CF_brace | CF_inline, 2,
@@ -270,7 +272,7 @@ COMMAND builtin_command_data[] = {
 "raisesections", CF_line, LINE_skipline,
 "rbracechar", CF_brace, 0,
 "ref", CF_brace | CF_ref, 5,
-"refill", CF_other, OTHER_noarg,
+"refill", CF_other | CF_deprecated, OTHER_noarg,
 "registeredsymbol", CF_brace, 0,
 "result", CF_brace, 0,
 "ringaccent", CF_brace | CF_accent, BRACE_accent,
@@ -283,9 +285,7 @@ COMMAND builtin_command_data[] = {
 "seeentry", CF_brace, 1,
 "set", CF_line, LINE_special,
 "setchapternewpage", CF_line | CF_global_unique, 1,
-"setcontentsaftertitlepage", CF_line | CF_deprecated, LINE_skipline,
 "setfilename", CF_line | CF_global_unique, LINE_text,
-"setshortcontentsaftertitlepage", CF_line | CF_deprecated, LINE_skipline,
 "settitle", CF_line | CF_global_unique, LINE_line,
 "shortcaption", CF_brace, BRACE_context,
 "shortcontents", CF_line | CF_global, LINE_skipline,
@@ -344,7 +344,6 @@ COMMAND builtin_command_data[] = {
 "urefbreakstyle", CF_line | CF_global, 1,
 "url", CF_brace, 3,
 "v", CF_brace | CF_accent, BRACE_accent,
-"validatemenus", CF_line | CF_global_unique, 1,
 "value", CF_brace, 0,
 "var", CF_brace, BRACE_style,
 "verb", CF_brace | CF_code_style, BRACE_other,
