@@ -1,5 +1,7 @@
 /* commands.h - declarations for commands.c */
-/* Copyright 2010-2019 Free Software Foundation, Inc.
+#ifndef COMMANDS_H
+#define COMMANDS_H
+/* Copyright 2010-2021 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -105,9 +107,12 @@ void wipe_user_commands (void);
 #define BLOCK_raw -2
 #define BLOCK_multitable -3
 #define BLOCK_region -4
+#define BLOCK_variadic -5
 
 /* Types of brace command (CF_brace). */
 #define BRACE_context -1 /* Can enclose paragraph breaks. */
 #define BRACE_accent -2
 #define BRACE_style -3
 #define BRACE_other -4
+
+#endif
