@@ -1,5 +1,7 @@
 /* labels.h - declarations for labels.c */
-/* Copyright 2010-2019 Free Software Foundation, Inc.
+#ifndef LABELS_H
+#define LABELS_H
+/* Copyright 2010-2021 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -14,6 +16,8 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>. */
 
+#include "tree_types.h"
+
 /* Information about a possible target of a cross-reference, often a node. */
 typedef struct {
     /* Pointer to the element for the command defining this label, usually a
@@ -35,3 +39,4 @@ extern size_t internal_xref_space;
 
 void remember_internal_xref (ELEMENT *element);
 void reset_internal_xrefs (void);
+#endif
