@@ -62,9 +62,6 @@ $result_trees{'empty_ifset_in_ifset_set'} = {
           'type' => 'raw'
         }
       ],
-      'extra' => {
-        'spaces_after_command' => {}
-      },
       'line_nr' => {
         'file_name' => '',
         'line_nr' => 5,
@@ -73,9 +70,6 @@ $result_trees{'empty_ifset_in_ifset_set'} = {
       'parent' => {}
     },
     {
-      'extra' => {
-        'command' => {}
-      },
       'parent' => {},
       'text' => '
 ',
@@ -92,9 +86,7 @@ $result_trees{'empty_ifset_in_ifset_set'}{'contents'}[2]{'parent'} = $result_tre
 $result_trees{'empty_ifset_in_ifset_set'}{'contents'}[3]{'contents'}[0]{'extra'}{'command'} = $result_trees{'empty_ifset_in_ifset_set'}{'contents'}[3];
 $result_trees{'empty_ifset_in_ifset_set'}{'contents'}[3]{'contents'}[0]{'parent'} = $result_trees{'empty_ifset_in_ifset_set'}{'contents'}[3];
 $result_trees{'empty_ifset_in_ifset_set'}{'contents'}[3]{'contents'}[1]{'parent'} = $result_trees{'empty_ifset_in_ifset_set'}{'contents'}[3];
-$result_trees{'empty_ifset_in_ifset_set'}{'contents'}[3]{'extra'}{'spaces_after_command'} = $result_trees{'empty_ifset_in_ifset_set'}{'contents'}[3]{'contents'}[0];
 $result_trees{'empty_ifset_in_ifset_set'}{'contents'}[3]{'parent'} = $result_trees{'empty_ifset_in_ifset_set'};
-$result_trees{'empty_ifset_in_ifset_set'}{'contents'}[4]{'extra'}{'command'} = $result_trees{'empty_ifset_in_ifset_set'}{'contents'}[3];
 $result_trees{'empty_ifset_in_ifset_set'}{'contents'}[4]{'parent'} = $result_trees{'empty_ifset_in_ifset_set'};
 
 $result_texis{'empty_ifset_in_ifset_set'} = '
@@ -114,4 +106,7 @@ $result_texts{'empty_ifset_in_ifset_set'} = '
 $result_errors{'empty_ifset_in_ifset_set'} = [];
 
 
+$result_floats{'empty_ifset_in_ifset_set'} = {};
+
+
 1;
