@@ -1,20 +1,14 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
 $result_trees{'ifnotinfo_exception'} = {
-  'contents' => [
-    {
-      'parent' => {},
-      'type' => 'before_node_section'
-    }
-  ],
-  'type' => 'document_root'
+  'contents' => [],
+  'type' => 'text_root'
 };
-$result_trees{'ifnotinfo_exception'}{'contents'}[0]{'parent'} = $result_trees{'ifnotinfo_exception'};
 
 $result_texis{'ifnotinfo_exception'} = '';
 
