@@ -32,9 +32,6 @@ $result_trees{'ignore_not_closed'} = {
           'type' => 'raw'
         }
       ],
-      'extra' => {
-        'spaces_after_command' => {}
-      },
       'line_nr' => {
         'file_name' => '',
         'line_nr' => 1,
@@ -49,7 +46,6 @@ $result_trees{'ignore_not_closed'}{'contents'}[0]{'contents'}[0]{'extra'}{'comma
 $result_trees{'ignore_not_closed'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'ignore_not_closed'}{'contents'}[0];
 $result_trees{'ignore_not_closed'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'ignore_not_closed'}{'contents'}[0];
 $result_trees{'ignore_not_closed'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'ignore_not_closed'}{'contents'}[0];
-$result_trees{'ignore_not_closed'}{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'ignore_not_closed'}{'contents'}[0]{'contents'}[0];
 $result_trees{'ignore_not_closed'}{'contents'}[0]{'parent'} = $result_trees{'ignore_not_closed'};
 
 $result_texis{'ignore_not_closed'} = '@ignore
@@ -73,4 +69,7 @@ $result_errors{'ignore_not_closed'} = [
 ];
 
 
+$result_floats{'ignore_not_closed'} = {};
+
+
 1;
