@@ -50,7 +50,11 @@ $result_trees{'accent_with_text'} = {
           ],
           'cmdname' => 'dotless',
           'contents' => [],
-          'line_nr' => {},
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 1,
+            'macro' => ''
+          },
           'parent' => {}
         },
         {
@@ -80,7 +84,11 @@ $result_trees{'accent_with_text'} = {
                   ],
                   'cmdname' => 'dotless',
                   'contents' => [],
-                  'line_nr' => {},
+                  'line_nr' => {
+                    'file_name' => '',
+                    'line_nr' => 1,
+                    'macro' => ''
+                  },
                   'parent' => {}
                 }
               ],
@@ -90,7 +98,11 @@ $result_trees{'accent_with_text'} = {
           ],
           'cmdname' => '^',
           'contents' => [],
-          'line_nr' => {},
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 1,
+            'macro' => ''
+          },
           'parent' => {}
         },
         {
@@ -120,7 +132,11 @@ $result_trees{'accent_with_text'} = {
                   ],
                   'cmdname' => 'dotless',
                   'contents' => [],
-                  'line_nr' => {},
+                  'line_nr' => {
+                    'file_name' => '',
+                    'line_nr' => 1,
+                    'macro' => ''
+                  },
                   'parent' => {}
                 }
               ],
@@ -130,7 +146,11 @@ $result_trees{'accent_with_text'} = {
           ],
           'cmdname' => '^',
           'contents' => [],
-          'line_nr' => {},
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 1,
+            'macro' => ''
+          },
           'parent' => {}
         },
         {
@@ -152,7 +172,11 @@ $result_trees{'accent_with_text'} = {
           ],
           'cmdname' => '^',
           'contents' => [],
-          'line_nr' => {},
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 1,
+            'macro' => ''
+          },
           'parent' => {}
         },
         {
@@ -173,30 +197,24 @@ $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[0]{'parent'} = $res
 $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'accent_with_text'}{'contents'}[0];
 $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[2]{'args'}[0];
 $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[2];
-$result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[2]{'line_nr'} = $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'accent_with_text'}{'contents'}[0];
 $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[3]{'parent'} = $result_trees{'accent_with_text'}{'contents'}[0];
 $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[4]{'args'}[0];
 $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[4]{'args'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[4]{'args'}[0]{'contents'}[1]{'args'}[0];
 $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[4]{'args'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[4]{'args'}[0]{'contents'}[1];
-$result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[4]{'args'}[0]{'contents'}[1]{'line_nr'} = $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[4]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[4]{'args'}[0];
 $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[4];
-$result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[4]{'line_nr'} = $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[4]{'parent'} = $result_trees{'accent_with_text'}{'contents'}[0];
 $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[5]{'parent'} = $result_trees{'accent_with_text'}{'contents'}[0];
 $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[6]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[6]{'args'}[0];
 $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[6]{'args'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[6]{'args'}[0]{'contents'}[1]{'args'}[0];
 $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[6]{'args'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[6]{'args'}[0]{'contents'}[1];
-$result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[6]{'args'}[0]{'contents'}[1]{'line_nr'} = $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[6]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[6]{'args'}[0];
 $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[6]{'args'}[0]{'parent'} = $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[6];
-$result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[6]{'line_nr'} = $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[6]{'parent'} = $result_trees{'accent_with_text'}{'contents'}[0];
 $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[7]{'parent'} = $result_trees{'accent_with_text'}{'contents'}[0];
 $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[8]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[8]{'args'}[0];
 $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[8]{'args'}[0]{'parent'} = $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[8];
-$result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[8]{'line_nr'} = $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[8]{'parent'} = $result_trees{'accent_with_text'}{'contents'}[0];
 $result_trees{'accent_with_text'}{'contents'}[0]{'contents'}[9]{'parent'} = $result_trees{'accent_with_text'}{'contents'}[0];
 $result_trees{'accent_with_text'}{'contents'}[0]{'parent'} = $result_trees{'accent_with_text'};
@@ -221,6 +239,9 @@ $result_errors{'accent_with_text'} = [
 ];
 
 
+$result_floats{'accent_with_text'} = {};
+
+
 
 $result_converted{'plaintext'}->{'accent_with_text'} = '-ă -b î ĵ -â
 ';
