@@ -38,7 +38,7 @@ $result_trees{'image_extension'} = {
           'contents' => [
             {
               'parent' => {},
-              'text' => 'gr--a'
+              'text' => '.gr--a'
             }
           ],
           'parent' => {},
@@ -47,6 +47,9 @@ $result_trees{'image_extension'} = {
       ],
       'cmdname' => 'image',
       'contents' => [],
+      'extra' => {
+        'input_perl_encoding' => 'utf-8'
+      },
       'line_nr' => {
         'file_name' => '',
         'line_nr' => 1,
@@ -72,7 +75,7 @@ $result_trees{'image_extension'}{'contents'}[0]{'args'}[4]{'parent'} = $result_t
 $result_trees{'image_extension'}{'contents'}[0]{'parent'} = $result_trees{'image_extension'};
 $result_trees{'image_extension'}{'contents'}[1]{'parent'} = $result_trees{'image_extension'};
 
-$result_texis{'image_extension'} = '@image{f---ile,,,,gr--a}
+$result_texis{'image_extension'} = '@image{f---ile,,,,.gr--a}
 ';
 
 
@@ -82,8 +85,12 @@ $result_texts{'image_extension'} = 'f---ile
 $result_errors{'image_extension'} = [];
 
 
+$result_floats{'image_extension'} = {};
 
-$result_converted{'plaintext'}->{'image_extension'} = '[f---ile]';
+
+
+$result_converted{'plaintext'}->{'image_extension'} = '[f---ile]
+';
 
 $result_converted_errors{'plaintext'}->{'image_extension'} = [
   {
@@ -116,7 +123,7 @@ $result_converted_errors{'html_text'}->{'image_extension'} = [
 
 
 
-$result_converted{'xml'}->{'image_extension'} = '<image><imagefile>f---ile</imagefile><imageextension>gr--a</imageextension></image>
+$result_converted{'xml'}->{'image_extension'} = '<image><imagefile>f---ile</imagefile><imageextension>.gr--a</imageextension></image>
 ';
 
 
@@ -140,10 +147,16 @@ $result_converted_errors{'docbook'}->{'image_extension'} = [
 $result_converted{'info'}->{'image_extension'} = 'This is , produced from .
 
 [f---ile]
+
 
 Tag Table:
 
 End Tag Table
+
+
+Local Variables:
+coding: utf-8
+End:
 ';
 
 $result_converted_errors{'info'}->{'image_extension'} = [
