@@ -43,16 +43,7 @@ $result_trees{'image_with_spaces'} = {
       'cmdname' => 'image',
       'contents' => [],
       'extra' => {
-        'brace_command_contents' => [
-          [
-            {}
-          ],
-          undef,
-          undef,
-          [
-            {}
-          ]
-        ]
+        'input_perl_encoding' => 'utf-8'
       },
       'line_nr' => {
         'file_name' => '',
@@ -104,16 +95,7 @@ $result_trees{'image_with_spaces'} = {
           'cmdname' => 'image',
           'contents' => [],
           'extra' => {
-            'brace_command_contents' => [
-              [
-                {}
-              ],
-              undef,
-              undef,
-              [
-                {}
-              ]
-            ]
+            'input_perl_encoding' => 'utf-8'
           },
           'line_nr' => {
             'file_name' => '',
@@ -140,8 +122,6 @@ $result_trees{'image_with_spaces'}{'contents'}[0]{'args'}[1]{'parent'} = $result
 $result_trees{'image_with_spaces'}{'contents'}[0]{'args'}[2]{'parent'} = $result_trees{'image_with_spaces'}{'contents'}[0];
 $result_trees{'image_with_spaces'}{'contents'}[0]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'image_with_spaces'}{'contents'}[0]{'args'}[3];
 $result_trees{'image_with_spaces'}{'contents'}[0]{'args'}[3]{'parent'} = $result_trees{'image_with_spaces'}{'contents'}[0];
-$result_trees{'image_with_spaces'}{'contents'}[0]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'image_with_spaces'}{'contents'}[0]{'args'}[0]{'contents'}[0];
-$result_trees{'image_with_spaces'}{'contents'}[0]{'extra'}{'brace_command_contents'}[3][0] = $result_trees{'image_with_spaces'}{'contents'}[0]{'args'}[3]{'contents'}[0];
 $result_trees{'image_with_spaces'}{'contents'}[0]{'parent'} = $result_trees{'image_with_spaces'};
 $result_trees{'image_with_spaces'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'image_with_spaces'}{'contents'}[1];
 $result_trees{'image_with_spaces'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'image_with_spaces'}{'contents'}[1]{'contents'}[1]{'args'}[0];
@@ -150,8 +130,6 @@ $result_trees{'image_with_spaces'}{'contents'}[1]{'contents'}[1]{'args'}[1]{'par
 $result_trees{'image_with_spaces'}{'contents'}[1]{'contents'}[1]{'args'}[2]{'parent'} = $result_trees{'image_with_spaces'}{'contents'}[1]{'contents'}[1];
 $result_trees{'image_with_spaces'}{'contents'}[1]{'contents'}[1]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'image_with_spaces'}{'contents'}[1]{'contents'}[1]{'args'}[3];
 $result_trees{'image_with_spaces'}{'contents'}[1]{'contents'}[1]{'args'}[3]{'parent'} = $result_trees{'image_with_spaces'}{'contents'}[1]{'contents'}[1];
-$result_trees{'image_with_spaces'}{'contents'}[1]{'contents'}[1]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'image_with_spaces'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'image_with_spaces'}{'contents'}[1]{'contents'}[1]{'extra'}{'brace_command_contents'}[3][0] = $result_trees{'image_with_spaces'}{'contents'}[1]{'contents'}[1]{'args'}[3]{'contents'}[0];
 $result_trees{'image_with_spaces'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'image_with_spaces'}{'contents'}[1];
 $result_trees{'image_with_spaces'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'image_with_spaces'}{'contents'}[1];
 $result_trees{'image_with_spaces'}{'contents'}[1]{'parent'} = $result_trees{'image_with_spaces'};
@@ -168,8 +146,11 @@ f--ile.
 $result_errors{'image_with_spaces'} = [];
 
 
+$result_floats{'image_with_spaces'} = {};
 
-$result_converted{'plaintext'}->{'image_with_spaces'} = 'Image description""\\.. Image description""\\..
+
+
+$result_converted{'plaintext'}->{'image_with_spaces'} = 'Image description""\\..  Image description""\\..
 ';
 
 
@@ -191,12 +172,17 @@ $result_converted{'docbook'}->{'image_with_spaces'} = '<informalfigure><mediaobj
 $result_converted{'info'}->{'image_with_spaces'} = 'This is , produced from .
 
  [image src="f--ile.png" alt=" " text="Image description\\"\\"\\\\." ]
-.  [image src="f--ile.png" alt="" text="Image description\\"\\"\\\\." ].
+.   [image src="f--ile.png" alt="" text="Image description\\"\\"\\\\." ].
 
 
 Tag Table:
 
 End Tag Table
+
+
+Local Variables:
+coding: utf-8
+End:
 ';
 
 $result_converted_errors{'info'}->{'image_with_spaces'} = [
