@@ -259,7 +259,9 @@ $result_trees{'index_entry_in_preformatted'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -315,7 +317,7 @@ $result_trees{'index_entry_in_preformatted'}{'contents'}[1]{'contents'}[1]{'cont
 $result_trees{'index_entry_in_preformatted'}{'contents'}[1]{'contents'}[1]{'extra'}{'end_command'} = $result_trees{'index_entry_in_preformatted'}{'contents'}[1]{'contents'}[1]{'contents'}[2];
 $result_trees{'index_entry_in_preformatted'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'index_entry_in_preformatted'}{'contents'}[1];
 $result_trees{'index_entry_in_preformatted'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'index_entry_in_preformatted'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'index_entry_in_preformatted'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'index_entry_in_preformatted'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'index_entry_in_preformatted'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'index_entry_in_preformatted'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'index_entry_in_preformatted'}{'contents'}[1]{'parent'} = $result_trees{'index_entry_in_preformatted'};
 
 $result_texis{'index_entry_in_preformatted'} = '@node Top
@@ -344,20 +346,8 @@ $result_nodes{'index_entry_in_preformatted'} = {
   'extra' => {
     'normalized' => 'Top',
     'spaces_before_argument' => ' '
-  },
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
   }
 };
-$result_nodes{'index_entry_in_preformatted'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'index_entry_in_preformatted'};
 
 $result_menus{'index_entry_in_preformatted'} = {
   'cmdname' => 'node',
@@ -370,6 +360,9 @@ $result_menus{'index_entry_in_preformatted'} = {
 $result_errors{'index_entry_in_preformatted'} = [];
 
 
+$result_floats{'index_entry_in_preformatted'} = {};
+
+
 
 $result_converted{'plaintext'}->{'index_entry_in_preformatted'} = '     text
 
@@ -384,11 +377,10 @@ $result_converted{'html_text'}->{'index_entry_in_preformatted'} = '<span id="Top
 
 <span id="index-other"></span>text2
 <span id="index-last"></span></pre></div>
-<hr>
-';
+<hr>';
 
 
-$result_converted{'xml'}->{'index_entry_in_preformatted'} = '<node name="Top" spaces=" "><nodename>Top</nodename><nodeup automatic="on">(dir)</nodeup></node>
+$result_converted{'xml'}->{'index_entry_in_preformatted'} = '<node name="Top" spaces=" "><nodename>Top</nodename></node>
 
 <example endspaces=" ">
 <pre xml:space="preserve"><cindex index="cp" spaces=" "><indexterm index="cp" number="1">first</indexterm></cindex>
