@@ -60,7 +60,11 @@ $result_trees{'no_documentencoding_and_insertions'} = {
           ],
           'cmdname' => '~',
           'contents' => [],
-          'line_nr' => {},
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 2,
+            'macro' => ''
+          },
           'parent' => {}
         },
         {
@@ -137,7 +141,11 @@ $result_trees{'no_documentencoding_and_insertions'} = {
               ],
               'cmdname' => '~',
               'contents' => [],
-              'line_nr' => {},
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 5,
+                'macro' => ''
+              },
               'parent' => {}
             },
             {
@@ -201,7 +209,6 @@ $result_trees{'no_documentencoding_and_insertions'}{'contents'}[1]{'contents'}[1
 $result_trees{'no_documentencoding_and_insertions'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'no_documentencoding_and_insertions'}{'contents'}[1];
 $result_trees{'no_documentencoding_and_insertions'}{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'no_documentencoding_and_insertions'}{'contents'}[1]{'contents'}[3]{'args'}[0];
 $result_trees{'no_documentencoding_and_insertions'}{'contents'}[1]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'no_documentencoding_and_insertions'}{'contents'}[1]{'contents'}[3];
-$result_trees{'no_documentencoding_and_insertions'}{'contents'}[1]{'contents'}[3]{'line_nr'} = $result_trees{'no_documentencoding_and_insertions'}{'contents'}[1]{'contents'}[1]{'line_nr'};
 $result_trees{'no_documentencoding_and_insertions'}{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'no_documentencoding_and_insertions'}{'contents'}[1];
 $result_trees{'no_documentencoding_and_insertions'}{'contents'}[1]{'contents'}[4]{'parent'} = $result_trees{'no_documentencoding_and_insertions'}{'contents'}[1];
 $result_trees{'no_documentencoding_and_insertions'}{'contents'}[1]{'parent'} = $result_trees{'no_documentencoding_and_insertions'};
@@ -215,7 +222,6 @@ $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[1
 $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[1];
 $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[1]{'contents'}[3]{'args'}[0];
 $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[1]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[1]{'contents'}[3];
-$result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[1]{'contents'}[3]{'line_nr'} = $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[1]{'contents'}[1]{'line_nr'};
 $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[1];
 $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[1]{'contents'}[4]{'parent'} = $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[1];
 $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3]{'contents'}[1]{'parent'} = $result_trees{'no_documentencoding_and_insertions'}{'contents'}[3];
@@ -243,10 +249,13 @@ $result_texts{'no_documentencoding_and_insertions'} = '
 $result_errors{'no_documentencoding_and_insertions'} = [];
 
 
+$result_floats{'no_documentencoding_and_insertions'} = {};
 
-$result_converted{'plaintext'}->{'no_documentencoding_and_insertions'} = '- -- " " \' \' \'in code\'.  e~.
 
-     -- --- \'\' `` ` \' in code. e~.
+
+$result_converted{'plaintext'}->{'no_documentencoding_and_insertions'} = '- -- " " \' \' \'in code\'.  ẽ.
+
+     -- --- \'\' `` ` \' in code. ẽ.
 ';
 
 
