@@ -44,34 +44,23 @@ $result_trees{'raw_block_commands'} = {
           'args' => [
             {
               'contents' => [
-                {
-                  'extra' => {
-                    'command' => {}
-                  },
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_after_command'
-                },
                 {
                   'parent' => {},
                   'text' => 'html'
-                },
-                {
-                  'parent' => {},
-                  'text' => '
-',
-                  'type' => 'spaces_at_end'
                 }
               ],
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
               'parent' => {},
-              'type' => 'misc_line_arg'
+              'type' => 'line_arg'
             }
           ],
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
             'command_argument' => 'html',
-            'spaces_after_command' => {},
+            'spaces_before_argument' => ' ',
             'text_arg' => 'html'
           },
           'line_nr' => {
@@ -83,8 +72,7 @@ $result_trees{'raw_block_commands'} = {
         }
       ],
       'extra' => {
-        'end_command' => {},
-        'spaces_after_command' => {}
+        'end_command' => {}
       },
       'line_nr' => {
         'file_name' => '',
@@ -130,34 +118,23 @@ $result_trees{'raw_block_commands'} = {
           'args' => [
             {
               'contents' => [
-                {
-                  'extra' => {
-                    'command' => {}
-                  },
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_after_command'
-                },
                 {
                   'parent' => {},
                   'text' => 'xml'
-                },
-                {
-                  'parent' => {},
-                  'text' => '
-',
-                  'type' => 'spaces_at_end'
                 }
               ],
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
               'parent' => {},
-              'type' => 'misc_line_arg'
+              'type' => 'line_arg'
             }
           ],
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
             'command_argument' => 'xml',
-            'spaces_after_command' => {},
+            'spaces_before_argument' => ' ',
             'text_arg' => 'xml'
           },
           'line_nr' => {
@@ -169,8 +146,7 @@ $result_trees{'raw_block_commands'} = {
         }
       ],
       'extra' => {
-        'end_command' => {},
-        'spaces_after_command' => {}
+        'end_command' => {}
       },
       'line_nr' => {
         'file_name' => '',
@@ -216,34 +192,23 @@ $result_trees{'raw_block_commands'} = {
           'args' => [
             {
               'contents' => [
-                {
-                  'extra' => {
-                    'command' => {}
-                  },
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_after_command'
-                },
                 {
                   'parent' => {},
                   'text' => 'docbook'
-                },
-                {
-                  'parent' => {},
-                  'text' => '
-',
-                  'type' => 'spaces_at_end'
                 }
               ],
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
               'parent' => {},
-              'type' => 'misc_line_arg'
+              'type' => 'line_arg'
             }
           ],
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
             'command_argument' => 'docbook',
-            'spaces_after_command' => {},
+            'spaces_before_argument' => ' ',
             'text_arg' => 'docbook'
           },
           'line_nr' => {
@@ -255,8 +220,7 @@ $result_trees{'raw_block_commands'} = {
         }
       ],
       'extra' => {
-        'end_command' => {},
-        'spaces_after_command' => {}
+        'end_command' => {}
       },
       'line_nr' => {
         'file_name' => '',
@@ -323,7 +287,11 @@ $result_trees{'raw_block_commands'} = {
               ],
               'cmdname' => 'code',
               'contents' => [],
-              'line_nr' => {},
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 15,
+                'macro' => ''
+              },
               'parent' => {}
             },
             {
@@ -343,34 +311,23 @@ $result_trees{'raw_block_commands'} = {
           'args' => [
             {
               'contents' => [
-                {
-                  'extra' => {
-                    'command' => {}
-                  },
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_after_command'
-                },
                 {
                   'parent' => {},
                   'text' => 'tex'
-                },
-                {
-                  'parent' => {},
-                  'text' => '
-',
-                  'type' => 'spaces_at_end'
                 }
               ],
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
               'parent' => {},
-              'type' => 'misc_line_arg'
+              'type' => 'line_arg'
             }
           ],
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
             'command_argument' => 'tex',
-            'spaces_after_command' => {},
+            'spaces_before_argument' => ' ',
             'text_arg' => 'tex'
           },
           'line_nr' => {
@@ -382,8 +339,7 @@ $result_trees{'raw_block_commands'} = {
         }
       ],
       'extra' => {
-        'end_command' => {},
-        'spaces_after_command' => {}
+        'end_command' => {}
       },
       'line_nr' => {
         'file_name' => '',
@@ -401,16 +357,10 @@ $result_trees{'raw_block_commands'}{'contents'}[1]{'contents'}[0]{'parent'} = $r
 $result_trees{'raw_block_commands'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[1]{'contents'}[1];
 $result_trees{'raw_block_commands'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[1]{'contents'}[1];
 $result_trees{'raw_block_commands'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[1];
-$result_trees{'raw_block_commands'}{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'raw_block_commands'}{'contents'}[1]{'contents'}[2];
 $result_trees{'raw_block_commands'}{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[1]{'contents'}[2]{'args'}[0];
-$result_trees{'raw_block_commands'}{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[1]{'contents'}[2]{'args'}[0];
-$result_trees{'raw_block_commands'}{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[1]{'contents'}[2]{'args'}[0];
 $result_trees{'raw_block_commands'}{'contents'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[1]{'contents'}[2];
-$result_trees{'raw_block_commands'}{'contents'}[1]{'contents'}[2]{'extra'}{'command'} = $result_trees{'raw_block_commands'}{'contents'}[1];
-$result_trees{'raw_block_commands'}{'contents'}[1]{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'raw_block_commands'}{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'raw_block_commands'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[1];
 $result_trees{'raw_block_commands'}{'contents'}[1]{'extra'}{'end_command'} = $result_trees{'raw_block_commands'}{'contents'}[1]{'contents'}[2];
-$result_trees{'raw_block_commands'}{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'raw_block_commands'}{'contents'}[1]{'contents'}[0];
 $result_trees{'raw_block_commands'}{'contents'}[1]{'parent'} = $result_trees{'raw_block_commands'};
 $result_trees{'raw_block_commands'}{'contents'}[2]{'parent'} = $result_trees{'raw_block_commands'};
 $result_trees{'raw_block_commands'}{'contents'}[3]{'contents'}[0]{'extra'}{'command'} = $result_trees{'raw_block_commands'}{'contents'}[3];
@@ -418,16 +368,10 @@ $result_trees{'raw_block_commands'}{'contents'}[3]{'contents'}[0]{'parent'} = $r
 $result_trees{'raw_block_commands'}{'contents'}[3]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[3]{'contents'}[1];
 $result_trees{'raw_block_commands'}{'contents'}[3]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[3]{'contents'}[1];
 $result_trees{'raw_block_commands'}{'contents'}[3]{'contents'}[1]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[3];
-$result_trees{'raw_block_commands'}{'contents'}[3]{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'raw_block_commands'}{'contents'}[3]{'contents'}[2];
 $result_trees{'raw_block_commands'}{'contents'}[3]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[3]{'contents'}[2]{'args'}[0];
-$result_trees{'raw_block_commands'}{'contents'}[3]{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[3]{'contents'}[2]{'args'}[0];
-$result_trees{'raw_block_commands'}{'contents'}[3]{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[3]{'contents'}[2]{'args'}[0];
 $result_trees{'raw_block_commands'}{'contents'}[3]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[3]{'contents'}[2];
-$result_trees{'raw_block_commands'}{'contents'}[3]{'contents'}[2]{'extra'}{'command'} = $result_trees{'raw_block_commands'}{'contents'}[3];
-$result_trees{'raw_block_commands'}{'contents'}[3]{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'raw_block_commands'}{'contents'}[3]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'raw_block_commands'}{'contents'}[3]{'contents'}[2]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[3];
 $result_trees{'raw_block_commands'}{'contents'}[3]{'extra'}{'end_command'} = $result_trees{'raw_block_commands'}{'contents'}[3]{'contents'}[2];
-$result_trees{'raw_block_commands'}{'contents'}[3]{'extra'}{'spaces_after_command'} = $result_trees{'raw_block_commands'}{'contents'}[3]{'contents'}[0];
 $result_trees{'raw_block_commands'}{'contents'}[3]{'parent'} = $result_trees{'raw_block_commands'};
 $result_trees{'raw_block_commands'}{'contents'}[4]{'parent'} = $result_trees{'raw_block_commands'};
 $result_trees{'raw_block_commands'}{'contents'}[5]{'contents'}[0]{'extra'}{'command'} = $result_trees{'raw_block_commands'}{'contents'}[5];
@@ -435,16 +379,10 @@ $result_trees{'raw_block_commands'}{'contents'}[5]{'contents'}[0]{'parent'} = $r
 $result_trees{'raw_block_commands'}{'contents'}[5]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[5]{'contents'}[1];
 $result_trees{'raw_block_commands'}{'contents'}[5]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[5]{'contents'}[1];
 $result_trees{'raw_block_commands'}{'contents'}[5]{'contents'}[1]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[5];
-$result_trees{'raw_block_commands'}{'contents'}[5]{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'raw_block_commands'}{'contents'}[5]{'contents'}[2];
 $result_trees{'raw_block_commands'}{'contents'}[5]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[5]{'contents'}[2]{'args'}[0];
-$result_trees{'raw_block_commands'}{'contents'}[5]{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[5]{'contents'}[2]{'args'}[0];
-$result_trees{'raw_block_commands'}{'contents'}[5]{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[5]{'contents'}[2]{'args'}[0];
 $result_trees{'raw_block_commands'}{'contents'}[5]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[5]{'contents'}[2];
-$result_trees{'raw_block_commands'}{'contents'}[5]{'contents'}[2]{'extra'}{'command'} = $result_trees{'raw_block_commands'}{'contents'}[5];
-$result_trees{'raw_block_commands'}{'contents'}[5]{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'raw_block_commands'}{'contents'}[5]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'raw_block_commands'}{'contents'}[5]{'contents'}[2]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[5];
 $result_trees{'raw_block_commands'}{'contents'}[5]{'extra'}{'end_command'} = $result_trees{'raw_block_commands'}{'contents'}[5]{'contents'}[2];
-$result_trees{'raw_block_commands'}{'contents'}[5]{'extra'}{'spaces_after_command'} = $result_trees{'raw_block_commands'}{'contents'}[5]{'contents'}[0];
 $result_trees{'raw_block_commands'}{'contents'}[5]{'parent'} = $result_trees{'raw_block_commands'};
 $result_trees{'raw_block_commands'}{'contents'}[6]{'parent'} = $result_trees{'raw_block_commands'};
 $result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[0]{'extra'}{'command'} = $result_trees{'raw_block_commands'}{'contents'}[7];
@@ -455,21 +393,14 @@ $result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[1]{'contents'}[2]
 $result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[1];
 $result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[1]{'contents'}[2]{'args'}[0];
 $result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[1]{'contents'}[2];
-$result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[1]{'contents'}[2]{'line_nr'} = $result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[1];
 $result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[1];
 $result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[1]{'contents'}[4]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[1];
 $result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[1]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[7];
-$result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[2];
 $result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[2]{'args'}[0];
-$result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[2]{'args'}[0];
-$result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[2]{'args'}[0];
 $result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[2];
-$result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[2]{'extra'}{'command'} = $result_trees{'raw_block_commands'}{'contents'}[7];
-$result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[2]{'parent'} = $result_trees{'raw_block_commands'}{'contents'}[7];
 $result_trees{'raw_block_commands'}{'contents'}[7]{'extra'}{'end_command'} = $result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[2];
-$result_trees{'raw_block_commands'}{'contents'}[7]{'extra'}{'spaces_after_command'} = $result_trees{'raw_block_commands'}{'contents'}[7]{'contents'}[0];
 $result_trees{'raw_block_commands'}{'contents'}[7]{'parent'} = $result_trees{'raw_block_commands'};
 
 $result_texis{'raw_block_commands'} = '
@@ -500,6 +431,9 @@ $result_texts{'raw_block_commands'} = '
 $result_errors{'raw_block_commands'} = [];
 
 
+$result_floats{'raw_block_commands'} = {};
+
+
 
 $result_converted{'plaintext'}->{'raw_block_commands'} = '';
 
