@@ -1,29 +1,21 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
 $result_trees{'unknown_value'} = {
   'contents' => [
     {
-      'contents' => [
-        {
-          'cmdname' => 'value',
-          'extra' => {
-            'flag' => 'unknown'
-          },
-          'parent' => {}
-        }
-      ],
+      'cmdname' => 'value',
+      'contents' => [],
       'parent' => {},
-      'type' => 'before_node_section'
+      'type' => 'unknown'
     }
   ],
-  'type' => 'document_root'
+  'type' => 'text_root'
 };
-$result_trees{'unknown_value'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'unknown_value'}{'contents'}[0];
 $result_trees{'unknown_value'}{'contents'}[0]{'parent'} = $result_trees{'unknown_value'};
 
 $result_texis{'unknown_value'} = '@value{unknown}';
@@ -33,7 +25,7 @@ $result_texts{'unknown_value'} = '';
 
 $result_errors{'unknown_value'} = [
   {
-    'error_line' => 'warning: undefined flag: unknown
+    'error_line' => ':1: warning: undefined flag: unknown
 ',
     'file_name' => '',
     'line_nr' => 1,
@@ -48,7 +40,7 @@ $result_floats{'unknown_value'} = {};
 
 
 
-$result_converted{'plaintext'}->{'unknown_value'} = '{No value for ‘unknown’}
+$result_converted{'plaintext'}->{'unknown_value'} = '{No value for \'unknown\'}
 ';
 
 
@@ -60,7 +52,4 @@ $result_converted{'xml'}->{'unknown_value'} = '';
 
 $result_converted{'docbook'}->{'unknown_value'} = '';
 
-
-$result_converted{'latex_text'}->{'unknown_value'} = '\\{No value for `unknown\'\\}';
-
 1;
