@@ -13,34 +13,24 @@ $result_trees{'weird_accents_disable_encoding'} = {
           'args' => [
             {
               'contents' => [
-                {
-                  'extra' => {
-                    'command' => {}
-                  },
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_after_command'
-                },
                 {
                   'parent' => {},
                   'text' => 'ISO-8859-1'
-                },
-                {
-                  'parent' => {},
-                  'text' => '
-',
-                  'type' => 'spaces_at_end'
                 }
               ],
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
               'parent' => {},
-              'type' => 'misc_line_arg'
+              'type' => 'line_arg'
             }
           ],
           'cmdname' => 'documentencoding',
           'extra' => {
             'input_encoding_name' => 'iso-8859-1',
             'input_perl_encoding' => 'iso-8859-1',
-            'spaces_after_command' => {},
+            'spaces_before_argument' => ' ',
             'text_arg' => 'ISO-8859-1'
           },
           'line_nr' => {
@@ -64,27 +54,17 @@ $result_trees{'weird_accents_disable_encoding'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'Top'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'node',
@@ -95,12 +75,14 @@ $result_trees{'weird_accents_disable_encoding'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
         'normalized' => 'Top',
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'line_nr' => {
         'file_name' => '',
@@ -113,27 +95,17 @@ $result_trees{'weird_accents_disable_encoding'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'top'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'top',
@@ -183,7 +155,11 @@ $result_trees{'weird_accents_disable_encoding'} = {
                       ],
                       'cmdname' => '~',
                       'contents' => [],
-                      'line_nr' => {},
+                      'line_nr' => {
+                        'file_name' => '',
+                        'line_nr' => 6,
+                        'macro' => ''
+                      },
                       'parent' => {}
                     }
                   ],
@@ -193,7 +169,11 @@ $result_trees{'weird_accents_disable_encoding'} = {
               ],
               'cmdname' => '=',
               'contents' => [],
-              'line_nr' => {},
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 6,
+                'macro' => ''
+              },
               'parent' => {}
             },
             {
@@ -250,7 +230,11 @@ $result_trees{'weird_accents_disable_encoding'} = {
                       ],
                       'cmdname' => ',',
                       'contents' => [],
-                      'line_nr' => {},
+                      'line_nr' => {
+                        'file_name' => '',
+                        'line_nr' => 8,
+                        'macro' => ''
+                      },
                       'parent' => {}
                     }
                   ],
@@ -260,7 +244,11 @@ $result_trees{'weird_accents_disable_encoding'} = {
               ],
               'cmdname' => '=',
               'contents' => [],
-              'line_nr' => {},
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 8,
+                'macro' => ''
+              },
               'parent' => {}
             },
             {
@@ -313,7 +301,11 @@ $result_trees{'weird_accents_disable_encoding'} = {
               ],
               'cmdname' => '=',
               'contents' => [],
-              'line_nr' => {},
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 10,
+                'macro' => ''
+              },
               'parent' => {}
             },
             {
@@ -370,7 +362,11 @@ $result_trees{'weird_accents_disable_encoding'} = {
                       ],
                       'cmdname' => 'udotaccent',
                       'contents' => [],
-                      'line_nr' => {},
+                      'line_nr' => {
+                        'file_name' => '',
+                        'line_nr' => 12,
+                        'macro' => ''
+                      },
                       'parent' => {}
                     }
                   ],
@@ -380,7 +376,11 @@ $result_trees{'weird_accents_disable_encoding'} = {
               ],
               'cmdname' => '^',
               'contents' => [],
-              'line_nr' => {},
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 12,
+                'macro' => ''
+              },
               'parent' => {}
             },
             {
@@ -437,7 +437,11 @@ $result_trees{'weird_accents_disable_encoding'} = {
                       ],
                       'cmdname' => '\'',
                       'contents' => [],
-                      'line_nr' => {},
+                      'line_nr' => {
+                        'file_name' => '',
+                        'line_nr' => 14,
+                        'macro' => ''
+                      },
                       'parent' => {}
                     }
                   ],
@@ -447,7 +451,11 @@ $result_trees{'weird_accents_disable_encoding'} = {
               ],
               'cmdname' => '=',
               'contents' => [],
-              'line_nr' => {},
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 14,
+                'macro' => ''
+              },
               'parent' => {}
             },
             {
@@ -461,10 +469,7 @@ $result_trees{'weird_accents_disable_encoding'} = {
         }
       ],
       'extra' => {
-        'misc_content' => [
-          {}
-        ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'level' => 0,
       'line_nr' => {
@@ -477,38 +482,25 @@ $result_trees{'weird_accents_disable_encoding'} = {
   ],
   'type' => 'document_root'
 };
-$result_trees{'weird_accents_disable_encoding'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[0]{'contents'}[0];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[0]{'contents'}[0]{'args'}[0];
-$result_trees{'weird_accents_disable_encoding'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[0]{'contents'}[0]{'args'}[0];
-$result_trees{'weird_accents_disable_encoding'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[0]{'contents'}[0]{'args'}[0];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[0]{'contents'}[0];
-$result_trees{'weird_accents_disable_encoding'}{'contents'}[0]{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[0];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[0];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'};
-$result_trees{'weird_accents_disable_encoding'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[1];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[1]{'args'}[0];
-$result_trees{'weird_accents_disable_encoding'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[1]{'args'}[0];
-$result_trees{'weird_accents_disable_encoding'}{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[1]{'args'}[0];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[1];
-$result_trees{'weird_accents_disable_encoding'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'weird_accents_disable_encoding'}{'contents'}[1]{'args'}[0]{'contents'}[1];
-$result_trees{'weird_accents_disable_encoding'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[1]{'extra'}{'node_content'};
-$result_trees{'weird_accents_disable_encoding'}{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[1]{'args'}[0]{'contents'}[0];
+$result_trees{'weird_accents_disable_encoding'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'weird_accents_disable_encoding'}{'contents'}[1]{'args'}[0]{'contents'}[0];
+$result_trees{'weird_accents_disable_encoding'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'weird_accents_disable_encoding'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[1]{'parent'} = $result_trees{'weird_accents_disable_encoding'};
-$result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'args'}[0];
-$result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'args'}[0];
-$result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'args'}[0];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0];
-$result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'line_nr'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[1]{'contents'}[0]{'args'}[0];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[1]{'contents'}[0];
-$result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[1]{'contents'}[0]{'line_nr'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[1];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[1];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[1]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2];
@@ -517,10 +509,8 @@ $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[3]{'c
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[0]{'contents'}[0];
-$result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[0]{'contents'}[0]{'line_nr'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[0];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[3]{'contents'}[0];
-$result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'line_nr'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[3];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[3];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[3]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2];
@@ -529,7 +519,6 @@ $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[5]{'c
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[5]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[5]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[5]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[5]{'contents'}[0]{'args'}[0];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[5]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[5]{'contents'}[0];
-$result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[5]{'contents'}[0]{'line_nr'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[5]{'contents'}[0]{'args'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[5]{'contents'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[5];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[5]{'contents'}[1]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[5];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[5]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2];
@@ -538,10 +527,8 @@ $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[7]{'c
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[7]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[7]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[7]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[7]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[7]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[7]{'contents'}[0]{'args'}[0]{'contents'}[0];
-$result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[7]{'contents'}[0]{'args'}[0]{'contents'}[0]{'line_nr'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[7]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[7]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[7]{'contents'}[0]{'args'}[0];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[7]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[7]{'contents'}[0];
-$result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[7]{'contents'}[0]{'line_nr'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[7]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[7]{'contents'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[7];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[7]{'contents'}[1]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[7];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[7]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2];
@@ -550,15 +537,11 @@ $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[9]{'c
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[9]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[9]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[9]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[9]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[9]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[9]{'contents'}[0]{'args'}[0]{'contents'}[0];
-$result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[9]{'contents'}[0]{'args'}[0]{'contents'}[0]{'line_nr'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[9]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[9]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[9]{'contents'}[0]{'args'}[0];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[9]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[9]{'contents'}[0];
-$result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[9]{'contents'}[0]{'line_nr'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[9]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[9]{'contents'}[0]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[9];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[9]{'contents'}[1]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[9];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'contents'}[9]{'parent'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2];
-$result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'extra'}{'misc_content'}[0] = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'args'}[0]{'contents'}[1];
-$result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'weird_accents_disable_encoding'}{'contents'}[2]{'parent'} = $result_trees{'weird_accents_disable_encoding'};
 
 $result_texis{'weird_accents_disable_encoding'} = '@documentencoding ISO-8859-1
@@ -602,9 +585,11 @@ $result_sectioning{'weird_accents_disable_encoding'} = {
         'associated_node' => {
           'cmdname' => 'node',
           'extra' => {
-            'normalized' => 'Top'
+            'normalized' => 'Top',
+            'spaces_before_argument' => ' '
           }
-        }
+        },
+        'spaces_before_argument' => ' '
       },
       'level' => 0,
       'section_up' => {}
@@ -618,35 +603,30 @@ $result_nodes{'weird_accents_disable_encoding'} = {
   'extra' => {
     'associated_section' => {
       'cmdname' => 'top',
-      'extra' => {},
+      'extra' => {
+        'spaces_before_argument' => ' '
+      },
       'level' => 0
     },
-    'normalized' => 'Top'
-  },
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   }
 };
-$result_nodes{'weird_accents_disable_encoding'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'weird_accents_disable_encoding'};
 
 $result_menus{'weird_accents_disable_encoding'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   }
 };
 
 $result_errors{'weird_accents_disable_encoding'} = [];
 
 
+$result_floats{'weird_accents_disable_encoding'} = {};
+
+
 
 $result_converted{'plaintext'}->{'weird_accents_disable_encoding'} = 'top
 ***
@@ -664,9 +644,8 @@ i~=
 
 
 $result_converted{'html_text'}->{'weird_accents_disable_encoding'} = '
-<a name="Top"></a>
-<a name="top"></a>
-<h1 class="top">top</h1>
+<div class="top" id="Top">
+<span id="top"></span><h1 class="top">top</h1>
 
 <p>&#297;=
 </p>
@@ -677,13 +656,13 @@ $result_converted{'html_text'}->{'weird_accents_disable_encoding'} = '
 <p>.r`^
 </p>
 <p>r`\'=
-</p><hr>
+</p><hr></div>
 ';
 
 
 $result_converted{'xml'}->{'weird_accents_disable_encoding'} = '<documentencoding encoding="ISO-8859-1" spaces=" ">ISO-8859-1</documentencoding>
 
-<node name="Top" spaces=" "><nodename>Top</nodename><nodeup automatic="on">(dir)</nodeup></node>
+<node name="Top" spaces=" "><nodename>Top</nodename></node>
 <top spaces=" "><sectiontitle>top</sectiontitle>
 
 <para><accent type="macr"><accent type="tilde"><dotless>i</dotless></accent></accent>
