@@ -17,14 +17,6 @@ $result_trees{'center'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => '  ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'in center '
@@ -50,27 +42,25 @@ $result_trees{'center'} = {
                 'macro' => ''
               },
               'parent' => {}
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'center',
       'extra' => {
-        'misc_content' => [
-          {},
-          {}
-        ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => '  '
+      },
+      'line_nr' => {
+        'file_name' => '',
+        'line_nr' => 2,
+        'macro' => ''
       },
-      'line_nr' => {},
       'parent' => {}
     },
     {
@@ -83,18 +73,11 @@ $result_trees{'center'} = {
   'type' => 'text_root'
 };
 $result_trees{'center'}{'contents'}[0]{'parent'} = $result_trees{'center'};
-$result_trees{'center'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'center'}{'contents'}[1];
 $result_trees{'center'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'center'}{'contents'}[1]{'args'}[0];
+$result_trees{'center'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'center'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'args'}[0];
+$result_trees{'center'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'center'}{'contents'}[1]{'args'}[0]{'contents'}[1];
 $result_trees{'center'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'center'}{'contents'}[1]{'args'}[0];
-$result_trees{'center'}{'contents'}[1]{'args'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'center'}{'contents'}[1]{'args'}[0]{'contents'}[2]{'args'}[0];
-$result_trees{'center'}{'contents'}[1]{'args'}[0]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'center'}{'contents'}[1]{'args'}[0]{'contents'}[2];
-$result_trees{'center'}{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'center'}{'contents'}[1]{'args'}[0];
-$result_trees{'center'}{'contents'}[1]{'args'}[0]{'contents'}[3]{'parent'} = $result_trees{'center'}{'contents'}[1]{'args'}[0];
 $result_trees{'center'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'center'}{'contents'}[1];
-$result_trees{'center'}{'contents'}[1]{'extra'}{'misc_content'}[0] = $result_trees{'center'}{'contents'}[1]{'args'}[0]{'contents'}[1];
-$result_trees{'center'}{'contents'}[1]{'extra'}{'misc_content'}[1] = $result_trees{'center'}{'contents'}[1]{'args'}[0]{'contents'}[2];
-$result_trees{'center'}{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'center'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'center'}{'contents'}[1]{'line_nr'} = $result_trees{'center'}{'contents'}[1]{'args'}[0]{'contents'}[2]{'line_nr'};
 $result_trees{'center'}{'contents'}[1]{'parent'} = $result_trees{'center'};
 $result_trees{'center'}{'contents'}[2]{'parent'} = $result_trees{'center'};
 
@@ -112,6 +95,9 @@ in center in code
 $result_errors{'center'} = [];
 
 
+$result_floats{'center'} = {};
+
+
 
 $result_converted{'plaintext'}->{'center'} = '                          in center \'in code\'
 
