@@ -208,7 +208,7 @@ $result_trees{'formats_only_title_comments'} = {
       ],
       'extra' => {
         'end_command' => {},
-        'enumerate_specification' => 1,
+        'enumerate_specification' => '1',
         'spaces_before_argument' => ' '
       },
       'line_nr' => {
@@ -321,7 +321,11 @@ $result_trees{'formats_only_title_comments'} = {
         'end_command' => {},
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {},
+      'line_nr' => {
+        'file_name' => '',
+        'line_nr' => 11,
+        'macro' => ''
+      },
       'parent' => {}
     },
     {
@@ -426,7 +430,11 @@ $result_trees{'formats_only_title_comments'} = {
         'end_command' => {},
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {},
+      'line_nr' => {
+        'file_name' => '',
+        'line_nr' => 16,
+        'macro' => ''
+      },
       'parent' => {}
     },
     {
@@ -550,7 +558,11 @@ $result_trees{'formats_only_title_comments'} = {
         'max_columns' => 2,
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {},
+      'line_nr' => {
+        'file_name' => '',
+        'line_nr' => 20,
+        'macro' => ''
+      },
       'parent' => {}
     }
   ],
@@ -597,7 +609,6 @@ $result_trees{'formats_only_title_comments'}{'contents'}[4]{'contents'}[1]{'args
 $result_trees{'formats_only_title_comments'}{'contents'}[4]{'contents'}[1]{'parent'} = $result_trees{'formats_only_title_comments'}{'contents'}[4];
 $result_trees{'formats_only_title_comments'}{'contents'}[4]{'extra'}{'command_as_argument'} = $result_trees{'formats_only_title_comments'}{'contents'}[4]{'args'}[0]{'contents'}[0];
 $result_trees{'formats_only_title_comments'}{'contents'}[4]{'extra'}{'end_command'} = $result_trees{'formats_only_title_comments'}{'contents'}[4]{'contents'}[1];
-$result_trees{'formats_only_title_comments'}{'contents'}[4]{'line_nr'} = $result_trees{'formats_only_title_comments'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'formats_only_title_comments'}{'contents'}[4]{'parent'} = $result_trees{'formats_only_title_comments'};
 $result_trees{'formats_only_title_comments'}{'contents'}[5]{'parent'} = $result_trees{'formats_only_title_comments'};
 $result_trees{'formats_only_title_comments'}{'contents'}[6]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'formats_only_title_comments'}{'contents'}[6]{'args'}[0];
@@ -612,7 +623,6 @@ $result_trees{'formats_only_title_comments'}{'contents'}[6]{'contents'}[1]{'args
 $result_trees{'formats_only_title_comments'}{'contents'}[6]{'contents'}[1]{'parent'} = $result_trees{'formats_only_title_comments'}{'contents'}[6];
 $result_trees{'formats_only_title_comments'}{'contents'}[6]{'extra'}{'command_as_argument'} = $result_trees{'formats_only_title_comments'}{'contents'}[6]{'args'}[0]{'contents'}[0];
 $result_trees{'formats_only_title_comments'}{'contents'}[6]{'extra'}{'end_command'} = $result_trees{'formats_only_title_comments'}{'contents'}[6]{'contents'}[1];
-$result_trees{'formats_only_title_comments'}{'contents'}[6]{'line_nr'} = $result_trees{'formats_only_title_comments'}{'contents'}[6]{'args'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'formats_only_title_comments'}{'contents'}[6]{'parent'} = $result_trees{'formats_only_title_comments'};
 $result_trees{'formats_only_title_comments'}{'contents'}[7]{'parent'} = $result_trees{'formats_only_title_comments'};
 $result_trees{'formats_only_title_comments'}{'contents'}[8]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'formats_only_title_comments'}{'contents'}[8]{'args'}[0]{'contents'}[0]{'args'}[0];
@@ -629,7 +639,6 @@ $result_trees{'formats_only_title_comments'}{'contents'}[8]{'contents'}[1]{'args
 $result_trees{'formats_only_title_comments'}{'contents'}[8]{'contents'}[1]{'parent'} = $result_trees{'formats_only_title_comments'}{'contents'}[8];
 $result_trees{'formats_only_title_comments'}{'contents'}[8]{'extra'}{'columnfractions'} = $result_trees{'formats_only_title_comments'}{'contents'}[8]{'args'}[0]{'contents'}[0];
 $result_trees{'formats_only_title_comments'}{'contents'}[8]{'extra'}{'end_command'} = $result_trees{'formats_only_title_comments'}{'contents'}[8]{'contents'}[1];
-$result_trees{'formats_only_title_comments'}{'contents'}[8]{'line_nr'} = $result_trees{'formats_only_title_comments'}{'contents'}[8]{'args'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'formats_only_title_comments'}{'contents'}[8]{'parent'} = $result_trees{'formats_only_title_comments'};
 
 $result_texis{'formats_only_title_comments'} = '@itemize
@@ -718,4 +727,7 @@ $result_errors{'formats_only_title_comments'} = [
 ];
 
 
+$result_floats{'formats_only_title_comments'} = {};
+
+
 1;
