@@ -8,6 +8,14 @@ use utf8;
 $result_trees{'formats_only_titles'} = {
   'contents' => [
     {
+      'args' => [
+        {
+          'cmdname' => 'bullet',
+          'contents' => [],
+          'parent' => {},
+          'type' => 'command_as_argument_inserted'
+        }
+      ],
       'cmdname' => 'itemize',
       'contents' => [
         {
@@ -40,34 +48,23 @@ $result_trees{'formats_only_titles'} = {
           'args' => [
             {
               'contents' => [
-                {
-                  'extra' => {
-                    'command' => {}
-                  },
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_after_command'
-                },
                 {
                   'parent' => {},
                   'text' => 'itemize'
-                },
-                {
-                  'parent' => {},
-                  'text' => '
-',
-                  'type' => 'spaces_at_end'
                 }
               ],
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
               'parent' => {},
-              'type' => 'misc_line_arg'
+              'type' => 'line_arg'
             }
           ],
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
             'command_argument' => 'itemize',
-            'spaces_after_command' => {},
+            'spaces_before_argument' => ' ',
             'text_arg' => 'itemize'
           },
           'line_nr' => {
@@ -79,19 +76,8 @@ $result_trees{'formats_only_titles'} = {
         }
       ],
       'extra' => {
-        'block_command_line_contents' => [
-          [
-            {
-              'cmdname' => 'bullet',
-              'contents' => [],
-              'parent' => {},
-              'type' => 'command_as_argument'
-            }
-          ]
-        ],
         'command_as_argument' => {},
-        'end_command' => {},
-        'spaces_after_command' => {}
+        'end_command' => {}
       },
       'line_nr' => {
         'file_name' => '',
@@ -139,34 +125,23 @@ $result_trees{'formats_only_titles'} = {
           'args' => [
             {
               'contents' => [
-                {
-                  'extra' => {
-                    'command' => {}
-                  },
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_after_command'
-                },
                 {
                   'parent' => {},
                   'text' => 'enumerate'
-                },
-                {
-                  'parent' => {},
-                  'text' => '
-',
-                  'type' => 'spaces_at_end'
                 }
               ],
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
               'parent' => {},
-              'type' => 'misc_line_arg'
+              'type' => 'line_arg'
             }
           ],
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
             'command_argument' => 'enumerate',
-            'spaces_after_command' => {},
+            'spaces_before_argument' => ' ',
             'text_arg' => 'enumerate'
           },
           'line_nr' => {
@@ -179,8 +154,7 @@ $result_trees{'formats_only_titles'} = {
       ],
       'extra' => {
         'end_command' => {},
-        'enumerate_specification' => 1,
-        'spaces_after_command' => {}
+        'enumerate_specification' => '1'
       },
       'line_nr' => {
         'file_name' => '',
@@ -199,14 +173,6 @@ $result_trees{'formats_only_titles'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'cmdname' => 'emph',
               'contents' => [],
@@ -217,14 +183,12 @@ $result_trees{'formats_only_titles'} = {
               },
               'parent' => {},
               'type' => 'command_as_argument'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'space_at_end_block_command'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
           'type' => 'block_line_arg'
         }
@@ -252,34 +216,23 @@ $result_trees{'formats_only_titles'} = {
           'args' => [
             {
               'contents' => [
-                {
-                  'extra' => {
-                    'command' => {}
-                  },
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_after_command'
-                },
                 {
                   'parent' => {},
                   'text' => 'table'
-                },
-                {
-                  'parent' => {},
-                  'text' => '
-',
-                  'type' => 'spaces_at_end'
                 }
               ],
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
               'parent' => {},
-              'type' => 'misc_line_arg'
+              'type' => 'line_arg'
             }
           ],
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
             'command_argument' => 'table',
-            'spaces_after_command' => {},
+            'spaces_before_argument' => ' ',
             'text_arg' => 'table'
           },
           'line_nr' => {
@@ -291,16 +244,15 @@ $result_trees{'formats_only_titles'} = {
         }
       ],
       'extra' => {
-        'block_command_line_contents' => [
-          [
-            {}
-          ]
-        ],
         'command_as_argument' => {},
         'end_command' => {},
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
+      },
+      'line_nr' => {
+        'file_name' => '',
+        'line_nr' => 9,
+        'macro' => ''
       },
-      'line_nr' => {},
       'parent' => {}
     },
     {
@@ -313,14 +265,6 @@ $result_trees{'formats_only_titles'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'cmdname' => 'asis',
               'contents' => [],
@@ -331,14 +275,12 @@ $result_trees{'formats_only_titles'} = {
               },
               'parent' => {},
               'type' => 'command_as_argument'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'space_at_end_block_command'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
           'type' => 'block_line_arg'
         }
@@ -366,34 +308,23 @@ $result_trees{'formats_only_titles'} = {
           'args' => [
             {
               'contents' => [
-                {
-                  'extra' => {
-                    'command' => {}
-                  },
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_after_command'
-                },
                 {
                   'parent' => {},
                   'text' => 'vtable'
-                },
-                {
-                  'parent' => {},
-                  'text' => '
-',
-                  'type' => 'spaces_at_end'
                 }
               ],
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
               'parent' => {},
-              'type' => 'misc_line_arg'
+              'type' => 'line_arg'
             }
           ],
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
             'command_argument' => 'vtable',
-            'spaces_after_command' => {},
+            'spaces_before_argument' => ' ',
             'text_arg' => 'vtable'
           },
           'line_nr' => {
@@ -405,16 +336,15 @@ $result_trees{'formats_only_titles'} = {
         }
       ],
       'extra' => {
-        'block_command_line_contents' => [
-          [
-            {}
-          ]
-        ],
         'command_as_argument' => {},
         'end_command' => {},
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
+      },
+      'line_nr' => {
+        'file_name' => '',
+        'line_nr' => 13,
+        'macro' => ''
       },
-      'line_nr' => {},
       'parent' => {}
     },
     {
@@ -427,39 +357,21 @@ $result_trees{'formats_only_titles'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'args' => [
                 {
                   'contents' => [
-                    {
-                      'extra' => {
-                        'command' => {}
-                      },
-                      'parent' => {},
-                      'text' => ' ',
-                      'type' => 'empty_spaces_after_command'
-                    },
                     {
                       'parent' => {},
                       'text' => '0.5 0.5'
-                    },
-                    {
-                      'parent' => {},
-                      'text' => '
-',
-                      'type' => 'spaces_at_end'
                     }
                   ],
+                  'extra' => {
+                    'spaces_after_argument' => '
+'
+                  },
                   'parent' => {},
-                  'type' => 'misc_line_arg'
+                  'type' => 'line_arg'
                 }
               ],
               'cmdname' => 'columnfractions',
@@ -468,7 +380,7 @@ $result_trees{'formats_only_titles'} = {
                   '0.5',
                   '0.5'
                 ],
-                'spaces_after_command' => {}
+                'spaces_before_argument' => ' '
               },
               'line_nr' => {
                 'file_name' => '',
@@ -505,34 +417,23 @@ $result_trees{'formats_only_titles'} = {
           'args' => [
             {
               'contents' => [
-                {
-                  'extra' => {
-                    'command' => {}
-                  },
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_after_command'
-                },
                 {
                   'parent' => {},
                   'text' => 'multitable'
-                },
-                {
-                  'parent' => {},
-                  'text' => '
-',
-                  'type' => 'spaces_at_end'
                 }
               ],
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
               'parent' => {},
-              'type' => 'misc_line_arg'
+              'type' => 'line_arg'
             }
           ],
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
             'command_argument' => 'multitable',
-            'spaces_after_command' => {},
+            'spaces_before_argument' => ' ',
             'text_arg' => 'multitable'
           },
           'line_nr' => {
@@ -544,34 +445,32 @@ $result_trees{'formats_only_titles'} = {
         }
       ],
       'extra' => {
-        'columnfractions' => [],
+        'columnfractions' => {},
         'end_command' => {},
         'max_columns' => 2,
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
+      },
+      'line_nr' => {
+        'file_name' => '',
+        'line_nr' => 17,
+        'macro' => ''
       },
-      'line_nr' => {},
       'parent' => {}
     }
   ],
   'type' => 'text_root'
 };
+$result_trees{'formats_only_titles'}{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[0];
 $result_trees{'formats_only_titles'}{'contents'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'formats_only_titles'}{'contents'}[0];
 $result_trees{'formats_only_titles'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[0];
 $result_trees{'formats_only_titles'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[0]{'contents'}[1]{'contents'}[0];
 $result_trees{'formats_only_titles'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[0]{'contents'}[1];
 $result_trees{'formats_only_titles'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[0];
-$result_trees{'formats_only_titles'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'formats_only_titles'}{'contents'}[0]{'contents'}[2];
 $result_trees{'formats_only_titles'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[0]{'contents'}[2]{'args'}[0];
-$result_trees{'formats_only_titles'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[0]{'contents'}[2]{'args'}[0];
-$result_trees{'formats_only_titles'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[0]{'contents'}[2]{'args'}[0];
 $result_trees{'formats_only_titles'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[0]{'contents'}[2];
-$result_trees{'formats_only_titles'}{'contents'}[0]{'contents'}[2]{'extra'}{'command'} = $result_trees{'formats_only_titles'}{'contents'}[0];
-$result_trees{'formats_only_titles'}{'contents'}[0]{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'formats_only_titles'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'formats_only_titles'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[0];
-$result_trees{'formats_only_titles'}{'contents'}[0]{'extra'}{'block_command_line_contents'}[0][0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[0];
-$result_trees{'formats_only_titles'}{'contents'}[0]{'extra'}{'command_as_argument'} = $result_trees{'formats_only_titles'}{'contents'}[0]{'extra'}{'block_command_line_contents'}[0][0];
+$result_trees{'formats_only_titles'}{'contents'}[0]{'extra'}{'command_as_argument'} = $result_trees{'formats_only_titles'}{'contents'}[0]{'args'}[0];
 $result_trees{'formats_only_titles'}{'contents'}[0]{'extra'}{'end_command'} = $result_trees{'formats_only_titles'}{'contents'}[0]{'contents'}[2];
-$result_trees{'formats_only_titles'}{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'formats_only_titles'}{'contents'}[0]{'contents'}[0];
 $result_trees{'formats_only_titles'}{'contents'}[0]{'parent'} = $result_trees{'formats_only_titles'};
 $result_trees{'formats_only_titles'}{'contents'}[1]{'parent'} = $result_trees{'formats_only_titles'};
 $result_trees{'formats_only_titles'}{'contents'}[2]{'contents'}[0]{'extra'}{'command'} = $result_trees{'formats_only_titles'}{'contents'}[2];
@@ -579,89 +478,48 @@ $result_trees{'formats_only_titles'}{'contents'}[2]{'contents'}[0]{'parent'} = $
 $result_trees{'formats_only_titles'}{'contents'}[2]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[2]{'contents'}[1]{'contents'}[0];
 $result_trees{'formats_only_titles'}{'contents'}[2]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[2]{'contents'}[1];
 $result_trees{'formats_only_titles'}{'contents'}[2]{'contents'}[1]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[2];
-$result_trees{'formats_only_titles'}{'contents'}[2]{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'formats_only_titles'}{'contents'}[2]{'contents'}[2];
 $result_trees{'formats_only_titles'}{'contents'}[2]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[2]{'contents'}[2]{'args'}[0];
-$result_trees{'formats_only_titles'}{'contents'}[2]{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[2]{'contents'}[2]{'args'}[0];
-$result_trees{'formats_only_titles'}{'contents'}[2]{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[2]{'contents'}[2]{'args'}[0];
 $result_trees{'formats_only_titles'}{'contents'}[2]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[2]{'contents'}[2];
-$result_trees{'formats_only_titles'}{'contents'}[2]{'contents'}[2]{'extra'}{'command'} = $result_trees{'formats_only_titles'}{'contents'}[2];
-$result_trees{'formats_only_titles'}{'contents'}[2]{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'formats_only_titles'}{'contents'}[2]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'formats_only_titles'}{'contents'}[2]{'contents'}[2]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[2];
 $result_trees{'formats_only_titles'}{'contents'}[2]{'extra'}{'end_command'} = $result_trees{'formats_only_titles'}{'contents'}[2]{'contents'}[2];
-$result_trees{'formats_only_titles'}{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'formats_only_titles'}{'contents'}[2]{'contents'}[0];
 $result_trees{'formats_only_titles'}{'contents'}[2]{'parent'} = $result_trees{'formats_only_titles'};
 $result_trees{'formats_only_titles'}{'contents'}[3]{'parent'} = $result_trees{'formats_only_titles'};
-$result_trees{'formats_only_titles'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'formats_only_titles'}{'contents'}[4];
 $result_trees{'formats_only_titles'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[4]{'args'}[0];
-$result_trees{'formats_only_titles'}{'contents'}[4]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[4]{'args'}[0];
-$result_trees{'formats_only_titles'}{'contents'}[4]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[4]{'args'}[0];
 $result_trees{'formats_only_titles'}{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[4];
 $result_trees{'formats_only_titles'}{'contents'}[4]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[4]{'contents'}[0]{'contents'}[0];
 $result_trees{'formats_only_titles'}{'contents'}[4]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[4]{'contents'}[0];
 $result_trees{'formats_only_titles'}{'contents'}[4]{'contents'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[4];
-$result_trees{'formats_only_titles'}{'contents'}[4]{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'formats_only_titles'}{'contents'}[4]{'contents'}[1];
 $result_trees{'formats_only_titles'}{'contents'}[4]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[4]{'contents'}[1]{'args'}[0];
-$result_trees{'formats_only_titles'}{'contents'}[4]{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[4]{'contents'}[1]{'args'}[0];
-$result_trees{'formats_only_titles'}{'contents'}[4]{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[4]{'contents'}[1]{'args'}[0];
 $result_trees{'formats_only_titles'}{'contents'}[4]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[4]{'contents'}[1];
-$result_trees{'formats_only_titles'}{'contents'}[4]{'contents'}[1]{'extra'}{'command'} = $result_trees{'formats_only_titles'}{'contents'}[4];
-$result_trees{'formats_only_titles'}{'contents'}[4]{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'formats_only_titles'}{'contents'}[4]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'formats_only_titles'}{'contents'}[4]{'contents'}[1]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[4];
-$result_trees{'formats_only_titles'}{'contents'}[4]{'extra'}{'block_command_line_contents'}[0][0] = $result_trees{'formats_only_titles'}{'contents'}[4]{'args'}[0]{'contents'}[1];
-$result_trees{'formats_only_titles'}{'contents'}[4]{'extra'}{'command_as_argument'} = $result_trees{'formats_only_titles'}{'contents'}[4]{'args'}[0]{'contents'}[1];
+$result_trees{'formats_only_titles'}{'contents'}[4]{'extra'}{'command_as_argument'} = $result_trees{'formats_only_titles'}{'contents'}[4]{'args'}[0]{'contents'}[0];
 $result_trees{'formats_only_titles'}{'contents'}[4]{'extra'}{'end_command'} = $result_trees{'formats_only_titles'}{'contents'}[4]{'contents'}[1];
-$result_trees{'formats_only_titles'}{'contents'}[4]{'extra'}{'spaces_after_command'} = $result_trees{'formats_only_titles'}{'contents'}[4]{'args'}[0]{'contents'}[0];
-$result_trees{'formats_only_titles'}{'contents'}[4]{'line_nr'} = $result_trees{'formats_only_titles'}{'contents'}[4]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'formats_only_titles'}{'contents'}[4]{'parent'} = $result_trees{'formats_only_titles'};
 $result_trees{'formats_only_titles'}{'contents'}[5]{'parent'} = $result_trees{'formats_only_titles'};
-$result_trees{'formats_only_titles'}{'contents'}[6]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'formats_only_titles'}{'contents'}[6];
 $result_trees{'formats_only_titles'}{'contents'}[6]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[6]{'args'}[0];
-$result_trees{'formats_only_titles'}{'contents'}[6]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[6]{'args'}[0];
-$result_trees{'formats_only_titles'}{'contents'}[6]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[6]{'args'}[0];
 $result_trees{'formats_only_titles'}{'contents'}[6]{'args'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[6];
 $result_trees{'formats_only_titles'}{'contents'}[6]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[6]{'contents'}[0]{'contents'}[0];
 $result_trees{'formats_only_titles'}{'contents'}[6]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[6]{'contents'}[0];
 $result_trees{'formats_only_titles'}{'contents'}[6]{'contents'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[6];
-$result_trees{'formats_only_titles'}{'contents'}[6]{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'formats_only_titles'}{'contents'}[6]{'contents'}[1];
 $result_trees{'formats_only_titles'}{'contents'}[6]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[6]{'contents'}[1]{'args'}[0];
-$result_trees{'formats_only_titles'}{'contents'}[6]{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[6]{'contents'}[1]{'args'}[0];
-$result_trees{'formats_only_titles'}{'contents'}[6]{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[6]{'contents'}[1]{'args'}[0];
 $result_trees{'formats_only_titles'}{'contents'}[6]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[6]{'contents'}[1];
-$result_trees{'formats_only_titles'}{'contents'}[6]{'contents'}[1]{'extra'}{'command'} = $result_trees{'formats_only_titles'}{'contents'}[6];
-$result_trees{'formats_only_titles'}{'contents'}[6]{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'formats_only_titles'}{'contents'}[6]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'formats_only_titles'}{'contents'}[6]{'contents'}[1]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[6];
-$result_trees{'formats_only_titles'}{'contents'}[6]{'extra'}{'block_command_line_contents'}[0][0] = $result_trees{'formats_only_titles'}{'contents'}[6]{'args'}[0]{'contents'}[1];
-$result_trees{'formats_only_titles'}{'contents'}[6]{'extra'}{'command_as_argument'} = $result_trees{'formats_only_titles'}{'contents'}[6]{'args'}[0]{'contents'}[1];
+$result_trees{'formats_only_titles'}{'contents'}[6]{'extra'}{'command_as_argument'} = $result_trees{'formats_only_titles'}{'contents'}[6]{'args'}[0]{'contents'}[0];
 $result_trees{'formats_only_titles'}{'contents'}[6]{'extra'}{'end_command'} = $result_trees{'formats_only_titles'}{'contents'}[6]{'contents'}[1];
-$result_trees{'formats_only_titles'}{'contents'}[6]{'extra'}{'spaces_after_command'} = $result_trees{'formats_only_titles'}{'contents'}[6]{'args'}[0]{'contents'}[0];
-$result_trees{'formats_only_titles'}{'contents'}[6]{'line_nr'} = $result_trees{'formats_only_titles'}{'contents'}[6]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'formats_only_titles'}{'contents'}[6]{'parent'} = $result_trees{'formats_only_titles'};
 $result_trees{'formats_only_titles'}{'contents'}[7]{'parent'} = $result_trees{'formats_only_titles'};
-$result_trees{'formats_only_titles'}{'contents'}[8]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'formats_only_titles'}{'contents'}[8];
+$result_trees{'formats_only_titles'}{'contents'}[8]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[8]{'args'}[0]{'contents'}[0]{'args'}[0];
+$result_trees{'formats_only_titles'}{'contents'}[8]{'args'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[8]{'args'}[0]{'contents'}[0];
 $result_trees{'formats_only_titles'}{'contents'}[8]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[8]{'args'}[0];
-$result_trees{'formats_only_titles'}{'contents'}[8]{'args'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'formats_only_titles'}{'contents'}[8]{'args'}[0]{'contents'}[1];
-$result_trees{'formats_only_titles'}{'contents'}[8]{'args'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[8]{'args'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'formats_only_titles'}{'contents'}[8]{'args'}[0]{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[8]{'args'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'formats_only_titles'}{'contents'}[8]{'args'}[0]{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[8]{'args'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'formats_only_titles'}{'contents'}[8]{'args'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[8]{'args'}[0]{'contents'}[1];
-$result_trees{'formats_only_titles'}{'contents'}[8]{'args'}[0]{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'formats_only_titles'}{'contents'}[8]{'args'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'formats_only_titles'}{'contents'}[8]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[8]{'args'}[0];
 $result_trees{'formats_only_titles'}{'contents'}[8]{'args'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[8];
 $result_trees{'formats_only_titles'}{'contents'}[8]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[8]{'contents'}[0]{'contents'}[0];
 $result_trees{'formats_only_titles'}{'contents'}[8]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[8]{'contents'}[0];
 $result_trees{'formats_only_titles'}{'contents'}[8]{'contents'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[8];
-$result_trees{'formats_only_titles'}{'contents'}[8]{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'formats_only_titles'}{'contents'}[8]{'contents'}[1];
 $result_trees{'formats_only_titles'}{'contents'}[8]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[8]{'contents'}[1]{'args'}[0];
-$result_trees{'formats_only_titles'}{'contents'}[8]{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[8]{'contents'}[1]{'args'}[0];
-$result_trees{'formats_only_titles'}{'contents'}[8]{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[8]{'contents'}[1]{'args'}[0];
 $result_trees{'formats_only_titles'}{'contents'}[8]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[8]{'contents'}[1];
-$result_trees{'formats_only_titles'}{'contents'}[8]{'contents'}[1]{'extra'}{'command'} = $result_trees{'formats_only_titles'}{'contents'}[8];
-$result_trees{'formats_only_titles'}{'contents'}[8]{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'formats_only_titles'}{'contents'}[8]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'formats_only_titles'}{'contents'}[8]{'contents'}[1]{'parent'} = $result_trees{'formats_only_titles'}{'contents'}[8];
-$result_trees{'formats_only_titles'}{'contents'}[8]{'extra'}{'columnfractions'} = $result_trees{'formats_only_titles'}{'contents'}[8]{'args'}[0]{'contents'}[1]{'extra'}{'misc_args'};
+$result_trees{'formats_only_titles'}{'contents'}[8]{'extra'}{'columnfractions'} = $result_trees{'formats_only_titles'}{'contents'}[8]{'args'}[0]{'contents'}[0];
 $result_trees{'formats_only_titles'}{'contents'}[8]{'extra'}{'end_command'} = $result_trees{'formats_only_titles'}{'contents'}[8]{'contents'}[1];
-$result_trees{'formats_only_titles'}{'contents'}[8]{'extra'}{'spaces_after_command'} = $result_trees{'formats_only_titles'}{'contents'}[8]{'args'}[0]{'contents'}[0];
-$result_trees{'formats_only_titles'}{'contents'}[8]{'line_nr'} = $result_trees{'formats_only_titles'}{'contents'}[8]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'formats_only_titles'}{'contents'}[8]{'parent'} = $result_trees{'formats_only_titles'};
 
 $result_texis{'formats_only_titles'} = '@itemize
@@ -746,4 +604,7 @@ $result_errors{'formats_only_titles'} = [
 ];
 
 
+$result_floats{'formats_only_titles'} = {};
+
+
 1;
