@@ -56,34 +56,23 @@ $result_trees{'indentedblock'} = {
           'args' => [
             {
               'contents' => [
-                {
-                  'extra' => {
-                    'command' => {}
-                  },
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_after_command'
-                },
                 {
                   'parent' => {},
                   'text' => 'indentedblock'
-                },
-                {
-                  'parent' => {},
-                  'text' => '
-',
-                  'type' => 'spaces_at_end'
                 }
               ],
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
               'parent' => {},
-              'type' => 'misc_line_arg'
+              'type' => 'line_arg'
             }
           ],
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
             'command_argument' => 'indentedblock',
-            'spaces_after_command' => {},
+            'spaces_before_argument' => ' ',
             'text_arg' => 'indentedblock'
           },
           'line_nr' => {
@@ -95,8 +84,7 @@ $result_trees{'indentedblock'} = {
         }
       ],
       'extra' => {
-        'end_command' => {},
-        'spaces_after_command' => {}
+        'end_command' => {}
       },
       'line_nr' => {
         'file_name' => '',
@@ -116,16 +104,10 @@ $result_trees{'indentedblock'}{'contents'}[0]{'contents'}[2]{'parent'} = $result
 $result_trees{'indentedblock'}{'contents'}[0]{'contents'}[3]{'parent'} = $result_trees{'indentedblock'}{'contents'}[0];
 $result_trees{'indentedblock'}{'contents'}[0]{'contents'}[4]{'contents'}[0]{'parent'} = $result_trees{'indentedblock'}{'contents'}[0]{'contents'}[4];
 $result_trees{'indentedblock'}{'contents'}[0]{'contents'}[4]{'parent'} = $result_trees{'indentedblock'}{'contents'}[0];
-$result_trees{'indentedblock'}{'contents'}[0]{'contents'}[5]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'indentedblock'}{'contents'}[0]{'contents'}[5];
 $result_trees{'indentedblock'}{'contents'}[0]{'contents'}[5]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'indentedblock'}{'contents'}[0]{'contents'}[5]{'args'}[0];
-$result_trees{'indentedblock'}{'contents'}[0]{'contents'}[5]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'indentedblock'}{'contents'}[0]{'contents'}[5]{'args'}[0];
-$result_trees{'indentedblock'}{'contents'}[0]{'contents'}[5]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'indentedblock'}{'contents'}[0]{'contents'}[5]{'args'}[0];
 $result_trees{'indentedblock'}{'contents'}[0]{'contents'}[5]{'args'}[0]{'parent'} = $result_trees{'indentedblock'}{'contents'}[0]{'contents'}[5];
-$result_trees{'indentedblock'}{'contents'}[0]{'contents'}[5]{'extra'}{'command'} = $result_trees{'indentedblock'}{'contents'}[0];
-$result_trees{'indentedblock'}{'contents'}[0]{'contents'}[5]{'extra'}{'spaces_after_command'} = $result_trees{'indentedblock'}{'contents'}[0]{'contents'}[5]{'args'}[0]{'contents'}[0];
 $result_trees{'indentedblock'}{'contents'}[0]{'contents'}[5]{'parent'} = $result_trees{'indentedblock'}{'contents'}[0];
 $result_trees{'indentedblock'}{'contents'}[0]{'extra'}{'end_command'} = $result_trees{'indentedblock'}{'contents'}[0]{'contents'}[5];
-$result_trees{'indentedblock'}{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'indentedblock'}{'contents'}[0]{'contents'}[0];
 $result_trees{'indentedblock'}{'contents'}[0]{'parent'} = $result_trees{'indentedblock'};
 
 $result_texis{'indentedblock'} = '@indentedblock
@@ -144,6 +126,9 @@ Text
 $result_errors{'indentedblock'} = [];
 
 
+$result_floats{'indentedblock'} = {};
+
+
 
 $result_converted{'plaintext'}->{'indentedblock'} = '     indented block
 
