@@ -207,7 +207,11 @@ $result_trees{'item_container'} = {
         'end_command' => {},
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {},
+      'line_nr' => {
+        'file_name' => '',
+        'line_nr' => 6,
+        'macro' => ''
+      },
       'parent' => {}
     },
     {
@@ -332,7 +336,6 @@ $result_trees{'item_container'}{'contents'}[3]{'contents'}[1]{'args'}[0]{'parent
 $result_trees{'item_container'}{'contents'}[3]{'contents'}[1]{'parent'} = $result_trees{'item_container'}{'contents'}[3];
 $result_trees{'item_container'}{'contents'}[3]{'extra'}{'command_as_argument'} = $result_trees{'item_container'}{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'item_container'}{'contents'}[3]{'extra'}{'end_command'} = $result_trees{'item_container'}{'contents'}[3]{'contents'}[1];
-$result_trees{'item_container'}{'contents'}[3]{'line_nr'} = $result_trees{'item_container'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'item_container'}{'contents'}[3]{'parent'} = $result_trees{'item_container'};
 $result_trees{'item_container'}{'contents'}[4]{'parent'} = $result_trees{'item_container'};
 $result_trees{'item_container'}{'contents'}[5]{'args'}[0]{'parent'} = $result_trees{'item_container'}{'contents'}[5];
@@ -375,6 +378,9 @@ no itemize argument
 $result_errors{'item_container'} = [];
 
 
+$result_floats{'item_container'} = {};
+
+
 
 $result_converted{'plaintext'}->{'item_container'} = '   + i-tem +
 
