@@ -62,8 +62,11 @@ $result_texts{'lettered_accent_and_spaces'} = 'a*
 $result_errors{'lettered_accent_and_spaces'} = [];
 
 
+$result_floats{'lettered_accent_and_spaces'} = {};
 
-$result_converted{'plaintext'}->{'lettered_accent_and_spaces'} = 'a*
+
+
+$result_converted{'plaintext'}->{'lettered_accent_and_spaces'} = 'å
 ';
 
 
