@@ -40,34 +40,23 @@ $result_trees{'raggedright'} = {
           'args' => [
             {
               'contents' => [
-                {
-                  'extra' => {
-                    'command' => {}
-                  },
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_after_command'
-                },
                 {
                   'parent' => {},
                   'text' => 'raggedright'
-                },
-                {
-                  'parent' => {},
-                  'text' => '
-',
-                  'type' => 'spaces_at_end'
                 }
               ],
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
               'parent' => {},
-              'type' => 'misc_line_arg'
+              'type' => 'line_arg'
             }
           ],
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
             'command_argument' => 'raggedright',
-            'spaces_after_command' => {},
+            'spaces_before_argument' => ' ',
             'text_arg' => 'raggedright'
           },
           'line_nr' => {
@@ -79,8 +68,7 @@ $result_trees{'raggedright'} = {
         }
       ],
       'extra' => {
-        'end_command' => {},
-        'spaces_after_command' => {}
+        'end_command' => {}
       },
       'line_nr' => {
         'file_name' => '',
@@ -97,16 +85,10 @@ $result_trees{'raggedright'}{'contents'}[1]{'contents'}[0]{'extra'}{'command'} =
 $result_trees{'raggedright'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'raggedright'}{'contents'}[1];
 $result_trees{'raggedright'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'raggedright'}{'contents'}[1]{'contents'}[1];
 $result_trees{'raggedright'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'raggedright'}{'contents'}[1];
-$result_trees{'raggedright'}{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'raggedright'}{'contents'}[1]{'contents'}[2];
 $result_trees{'raggedright'}{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'raggedright'}{'contents'}[1]{'contents'}[2]{'args'}[0];
-$result_trees{'raggedright'}{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'raggedright'}{'contents'}[1]{'contents'}[2]{'args'}[0];
-$result_trees{'raggedright'}{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'raggedright'}{'contents'}[1]{'contents'}[2]{'args'}[0];
 $result_trees{'raggedright'}{'contents'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'raggedright'}{'contents'}[1]{'contents'}[2];
-$result_trees{'raggedright'}{'contents'}[1]{'contents'}[2]{'extra'}{'command'} = $result_trees{'raggedright'}{'contents'}[1];
-$result_trees{'raggedright'}{'contents'}[1]{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'raggedright'}{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'raggedright'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'raggedright'}{'contents'}[1];
 $result_trees{'raggedright'}{'contents'}[1]{'extra'}{'end_command'} = $result_trees{'raggedright'}{'contents'}[1]{'contents'}[2];
-$result_trees{'raggedright'}{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'raggedright'}{'contents'}[1]{'contents'}[0];
 $result_trees{'raggedright'}{'contents'}[1]{'parent'} = $result_trees{'raggedright'};
 
 $result_texis{'raggedright'} = '
@@ -123,6 +105,9 @@ in raggedright
 $result_errors{'raggedright'} = [];
 
 
+$result_floats{'raggedright'} = {};
+
+
 
 $result_converted{'plaintext'}->{'raggedright'} = 'in raggedright
 ';
