@@ -19,6 +19,11 @@ $result_trees{'test_today'} = {
           ],
           'cmdname' => 'today',
           'contents' => [],
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 1,
+            'macro' => ''
+          },
           'parent' => {}
         },
         {
@@ -45,6 +50,9 @@ $result_texts{'test_today'} = 'a sunny day.';
 $result_errors{'test_today'} = [];
 
 
+$result_floats{'test_today'} = {};
+
+
 
 $result_converted{'plaintext'}->{'test_today'} = 'a sunny day.
 ';
