@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
@@ -10,31 +10,24 @@ $result_trees{'unknown_commands'} = {
     {
       'contents' => [
         {
-          'contents' => [
-            {
-              'parent' => {},
-              'text' => '
-'
-            },
-            {
-              'parent' => {},
-              'text' => '#
-'
-            }
-          ],
           'parent' => {},
-          'type' => 'paragraph'
+          'text' => '
+'
+        },
+        {
+          'parent' => {},
+          'text' => '#
+'
         }
       ],
       'parent' => {},
-      'type' => 'before_node_section'
+      'type' => 'paragraph'
     }
   ],
-  'type' => 'document_root'
+  'type' => 'text_root'
 };
-$result_trees{'unknown_commands'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'unknown_commands'}{'contents'}[0]{'contents'}[0];
-$result_trees{'unknown_commands'}{'contents'}[0]{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'unknown_commands'}{'contents'}[0]{'contents'}[0];
 $result_trees{'unknown_commands'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'unknown_commands'}{'contents'}[0];
+$result_trees{'unknown_commands'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'unknown_commands'}{'contents'}[0];
 $result_trees{'unknown_commands'}{'contents'}[0]{'parent'} = $result_trees{'unknown_commands'};
 
 $result_texis{'unknown_commands'} = '
@@ -48,7 +41,7 @@ $result_texts{'unknown_commands'} = '
 
 $result_errors{'unknown_commands'} = [
   {
-    'error_line' => 'unknown command `unknwon\'
+    'error_line' => ':1: unknown command `unknwon\'
 ',
     'file_name' => '',
     'line_nr' => 1,
@@ -57,7 +50,7 @@ $result_errors{'unknown_commands'} = [
     'type' => 'error'
   },
   {
-    'error_line' => 'unexpected @
+    'error_line' => ':2: unexpected @
 ',
     'file_name' => '',
     'line_nr' => 2,
