@@ -32,6 +32,7 @@ $result_trees{'verbatiminclude'} = {
       ],
       'cmdname' => 'verbatiminclude',
       'extra' => {
+        'input_perl_encoding' => 'utf-8',
         'spaces_before_argument' => ' ',
         'text_arg' => 'incl-incl.txi'
       },
@@ -61,6 +62,9 @@ $result_texts{'verbatiminclude'} = '
 $result_errors{'verbatiminclude'} = [];
 
 
+$result_floats{'verbatiminclude'} = {};
+
+
 
 $result_converted{'plaintext'}->{'verbatiminclude'} = 'This is the @emph{included} file (include-value2.txi) <> ---. 
 ';
