@@ -50,15 +50,18 @@ $result_texts{'code_not_closed'} = 'in code';
 
 $result_errors{'code_not_closed'} = [
   {
-    'error_line' => ':1: @code missing close brace
+    'error_line' => ':1: @code missing closing brace
 ',
     'file_name' => '',
     'line_nr' => 1,
     'macro' => '',
-    'text' => '@code missing close brace',
+    'text' => '@code missing closing brace',
     'type' => 'error'
   }
 ];
 
 
+$result_floats{'code_not_closed'} = {};
+
+
 1;
