@@ -18,9 +18,7 @@ $result_trees{'empty_images'} = {
       'cmdname' => 'image',
       'contents' => [],
       'extra' => {
-        'brace_command_contents' => [
-          undef
-        ]
+        'input_perl_encoding' => 'utf-8'
       },
       'line_nr' => {
         'file_name' => '',
@@ -43,13 +41,10 @@ $result_trees{'empty_images'} = {
     {
       'args' => [
         {
-          'contents' => [
-            {
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_before_argument'
-            }
-          ],
+          'contents' => [],
+          'extra' => {
+            'spaces_before_argument' => ' '
+          },
           'parent' => {},
           'type' => 'brace_command_arg'
         },
@@ -78,13 +73,11 @@ $result_trees{'empty_images'} = {
             {
               'parent' => {},
               'text' => 'cc'
-            },
-            {
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => ' '
+          },
           'parent' => {},
           'type' => 'brace_command_arg'
         },
@@ -102,22 +95,7 @@ $result_trees{'empty_images'} = {
       'cmdname' => 'image',
       'contents' => [],
       'extra' => {
-        'brace_command_contents' => [
-          undef,
-          [
-            {}
-          ],
-          [
-            {}
-          ],
-          [
-            {}
-          ],
-          [
-            {}
-          ]
-        ],
-        'spaces_before_argument' => {}
+        'input_perl_encoding' => 'utf-8'
       },
       'line_nr' => {
         'file_name' => '',
@@ -168,14 +146,7 @@ $result_trees{'empty_images'} = {
       'cmdname' => 'image',
       'contents' => [],
       'extra' => {
-        'brace_command_contents' => [
-          undef,
-          undef,
-          undef,
-          [
-            {}
-          ]
-        ]
+        'input_perl_encoding' => 'utf-8'
       },
       'line_nr' => {
         'file_name' => '',
@@ -220,14 +191,7 @@ $result_trees{'empty_images'} = {
       'cmdname' => 'image',
       'contents' => [],
       'extra' => {
-        'brace_command_contents' => [
-          undef,
-          undef,
-          undef,
-          [
-            {}
-          ]
-        ]
+        'input_perl_encoding' => 'utf-8'
       },
       'line_nr' => {
         'file_name' => '',
@@ -248,22 +212,15 @@ $result_trees{'empty_images'}{'contents'}[0]{'args'}[0]{'parent'} = $result_tree
 $result_trees{'empty_images'}{'contents'}[0]{'parent'} = $result_trees{'empty_images'};
 $result_trees{'empty_images'}{'contents'}[1]{'parent'} = $result_trees{'empty_images'};
 $result_trees{'empty_images'}{'contents'}[2]{'parent'} = $result_trees{'empty_images'};
-$result_trees{'empty_images'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'empty_images'}{'contents'}[3]{'args'}[0];
 $result_trees{'empty_images'}{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'empty_images'}{'contents'}[3];
 $result_trees{'empty_images'}{'contents'}[3]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'empty_images'}{'contents'}[3]{'args'}[1];
 $result_trees{'empty_images'}{'contents'}[3]{'args'}[1]{'parent'} = $result_trees{'empty_images'}{'contents'}[3];
 $result_trees{'empty_images'}{'contents'}[3]{'args'}[2]{'contents'}[0]{'parent'} = $result_trees{'empty_images'}{'contents'}[3]{'args'}[2];
 $result_trees{'empty_images'}{'contents'}[3]{'args'}[2]{'parent'} = $result_trees{'empty_images'}{'contents'}[3];
 $result_trees{'empty_images'}{'contents'}[3]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'empty_images'}{'contents'}[3]{'args'}[3];
-$result_trees{'empty_images'}{'contents'}[3]{'args'}[3]{'contents'}[1]{'parent'} = $result_trees{'empty_images'}{'contents'}[3]{'args'}[3];
 $result_trees{'empty_images'}{'contents'}[3]{'args'}[3]{'parent'} = $result_trees{'empty_images'}{'contents'}[3];
 $result_trees{'empty_images'}{'contents'}[3]{'args'}[4]{'contents'}[0]{'parent'} = $result_trees{'empty_images'}{'contents'}[3]{'args'}[4];
 $result_trees{'empty_images'}{'contents'}[3]{'args'}[4]{'parent'} = $result_trees{'empty_images'}{'contents'}[3];
-$result_trees{'empty_images'}{'contents'}[3]{'extra'}{'brace_command_contents'}[1][0] = $result_trees{'empty_images'}{'contents'}[3]{'args'}[1]{'contents'}[0];
-$result_trees{'empty_images'}{'contents'}[3]{'extra'}{'brace_command_contents'}[2][0] = $result_trees{'empty_images'}{'contents'}[3]{'args'}[2]{'contents'}[0];
-$result_trees{'empty_images'}{'contents'}[3]{'extra'}{'brace_command_contents'}[3][0] = $result_trees{'empty_images'}{'contents'}[3]{'args'}[3]{'contents'}[0];
-$result_trees{'empty_images'}{'contents'}[3]{'extra'}{'brace_command_contents'}[4][0] = $result_trees{'empty_images'}{'contents'}[3]{'args'}[4]{'contents'}[0];
-$result_trees{'empty_images'}{'contents'}[3]{'extra'}{'spaces_before_argument'} = $result_trees{'empty_images'}{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'empty_images'}{'contents'}[3]{'parent'} = $result_trees{'empty_images'};
 $result_trees{'empty_images'}{'contents'}[4]{'parent'} = $result_trees{'empty_images'};
 $result_trees{'empty_images'}{'contents'}[5]{'parent'} = $result_trees{'empty_images'};
@@ -272,7 +229,6 @@ $result_trees{'empty_images'}{'contents'}[6]{'args'}[1]{'parent'} = $result_tree
 $result_trees{'empty_images'}{'contents'}[6]{'args'}[2]{'parent'} = $result_trees{'empty_images'}{'contents'}[6];
 $result_trees{'empty_images'}{'contents'}[6]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'empty_images'}{'contents'}[6]{'args'}[3];
 $result_trees{'empty_images'}{'contents'}[6]{'args'}[3]{'parent'} = $result_trees{'empty_images'}{'contents'}[6];
-$result_trees{'empty_images'}{'contents'}[6]{'extra'}{'brace_command_contents'}[3][0] = $result_trees{'empty_images'}{'contents'}[6]{'args'}[3]{'contents'}[0];
 $result_trees{'empty_images'}{'contents'}[6]{'parent'} = $result_trees{'empty_images'};
 $result_trees{'empty_images'}{'contents'}[7]{'parent'} = $result_trees{'empty_images'};
 $result_trees{'empty_images'}{'contents'}[8]{'args'}[0]{'parent'} = $result_trees{'empty_images'}{'contents'}[8];
@@ -280,7 +236,6 @@ $result_trees{'empty_images'}{'contents'}[8]{'args'}[1]{'parent'} = $result_tree
 $result_trees{'empty_images'}{'contents'}[8]{'args'}[2]{'parent'} = $result_trees{'empty_images'}{'contents'}[8];
 $result_trees{'empty_images'}{'contents'}[8]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'empty_images'}{'contents'}[8]{'args'}[3];
 $result_trees{'empty_images'}{'contents'}[8]{'args'}[3]{'parent'} = $result_trees{'empty_images'}{'contents'}[8];
-$result_trees{'empty_images'}{'contents'}[8]{'extra'}{'brace_command_contents'}[3][0] = $result_trees{'empty_images'}{'contents'}[8]{'args'}[3]{'contents'}[0];
 $result_trees{'empty_images'}{'contents'}[8]{'parent'} = $result_trees{'empty_images'};
 $result_trees{'empty_images'}{'contents'}[9]{'parent'} = $result_trees{'empty_images'};
 
@@ -341,4 +296,7 @@ $result_errors{'empty_images'} = [
 ];
 
 
+$result_floats{'empty_images'} = {};
+
+
 1;
