@@ -1,15 +1,16 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
 $result_trees{'footnote_no_node'} = {
   'contents' => [
     {
+      'contents' => [],
       'parent' => {},
-      'type' => 'before_node_section'
+      'type' => 'text_root'
     },
     {
       'args' => [
@@ -62,12 +63,13 @@ $result_trees{'footnote_no_node'} = {
                 }
               ],
               'cmdname' => 'footnote',
-              'parent' => {},
-              'source_info' => {
+              'contents' => [],
+              'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 3,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             },
             {
               'parent' => {},
@@ -82,12 +84,13 @@ $result_trees{'footnote_no_node'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 0,
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 1,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     }
   ],
   'type' => 'document_root'
@@ -118,21 +121,19 @@ F.
 ';
 
 $result_sectioning{'footnote_no_node'} = {
-  'structure' => {
-    'section_childs' => [
-      {
-        'cmdname' => 'top',
-        'extra' => {},
-        'structure' => {
-          'section_level' => 0,
-          'section_up' => {}
-        }
-      }
-    ],
-    'section_level' => -1
-  }
+  'level' => -1,
+  'section_childs' => [
+    {
+      'cmdname' => 'top',
+      'extra' => {
+        'spaces_before_argument' => ' '
+      },
+      'level' => 0,
+      'section_up' => {}
+    }
+  ]
 };
-$result_sectioning{'footnote_no_node'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'footnote_no_node'};
+$result_sectioning{'footnote_no_node'}{'section_childs'}[0]{'section_up'} = $result_sectioning{'footnote_no_node'};
 
 $result_errors{'footnote_no_node'} = [];
 
@@ -153,24 +154,18 @@ F(1).
 ';
 
 
-$result_converted{'html_text'}->{'footnote_no_node'} = '<div class="top-level-extent" id="top">
+$result_converted{'html_text'}->{'footnote_no_node'} = '<div class="top" id="top">
 <h1 class="top">top</h1>
 
-<p>F<a class="footnote" id="DOCF1" href="#FOOT1"><sup>1</sup></a>.
-</p><div class="footnotes-segment">
+<p>F<a id="DOCF1" href="#FOOT1"><sup>1</sup></a>.
+</p><div class="footnote">
 <hr>
 <h4 class="footnotes-heading">Footnotes</h4>
 
-<h5 class="footnote-body-heading"><a id="FOOT1" href="#DOCF1">(1)</a></h5>
+<h5><a id="FOOT1" href="#DOCF1">(1)</a></h5>
 <p>In footnote</p>
 </div>
-</div>
-';
-
-
-$result_converted{'latex_text'}->{'footnote_no_node'} = '\\part*{{top}}
-
-F\\footnote{In footnote}.
+<hr></div>
 ';
 
 1;
