@@ -64,7 +64,11 @@ $result_trees{'ref_in_style_command'} = {
           ],
           'cmdname' => 'samp',
           'contents' => [],
-          'line_nr' => {},
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 1,
+            'macro' => ''
+          },
           'parent' => {}
         },
         {
@@ -87,7 +91,6 @@ $result_trees{'ref_in_style_command'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'
 $result_trees{'ref_in_style_command'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'extra'}{'node_argument'}{'node_content'}[0] = $result_trees{'ref_in_style_command'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[3];
 $result_trees{'ref_in_style_command'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'ref_in_style_command'}{'contents'}[0]{'contents'}[0]{'args'}[0];
 $result_trees{'ref_in_style_command'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'ref_in_style_command'}{'contents'}[0]{'contents'}[0];
-$result_trees{'ref_in_style_command'}{'contents'}[0]{'contents'}[0]{'line_nr'} = $result_trees{'ref_in_style_command'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'ref_in_style_command'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'ref_in_style_command'}{'contents'}[0];
 $result_trees{'ref_in_style_command'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'ref_in_style_command'}{'contents'}[0];
 $result_trees{'ref_in_style_command'}{'contents'}[0]{'parent'} = $result_trees{'ref_in_style_command'};
@@ -100,11 +103,14 @@ $result_texts{'ref_in_style_command'} = '(manula)other node.';
 $result_errors{'ref_in_style_command'} = [];
 
 
+$result_floats{'ref_in_style_command'} = {};
+
+
 
 $result_converted{'plaintext'}->{'ref_in_style_command'} = '\'*note (manula)other node::\'.
 ';
 
 
-$result_converted{'html_text'}->{'ref_in_style_command'} = '<p>&lsquo;<samp><a href="manula.html#other-node">(manula)other node</a></samp>&rsquo;.</p>';
+$result_converted{'html_text'}->{'ref_in_style_command'} = '<p>&lsquo;<samp><a data-manual="manula" href="manula.html#other-node">(manula)other node</a></samp>&rsquo;.</p>';
 
 1;
