@@ -63,7 +63,7 @@ $result_trees{'space_in_image'} = {
           'contents' => [
             {
               'parent' => {},
-              'text' => 'e'
+              'text' => '.e'
             }
           ],
           'extra' => {
@@ -75,7 +75,9 @@ $result_trees{'space_in_image'} = {
       ],
       'cmdname' => 'image',
       'contents' => [],
-      'extra' => {},
+      'extra' => {
+        'input_perl_encoding' => 'utf-8'
+      },
       'line_nr' => {
         'file_name' => '',
         'line_nr' => 1,
@@ -108,8 +110,14 @@ $result_trees{'space_in_image'} = {
           ],
           'cmdname' => 'image',
           'contents' => [],
-          'extra' => {},
-          'line_nr' => {},
+          'extra' => {
+            'input_perl_encoding' => 'utf-8'
+          },
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 1,
+            'macro' => ''
+          },
           'parent' => {}
         },
         {
@@ -137,12 +145,11 @@ $result_trees{'space_in_image'}{'contents'}[0]{'parent'} = $result_trees{'space_
 $result_trees{'space_in_image'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'space_in_image'}{'contents'}[1];
 $result_trees{'space_in_image'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'space_in_image'}{'contents'}[1]{'contents'}[1]{'args'}[0];
 $result_trees{'space_in_image'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'space_in_image'}{'contents'}[1]{'contents'}[1];
-$result_trees{'space_in_image'}{'contents'}[1]{'contents'}[1]{'line_nr'} = $result_trees{'space_in_image'}{'contents'}[0]{'line_nr'};
 $result_trees{'space_in_image'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'space_in_image'}{'contents'}[1];
 $result_trees{'space_in_image'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'space_in_image'}{'contents'}[1];
 $result_trees{'space_in_image'}{'contents'}[1]{'parent'} = $result_trees{'space_in_image'};
 
-$result_texis{'space_in_image'} = '@image{ a ,bb, cc,dd ,e }. @image{ f }.';
+$result_texis{'space_in_image'} = '@image{ a ,bb, cc,dd ,.e }. @image{ f }.';
 
 
 $result_texts{'space_in_image'} = 'a. f.';
@@ -150,8 +157,11 @@ $result_texts{'space_in_image'} = 'a. f.';
 $result_errors{'space_in_image'} = [];
 
 
+$result_floats{'space_in_image'} = {};
 
-$result_converted{'plaintext'}->{'space_in_image'} = 'An image text before paragraph.. Another image text, in paragraph..
+
+
+$result_converted{'plaintext'}->{'space_in_image'} = 'An image text before paragraph..  Another image text, in paragraph..
 ';
 
 
