@@ -34,16 +34,6 @@ $result_trees{'uref_url'} = {
           ],
           'cmdname' => 'uref',
           'contents' => [],
-          'extra' => {
-            'brace_command_contents' => [
-              [
-                {}
-              ],
-              [
-                {}
-              ]
-            ]
-          },
           'line_nr' => {
             'file_name' => '',
             'line_nr' => 1,
@@ -71,13 +61,6 @@ $result_trees{'uref_url'} = {
           ],
           'cmdname' => 'uref',
           'contents' => [],
-          'extra' => {
-            'brace_command_contents' => [
-              [
-                {}
-              ]
-            ]
-          },
           'line_nr' => {
             'file_name' => '',
             'line_nr' => 2,
@@ -110,14 +93,6 @@ $result_trees{'uref_url'} = {
           ],
           'cmdname' => 'uref',
           'contents' => [],
-          'extra' => {
-            'brace_command_contents' => [
-              undef,
-              [
-                {}
-              ]
-            ]
-          },
           'line_nr' => {
             'file_name' => '',
             'line_nr' => 3,
@@ -165,19 +140,6 @@ $result_trees{'uref_url'} = {
           ],
           'cmdname' => 'uref',
           'contents' => [],
-          'extra' => {
-            'brace_command_contents' => [
-              [
-                {}
-              ],
-              [
-                {}
-              ],
-              [
-                {}
-              ]
-            ]
-          },
           'line_nr' => {
             'file_name' => '',
             'line_nr' => 4,
@@ -220,17 +182,6 @@ $result_trees{'uref_url'} = {
           ],
           'cmdname' => 'uref',
           'contents' => [],
-          'extra' => {
-            'brace_command_contents' => [
-              undef,
-              [
-                {}
-              ],
-              [
-                {}
-              ]
-            ]
-          },
           'line_nr' => {
             'file_name' => '',
             'line_nr' => 5,
@@ -273,17 +224,6 @@ $result_trees{'uref_url'} = {
           ],
           'cmdname' => 'uref',
           'contents' => [],
-          'extra' => {
-            'brace_command_contents' => [
-              [
-                {}
-              ],
-              undef,
-              [
-                {}
-              ]
-            ]
-          },
           'line_nr' => {
             'file_name' => '',
             'line_nr' => 6,
@@ -321,15 +261,6 @@ $result_trees{'uref_url'} = {
           ],
           'cmdname' => 'uref',
           'contents' => [],
-          'extra' => {
-            'brace_command_contents' => [
-              undef,
-              undef,
-              [
-                {}
-              ]
-            ]
-          },
           'line_nr' => {
             'file_name' => '',
             'line_nr' => 7,
@@ -367,16 +298,6 @@ $result_trees{'uref_url'} = {
           ],
           'cmdname' => 'url',
           'contents' => [],
-          'extra' => {
-            'brace_command_contents' => [
-              [
-                {}
-              ],
-              [
-                {}
-              ]
-            ]
-          },
           'line_nr' => {
             'file_name' => '',
             'line_nr' => 8,
@@ -424,19 +345,6 @@ $result_trees{'uref_url'} = {
           ],
           'cmdname' => 'url',
           'contents' => [],
-          'extra' => {
-            'brace_command_contents' => [
-              [
-                {}
-              ],
-              [
-                {}
-              ],
-              [
-                {}
-              ]
-            ]
-          },
           'line_nr' => {
             'file_name' => '',
             'line_nr' => 9,
@@ -460,19 +368,15 @@ $result_trees{'uref_url'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[0];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[0]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[0]{'args'}[1];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[0]{'args'}[1]{'parent'} = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[0];
-$result_trees{'uref_url'}{'contents'}[0]{'contents'}[0]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0];
-$result_trees{'uref_url'}{'contents'}[0]{'contents'}[0]{'extra'}{'brace_command_contents'}[1][0] = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[0]{'args'}[1]{'contents'}[0];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'uref_url'}{'contents'}[0];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'uref_url'}{'contents'}[0];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[2]{'args'}[0];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[2];
-$result_trees{'uref_url'}{'contents'}[0]{'contents'}[2]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'uref_url'}{'contents'}[0];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[3]{'parent'} = $result_trees{'uref_url'}{'contents'}[0];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[4];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[4]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[4]{'args'}[1];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[4]{'args'}[1]{'parent'} = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[4];
-$result_trees{'uref_url'}{'contents'}[0]{'contents'}[4]{'extra'}{'brace_command_contents'}[1][0] = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[4]{'args'}[1]{'contents'}[0];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[4]{'parent'} = $result_trees{'uref_url'}{'contents'}[0];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[5]{'parent'} = $result_trees{'uref_url'}{'contents'}[0];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[6]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[6]{'args'}[0];
@@ -481,9 +385,6 @@ $result_trees{'uref_url'}{'contents'}[0]{'contents'}[6]{'args'}[1]{'contents'}[0
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[6]{'args'}[1]{'parent'} = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[6];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[6]{'args'}[2]{'contents'}[0]{'parent'} = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[6]{'args'}[2];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[6]{'args'}[2]{'parent'} = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[6];
-$result_trees{'uref_url'}{'contents'}[0]{'contents'}[6]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[6]{'args'}[0]{'contents'}[0];
-$result_trees{'uref_url'}{'contents'}[0]{'contents'}[6]{'extra'}{'brace_command_contents'}[1][0] = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[6]{'args'}[1]{'contents'}[0];
-$result_trees{'uref_url'}{'contents'}[0]{'contents'}[6]{'extra'}{'brace_command_contents'}[2][0] = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[6]{'args'}[2]{'contents'}[0];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[6]{'parent'} = $result_trees{'uref_url'}{'contents'}[0];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[7]{'parent'} = $result_trees{'uref_url'}{'contents'}[0];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[8]{'args'}[0]{'parent'} = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[8];
@@ -491,8 +392,6 @@ $result_trees{'uref_url'}{'contents'}[0]{'contents'}[8]{'args'}[1]{'contents'}[0
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[8]{'args'}[1]{'parent'} = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[8];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[8]{'args'}[2]{'contents'}[0]{'parent'} = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[8]{'args'}[2];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[8]{'args'}[2]{'parent'} = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[8];
-$result_trees{'uref_url'}{'contents'}[0]{'contents'}[8]{'extra'}{'brace_command_contents'}[1][0] = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[8]{'args'}[1]{'contents'}[0];
-$result_trees{'uref_url'}{'contents'}[0]{'contents'}[8]{'extra'}{'brace_command_contents'}[2][0] = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[8]{'args'}[2]{'contents'}[0];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[8]{'parent'} = $result_trees{'uref_url'}{'contents'}[0];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[9]{'parent'} = $result_trees{'uref_url'}{'contents'}[0];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[10]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[10]{'args'}[0];
@@ -500,23 +399,18 @@ $result_trees{'uref_url'}{'contents'}[0]{'contents'}[10]{'args'}[0]{'parent'} =
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[10]{'args'}[1]{'parent'} = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[10];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[10]{'args'}[2]{'contents'}[0]{'parent'} = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[10]{'args'}[2];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[10]{'args'}[2]{'parent'} = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[10];
-$result_trees{'uref_url'}{'contents'}[0]{'contents'}[10]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[10]{'args'}[0]{'contents'}[0];
-$result_trees{'uref_url'}{'contents'}[0]{'contents'}[10]{'extra'}{'brace_command_contents'}[2][0] = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[10]{'args'}[2]{'contents'}[0];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[10]{'parent'} = $result_trees{'uref_url'}{'contents'}[0];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[11]{'parent'} = $result_trees{'uref_url'}{'contents'}[0];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[12]{'args'}[0]{'parent'} = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[12];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[12]{'args'}[1]{'parent'} = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[12];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[12]{'args'}[2]{'contents'}[0]{'parent'} = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[12]{'args'}[2];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[12]{'args'}[2]{'parent'} = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[12];
-$result_trees{'uref_url'}{'contents'}[0]{'contents'}[12]{'extra'}{'brace_command_contents'}[2][0] = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[12]{'args'}[2]{'contents'}[0];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[12]{'parent'} = $result_trees{'uref_url'}{'contents'}[0];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[13]{'parent'} = $result_trees{'uref_url'}{'contents'}[0];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[14]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[14]{'args'}[0];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[14]{'args'}[0]{'parent'} = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[14];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[14]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[14]{'args'}[1];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[14]{'args'}[1]{'parent'} = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[14];
-$result_trees{'uref_url'}{'contents'}[0]{'contents'}[14]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[14]{'args'}[0]{'contents'}[0];
-$result_trees{'uref_url'}{'contents'}[0]{'contents'}[14]{'extra'}{'brace_command_contents'}[1][0] = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[14]{'args'}[1]{'contents'}[0];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[14]{'parent'} = $result_trees{'uref_url'}{'contents'}[0];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[15]{'parent'} = $result_trees{'uref_url'}{'contents'}[0];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[16]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[16]{'args'}[0];
@@ -525,9 +419,6 @@ $result_trees{'uref_url'}{'contents'}[0]{'contents'}[16]{'args'}[1]{'contents'}[
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[16]{'args'}[1]{'parent'} = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[16];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[16]{'args'}[2]{'contents'}[0]{'parent'} = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[16]{'args'}[2];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[16]{'args'}[2]{'parent'} = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[16];
-$result_trees{'uref_url'}{'contents'}[0]{'contents'}[16]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[16]{'args'}[0]{'contents'}[0];
-$result_trees{'uref_url'}{'contents'}[0]{'contents'}[16]{'extra'}{'brace_command_contents'}[1][0] = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[16]{'args'}[1]{'contents'}[0];
-$result_trees{'uref_url'}{'contents'}[0]{'contents'}[16]{'extra'}{'brace_command_contents'}[2][0] = $result_trees{'uref_url'}{'contents'}[0]{'contents'}[16]{'args'}[2]{'contents'}[0];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[16]{'parent'} = $result_trees{'uref_url'}{'contents'}[0];
 $result_trees{'uref_url'}{'contents'}[0]{'contents'}[17]{'parent'} = $result_trees{'uref_url'}{'contents'}[0];
 $result_trees{'uref_url'}{'contents'}[0]{'parent'} = $result_trees{'uref_url'};
@@ -558,6 +449,9 @@ $result_texts{'uref_url'} = '--a (-b)
 $result_errors{'uref_url'} = [];
 
 
+$result_floats{'uref_url'} = {};
+
+
 
 $result_converted{'plaintext'}->{'uref_url'} = '-b (--a) <--c> -d -g -i -k -l -n (--m) -q
 ';
