@@ -133,7 +133,11 @@ $result_trees{'defx_after_comment_in_example'} = {
                 },
                 'original_def_cmdname' => 'deffn'
               },
-              'line_nr' => {},
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 2,
+                'macro' => ''
+              },
               'parent' => {},
               'type' => 'def_line'
             },
@@ -258,7 +262,11 @@ $result_trees{'defx_after_comment_in_example'} = {
                 'original_def_cmdname' => 'deffnx',
                 'spaces_before_argument' => ' '
               },
-              'line_nr' => {},
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 4,
+                'macro' => ''
+              },
               'parent' => {},
               'type' => 'def_line'
             },
@@ -297,7 +305,11 @@ $result_trees{'defx_after_comment_in_example'} = {
             'end_command' => {},
             'spaces_before_argument' => ' '
           },
-          'line_nr' => {},
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 2,
+            'macro' => ''
+          },
           'parent' => {}
         },
         {
@@ -362,7 +374,6 @@ $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'co
 $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'extra'}{'index_entry'}{'command'} = $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'contents'}[0];
 $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'extra'}{'index_entry'}{'content'}[0] = $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[2];
 $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'extra'}{'index_entry'}{'content_normalized'}[0] = $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[2];
-$result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'line_nr'} = $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[2]{'line_nr'};
 $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1];
 $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[0]{'contents'}[0];
 $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[0];
@@ -381,13 +392,11 @@ $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'co
 $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'contents'}[2]{'extra'}{'index_entry'}{'command'} = $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'contents'}[2];
 $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'contents'}[2]{'extra'}{'index_entry'}{'content'}[0] = $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[2];
 $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'contents'}[2]{'extra'}{'index_entry'}{'content_normalized'}[0] = $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[2];
-$result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'contents'}[2]{'line_nr'} = $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1];
 $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'contents'}[3]{'args'}[0];
 $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'contents'}[3];
 $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1];
 $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'extra'}{'end_command'} = $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'contents'}[3];
-$result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'line_nr'} = $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[2]{'line_nr'};
 $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'defx_after_comment_in_example'}{'contents'}[0];
 $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[2]{'args'}[0];
 $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'defx_after_comment_in_example'}{'contents'}[0]{'contents'}[2];
@@ -430,6 +439,9 @@ $result_errors{'defx_after_comment_in_example'} = [
 ];
 
 
+$result_floats{'defx_after_comment_in_example'} = {};
+
+
 
 $result_converted{'plaintext'}->{'defx_after_comment_in_example'} = '      -- fset: I a g
       -- truc: bidulr machin...
