@@ -1,22 +1,16 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
 $result_trees{'comment_space_comand_in_float'} = {
   'contents' => [
     {
-      'contents' => [
-        {
-          'contents' => [],
-          'parent' => {},
-          'type' => 'preamble_before_content'
-        }
-      ],
+      'contents' => [],
       'parent' => {},
-      'type' => 'before_node_section'
+      'type' => 'text_root'
     },
     {
       'args' => [
@@ -127,23 +121,25 @@ $result_trees{'comment_space_comand_in_float'} = {
               ],
               'cmdname' => 'end',
               'extra' => {
+                'command_argument' => 'float',
                 'spaces_before_argument' => ' ',
                 'text_arg' => 'float'
               },
-              'parent' => {},
-              'source_info' => {
+              'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 5,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             }
           ],
           'extra' => {
+            'end_command' => {},
             'node_content' => [
               {},
               {}
             ],
-            'normalized' => 'label-',
+            'normalized' => 'label--',
             'spaces_before_argument' => ' ',
             'type' => {
               'content' => [
@@ -153,12 +149,13 @@ $result_trees{'comment_space_comand_in_float'} = {
               'normalized' => 'Text @ '
             }
           },
-          'parent' => {},
-          'source_info' => {
+          'line_nr' => {
             'file_name' => '',
             'line_nr' => 3,
             'macro' => ''
-          }
+          },
+          'number' => 1,
+          'parent' => {}
         },
         {
           'parent' => {},
@@ -214,12 +211,12 @@ $result_trees{'comment_space_comand_in_float'} = {
               'normalized' => 'Text @ '
             }
           },
-          'parent' => {},
-          'source_info' => {
+          'line_nr' => {
             'file_name' => '',
             'line_nr' => 7,
             'macro' => ''
-          }
+          },
+          'parent' => {}
         }
       ],
       'extra' => {
@@ -237,17 +234,16 @@ $result_trees{'comment_space_comand_in_float'} = {
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 1,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     }
   ],
   'type' => 'document_root'
 };
-$result_trees{'comment_space_comand_in_float'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'comment_space_comand_in_float'}{'contents'}[0];
 $result_trees{'comment_space_comand_in_float'}{'contents'}[0]{'parent'} = $result_trees{'comment_space_comand_in_float'};
 $result_trees{'comment_space_comand_in_float'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'comment_space_comand_in_float'}{'contents'}[1]{'args'}[0];
 $result_trees{'comment_space_comand_in_float'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'comment_space_comand_in_float'}{'contents'}[1];
@@ -265,6 +261,7 @@ $result_trees{'comment_space_comand_in_float'}{'contents'}[1]{'contents'}[1]{'co
 $result_trees{'comment_space_comand_in_float'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'comment_space_comand_in_float'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[0];
 $result_trees{'comment_space_comand_in_float'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'comment_space_comand_in_float'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
 $result_trees{'comment_space_comand_in_float'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'comment_space_comand_in_float'}{'contents'}[1]{'contents'}[1];
+$result_trees{'comment_space_comand_in_float'}{'contents'}[1]{'contents'}[1]{'extra'}{'end_command'} = $result_trees{'comment_space_comand_in_float'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
 $result_trees{'comment_space_comand_in_float'}{'contents'}[1]{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'comment_space_comand_in_float'}{'contents'}[1]{'contents'}[1]{'args'}[1]{'contents'}[0];
 $result_trees{'comment_space_comand_in_float'}{'contents'}[1]{'contents'}[1]{'extra'}{'node_content'}[1] = $result_trees{'comment_space_comand_in_float'}{'contents'}[1]{'contents'}[1]{'args'}[1]{'contents'}[1];
 $result_trees{'comment_space_comand_in_float'}{'contents'}[1]{'contents'}[1]{'extra'}{'type'}{'content'}[0] = $result_trees{'comment_space_comand_in_float'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0];
@@ -299,17 +296,21 @@ Float
 
 ';
 
+$result_sectioning{'comment_space_comand_in_float'} = {};
+
 $result_nodes{'comment_space_comand_in_float'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   }
 };
 
 $result_menus{'comment_space_comand_in_float'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   }
 };
 
@@ -321,7 +322,16 @@ $result_floats{'comment_space_comand_in_float'} = {
     {
       'cmdname' => 'float',
       'extra' => {
-        'normalized' => 'label-',
+        'end_command' => {
+          'cmdname' => 'end',
+          'extra' => {
+            'command_argument' => 'float',
+            'spaces_before_argument' => ' ',
+            'text_arg' => 'float'
+          }
+        },
+        'normalized' => 'label--',
+        'spaces_before_argument' => ' ',
         'type' => {
           'content' => [
             {
@@ -334,9 +344,7 @@ $result_floats{'comment_space_comand_in_float'} = {
           'normalized' => 'Text @ '
         }
       },
-      'structure' => {
-        'float_number' => 1
-      }
+      'number' => 1
     }
   ]
 };
@@ -382,7 +390,7 @@ End:
 ';
 
 
-$result_converted{'html'}->{'comment_space_comand_in_float'} = '<!DOCTYPE html>
+$result_converted{'html'}->{'comment_space_comand_in_float'} = '<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
 <html>
 <!-- Created by texinfo, http://www.gnu.org/software/texinfo/ -->
 <head>
@@ -396,21 +404,40 @@ $result_converted{'html'}->{'comment_space_comand_in_float'} = '<!DOCTYPE html>
 <meta name="viewport" content="width=device-width,initial-scale=1">
 
 <link href="#Top" rel="start" title="Top">
+<style type="text/css">
+<!--
+a.copiable-anchor {visibility: hidden; text-decoration: none; line-height: 0em}
+a.summary-letter {text-decoration: none}
+blockquote.indentedblock {margin-right: 0em}
+div.display {margin-left: 3.2em}
+div.example {margin-left: 3.2em}
+kbd {font-style: oblique}
+pre.display {font-family: inherit}
+pre.format {font-family: inherit}
+pre.menu-comment {font-family: serif}
+pre.menu-preformatted {font-family: serif}
+span.nolinebreak {white-space: nowrap}
+span.roman {font-family: initial; font-weight: normal}
+span.sansserif {font-family: sans-serif; font-weight: normal}
+span:hover a.copiable-anchor {visibility: visible}
+ul.no-bullet {list-style: none}
+-->
+</style>
 
 
 </head>
 
 <body lang="en">
-<h1 class="node" id="Top">Top</h1>
+<span id="Top"></span><h1 class="node-heading">Top</h1>
 
-<div class="float" id="label-">
+<div class="float"><span id="label--"></span>
 <p>Float
-</p><div class="type-number-float"><p><strong class="strong">Text &nbsp; 1
+</p><div class="float-caption"><p><strong>Text &nbsp; 1
 </strong></p></div></div>
 <dl class="listoffloats">
-<dt><a href="#label-">Text &nbsp; 1</a></dt><dd></dd>
+<dt><a href="#label--">Text &nbsp; 1</a></dt><dd></dd>
 </dl>
-
+<hr>
 
 
 </body>
