@@ -305,7 +305,9 @@ $result_trees{'cond'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -378,7 +380,7 @@ $result_trees{'cond'}{'contents'}[1]{'contents'}[14]{'contents'}[0]{'parent'} =
 $result_trees{'cond'}{'contents'}[1]{'contents'}[14]{'parent'} = $result_trees{'cond'}{'contents'}[1];
 $result_trees{'cond'}{'contents'}[1]{'contents'}[15]{'parent'} = $result_trees{'cond'}{'contents'}[1];
 $result_trees{'cond'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'cond'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'cond'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'cond'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'cond'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'cond'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'cond'}{'contents'}[1]{'parent'} = $result_trees{'cond'};
 $result_trees{'cond'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'cond'}{'contents'}[2];
 $result_trees{'cond'}{'contents'}[2]{'parent'} = $result_trees{'cond'};
@@ -434,20 +436,8 @@ $result_nodes{'cond'} = {
   'extra' => {
     'normalized' => 'Top',
     'spaces_before_argument' => ' '
-  },
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
   }
 };
-$result_nodes{'cond'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'cond'};
 
 $result_menus{'cond'} = {
   'cmdname' => 'node',
@@ -460,6 +450,9 @@ $result_menus{'cond'} = {
 $result_errors{'cond'} = [];
 
 
+$result_floats{'cond'} = {};
+
+
 
 $result_converted{'html'}->{'cond'} = '<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
 <html>
@@ -473,13 +466,15 @@ $result_converted{'html'}->{'cond'} = '<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
 <meta name="Generator" content="texi2any">
+<meta name="viewport" content="width=device-width,initial-scale=1">
+
 <style type="text/css">
 <!--
+a.copiable-anchor {visibility: hidden; text-decoration: none; line-height: 0em}
 a.summary-letter {text-decoration: none}
 blockquote.indentedblock {margin-right: 0em}
 div.display {margin-left: 3.2em}
 div.example {margin-left: 3.2em}
-div.lisp {margin-left: 3.2em}
 kbd {font-style: oblique}
 pre.display {font-family: inherit}
 pre.format {font-family: inherit}
@@ -488,6 +483,7 @@ pre.menu-preformatted {font-family: serif}
 span.nolinebreak {white-space: nowrap}
 span.roman {font-family: initial; font-weight: normal}
 span.sansserif {font-family: sans-serif; font-weight: normal}
+span:hover a.copiable-anchor {visibility: visible}
 ul.no-bullet {list-style: none}
 -->
 </style>
@@ -512,8 +508,7 @@ This is html text.
 
 <p>This is ifnottex text.
 </p>
-<hr>
-<p><font size="-1">
+<hr><p><font size="-1">
   This document was generated on <em>a sunny day</em> using <a href="http://www.gnu.org/software/texinfo/"><em>texi2any</em></a>.
 </font></p>
 
