@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
@@ -17,60 +17,54 @@ $result_trees{'cond_ifhtml_ifinfo_iftex'} = {
                   'parent' => {},
                   'text' => '\\input texinfo
 ',
-                  'type' => 'text_before_beginning'
+                  'type' => 'preamble_text'
                 }
               ],
               'parent' => {},
-              'type' => 'preamble_before_beginning'
+              'type' => 'preamble'
             }
           ],
           'parent' => {},
           'type' => 'preamble_before_setfilename'
         },
         {
-          'contents' => [
+          'args' => [
             {
-              'args' => [
+              'contents' => [
                 {
-                  'contents' => [
-                    {
-                      'parent' => {},
-                      'text' => 'cond.info'
-                    }
-                  ],
-                  'extra' => {
-                    'spaces_after_argument' => '
-'
-                  },
                   'parent' => {},
-                  'type' => 'line_arg'
+                  'text' => 'cond.info'
                 }
               ],
-              'cmdname' => 'setfilename',
               'extra' => {
-                'spaces_before_argument' => ' ',
-                'text_arg' => 'cond.info'
+                'spaces_after_argument' => '
+'
               },
               'parent' => {},
-              'source_info' => {
-                'file_name' => 'cond.texi',
-                'line_nr' => 2,
-                'macro' => ''
-              }
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'empty_line'
+              'type' => 'line_arg'
             }
           ],
+          'cmdname' => 'setfilename',
+          'extra' => {
+            'spaces_before_argument' => ' ',
+            'text_arg' => 'cond.info'
+          },
+          'line_nr' => {
+            'file_name' => 'cond.texi',
+            'line_nr' => 2,
+            'macro' => ''
+          },
+          'parent' => {}
+        },
+        {
           'parent' => {},
-          'type' => 'preamble_before_content'
+          'text' => '
+',
+          'type' => 'empty_line'
         }
       ],
       'parent' => {},
-      'type' => 'before_node_section'
+      'type' => 'text_root'
     },
     {
       'args' => [
@@ -98,18 +92,17 @@ $result_trees{'cond_ifhtml_ifinfo_iftex'} = {
           'type' => 'empty_line'
         },
         {
-          'args' => [
-            {
-              'extra' => {
-                'spaces_after_argument' => '
-'
-              },
-              'parent' => {},
-              'type' => 'block_line_arg'
-            }
-          ],
           'cmdname' => 'html',
           'contents' => [
+            {
+              'extra' => {
+                'command' => {}
+              },
+              'parent' => {},
+              'text' => '
+',
+              'type' => 'empty_line_after_command'
+            },
             {
               'contents' => [
                 {
@@ -140,23 +133,27 @@ $result_trees{'cond_ifhtml_ifinfo_iftex'} = {
               ],
               'cmdname' => 'end',
               'extra' => {
+                'command_argument' => 'html',
                 'spaces_before_argument' => ' ',
                 'text_arg' => 'html'
               },
-              'parent' => {},
-              'source_info' => {
+              'line_nr' => {
                 'file_name' => 'cond.texi',
                 'line_nr' => 8,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             }
           ],
-          'parent' => {},
-          'source_info' => {
+          'extra' => {
+            'end_command' => {}
+          },
+          'line_nr' => {
             'file_name' => 'cond.texi',
             'line_nr' => 6,
             'macro' => ''
-          }
+          },
+          'parent' => {}
         },
         {
           'parent' => {},
@@ -223,18 +220,17 @@ $result_trees{'cond_ifhtml_ifinfo_iftex'} = {
           'type' => 'empty_line'
         },
         {
-          'args' => [
-            {
-              'extra' => {
-                'spaces_after_argument' => '
-'
-              },
-              'parent' => {},
-              'type' => 'block_line_arg'
-            }
-          ],
           'cmdname' => 'tex',
           'contents' => [
+            {
+              'extra' => {
+                'command' => {}
+              },
+              'parent' => {},
+              'text' => '
+',
+              'type' => 'empty_line_after_command'
+            },
             {
               'contents' => [
                 {
@@ -265,23 +261,27 @@ $result_trees{'cond_ifhtml_ifinfo_iftex'} = {
               ],
               'cmdname' => 'end',
               'extra' => {
+                'command_argument' => 'tex',
                 'spaces_before_argument' => ' ',
                 'text_arg' => 'tex'
               },
-              'parent' => {},
-              'source_info' => {
+              'line_nr' => {
                 'file_name' => 'cond.texi',
                 'line_nr' => 30,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             }
           ],
-          'parent' => {},
-          'source_info' => {
+          'extra' => {
+            'end_command' => {}
+          },
+          'line_nr' => {
             'file_name' => 'cond.texi',
             'line_nr' => 28,
             'macro' => ''
-          }
+          },
+          'parent' => {}
         },
         {
           'parent' => {},
@@ -328,12 +328,12 @@ $result_trees{'cond_ifhtml_ifinfo_iftex'} = {
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'line_nr' => {
         'file_name' => 'cond.texi',
         'line_nr' => 4,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     },
     {
       'args' => [
@@ -353,21 +353,22 @@ $result_trees{'cond_ifhtml_ifinfo_iftex'} = {
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[0]{'contents'}[0];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[0];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0];
-$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0];
-$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[1]{'contents'}[0];
-$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[1];
-$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[1];
+$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[1]{'args'}[0];
+$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[1];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0];
+$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'};
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'args'}[0];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1];
-$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1];
-$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[0];
+$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'extra'}{'command'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1];
-$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[0];
-$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
+$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1];
+$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0];
+$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[2];
+$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1];
+$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'extra'}{'end_command'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[2];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[3]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[3];
@@ -380,12 +381,14 @@ $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[7]{'parent'
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[8]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[9]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[10]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1];
-$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'args'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11];
-$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[0];
+$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[0]{'extra'}{'command'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11];
-$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[1]{'args'}[0];
-$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[1];
+$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[1];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[1]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11];
+$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[2]{'args'}[0];
+$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[2];
+$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[2]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11];
+$result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'extra'}{'end_command'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[2];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[11]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[12]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1];
 $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[13]{'contents'}[0]{'parent'} = $result_trees{'cond_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[13];
@@ -443,17 +446,21 @@ This is iftex text.
 
 ';
 
+$result_sectioning{'cond_ifhtml_ifinfo_iftex'} = {};
+
 $result_nodes{'cond_ifhtml_ifinfo_iftex'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   }
 };
 
 $result_menus{'cond_ifhtml_ifinfo_iftex'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   }
 };
 
@@ -464,7 +471,7 @@ $result_floats{'cond_ifhtml_ifinfo_iftex'} = {};
 
 
 
-$result_converted{'html'}->{'cond_ifhtml_ifinfo_iftex'} = '<!DOCTYPE html>
+$result_converted{'html'}->{'cond_ifhtml_ifinfo_iftex'} = '<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
 <html>
 <!-- Created by texinfo, http://www.gnu.org/software/texinfo/ -->
 <head>
@@ -480,7 +487,21 @@ $result_converted{'html'}->{'cond_ifhtml_ifinfo_iftex'} = '<!DOCTYPE html>
 
 <style type="text/css">
 <!--
-span.program-in-footer {font-size: smaller}
+a.copiable-anchor {visibility: hidden; text-decoration: none; line-height: 0em}
+a.summary-letter {text-decoration: none}
+blockquote.indentedblock {margin-right: 0em}
+div.display {margin-left: 3.2em}
+div.example {margin-left: 3.2em}
+kbd {font-style: oblique}
+pre.display {font-family: inherit}
+pre.format {font-family: inherit}
+pre.menu-comment {font-family: serif}
+pre.menu-preformatted {font-family: serif}
+span.nolinebreak {white-space: nowrap}
+span.roman {font-family: initial; font-weight: normal}
+span.sansserif {font-family: sans-serif; font-weight: normal}
+span:hover a.copiable-anchor {visibility: visible}
+ul.no-bullet {list-style: none}
 -->
 </style>
 
@@ -489,7 +510,7 @@ span.program-in-footer {font-size: smaller}
 
 <body lang="en">
 
-<a class="node" id="Top"></a>
+<span id="Top"></span>
 This is html text.
 
 <p>This is ifhtml text.
@@ -505,10 +526,9 @@ This is tex text.
 <p>This is iftex text.
 </p>
 
-<hr>
-<p>
-  <span class="program-in-footer">This document was generated on <em class="emph">a sunny day</em> using <a class="uref" href="http://www.gnu.org/software/texinfo/"><em class="emph">texi2any</em></a>.</span>
-</p>
+<hr><p><font size="-1">
+  This document was generated on <em>a sunny day</em> using <a href="http://www.gnu.org/software/texinfo/"><em>texi2any</em></a>.
+</font></p>
 
 
 </body>
@@ -517,14 +537,13 @@ This is tex text.
 
 $result_converted_errors{'html'}->{'cond_ifhtml_ifinfo_iftex'} = [
   {
-    'error_line' => 'warning: must specify a title with a title command or @top
+    'error_line' => 'cond.texi: warning: must specify a title with a title command or @top
 ',
-    'file_name' => 'cond.texi',
     'text' => 'must specify a title with a title command or @top',
     'type' => 'warning'
   },
   {
-    'error_line' => 'warning: raw format tex is not converted
+    'error_line' => 'cond.texi:28: warning: raw format tex is not converted
 ',
     'file_name' => 'cond.texi',
     'line_nr' => 28,
