@@ -319,7 +319,9 @@ $result_trees{'cond_info_ifhtml_ifinfo_iftex'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -394,7 +396,7 @@ $result_trees{'cond_info_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[13]{'p
 $result_trees{'cond_info_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[14]{'parent'} = $result_trees{'cond_info_ifhtml_ifinfo_iftex'}{'contents'}[1];
 $result_trees{'cond_info_ifhtml_ifinfo_iftex'}{'contents'}[1]{'contents'}[15]{'parent'} = $result_trees{'cond_info_ifhtml_ifinfo_iftex'}{'contents'}[1];
 $result_trees{'cond_info_ifhtml_ifinfo_iftex'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'cond_info_ifhtml_ifinfo_iftex'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'cond_info_ifhtml_ifinfo_iftex'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'cond_info_ifhtml_ifinfo_iftex'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'cond_info_ifhtml_ifinfo_iftex'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'cond_info_ifhtml_ifinfo_iftex'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'cond_info_ifhtml_ifinfo_iftex'}{'contents'}[1]{'parent'} = $result_trees{'cond_info_ifhtml_ifinfo_iftex'};
 $result_trees{'cond_info_ifhtml_ifinfo_iftex'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'cond_info_ifhtml_ifinfo_iftex'}{'contents'}[2];
 $result_trees{'cond_info_ifhtml_ifinfo_iftex'}{'contents'}[2]{'parent'} = $result_trees{'cond_info_ifhtml_ifinfo_iftex'};
@@ -465,6 +467,9 @@ $result_menus{'cond_info_ifhtml_ifinfo_iftex'} = {
 $result_errors{'cond_info_ifhtml_ifinfo_iftex'} = [];
 
 
+$result_floats{'cond_info_ifhtml_ifinfo_iftex'} = {};
+
+
 
 $result_converted{'info'}->{'cond_info_ifhtml_ifinfo_iftex'} = 'This is cond.info, produced by texi2any version from cond.texi.
 
