@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
@@ -17,60 +17,54 @@ $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'} = {
                   'parent' => {},
                   'text' => '\\input texinfo
 ',
-                  'type' => 'text_before_beginning'
+                  'type' => 'preamble_text'
                 }
               ],
               'parent' => {},
-              'type' => 'preamble_before_beginning'
+              'type' => 'preamble'
             }
           ],
           'parent' => {},
           'type' => 'preamble_before_setfilename'
         },
         {
-          'contents' => [
+          'args' => [
             {
-              'args' => [
+              'contents' => [
                 {
-                  'contents' => [
-                    {
-                      'parent' => {},
-                      'text' => 'cond.info'
-                    }
-                  ],
-                  'extra' => {
-                    'spaces_after_argument' => '
-'
-                  },
                   'parent' => {},
-                  'type' => 'line_arg'
+                  'text' => 'cond.info'
                 }
               ],
-              'cmdname' => 'setfilename',
               'extra' => {
-                'spaces_before_argument' => ' ',
-                'text_arg' => 'cond.info'
+                'spaces_after_argument' => '
+'
               },
               'parent' => {},
-              'source_info' => {
-                'file_name' => 'cond.texi',
-                'line_nr' => 2,
-                'macro' => ''
-              }
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'empty_line'
+              'type' => 'line_arg'
             }
           ],
+          'cmdname' => 'setfilename',
+          'extra' => {
+            'spaces_before_argument' => ' ',
+            'text_arg' => 'cond.info'
+          },
+          'line_nr' => {
+            'file_name' => 'cond.texi',
+            'line_nr' => 2,
+            'macro' => ''
+          },
+          'parent' => {}
+        },
+        {
           'parent' => {},
-          'type' => 'preamble_before_content'
+          'text' => '
+',
+          'type' => 'empty_line'
         }
       ],
       'parent' => {},
-      'type' => 'before_node_section'
+      'type' => 'text_root'
     },
     {
       'args' => [
@@ -98,22 +92,19 @@ $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'} = {
           'type' => 'empty_line'
         },
         {
-          'args' => [
-            {
-              'extra' => {
-                'spaces_after_argument' => '
-'
-              },
-              'parent' => {},
-              'type' => 'block_line_arg'
-            }
-          ],
           'cmdname' => 'html',
           'contents' => [
             {
+              'contents' => [],
               'parent' => {},
               'type' => 'elided_block'
             },
+            {
+              'parent' => {},
+              'text' => '
+',
+              'type' => 'empty_line_after_command'
+            },
             {
               'args' => [
                 {
@@ -133,23 +124,22 @@ $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'} = {
               ],
               'cmdname' => 'end',
               'extra' => {
+                'command_argument' => 'html',
                 'spaces_before_argument' => ' ',
                 'text_arg' => 'html'
               },
-              'parent' => {},
-              'source_info' => {
+              'line_nr' => {
                 'file_name' => 'cond.texi',
                 'line_nr' => 8,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             }
           ],
-          'parent' => {},
-          'source_info' => {
-            'file_name' => 'cond.texi',
-            'line_nr' => 6,
-            'macro' => ''
-          }
+          'extra' => {
+            'end_command' => {}
+          },
+          'parent' => {}
         },
         {
           'parent' => {},
@@ -216,22 +206,19 @@ $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'} = {
           'type' => 'empty_line'
         },
         {
-          'args' => [
-            {
-              'extra' => {
-                'spaces_after_argument' => '
-'
-              },
-              'parent' => {},
-              'type' => 'block_line_arg'
-            }
-          ],
           'cmdname' => 'tex',
           'contents' => [
             {
+              'contents' => [],
               'parent' => {},
               'type' => 'elided_block'
             },
+            {
+              'parent' => {},
+              'text' => '
+',
+              'type' => 'empty_line_after_command'
+            },
             {
               'args' => [
                 {
@@ -251,23 +238,22 @@ $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'} = {
               ],
               'cmdname' => 'end',
               'extra' => {
+                'command_argument' => 'tex',
                 'spaces_before_argument' => ' ',
                 'text_arg' => 'tex'
               },
-              'parent' => {},
-              'source_info' => {
+              'line_nr' => {
                 'file_name' => 'cond.texi',
                 'line_nr' => 30,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             }
           ],
-          'parent' => {},
-          'source_info' => {
-            'file_name' => 'cond.texi',
-            'line_nr' => 28,
-            'macro' => ''
-          }
+          'extra' => {
+            'end_command' => {}
+          },
+          'parent' => {}
         },
         {
           'parent' => {},
@@ -314,12 +300,12 @@ $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'} = {
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'line_nr' => {
         'file_name' => 'cond.texi',
         'line_nr' => 4,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     },
     {
       'args' => [
@@ -339,20 +325,20 @@ $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'} = {
 $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[0]{'contents'}[0]{'contents'}[0];
 $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[0]{'contents'}[0];
 $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[0];
-$result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0];
-$result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[0]{'contents'}[1]{'contents'}[0];
-$result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[0]{'contents'}[1];
-$result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[0]{'contents'}[1];
+$result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[0]{'contents'}[1]{'args'}[0];
+$result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[0]{'contents'}[1];
 $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[0];
+$result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[0];
 $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[0]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'};
 $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'args'}[0];
 $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1];
 $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1];
-$result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[1];
 $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[1];
-$result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[0];
-$result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
 $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[1];
+$result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0];
+$result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[2];
+$result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[1];
+$result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[1]{'extra'}{'end_command'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[1]{'contents'}[2];
 $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1];
 $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1];
 $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1];
@@ -365,11 +351,12 @@ $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents
 $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[8]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1];
 $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[9]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1];
 $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[10]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1];
-$result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[11]{'args'}[0]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[11];
 $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[0]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[11];
-$result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[1]{'args'}[0];
-$result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[1];
 $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[1]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[11];
+$result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[2]{'args'}[0];
+$result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[2];
+$result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[2]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[11];
+$result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[11]{'extra'}{'end_command'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[11]{'contents'}[2];
 $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[11]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1];
 $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[12]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1];
 $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1]{'contents'}[13]{'parent'} = $result_trees{'cond_info_no-ifhtml_no-ifinfo_no-iftex'}{'contents'}[1];
@@ -425,17 +412,21 @@ This is ifnottex text.
 
 ';
 
+$result_sectioning{'cond_info_no-ifhtml_no-ifinfo_no-iftex'} = {};
+
 $result_nodes{'cond_info_no-ifhtml_no-ifinfo_no-iftex'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   }
 };
 
 $result_menus{'cond_info_no-ifhtml_no-ifinfo_no-iftex'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   }
 };
 
