@@ -174,7 +174,9 @@ $result_trees{'documentlanguage_set_option_info'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -282,7 +284,7 @@ $result_trees{'documentlanguage_set_option_info'}{'contents'}[0]{'parent'} = $re
 $result_trees{'documentlanguage_set_option_info'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'documentlanguage_set_option_info'}{'contents'}[1]{'args'}[0];
 $result_trees{'documentlanguage_set_option_info'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'documentlanguage_set_option_info'}{'contents'}[1];
 $result_trees{'documentlanguage_set_option_info'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'documentlanguage_set_option_info'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'documentlanguage_set_option_info'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'documentlanguage_set_option_info'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'documentlanguage_set_option_info'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'documentlanguage_set_option_info'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'documentlanguage_set_option_info'}{'contents'}[1]{'parent'} = $result_trees{'documentlanguage_set_option_info'};
 $result_trees{'documentlanguage_set_option_info'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'documentlanguage_set_option_info'}{'contents'}[2]{'args'}[0];
 $result_trees{'documentlanguage_set_option_info'}{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'documentlanguage_set_option_info'}{'contents'}[2]{'args'}[0];
@@ -352,20 +354,8 @@ $result_nodes{'documentlanguage_set_option_info'} = {
     },
     'normalized' => 'Top',
     'spaces_before_argument' => ' '
-  },
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
   }
 };
-$result_nodes{'documentlanguage_set_option_info'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'documentlanguage_set_option_info'};
 
 $result_menus{'documentlanguage_set_option_info'} = {
   'cmdname' => 'node',
@@ -378,4 +368,7 @@ $result_menus{'documentlanguage_set_option_info'} = {
 $result_errors{'documentlanguage_set_option_info'} = [];
 
 
+$result_floats{'documentlanguage_set_option_info'} = {};
+
+
 1;
