@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
@@ -17,66 +17,60 @@ $result_trees{'simplest_test_prefix'} = {
                   'parent' => {},
                   'text' => '\\input texinfo @c -*-texinfo-*-
 ',
-                  'type' => 'text_before_beginning'
+                  'type' => 'preamble_text'
                 },
                 {
                   'parent' => {},
                   'text' => '
 ',
-                  'type' => 'text_before_beginning'
+                  'type' => 'preamble_text'
                 }
               ],
               'parent' => {},
-              'type' => 'preamble_before_beginning'
+              'type' => 'preamble'
             }
           ],
           'parent' => {},
           'type' => 'preamble_before_setfilename'
         },
         {
-          'contents' => [
+          'args' => [
             {
-              'args' => [
+              'contents' => [
                 {
-                  'contents' => [
-                    {
-                      'parent' => {},
-                      'text' => 'simplest.info'
-                    }
-                  ],
-                  'extra' => {
-                    'spaces_after_argument' => '
-'
-                  },
                   'parent' => {},
-                  'type' => 'line_arg'
+                  'text' => 'simplest.info'
                 }
               ],
-              'cmdname' => 'setfilename',
               'extra' => {
-                'spaces_before_argument' => ' ',
-                'text_arg' => 'simplest.info'
+                'spaces_after_argument' => '
+'
               },
               'parent' => {},
-              'source_info' => {
-                'file_name' => 'simplest.texi',
-                'line_nr' => 3,
-                'macro' => ''
-              }
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'empty_line'
+              'type' => 'line_arg'
             }
           ],
+          'cmdname' => 'setfilename',
+          'extra' => {
+            'spaces_before_argument' => ' ',
+            'text_arg' => 'simplest.info'
+          },
+          'line_nr' => {
+            'file_name' => 'simplest.texi',
+            'line_nr' => 3,
+            'macro' => ''
+          },
+          'parent' => {}
+        },
+        {
           'parent' => {},
-          'type' => 'preamble_before_content'
+          'text' => '
+',
+          'type' => 'empty_line'
         }
       ],
       'parent' => {},
-      'type' => 'before_node_section'
+      'type' => 'text_root'
     },
     {
       'args' => [
@@ -144,12 +138,12 @@ $result_trees{'simplest_test_prefix'} = {
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'line_nr' => {
         'file_name' => 'simplest.texi',
         'line_nr' => 5,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     },
     {
       'args' => [
@@ -170,11 +164,10 @@ $result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[0]{'contents'}[
 $result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[0]{'contents'}[0];
 $result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[0];
 $result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'simplest_test_prefix'}{'contents'}[0];
-$result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0];
-$result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[1]{'contents'}[0];
-$result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[1];
-$result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[1];
+$result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[1]{'args'}[0];
+$result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[1];
 $result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'simplest_test_prefix'}{'contents'}[0];
+$result_trees{'simplest_test_prefix'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'simplest_test_prefix'}{'contents'}[0];
 $result_trees{'simplest_test_prefix'}{'contents'}[0]{'parent'} = $result_trees{'simplest_test_prefix'};
 $result_trees{'simplest_test_prefix'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'simplest_test_prefix'}{'contents'}[1]{'args'}[0];
 $result_trees{'simplest_test_prefix'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'simplest_test_prefix'}{'contents'}[1];
@@ -208,17 +201,21 @@ This is a very simple texi manual   <>.
 
 ';
 
+$result_sectioning{'simplest_test_prefix'} = {};
+
 $result_nodes{'simplest_test_prefix'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   }
 };
 
 $result_menus{'simplest_test_prefix'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   }
 };
 
@@ -230,9 +227,8 @@ $result_floats{'simplest_test_prefix'} = {};
 
 $result_converted_errors{'file_html'}->{'simplest_test_prefix'} = [
   {
-    'error_line' => 'warning: must specify a title with a title command or @top
+    'error_line' => 'simplest.texi: warning: must specify a title with a title command or @top
 ',
-    'file_name' => 'simplest.texi',
     'text' => 'must specify a title with a title command or @top',
     'type' => 'warning'
   }
