@@ -129,7 +129,9 @@ $result_trees{'split_for_format_not_split'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -176,7 +178,7 @@ $result_trees{'split_for_format_not_split'}{'contents'}[1]{'contents'}[1]{'conte
 $result_trees{'split_for_format_not_split'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'split_for_format_not_split'}{'contents'}[1];
 $result_trees{'split_for_format_not_split'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'split_for_format_not_split'}{'contents'}[1];
 $result_trees{'split_for_format_not_split'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'split_for_format_not_split'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'split_for_format_not_split'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'split_for_format_not_split'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'split_for_format_not_split'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'split_for_format_not_split'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'split_for_format_not_split'}{'contents'}[1]{'parent'} = $result_trees{'split_for_format_not_split'};
 $result_trees{'split_for_format_not_split'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'split_for_format_not_split'}{'contents'}[2];
 $result_trees{'split_for_format_not_split'}{'contents'}[2]{'parent'} = $result_trees{'split_for_format_not_split'};
@@ -206,20 +208,8 @@ $result_nodes{'split_for_format_not_split'} = {
   'extra' => {
     'normalized' => 'Top',
     'spaces_before_argument' => ' '
-  },
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
   }
 };
-$result_nodes{'split_for_format_not_split'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'split_for_format_not_split'};
 
 $result_menus{'split_for_format_not_split'} = {
   'cmdname' => 'node',
@@ -232,4 +222,7 @@ $result_menus{'split_for_format_not_split'} = {
 $result_errors{'split_for_format_not_split'} = [];
 
 
+$result_floats{'split_for_format_not_split'} = {};
+
+
 1;
