@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
@@ -17,60 +17,54 @@ $result_trees{'split_nocopying'} = {
                   'parent' => {},
                   'text' => '\\input texinfo
 ',
-                  'type' => 'text_before_beginning'
+                  'type' => 'preamble_text'
                 }
               ],
               'parent' => {},
-              'type' => 'preamble_before_beginning'
+              'type' => 'preamble'
             }
           ],
           'parent' => {},
           'type' => 'preamble_before_setfilename'
         },
         {
-          'contents' => [
+          'args' => [
             {
-              'args' => [
+              'contents' => [
                 {
-                  'contents' => [
-                    {
-                      'parent' => {},
-                      'text' => 'split-nocopying.info'
-                    }
-                  ],
-                  'extra' => {
-                    'spaces_after_argument' => '
-'
-                  },
                   'parent' => {},
-                  'type' => 'line_arg'
+                  'text' => 'split-nocopying.info'
                 }
               ],
-              'cmdname' => 'setfilename',
               'extra' => {
-                'spaces_before_argument' => ' ',
-                'text_arg' => 'split-nocopying.info'
+                'spaces_after_argument' => '
+'
               },
               'parent' => {},
-              'source_info' => {
-                'file_name' => 'split_nocopying.texi',
-                'line_nr' => 2,
-                'macro' => ''
-              }
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'empty_line'
+              'type' => 'line_arg'
             }
           ],
+          'cmdname' => 'setfilename',
+          'extra' => {
+            'spaces_before_argument' => ' ',
+            'text_arg' => 'split-nocopying.info'
+          },
+          'line_nr' => {
+            'file_name' => 'split_nocopying.texi',
+            'line_nr' => 2,
+            'macro' => ''
+          },
+          'parent' => {}
+        },
+        {
           'parent' => {},
-          'type' => 'preamble_before_content'
+          'text' => '
+',
+          'type' => 'empty_line'
         }
       ],
       'parent' => {},
-      'type' => 'before_node_section'
+      'type' => 'text_root'
     },
     {
       'args' => [
@@ -90,6 +84,7 @@ $result_trees{'split_nocopying'} = {
         }
       ],
       'cmdname' => 'node',
+      'contents' => [],
       'extra' => {
         'node_content' => [
           {}
@@ -105,12 +100,12 @@ $result_trees{'split_nocopying'} = {
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'line_nr' => {
         'file_name' => 'split_nocopying.texi',
         'line_nr' => 4,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     },
     {
       'args' => [
@@ -155,18 +150,17 @@ $result_trees{'split_nocopying'} = {
           'type' => 'empty_line'
         },
         {
-          'args' => [
-            {
-              'extra' => {
-                'spaces_after_argument' => '
-'
-              },
-              'parent' => {},
-              'type' => 'block_line_arg'
-            }
-          ],
           'cmdname' => 'menu',
           'contents' => [
+            {
+              'extra' => {
+                'command' => {}
+              },
+              'parent' => {},
+              'text' => '
+',
+              'type' => 'empty_line_after_command'
+            },
             {
               'args' => [
                 {
@@ -216,12 +210,12 @@ $result_trees{'split_nocopying'} = {
                   'normalized' => 'Ch1'
                 }
               },
-              'parent' => {},
-              'source_info' => {
+              'line_nr' => {
                 'file_name' => 'split_nocopying.texi',
                 'line_nr' => 10,
                 'macro' => ''
               },
+              'parent' => {},
               'type' => 'menu_entry'
             },
             {
@@ -243,23 +237,27 @@ $result_trees{'split_nocopying'} = {
               ],
               'cmdname' => 'end',
               'extra' => {
+                'command_argument' => 'menu',
                 'spaces_before_argument' => ' ',
                 'text_arg' => 'menu'
               },
-              'parent' => {},
-              'source_info' => {
+              'line_nr' => {
                 'file_name' => 'split_nocopying.texi',
                 'line_nr' => 11,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             }
           ],
-          'parent' => {},
-          'source_info' => {
+          'extra' => {
+            'end_command' => {}
+          },
+          'line_nr' => {
             'file_name' => 'split_nocopying.texi',
             'line_nr' => 9,
             'macro' => ''
-          }
+          },
+          'parent' => {}
         },
         {
           'parent' => {},
@@ -271,12 +269,13 @@ $result_trees{'split_nocopying'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 0,
+      'line_nr' => {
         'file_name' => 'split_nocopying.texi',
         'line_nr' => 5,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     },
     {
       'args' => [
@@ -296,6 +295,7 @@ $result_trees{'split_nocopying'} = {
         }
       ],
       'cmdname' => 'node',
+      'contents' => [],
       'extra' => {
         'node_content' => [
           {}
@@ -311,12 +311,12 @@ $result_trees{'split_nocopying'} = {
         'normalized' => 'Ch1',
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'line_nr' => {
         'file_name' => 'split_nocopying.texi',
         'line_nr' => 13,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     },
     {
       'args' => [
@@ -364,12 +364,14 @@ $result_trees{'split_nocopying'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 1,
+      'line_nr' => {
         'file_name' => 'split_nocopying.texi',
         'line_nr' => 14,
         'macro' => ''
-      }
+      },
+      'number' => 1,
+      'parent' => {}
     },
     {
       'args' => [
@@ -389,11 +391,10 @@ $result_trees{'split_nocopying'} = {
 $result_trees{'split_nocopying'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[0]{'contents'}[0]{'contents'}[0];
 $result_trees{'split_nocopying'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[0]{'contents'}[0];
 $result_trees{'split_nocopying'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[0];
-$result_trees{'split_nocopying'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0];
-$result_trees{'split_nocopying'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[0]{'contents'}[1]{'contents'}[0];
-$result_trees{'split_nocopying'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[0]{'contents'}[1];
-$result_trees{'split_nocopying'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[0]{'contents'}[1];
+$result_trees{'split_nocopying'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[0]{'contents'}[1]{'args'}[0];
+$result_trees{'split_nocopying'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[0]{'contents'}[1];
 $result_trees{'split_nocopying'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[0];
+$result_trees{'split_nocopying'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[0];
 $result_trees{'split_nocopying'}{'contents'}[0]{'parent'} = $result_trees{'split_nocopying'};
 $result_trees{'split_nocopying'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[1]{'args'}[0];
 $result_trees{'split_nocopying'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[1];
@@ -406,20 +407,22 @@ $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[0]{'parent'} = $resu
 $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[1];
 $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[1]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[2];
 $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[2]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[2];
-$result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3];
-$result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[0];
-$result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[1];
-$result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[1]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[0];
-$result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[2]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[0];
-$result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[3]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[3]{'contents'}[0];
-$result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[3];
-$result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[3]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[0];
-$result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'extra'}{'menu_entry_description'} = $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[3];
-$result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'args'}[1]{'contents'}[0];
+$result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'extra'}{'command'} = $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3];
 $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3];
-$result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[0];
 $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[1];
+$result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[1];
+$result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[1]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[1];
+$result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[2]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[1];
+$result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[3]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[3]{'contents'}[0];
+$result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[3];
+$result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[3]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[1];
+$result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'extra'}{'menu_entry_description'} = $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[3];
+$result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'args'}[1]{'contents'}[0];
 $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[1]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3];
+$result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[2]{'args'}[0];
+$result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[2];
+$result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[2]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3];
+$result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'extra'}{'end_command'} = $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'contents'}[2];
 $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[3]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[2];
 $result_trees{'split_nocopying'}{'contents'}[2]{'contents'}[4]{'parent'} = $result_trees{'split_nocopying'}{'contents'}[2];
 $result_trees{'split_nocopying'}{'contents'}[2]{'parent'} = $result_trees{'split_nocopying'};
@@ -475,115 +478,120 @@ First chapter.
 ';
 
 $result_sectioning{'split_nocopying'} = {
-  'structure' => {
-    'section_childs' => [
-      {
-        'cmdname' => 'top',
-        'extra' => {
-          'associated_node' => {
-            'cmdname' => 'node',
-            'extra' => {
-              'normalized' => 'Top'
-            },
-            'structure' => {}
+  'level' => -1,
+  'section_childs' => [
+    {
+      'cmdname' => 'top',
+      'extra' => {
+        'associated_node' => {
+          'cmdname' => 'node',
+          'extra' => {
+            'normalized' => 'Top',
+            'spaces_before_argument' => ' '
           }
         },
-        'structure' => {
-          'section_childs' => [
-            {
-              'cmdname' => 'chapter',
+        'spaces_before_argument' => ' '
+      },
+      'level' => 0,
+      'section_childs' => [
+        {
+          'cmdname' => 'chapter',
+          'extra' => {
+            'associated_node' => {
+              'cmdname' => 'node',
               'extra' => {
-                'associated_node' => {
-                  'cmdname' => 'node',
-                  'extra' => {
-                    'normalized' => 'Ch1'
-                  },
-                  'structure' => {}
-                }
-              },
-              'structure' => {
-                'section_level' => 1,
-                'section_number' => 1,
-                'section_up' => {},
-                'toplevel_prev' => {},
-                'toplevel_up' => {}
+                'normalized' => 'Ch1',
+                'spaces_before_argument' => ' '
               }
-            }
-          ],
-          'section_level' => 0,
-          'section_up' => {}
+            },
+            'spaces_before_argument' => ' '
+          },
+          'level' => 1,
+          'number' => 1,
+          'section_up' => {},
+          'toplevel_prev' => {},
+          'toplevel_up' => {}
         }
-      }
-    ],
-    'section_level' => -1
-  }
+      ],
+      'section_up' => {}
+    }
+  ]
 };
-$result_sectioning{'split_nocopying'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'split_nocopying'}{'structure'}{'section_childs'}[0];
-$result_sectioning{'split_nocopying'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'toplevel_prev'} = $result_sectioning{'split_nocopying'}{'structure'}{'section_childs'}[0];
-$result_sectioning{'split_nocopying'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'toplevel_up'} = $result_sectioning{'split_nocopying'}{'structure'}{'section_childs'}[0];
-$result_sectioning{'split_nocopying'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'split_nocopying'};
+$result_sectioning{'split_nocopying'}{'section_childs'}[0]{'section_childs'}[0]{'section_up'} = $result_sectioning{'split_nocopying'}{'section_childs'}[0];
+$result_sectioning{'split_nocopying'}{'section_childs'}[0]{'section_childs'}[0]{'toplevel_prev'} = $result_sectioning{'split_nocopying'}{'section_childs'}[0];
+$result_sectioning{'split_nocopying'}{'section_childs'}[0]{'section_childs'}[0]{'toplevel_up'} = $result_sectioning{'split_nocopying'}{'section_childs'}[0];
+$result_sectioning{'split_nocopying'}{'section_childs'}[0]{'section_up'} = $result_sectioning{'split_nocopying'};
 
 $result_nodes{'split_nocopying'} = {
   'cmdname' => 'node',
   'extra' => {
     'associated_section' => {
       'cmdname' => 'top',
-      'extra' => {},
-      'structure' => {}
-    },
-    'menus' => [
-      {
-        'cmdname' => 'menu'
-      }
-    ],
-    'normalized' => 'Top'
-  },
-  'structure' => {
-    'menu_child' => {
-      'cmdname' => 'node',
       'extra' => {
-        'associated_section' => {
-          'cmdname' => 'chapter',
-          'extra' => {},
-          'structure' => {
-            'section_number' => 1
-          }
-        },
-        'normalized' => 'Ch1'
+        'spaces_before_argument' => ' '
       },
-      'structure' => {
-        'node_prev' => {},
-        'node_up' => {}
-      }
+      'level' => 0
     },
-    'node_next' => {}
-  }
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
+  },
+  'menu_child' => {
+    'cmdname' => 'node',
+    'extra' => {
+      'associated_section' => {
+        'cmdname' => 'chapter',
+        'extra' => {
+          'spaces_before_argument' => ' '
+        },
+        'level' => 1,
+        'number' => 1
+      },
+      'normalized' => 'Ch1',
+      'spaces_before_argument' => ' '
+    },
+    'node_prev' => {},
+    'node_up' => {}
+  },
+  'menus' => [
+    {
+      'cmdname' => 'menu',
+      'extra' => {
+        'end_command' => {
+          'cmdname' => 'end',
+          'extra' => {
+            'command_argument' => 'menu',
+            'spaces_before_argument' => ' ',
+            'text_arg' => 'menu'
+          }
+        }
+      }
+    }
+  ],
+  'node_next' => {}
 };
-$result_nodes{'split_nocopying'}{'structure'}{'menu_child'}{'structure'}{'node_prev'} = $result_nodes{'split_nocopying'};
-$result_nodes{'split_nocopying'}{'structure'}{'menu_child'}{'structure'}{'node_up'} = $result_nodes{'split_nocopying'};
-$result_nodes{'split_nocopying'}{'structure'}{'node_next'} = $result_nodes{'split_nocopying'}{'structure'}{'menu_child'};
+$result_nodes{'split_nocopying'}{'menu_child'}{'node_prev'} = $result_nodes{'split_nocopying'};
+$result_nodes{'split_nocopying'}{'menu_child'}{'node_up'} = $result_nodes{'split_nocopying'};
+$result_nodes{'split_nocopying'}{'node_next'} = $result_nodes{'split_nocopying'}{'menu_child'};
 
 $result_menus{'split_nocopying'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   },
-  'structure' => {
-    'menu_child' => {
-      'cmdname' => 'node',
-      'extra' => {
-        'normalized' => 'Ch1'
-      },
-      'structure' => {
-        'menu_up' => {},
-        'menu_up_hash' => {
-          'Top' => 1
-        }
-      }
+  'menu_child' => {
+    'cmdname' => 'node',
+    'extra' => {
+      'normalized' => 'Ch1',
+      'spaces_before_argument' => ' '
+    },
+    'menu_up' => {},
+    'menu_up_hash' => {
+      'Top' => 1
     }
   }
 };
-$result_menus{'split_nocopying'}{'structure'}{'menu_child'}{'structure'}{'menu_up'} = $result_menus{'split_nocopying'};
+$result_menus{'split_nocopying'}{'menu_child'}{'menu_up'} = $result_menus{'split_nocopying'};
 
 $result_errors{'split_nocopying'} = [];
 
