@@ -1,15 +1,16 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
 $result_trees{'character_number_leading_toc_stoc'} = {
   'contents' => [
     {
+      'contents' => [],
       'parent' => {},
-      'type' => 'before_node_section'
+      'type' => 'text_root'
     },
     {
       'args' => [
@@ -29,15 +30,17 @@ $result_trees{'character_number_leading_toc_stoc'} = {
         }
       ],
       'cmdname' => 'top',
+      'contents' => [],
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 0,
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 1,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     },
     {
       'args' => [
@@ -57,15 +60,18 @@ $result_trees{'character_number_leading_toc_stoc'} = {
         }
       ],
       'cmdname' => 'chapter',
+      'contents' => [],
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 1,
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 2,
         'macro' => ''
-      }
+      },
+      'number' => 1,
+      'parent' => {}
     },
     {
       'args' => [
@@ -85,15 +91,17 @@ $result_trees{'character_number_leading_toc_stoc'} = {
         }
       ],
       'cmdname' => 'unnumbered',
+      'contents' => [],
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 1,
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 3,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     },
     {
       'args' => [
@@ -130,12 +138,12 @@ $result_trees{'character_number_leading_toc_stoc'} = {
             }
           ],
           'cmdname' => 'contents',
-          'parent' => {},
-          'source_info' => {
+          'line_nr' => {
             'file_name' => '',
             'line_nr' => 6,
             'macro' => ''
-          }
+          },
+          'parent' => {}
         },
         {
           'parent' => {},
@@ -153,12 +161,12 @@ $result_trees{'character_number_leading_toc_stoc'} = {
             }
           ],
           'cmdname' => 'shortcontents',
-          'parent' => {},
-          'source_info' => {
+          'line_nr' => {
             'file_name' => '',
             'line_nr' => 8,
             'macro' => ''
-          }
+          },
+          'parent' => {}
         },
         {
           'parent' => {},
@@ -170,12 +178,13 @@ $result_trees{'character_number_leading_toc_stoc'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 2,
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 4,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     }
   ],
   'type' => 'document_root'
@@ -227,63 +236,61 @@ _
 ';
 
 $result_sectioning{'character_number_leading_toc_stoc'} = {
-  'structure' => {
-    'section_childs' => [
-      {
-        'cmdname' => 'top',
-        'extra' => {},
-        'structure' => {
+  'level' => -1,
+  'section_childs' => [
+    {
+      'cmdname' => 'top',
+      'extra' => {
+        'spaces_before_argument' => ' '
+      },
+      'level' => 0,
+      'section_childs' => [
+        {
+          'cmdname' => 'chapter',
+          'extra' => {
+            'spaces_before_argument' => ' '
+          },
+          'level' => 1,
+          'number' => 1,
+          'section_up' => {},
+          'toplevel_prev' => {},
+          'toplevel_up' => {}
+        },
+        {
+          'cmdname' => 'unnumbered',
+          'extra' => {
+            'spaces_before_argument' => ' '
+          },
+          'level' => 1,
           'section_childs' => [
             {
-              'cmdname' => 'chapter',
-              'extra' => {},
-              'structure' => {
-                'section_level' => 1,
-                'section_number' => 1,
-                'section_up' => {},
-                'toplevel_prev' => {},
-                'toplevel_up' => {}
-              }
-            },
-            {
-              'cmdname' => 'unnumbered',
-              'extra' => {},
-              'structure' => {
-                'section_childs' => [
-                  {
-                    'cmdname' => 'section',
-                    'extra' => {},
-                    'structure' => {
-                      'section_level' => 2,
-                      'section_up' => {}
-                    }
-                  }
-                ],
-                'section_level' => 1,
-                'section_prev' => {},
-                'section_up' => {},
-                'toplevel_prev' => {},
-                'toplevel_up' => {}
-              }
+              'cmdname' => 'section',
+              'extra' => {
+                'spaces_before_argument' => ' '
+              },
+              'level' => 2,
+              'section_up' => {}
             }
           ],
-          'section_level' => 0,
-          'section_up' => {}
+          'section_prev' => {},
+          'section_up' => {},
+          'toplevel_prev' => {},
+          'toplevel_up' => {}
         }
-      }
-    ],
-    'section_level' => -1
-  }
+      ],
+      'section_up' => {}
+    }
+  ]
 };
-$result_sectioning{'character_number_leading_toc_stoc'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'character_number_leading_toc_stoc'}{'structure'}{'section_childs'}[0];
-$result_sectioning{'character_number_leading_toc_stoc'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'toplevel_prev'} = $result_sectioning{'character_number_leading_toc_stoc'}{'structure'}{'section_childs'}[0];
-$result_sectioning{'character_number_leading_toc_stoc'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'toplevel_up'} = $result_sectioning{'character_number_leading_toc_stoc'}{'structure'}{'section_childs'}[0];
-$result_sectioning{'character_number_leading_toc_stoc'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[1]{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'character_number_leading_toc_stoc'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[1];
-$result_sectioning{'character_number_leading_toc_stoc'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[1]{'structure'}{'section_prev'} = $result_sectioning{'character_number_leading_toc_stoc'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0];
-$result_sectioning{'character_number_leading_toc_stoc'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[1]{'structure'}{'section_up'} = $result_sectioning{'character_number_leading_toc_stoc'}{'structure'}{'section_childs'}[0];
-$result_sectioning{'character_number_leading_toc_stoc'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[1]{'structure'}{'toplevel_prev'} = $result_sectioning{'character_number_leading_toc_stoc'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0];
-$result_sectioning{'character_number_leading_toc_stoc'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[1]{'structure'}{'toplevel_up'} = $result_sectioning{'character_number_leading_toc_stoc'}{'structure'}{'section_childs'}[0];
-$result_sectioning{'character_number_leading_toc_stoc'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'character_number_leading_toc_stoc'};
+$result_sectioning{'character_number_leading_toc_stoc'}{'section_childs'}[0]{'section_childs'}[0]{'section_up'} = $result_sectioning{'character_number_leading_toc_stoc'}{'section_childs'}[0];
+$result_sectioning{'character_number_leading_toc_stoc'}{'section_childs'}[0]{'section_childs'}[0]{'toplevel_prev'} = $result_sectioning{'character_number_leading_toc_stoc'}{'section_childs'}[0];
+$result_sectioning{'character_number_leading_toc_stoc'}{'section_childs'}[0]{'section_childs'}[0]{'toplevel_up'} = $result_sectioning{'character_number_leading_toc_stoc'}{'section_childs'}[0];
+$result_sectioning{'character_number_leading_toc_stoc'}{'section_childs'}[0]{'section_childs'}[1]{'section_childs'}[0]{'section_up'} = $result_sectioning{'character_number_leading_toc_stoc'}{'section_childs'}[0]{'section_childs'}[1];
+$result_sectioning{'character_number_leading_toc_stoc'}{'section_childs'}[0]{'section_childs'}[1]{'section_prev'} = $result_sectioning{'character_number_leading_toc_stoc'}{'section_childs'}[0]{'section_childs'}[0];
+$result_sectioning{'character_number_leading_toc_stoc'}{'section_childs'}[0]{'section_childs'}[1]{'section_up'} = $result_sectioning{'character_number_leading_toc_stoc'}{'section_childs'}[0];
+$result_sectioning{'character_number_leading_toc_stoc'}{'section_childs'}[0]{'section_childs'}[1]{'toplevel_prev'} = $result_sectioning{'character_number_leading_toc_stoc'}{'section_childs'}[0]{'section_childs'}[0];
+$result_sectioning{'character_number_leading_toc_stoc'}{'section_childs'}[0]{'section_childs'}[1]{'toplevel_up'} = $result_sectioning{'character_number_leading_toc_stoc'}{'section_childs'}[0];
+$result_sectioning{'character_number_leading_toc_stoc'}{'section_childs'}[0]{'section_up'} = $result_sectioning{'character_number_leading_toc_stoc'};
 
 $result_errors{'character_number_leading_toc_stoc'} = [];
 
@@ -292,7 +299,7 @@ $result_floats{'character_number_leading_toc_stoc'} = {};
 
 
 
-$result_converted{'html'}->{'character_number_leading_toc_stoc'} = '<!DOCTYPE html>
+$result_converted{'html'}->{'character_number_leading_toc_stoc'} = '<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
 <html>
 <!-- Created by texinfo, http://www.gnu.org/software/texinfo/ -->
 <head>
@@ -308,7 +315,21 @@ $result_converted{'html'}->{'character_number_leading_toc_stoc'} = '<!DOCTYPE ht
 <link href="#SEC_Contents" rel="contents" title="Table of Contents">
 <style type="text/css">
 <!--
-ul.toc-numbered-mark {list-style: none}
+a.copiable-anchor {visibility: hidden; text-decoration: none; line-height: 0em}
+a.summary-letter {text-decoration: none}
+blockquote.indentedblock {margin-right: 0em}
+div.display {margin-left: 3.2em}
+div.example {margin-left: 3.2em}
+kbd {font-style: oblique}
+pre.display {font-family: inherit}
+pre.format {font-family: inherit}
+pre.menu-comment {font-family: serif}
+pre.menu-preformatted {font-family: serif}
+span.nolinebreak {white-space: nowrap}
+span.roman {font-family: initial; font-weight: normal}
+span.sansserif {font-family: sans-serif; font-weight: normal}
+span:hover a.copiable-anchor {visibility: visible}
+ul.no-bullet {list-style: none}
 -->
 </style>
 
@@ -316,46 +337,46 @@ ul.toc-numbered-mark {list-style: none}
 </head>
 
 <body lang="en">
-<div class="top-level-extent" id="top">
+<div class="top" id="top">
 <h1 class="top">top</h1>
-<div class="element-contents" id="SEC_Contents">
+<div class="Contents_element" id="SEC_Contents">
 <h2 class="contents-heading">Table of Contents</h2>
 
 <div class="contents">
 
-<ul class="toc-numbered-mark">
+<ul class="no-bullet">
   <li><a id="toc-0" href="#g_t0">1 0</a></li>
   <li><a id="toc-_005f" href="#g_t_005f">_</a>
-  <ul class="toc-numbered-mark">
+  <ul class="no-bullet">
     <li><a id="toc-_003f" href="#g_t_003f">?</a></li>
   </ul></li>
 </ul>
 </div>
 </div>
-<div class="element-shortcontents" id="SEC_Shortcontents">
+<div class="Overview_element" id="SEC_Overview">
 <h2 class="shortcontents-heading">Short Table of Contents</h2>
 
 <div class="shortcontents">
-<ul class="toc-numbered-mark">
+<ul class="no-bullet">
 <li><a id="stoc-0" href="#toc-0">1 0</a></li>
 <li><a id="stoc-_005f" href="#toc-_005f">_</a></li>
 </ul>
 </div>
 </div>
-<div class="chapter-level-extent" id="g_t0">
+<div class="chapter" id="g_t0">
 <h2 class="chapter">1 0</h2>
 </div>
-<div class="unnumbered-level-extent" id="g_t_005f">
+<div class="unnumbered" id="g_t_005f">
 <h2 class="unnumbered">_</h2>
-<ul class="mini-toc">
+<ul class="section-toc">
 <li><a href="#g_t_003f" accesskey="1">?</a></li>
 </ul>
-<div class="section-level-extent" id="g_t_003f">
+<div class="section" id="g_t_003f">
 <h3 class="section">?</h3>
 
 
 
-</div>
+<hr></div>
 </div>
 </div>
 
