@@ -64,7 +64,14 @@ $result_trees{'commands_in_alt'} = {
       ],
       'cmdname' => 'image',
       'contents' => [],
-      'line_nr' => {},
+      'extra' => {
+        'input_perl_encoding' => 'utf-8'
+      },
+      'line_nr' => {
+        'file_name' => '',
+        'line_nr' => 1,
+        'macro' => ''
+      },
       'parent' => {}
     },
     {
@@ -149,7 +156,14 @@ $result_trees{'commands_in_alt'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'line_nr' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 4,
+                'macro' => ''
+              },
               'parent' => {}
             },
             {
@@ -214,7 +228,6 @@ $result_trees{'commands_in_alt'}{'contents'}[0]{'args'}[3]{'contents'}[1]{'args'
 $result_trees{'commands_in_alt'}{'contents'}[0]{'args'}[3]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'commands_in_alt'}{'contents'}[0]{'args'}[3]{'contents'}[1];
 $result_trees{'commands_in_alt'}{'contents'}[0]{'args'}[3]{'contents'}[1]{'parent'} = $result_trees{'commands_in_alt'}{'contents'}[0]{'args'}[3];
 $result_trees{'commands_in_alt'}{'contents'}[0]{'args'}[3]{'parent'} = $result_trees{'commands_in_alt'}{'contents'}[0];
-$result_trees{'commands_in_alt'}{'contents'}[0]{'line_nr'} = $result_trees{'commands_in_alt'}{'contents'}[0]{'args'}[3]{'contents'}[1]{'line_nr'};
 $result_trees{'commands_in_alt'}{'contents'}[0]{'parent'} = $result_trees{'commands_in_alt'};
 $result_trees{'commands_in_alt'}{'contents'}[1]{'parent'} = $result_trees{'commands_in_alt'};
 $result_trees{'commands_in_alt'}{'contents'}[2]{'parent'} = $result_trees{'commands_in_alt'};
@@ -229,7 +242,6 @@ $result_trees{'commands_in_alt'}{'contents'}[3]{'contents'}[1]{'contents'}[0]{'a
 $result_trees{'commands_in_alt'}{'contents'}[3]{'contents'}[1]{'contents'}[0]{'args'}[3]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'commands_in_alt'}{'contents'}[3]{'contents'}[1]{'contents'}[0]{'args'}[3]{'contents'}[1];
 $result_trees{'commands_in_alt'}{'contents'}[3]{'contents'}[1]{'contents'}[0]{'args'}[3]{'contents'}[1]{'parent'} = $result_trees{'commands_in_alt'}{'contents'}[3]{'contents'}[1]{'contents'}[0]{'args'}[3];
 $result_trees{'commands_in_alt'}{'contents'}[3]{'contents'}[1]{'contents'}[0]{'args'}[3]{'parent'} = $result_trees{'commands_in_alt'}{'contents'}[3]{'contents'}[1]{'contents'}[0];
-$result_trees{'commands_in_alt'}{'contents'}[3]{'contents'}[1]{'contents'}[0]{'line_nr'} = $result_trees{'commands_in_alt'}{'contents'}[3]{'contents'}[1]{'contents'}[0]{'args'}[3]{'contents'}[1]{'line_nr'};
 $result_trees{'commands_in_alt'}{'contents'}[3]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'commands_in_alt'}{'contents'}[3]{'contents'}[1];
 $result_trees{'commands_in_alt'}{'contents'}[3]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'commands_in_alt'}{'contents'}[3]{'contents'}[1];
 $result_trees{'commands_in_alt'}{'contents'}[3]{'contents'}[1]{'parent'} = $result_trees{'commands_in_alt'}{'contents'}[3];
@@ -255,6 +267,9 @@ f--ile
 $result_errors{'commands_in_alt'} = [];
 
 
+$result_floats{'commands_in_alt'} = {};
+
+
 
 $result_converted{'html'}->{'commands_in_alt'} = '<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
 <html>
@@ -267,13 +282,15 @@ $result_converted{'html'}->{'commands_in_alt'} = '<!DOCTYPE html PUBLIC "-//W3C/
 <meta name="keywords" content="Untitled Document">
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
+<meta name="viewport" content="width=device-width,initial-scale=1">
+
 <style type="text/css">
 <!--
+a.copiable-anchor {visibility: hidden; text-decoration: none; line-height: 0em}
 a.summary-letter {text-decoration: none}
 blockquote.indentedblock {margin-right: 0em}
 div.display {margin-left: 3.2em}
 div.example {margin-left: 3.2em}
-div.lisp {margin-left: 3.2em}
 kbd {font-style: oblique}
 pre.display {font-family: inherit}
 pre.format {font-family: inherit}
@@ -282,6 +299,7 @@ pre.menu-preformatted {font-family: serif}
 span.nolinebreak {white-space: nowrap}
 span.roman {font-family: initial; font-weight: normal}
 span.sansserif {font-family: sans-serif; font-weight: normal}
+span:hover a.copiable-anchor {visibility: visible}
 ul.no-bullet {list-style: none}
 -->
 </style>
@@ -293,7 +311,7 @@ ul.no-bullet {list-style: none}
 <img src="f--ile.png" alt="alt &ndash; in b">
 
 <div class="example">
-<pre class="example">[ alt -- <b>in b</b> ]
+<pre class="example"><img src="f--ile.png" alt="alt &ndash; in b">
 </pre></div>
 
 
