@@ -17,27 +17,17 @@ $result_trees{'index_below'} = [
         'args' => [
           {
             'contents' => [
-              {
-                'extra' => {
-                  'command' => {}
-                },
-                'parent' => {},
-                'text' => ' ',
-                'type' => 'empty_spaces_after_command'
-              },
               {
                 'parent' => {},
                 'text' => 'top'
-              },
-              {
-                'parent' => {},
-                'text' => '
-',
-                'type' => 'spaces_at_end'
               }
             ],
+            'extra' => {
+              'spaces_after_argument' => '
+'
+            },
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           }
         ],
         'cmdname' => 'top',
@@ -50,10 +40,7 @@ $result_trees{'index_below'} = [
           }
         ],
         'extra' => {
-          'misc_content' => [
-            {}
-          ],
-          'spaces_after_command' => {}
+          'spaces_before_argument' => ' '
         },
         'level' => 0,
         'line_nr' => {
@@ -76,27 +63,17 @@ $result_trees{'index_below'} = [
         'args' => [
           {
             'contents' => [
-              {
-                'extra' => {
-                  'command' => {}
-                },
-                'parent' => {},
-                'text' => ' ',
-                'type' => 'empty_spaces_after_command'
-              },
               {
                 'parent' => {},
                 'text' => 'chap'
-              },
-              {
-                'parent' => {},
-                'text' => '
-',
-                'type' => 'spaces_at_end'
               }
             ],
+            'extra' => {
+              'spaces_after_argument' => '
+'
+            },
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           }
         ],
         'cmdname' => 'chapter',
@@ -109,10 +86,7 @@ $result_trees{'index_below'} = [
           }
         ],
         'extra' => {
-          'misc_content' => [
-            {}
-          ],
-          'spaces_after_command' => {}
+          'spaces_before_argument' => ' '
         },
         'level' => 1,
         'line_nr' => {
@@ -137,27 +111,17 @@ $result_trees{'index_below'} = [
         'args' => [
           {
             'contents' => [
-              {
-                'extra' => {
-                  'command' => {}
-                },
-                'parent' => {},
-                'text' => ' ',
-                'type' => 'empty_spaces_after_command'
-              },
               {
                 'parent' => {},
                 'text' => 'sec'
-              },
-              {
-                'parent' => {},
-                'text' => '
-',
-                'type' => 'spaces_at_end'
               }
             ],
+            'extra' => {
+              'spaces_after_argument' => '
+'
+            },
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           }
         ],
         'cmdname' => 'section',
@@ -172,36 +136,24 @@ $result_trees{'index_below'} = [
             'args' => [
               {
                 'contents' => [
-                  {
-                    'extra' => {
-                      'command' => {}
-                    },
-                    'parent' => {},
-                    'text' => ' ',
-                    'type' => 'empty_spaces_after_command'
-                  },
                   {
                     'parent' => {},
                     'text' => 'entry'
-                  },
-                  {
-                    'parent' => {},
-                    'text' => '
-',
-                    'type' => 'spaces_at_end'
                   }
                 ],
+                'extra' => {
+                  'spaces_after_argument' => '
+'
+                },
                 'parent' => {},
-                'type' => 'misc_line_arg'
+                'type' => 'line_arg'
               }
             ],
             'cmdname' => 'cindex',
             'extra' => {
               'index_entry' => {
                 'command' => {},
-                'content' => [
-                  {}
-                ],
+                'content' => [],
                 'content_normalized' => [],
                 'in_code' => 0,
                 'index_at_command' => 'cindex',
@@ -210,8 +162,7 @@ $result_trees{'index_below'} = [
                 'key' => 'entry',
                 'number' => 1
               },
-              'misc_content' => [],
-              'spaces_after_command' => {}
+              'spaces_before_argument' => ' '
             },
             'line_nr' => {
               'file_name' => '',
@@ -225,27 +176,17 @@ $result_trees{'index_below'} = [
             'args' => [
               {
                 'contents' => [
-                  {
-                    'extra' => {
-                      'command' => {}
-                    },
-                    'parent' => {},
-                    'text' => ' ',
-                    'type' => 'empty_spaces_after_command'
-                  },
                   {
                     'parent' => {},
                     'text' => 'cp'
-                  },
-                  {
-                    'parent' => {},
-                    'text' => '
-',
-                    'type' => 'spaces_at_end'
                   }
                 ],
+                'extra' => {
+                  'spaces_after_argument' => '
+'
+                },
                 'parent' => {},
-                'type' => 'misc_line_arg'
+                'type' => 'line_arg'
               }
             ],
             'cmdname' => 'printindex',
@@ -253,7 +194,7 @@ $result_trees{'index_below'} = [
               'misc_args' => [
                 'cp'
               ],
-              'spaces_after_command' => {}
+              'spaces_before_argument' => ' '
             },
             'line_nr' => {
               'file_name' => '',
@@ -264,10 +205,7 @@ $result_trees{'index_below'} = [
           }
         ],
         'extra' => {
-          'misc_content' => [
-            {}
-          ],
-          'spaces_after_command' => {}
+          'spaces_before_argument' => ' '
         },
         'level' => 2,
         'line_nr' => {
@@ -288,55 +226,31 @@ $result_trees{'index_below'} = [
   }
 ];
 $result_trees{'index_below'}[0]{'contents'}[0]{'parent'} = $result_trees{'index_below'}[0];
-$result_trees{'index_below'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'index_below'}[0]{'contents'}[1];
 $result_trees{'index_below'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'index_below'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'index_below'}[0]{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'index_below'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'index_below'}[0]{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'index_below'}[0]{'contents'}[1]{'args'}[0];
 $result_trees{'index_below'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'index_below'}[0]{'contents'}[1];
 $result_trees{'index_below'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'index_below'}[0]{'contents'}[1];
-$result_trees{'index_below'}[0]{'contents'}[1]{'extra'}{'misc_content'}[0] = $result_trees{'index_below'}[0]{'contents'}[1]{'args'}[0]{'contents'}[1];
-$result_trees{'index_below'}[0]{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'index_below'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'index_below'}[0]{'contents'}[1]{'parent'} = $result_trees{'index_below'}[0];
 $result_trees{'index_below'}[0]{'extra'}{'element_command'} = $result_trees{'index_below'}[0]{'contents'}[1];
 $result_trees{'index_below'}[0]{'extra'}{'section'} = $result_trees{'index_below'}[0]{'contents'}[1];
-$result_trees{'index_below'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'index_below'}[1]{'contents'}[0];
 $result_trees{'index_below'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'index_below'}[1]{'contents'}[0]{'args'}[0];
-$result_trees{'index_below'}[1]{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'index_below'}[1]{'contents'}[0]{'args'}[0];
-$result_trees{'index_below'}[1]{'contents'}[0]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'index_below'}[1]{'contents'}[0]{'args'}[0];
 $result_trees{'index_below'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'index_below'}[1]{'contents'}[0];
 $result_trees{'index_below'}[1]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'index_below'}[1]{'contents'}[0];
-$result_trees{'index_below'}[1]{'contents'}[0]{'extra'}{'misc_content'}[0] = $result_trees{'index_below'}[1]{'contents'}[0]{'args'}[0]{'contents'}[1];
-$result_trees{'index_below'}[1]{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'index_below'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'index_below'}[1]{'contents'}[0]{'parent'} = $result_trees{'index_below'}[1];
 $result_trees{'index_below'}[1]{'element_prev'} = $result_trees{'index_below'}[0];
 $result_trees{'index_below'}[1]{'extra'}{'element_command'} = $result_trees{'index_below'}[1]{'contents'}[0];
 $result_trees{'index_below'}[1]{'extra'}{'section'} = $result_trees{'index_below'}[1]{'contents'}[0];
-$result_trees{'index_below'}[2]{'contents'}[0]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'index_below'}[2]{'contents'}[0];
 $result_trees{'index_below'}[2]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'index_below'}[2]{'contents'}[0]{'args'}[0];
-$result_trees{'index_below'}[2]{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'index_below'}[2]{'contents'}[0]{'args'}[0];
-$result_trees{'index_below'}[2]{'contents'}[0]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'index_below'}[2]{'contents'}[0]{'args'}[0];
 $result_trees{'index_below'}[2]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'index_below'}[2]{'contents'}[0];
 $result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'index_below'}[2]{'contents'}[0];
-$result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[1];
 $result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[1]{'args'}[0];
 $result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[1];
 $result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[1]{'extra'}{'index_entry'}{'command'} = $result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[1];
-$result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[1]{'extra'}{'index_entry'}{'content'}[0] = $result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[1];
-$result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[1]{'extra'}{'index_entry'}{'content_normalized'} = $result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[1]{'extra'}{'index_entry'}{'content'};
-$result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[1]{'extra'}{'misc_content'} = $result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[1]{'extra'}{'index_entry'}{'content'};
-$result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0];
+$result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[1]{'extra'}{'index_entry'}{'content'} = $result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'};
+$result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[1]{'extra'}{'index_entry'}{'content_normalized'} = $result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'};
 $result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'index_below'}[2]{'contents'}[0];
-$result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[2];
 $result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[2]{'args'}[0];
-$result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[2]{'args'}[0];
-$result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[2]{'args'}[0];
 $result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[2];
-$result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'index_below'}[2]{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'index_below'}[2]{'contents'}[0];
-$result_trees{'index_below'}[2]{'contents'}[0]{'extra'}{'misc_content'}[0] = $result_trees{'index_below'}[2]{'contents'}[0]{'args'}[0]{'contents'}[1];
-$result_trees{'index_below'}[2]{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'index_below'}[2]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'index_below'}[2]{'contents'}[0]{'parent'} = $result_trees{'index_below'}[2];
 $result_trees{'index_below'}[2]{'element_prev'} = $result_trees{'index_below'}[1];
 $result_trees{'index_below'}[2]{'extra'}{'element_command'} = $result_trees{'index_below'}[2]{'contents'}[0];
@@ -369,18 +283,24 @@ $result_sectioning{'index_below'} = {
   'section_childs' => [
     {
       'cmdname' => 'top',
-      'extra' => {},
+      'extra' => {
+        'spaces_before_argument' => ' '
+      },
       'level' => 0,
       'section_childs' => [
         {
           'cmdname' => 'chapter',
-          'extra' => {},
+          'extra' => {
+            'spaces_before_argument' => ' '
+          },
           'level' => 1,
           'number' => 1,
           'section_childs' => [
             {
               'cmdname' => 'section',
-              'extra' => {},
+              'extra' => {
+                'spaces_before_argument' => ' '
+              },
               'level' => 2,
               'number' => '1.1',
               'section_up' => {}
@@ -404,6 +324,9 @@ $result_sectioning{'index_below'}{'section_childs'}[0]{'section_up'} = $result_s
 $result_errors{'index_below'} = [];
 
 
+$result_floats{'index_below'} = {};
+
+
 $result_elements{'index_below'} = [
   {
     'extra' => {
@@ -423,7 +346,9 @@ $result_elements{'index_below'} = [
                   },
                   'element_command' => {
                     'cmdname' => 'section',
-                    'extra' => {},
+                    'extra' => {
+                      'spaces_before_argument' => ' '
+                    },
                     'level' => 2,
                     'number' => '1.1'
                   },
@@ -436,7 +361,9 @@ $result_elements{'index_below'} = [
             },
             'element_command' => {
               'cmdname' => 'chapter',
-              'extra' => {},
+              'extra' => {
+                'spaces_before_argument' => ' '
+              },
               'level' => 1,
               'number' => 1
             },
@@ -449,7 +376,9 @@ $result_elements{'index_below'} = [
       },
       'element_command' => {
         'cmdname' => 'top',
-        'extra' => {},
+        'extra' => {
+          'spaces_before_argument' => ' '
+        },
         'level' => 0
       },
       'section' => {}
@@ -506,32 +435,26 @@ $result_converted{'html'}->{'index_below'} = '<!DOCTYPE html PUBLIC "-//W3C//DTD
 <meta name="keywords" content="top">
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
+<meta name="viewport" content="width=device-width,initial-scale=1">
+
 <link href="#top" rel="start" title="top">
 <link href="#chap" rel="index" title="1 chap">
 <style type="text/css">
 <!--
+a.copiable-anchor {visibility: hidden; text-decoration: none; line-height: 0em}
 a.summary-letter {text-decoration: none}
 blockquote.indentedblock {margin-right: 0em}
-blockquote.smallindentedblock {margin-right: 0em; font-size: smaller}
-blockquote.smallquotation {font-size: smaller}
 div.display {margin-left: 3.2em}
 div.example {margin-left: 3.2em}
-div.lisp {margin-left: 3.2em}
-div.smalldisplay {margin-left: 3.2em}
-div.smallexample {margin-left: 3.2em}
-div.smalllisp {margin-left: 3.2em}
 kbd {font-style: oblique}
 pre.display {font-family: inherit}
 pre.format {font-family: inherit}
 pre.menu-comment {font-family: serif}
 pre.menu-preformatted {font-family: serif}
-pre.smalldisplay {font-family: inherit; font-size: smaller}
-pre.smallexample {font-size: smaller}
-pre.smallformat {font-family: inherit; font-size: smaller}
-pre.smalllisp {font-size: smaller}
 span.nolinebreak {white-space: nowrap}
 span.roman {font-family: initial; font-weight: normal}
 span.sansserif {font-family: sans-serif; font-weight: normal}
+span:hover a.copiable-anchor {visibility: visible}
 ul.no-bullet {list-style: none}
 -->
 </style>
@@ -540,44 +463,52 @@ ul.no-bullet {list-style: none}
 </head>
 
 <body lang="en">
-<a name="top"></a>
+<div class="top" id="top">
 <div class="header">
 <p>
  &nbsp; [<a href="#chap" title="Index" rel="index">Index</a>]</p>
 </div>
 <h1 class="top">top</h1>
 
+<ul class="section-toc">
+<li><a href="#chap" accesskey="1">chap</a></li>
+</ul>
 <hr>
-<a name="chap"></a>
+<div class="chapter" id="chap">
 <div class="header">
 <p>
- &nbsp; [<a href="#chap" title="Index" rel="index">Index</a>]</p>
+ Up : <a href="#top" accesskey="u" rel="up">top</a> &nbsp; [<a href="#chap" title="Index" rel="index">Index</a>]</p>
 </div>
 <h2 class="chapter">1 chap</h2>
 
+<ul class="section-toc">
+<li><a href="#sec" accesskey="1">sec</a></li>
+</ul>
 <hr>
-<a name="sec"></a>
+<div class="section" id="sec">
 <div class="header">
 <p>
- &nbsp; [<a href="#chap" title="Index" rel="index">Index</a>]</p>
+ Up : <a href="#chap" accesskey="u" rel="up">chap</a> &nbsp; [<a href="#chap" title="Index" rel="index">Index</a>]</p>
 </div>
 <h3 class="section">1.1 sec</h3>
 
-<a name="index-entry"></a>
+<span id="index-entry"></span>
 <table><tr><th valign="top">Jump to: &nbsp; </th><td><a class="summary-letter" href="#sec_cp_letter-E"><b>E</b></a>
  &nbsp; 
 </td></tr></table>
 <table class="index-cp" border="0">
 <tr><td></td><th align="left">Index Entry</th><td>&nbsp;</td><th align="left"> Section</th></tr>
 <tr><td colspan="4"> <hr></td></tr>
-<tr><th><a name="sec_cp_letter-E">E</a></th><td></td><td></td></tr>
+<tr><th id="sec_cp_letter-E">E</th><td></td><td></td></tr>
 <tr><td></td><td valign="top"><a href="#index-entry">entry</a>:</td><td>&nbsp;</td><td valign="top"><a href="#sec">1.1 sec</a></td></tr>
 <tr><td colspan="4"> <hr></td></tr>
 </table>
 <table><tr><th valign="top">Jump to: &nbsp; </th><td><a class="summary-letter" href="#sec_cp_letter-E"><b>E</b></a>
  &nbsp; 
 </td></tr></table>
-<hr>
+</div>
+</div>
+</div>
 
 
 
