@@ -34,34 +34,23 @@ $result_trees{'raw_html'} = {
           'args' => [
             {
               'contents' => [
-                {
-                  'extra' => {
-                    'command' => {}
-                  },
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_after_command'
-                },
                 {
                   'parent' => {},
                   'text' => 'html'
-                },
-                {
-                  'parent' => {},
-                  'text' => '
-',
-                  'type' => 'spaces_at_end'
                 }
               ],
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
               'parent' => {},
-              'type' => 'misc_line_arg'
+              'type' => 'line_arg'
             }
           ],
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
             'command_argument' => 'html',
-            'spaces_after_command' => {},
+            'spaces_before_argument' => ' ',
             'text_arg' => 'html'
           },
           'line_nr' => {
@@ -73,8 +62,7 @@ $result_trees{'raw_html'} = {
         }
       ],
       'extra' => {
-        'end_command' => {},
-        'spaces_after_command' => {}
+        'end_command' => {}
       },
       'line_nr' => {
         'file_name' => '',
@@ -90,16 +78,10 @@ $result_trees{'raw_html'}{'contents'}[0]{'contents'}[0]{'extra'}{'command'} = $r
 $result_trees{'raw_html'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'raw_html'}{'contents'}[0];
 $result_trees{'raw_html'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'raw_html'}{'contents'}[0]{'contents'}[1];
 $result_trees{'raw_html'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'raw_html'}{'contents'}[0];
-$result_trees{'raw_html'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'raw_html'}{'contents'}[0]{'contents'}[2];
 $result_trees{'raw_html'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'raw_html'}{'contents'}[0]{'contents'}[2]{'args'}[0];
-$result_trees{'raw_html'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'raw_html'}{'contents'}[0]{'contents'}[2]{'args'}[0];
-$result_trees{'raw_html'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'raw_html'}{'contents'}[0]{'contents'}[2]{'args'}[0];
 $result_trees{'raw_html'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'raw_html'}{'contents'}[0]{'contents'}[2];
-$result_trees{'raw_html'}{'contents'}[0]{'contents'}[2]{'extra'}{'command'} = $result_trees{'raw_html'}{'contents'}[0];
-$result_trees{'raw_html'}{'contents'}[0]{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'raw_html'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'raw_html'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'raw_html'}{'contents'}[0];
 $result_trees{'raw_html'}{'contents'}[0]{'extra'}{'end_command'} = $result_trees{'raw_html'}{'contents'}[0]{'contents'}[2];
-$result_trees{'raw_html'}{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'raw_html'}{'contents'}[0]{'contents'}[0];
 $result_trees{'raw_html'}{'contents'}[0]{'parent'} = $result_trees{'raw_html'};
 
 $result_texis{'raw_html'} = '@html
@@ -113,6 +95,9 @@ $result_texts{'raw_html'} = '';
 $result_errors{'raw_html'} = [];
 
 
+$result_floats{'raw_html'} = {};
+
+
 
 $result_converted{'html'}->{'raw_html'} = '<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
 <html>
@@ -125,30 +110,24 @@ $result_converted{'html'}->{'raw_html'} = '<!DOCTYPE html PUBLIC "-//W3C//DTD HT
 <meta name="keywords" content="Untitled Document">
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
+<meta name="viewport" content="width=device-width,initial-scale=1">
+
 <style type="text/css">
 <!--
+a.copiable-anchor {visibility: hidden; text-decoration: none; line-height: 0em}
 a.summary-letter {text-decoration: none}
 blockquote.indentedblock {margin-right: 0em}
-blockquote.smallindentedblock {margin-right: 0em; font-size: smaller}
-blockquote.smallquotation {font-size: smaller}
 div.display {margin-left: 3.2em}
 div.example {margin-left: 3.2em}
-div.lisp {margin-left: 3.2em}
-div.smalldisplay {margin-left: 3.2em}
-div.smallexample {margin-left: 3.2em}
-div.smalllisp {margin-left: 3.2em}
 kbd {font-style: oblique}
 pre.display {font-family: inherit}
 pre.format {font-family: inherit}
 pre.menu-comment {font-family: serif}
 pre.menu-preformatted {font-family: serif}
-pre.smalldisplay {font-family: inherit; font-size: smaller}
-pre.smallexample {font-size: smaller}
-pre.smallformat {font-family: inherit; font-size: smaller}
-pre.smalllisp {font-size: smaller}
 span.nolinebreak {white-space: nowrap}
 span.roman {font-family: initial; font-weight: normal}
 span.sansserif {font-family: sans-serif; font-weight: normal}
+span:hover a.copiable-anchor {visibility: visible}
 ul.no-bullet {list-style: none}
 -->
 </style>
