@@ -11,34 +11,24 @@ $result_trees{'utf8_enable_encoding_no_use_iso'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'utf-8'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'documentencoding',
       'extra' => {
         'input_encoding_name' => 'utf-8',
         'input_perl_encoding' => 'utf-8-strict',
-        'spaces_after_command' => {},
+        'spaces_before_argument' => ' ',
         'text_arg' => 'utf-8'
       },
       'line_nr' => {
@@ -93,12 +83,8 @@ $result_trees{'utf8_enable_encoding_no_use_iso'} = {
   ],
   'type' => 'text_root'
 };
-$result_trees{'utf8_enable_encoding_no_use_iso'}{'contents'}[0]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'utf8_enable_encoding_no_use_iso'}{'contents'}[0];
 $result_trees{'utf8_enable_encoding_no_use_iso'}{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'utf8_enable_encoding_no_use_iso'}{'contents'}[0]{'args'}[0];
-$result_trees{'utf8_enable_encoding_no_use_iso'}{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'utf8_enable_encoding_no_use_iso'}{'contents'}[0]{'args'}[0];
-$result_trees{'utf8_enable_encoding_no_use_iso'}{'contents'}[0]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'utf8_enable_encoding_no_use_iso'}{'contents'}[0]{'args'}[0];
 $result_trees{'utf8_enable_encoding_no_use_iso'}{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'utf8_enable_encoding_no_use_iso'}{'contents'}[0];
-$result_trees{'utf8_enable_encoding_no_use_iso'}{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'utf8_enable_encoding_no_use_iso'}{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'utf8_enable_encoding_no_use_iso'}{'contents'}[0]{'parent'} = $result_trees{'utf8_enable_encoding_no_use_iso'};
 $result_trees{'utf8_enable_encoding_no_use_iso'}{'contents'}[1]{'parent'} = $result_trees{'utf8_enable_encoding_no_use_iso'};
 $result_trees{'utf8_enable_encoding_no_use_iso'}{'contents'}[2]{'contents'}[0]{'parent'} = $result_trees{'utf8_enable_encoding_no_use_iso'}{'contents'}[2];
@@ -119,6 +105,9 @@ AA e^ -- - \'` " "';
 $result_errors{'utf8_enable_encoding_no_use_iso'} = [];
 
 
+$result_floats{'utf8_enable_encoding_no_use_iso'} = {};
+
+
 
 $result_converted{'html_text'}->{'utf8_enable_encoding_no_use_iso'} = '
 <p>AA ê -- - \'` &quot; &quot;</p>';
