@@ -26,9 +26,6 @@ $result_trees{'xml_protected_in_verb'} = {
           'type' => 'raw'
         }
       ],
-      'extra' => {
-        'spaces_after_command' => {}
-      },
       'line_nr' => {
         'file_name' => '',
         'line_nr' => 1,
@@ -37,9 +34,6 @@ $result_trees{'xml_protected_in_verb'} = {
       'parent' => {}
     },
     {
-      'extra' => {
-        'command' => {}
-      },
       'parent' => {},
       'text' => '
 ',
@@ -69,13 +63,15 @@ $result_trees{'xml_protected_in_verb'} = {
           ],
           'cmdname' => 'verb',
           'contents' => [],
+          'extra' => {
+            'delimiter' => '.'
+          },
           'line_nr' => {
             'file_name' => '',
             'line_nr' => 5,
             'macro' => ''
           },
-          'parent' => {},
-          'type' => '.'
+          'parent' => {}
         },
         {
           'parent' => {},
@@ -96,32 +92,23 @@ $result_trees{'xml_protected_in_verb'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'file_with_xml_chars.texi'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'verbatiminclude',
       'extra' => {
-        'spaces_after_command' => {},
+        'input_perl_encoding' => 'utf-8',
+        'spaces_before_argument' => ' ',
         'text_arg' => 'file_with_xml_chars.texi'
       },
       'line_nr' => {
@@ -137,9 +124,7 @@ $result_trees{'xml_protected_in_verb'} = {
 $result_trees{'xml_protected_in_verb'}{'contents'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'xml_protected_in_verb'}{'contents'}[0];
 $result_trees{'xml_protected_in_verb'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'xml_protected_in_verb'}{'contents'}[0];
 $result_trees{'xml_protected_in_verb'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'xml_protected_in_verb'}{'contents'}[0];
-$result_trees{'xml_protected_in_verb'}{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'xml_protected_in_verb'}{'contents'}[0]{'contents'}[0];
 $result_trees{'xml_protected_in_verb'}{'contents'}[0]{'parent'} = $result_trees{'xml_protected_in_verb'};
-$result_trees{'xml_protected_in_verb'}{'contents'}[1]{'extra'}{'command'} = $result_trees{'xml_protected_in_verb'}{'contents'}[0];
 $result_trees{'xml_protected_in_verb'}{'contents'}[1]{'parent'} = $result_trees{'xml_protected_in_verb'};
 $result_trees{'xml_protected_in_verb'}{'contents'}[2]{'parent'} = $result_trees{'xml_protected_in_verb'};
 $result_trees{'xml_protected_in_verb'}{'contents'}[3]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'xml_protected_in_verb'}{'contents'}[3]{'contents'}[0]{'args'}[0];
@@ -148,12 +133,8 @@ $result_trees{'xml_protected_in_verb'}{'contents'}[3]{'contents'}[0]{'parent'} =
 $result_trees{'xml_protected_in_verb'}{'contents'}[3]{'contents'}[1]{'parent'} = $result_trees{'xml_protected_in_verb'}{'contents'}[3];
 $result_trees{'xml_protected_in_verb'}{'contents'}[3]{'parent'} = $result_trees{'xml_protected_in_verb'};
 $result_trees{'xml_protected_in_verb'}{'contents'}[4]{'parent'} = $result_trees{'xml_protected_in_verb'};
-$result_trees{'xml_protected_in_verb'}{'contents'}[5]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'xml_protected_in_verb'}{'contents'}[5];
 $result_trees{'xml_protected_in_verb'}{'contents'}[5]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'xml_protected_in_verb'}{'contents'}[5]{'args'}[0];
-$result_trees{'xml_protected_in_verb'}{'contents'}[5]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'xml_protected_in_verb'}{'contents'}[5]{'args'}[0];
-$result_trees{'xml_protected_in_verb'}{'contents'}[5]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'xml_protected_in_verb'}{'contents'}[5]{'args'}[0];
 $result_trees{'xml_protected_in_verb'}{'contents'}[5]{'args'}[0]{'parent'} = $result_trees{'xml_protected_in_verb'}{'contents'}[5];
-$result_trees{'xml_protected_in_verb'}{'contents'}[5]{'extra'}{'spaces_after_command'} = $result_trees{'xml_protected_in_verb'}{'contents'}[5]{'args'}[0]{'contents'}[0];
 $result_trees{'xml_protected_in_verb'}{'contents'}[5]{'parent'} = $result_trees{'xml_protected_in_verb'};
 
 $result_texis{'xml_protected_in_verb'} = '@verbatim
@@ -175,6 +156,9 @@ $result_texts{'xml_protected_in_verb'} = '<a>
 $result_errors{'xml_protected_in_verb'} = [];
 
 
+$result_floats{'xml_protected_in_verb'} = {};
+
+
 
 $result_converted{'html'}->{'xml_protected_in_verb'} = '<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
 <html>
@@ -187,30 +171,24 @@ $result_converted{'html'}->{'xml_protected_in_verb'} = '<!DOCTYPE html PUBLIC "-
 <meta name="keywords" content="Untitled Document">
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
+<meta name="viewport" content="width=device-width,initial-scale=1">
+
 <style type="text/css">
 <!--
+a.copiable-anchor {visibility: hidden; text-decoration: none; line-height: 0em}
 a.summary-letter {text-decoration: none}
 blockquote.indentedblock {margin-right: 0em}
-blockquote.smallindentedblock {margin-right: 0em; font-size: smaller}
-blockquote.smallquotation {font-size: smaller}
 div.display {margin-left: 3.2em}
 div.example {margin-left: 3.2em}
-div.lisp {margin-left: 3.2em}
-div.smalldisplay {margin-left: 3.2em}
-div.smallexample {margin-left: 3.2em}
-div.smalllisp {margin-left: 3.2em}
 kbd {font-style: oblique}
 pre.display {font-family: inherit}
 pre.format {font-family: inherit}
 pre.menu-comment {font-family: serif}
 pre.menu-preformatted {font-family: serif}
-pre.smalldisplay {font-family: inherit; font-size: smaller}
-pre.smallexample {font-size: smaller}
-pre.smallformat {font-family: inherit; font-size: smaller}
-pre.smalllisp {font-size: smaller}
 span.nolinebreak {white-space: nowrap}
 span.roman {font-family: initial; font-weight: normal}
 span.sansserif {font-family: sans-serif; font-weight: normal}
+span:hover a.copiable-anchor {visibility: visible}
 ul.no-bullet {list-style: none}
 -->
 </style>
