@@ -11,14 +11,6 @@ $result_trees{'include_at_end_line'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'inc_file.texi'
@@ -30,12 +22,12 @@ $result_trees{'include_at_end_line'} = {
             }
           ],
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'include',
       'extra' => {
-        'spaces_after_command' => {},
+        'spaces_before_argument' => ' ',
         'text_arg' => 'inc_file.texi'
       },
       'line_nr' => {
@@ -64,12 +56,9 @@ $result_trees{'include_at_end_line'} = {
   ],
   'type' => 'text_root'
 };
-$result_trees{'include_at_end_line'}{'contents'}[0]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'include_at_end_line'}{'contents'}[0];
 $result_trees{'include_at_end_line'}{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'include_at_end_line'}{'contents'}[0]{'args'}[0];
 $result_trees{'include_at_end_line'}{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'include_at_end_line'}{'contents'}[0]{'args'}[0];
-$result_trees{'include_at_end_line'}{'contents'}[0]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'include_at_end_line'}{'contents'}[0]{'args'}[0];
 $result_trees{'include_at_end_line'}{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'include_at_end_line'}{'contents'}[0];
-$result_trees{'include_at_end_line'}{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'include_at_end_line'}{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'include_at_end_line'}{'contents'}[0]{'parent'} = $result_trees{'include_at_end_line'};
 $result_trees{'include_at_end_line'}{'contents'}[1]{'parent'} = $result_trees{'include_at_end_line'};
 $result_trees{'include_at_end_line'}{'contents'}[2]{'contents'}[0]{'parent'} = $result_trees{'include_at_end_line'}{'contents'}[2];
@@ -96,4 +85,7 @@ $result_errors{'include_at_end_line'} = [
 ];
 
 
+$result_floats{'include_at_end_line'} = {};
+
+
 1;
