@@ -267,7 +267,11 @@ $result_trees{'ftable_vtable'} = {
             'end_command' => {},
             'spaces_before_argument' => ' '
           },
-          'line_nr' => {},
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 4,
+            'macro' => ''
+          },
           'parent' => {}
         },
         {
@@ -350,13 +354,17 @@ $result_trees{'ftable_vtable'} = {
                           'index_at_command' => 'item',
                           'index_name' => 'vr',
                           'index_type_command' => 'vtable',
-                          'key' => 'var1 error->',
+                          'key' => 'var1 error-->',
                           'node' => {},
                           'number' => 1
                         },
                         'spaces_before_argument' => ' '
                       },
-                      'line_nr' => {},
+                      'line_nr' => {
+                        'file_name' => '',
+                        'line_nr' => 12,
+                        'macro' => ''
+                      },
                       'parent' => {}
                     },
                     {
@@ -512,7 +520,11 @@ $result_trees{'ftable_vtable'} = {
             'end_command' => {},
             'spaces_before_argument' => ' '
           },
-          'line_nr' => {},
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 11,
+            'macro' => ''
+          },
           'parent' => {}
         },
         {
@@ -650,7 +662,9 @@ $result_trees{'ftable_vtable'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -707,7 +721,6 @@ $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'arg
 $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[1];
 $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[1]{'extra'}{'command_as_argument'} = $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[1]{'extra'}{'end_command'} = $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[1]{'contents'}[2];
-$result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[1]{'line_nr'} = $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'ftable_vtable'}{'contents'}[1];
 $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'ftable_vtable'}{'contents'}[1];
 $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[3]{'args'}[0];
@@ -720,7 +733,6 @@ $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[3]{'contents'}[0]{'con
 $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[3]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'extra'}{'index_entry'}{'content'} = $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[3]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'};
 $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[3]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'extra'}{'index_entry'}{'content_normalized'} = $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[3]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'};
 $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[3]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'extra'}{'index_entry'}{'node'} = $result_trees{'ftable_vtable'}{'contents'}[1];
-$result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[3]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'line_nr'} = $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[3]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[3]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[3]{'contents'}[0]{'contents'}[0];
 $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[3]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[3]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'args'}[0];
 $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[3]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[3]{'contents'}[0]{'contents'}[0]{'contents'}[1];
@@ -748,7 +760,6 @@ $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[3]{'contents'}[2]{'arg
 $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[3]{'contents'}[2]{'parent'} = $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[3];
 $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[3]{'extra'}{'command_as_argument'} = $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[3]{'extra'}{'end_command'} = $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[3]{'contents'}[2];
-$result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[3]{'line_nr'} = $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'ftable_vtable'}{'contents'}[1];
 $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[4]{'parent'} = $result_trees{'ftable_vtable'}{'contents'}[1];
 $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[5]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[5]{'args'}[0];
@@ -768,7 +779,7 @@ $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[9]{'args'}[0]{'parent'
 $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[9]{'parent'} = $result_trees{'ftable_vtable'}{'contents'}[1];
 $result_trees{'ftable_vtable'}{'contents'}[1]{'contents'}[10]{'parent'} = $result_trees{'ftable_vtable'}{'contents'}[1];
 $result_trees{'ftable_vtable'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'ftable_vtable'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'ftable_vtable'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'ftable_vtable'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'ftable_vtable'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'ftable_vtable'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'ftable_vtable'}{'contents'}[1]{'parent'} = $result_trees{'ftable_vtable'};
 
 $result_texis{'ftable_vtable'} = '
@@ -837,6 +848,9 @@ $result_menus{'ftable_vtable'} = {
 $result_errors{'ftable_vtable'} = [];
 
 
+$result_floats{'ftable_vtable'} = {};
+
+
 
 $result_converted{'info'}->{'ftable_vtable'} = 'This is , produced from .
 
@@ -912,31 +926,19 @@ $result_converted{'html_text'}->{'ftable_vtable'} = '
 <span id="Top"></span><h1 class="node-heading">Top</h1>
 
 <dl compact="compact">
-<dt><em>function1</em>
-<span id="index-function1"></span>
-</dt>
-<dt><em>function2x</em>
-<span id="index-function2x"></span>
-</dt>
+<dt id=\'index-function1\'><span><em>function1</em><a href=\'#index-function1\' class=\'copiable-anchor\'> &para;</a></span></dt>
+<dt id=\'index-function2x\'><span><em>function2x</em><a href=\'#index-function2x\' class=\'copiable-anchor\'> &para;</a></span></dt>
 <dd><p>Text
 </p></dd>
-<dt><em>fun3</em>
-<span id="index-fun3"></span>
-</dt>
+<dt id=\'index-fun3\'><span><em>fun3</em><a href=\'#index-fun3\' class=\'copiable-anchor\'> &para;</a></span></dt>
 </dl>
 
 <dl compact="compact">
-<dt><em>var1 error&rarr;</em>
-<span id="index-var1-error_002d_002d_003e"></span>
-</dt>
-<dt><em>varx2</em>
-<span id="index-varx2"></span>
-</dt>
+<dt id=\'index-var1-error_002d_002d_003e\'><span><em>var1 error&rarr;</em><a href=\'#index-var1-error_002d_002d_003e\' class=\'copiable-anchor\'> &para;</a></span></dt>
+<dt id=\'index-varx2\'><span><em>varx2</em><a href=\'#index-varx2\' class=\'copiable-anchor\'> &para;</a></span></dt>
 <dd><p>Text
 </p></dd>
-<dt><em>var3</em>
-<span id="index-var3"></span>
-</dt>
+<dt id=\'index-var3\'><span><em>var3</em><a href=\'#index-var3\' class=\'copiable-anchor\'> &para;</a></span></dt>
 </dl>
 
 <span id="index-function1-1"></span>
@@ -974,7 +976,6 @@ $result_converted{'html_text'}->{'ftable_vtable'} = '
  &nbsp; 
 </td></tr></table>
 
-<hr>
-';
+<hr>';
 
 1;
