@@ -123,12 +123,15 @@ $result_trees{'index_entry_before_first_node'} = {
         }
       ],
       'extra' => {
+        'isindex' => 1,
         'node_content' => [
           {}
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -161,7 +164,7 @@ $result_trees{'index_entry_before_first_node'}{'contents'}[1]{'contents'}[1]{'ar
 $result_trees{'index_entry_before_first_node'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'index_entry_before_first_node'}{'contents'}[1]{'contents'}[1];
 $result_trees{'index_entry_before_first_node'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'index_entry_before_first_node'}{'contents'}[1];
 $result_trees{'index_entry_before_first_node'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'index_entry_before_first_node'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'index_entry_before_first_node'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'index_entry_before_first_node'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'index_entry_before_first_node'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'index_entry_before_first_node'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'index_entry_before_first_node'}{'contents'}[1]{'parent'} = $result_trees{'index_entry_before_first_node'};
 
 $result_texis{'index_entry_before_first_node'} = '
@@ -183,26 +186,16 @@ $result_sectioning{'index_entry_before_first_node'} = {};
 $result_nodes{'index_entry_before_first_node'} = {
   'cmdname' => 'node',
   'extra' => {
+    'isindex' => 1,
     'normalized' => 'Top',
     'spaces_before_argument' => ' '
-  },
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
   }
 };
-$result_nodes{'index_entry_before_first_node'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'index_entry_before_first_node'};
 
 $result_menus{'index_entry_before_first_node'} = {
   'cmdname' => 'node',
   'extra' => {
+    'isindex' => 1,
     'normalized' => 'Top',
     'spaces_before_argument' => ' '
   }
@@ -221,6 +214,9 @@ $result_errors{'index_entry_before_first_node'} = [
 ];
 
 
+$result_floats{'index_entry_before_first_node'} = {};
+
+
 
 $result_converted{'info'}->{'index_entry_before_first_node'} = 'This is , produced from .
 
@@ -238,6 +234,11 @@ Tag Table:
 Node: Top27
 
 End Tag Table
+
+
+Local Variables:
+coding: utf-8
+End:
 ';
 
 $result_converted_errors{'info'}->{'index_entry_before_first_node'} = [
@@ -292,7 +293,6 @@ $result_converted{'html_text'}->{'index_entry_before_first_node'} = '
 <table><tr><th valign="top">Jump to: &nbsp; </th><td><a class="summary-letter" href="#t_h_cp_letter-B"><b>B</b></a>
  &nbsp; 
 </td></tr></table>
-<hr>
-';
+<hr>';
 
 1;
