@@ -317,7 +317,11 @@ $result_trees{'printindex_index_entry_in_copying'} = {
                 'end_command' => {},
                 'spaces_before_argument' => ' '
               },
-              'line_nr' => {},
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 5,
+                'macro' => ''
+              },
               'parent' => {}
             },
             {
@@ -480,7 +484,11 @@ $result_trees{'printindex_index_entry_in_copying'} = {
                 'end_command' => {},
                 'spaces_before_argument' => ' '
               },
-              'line_nr' => {},
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 10,
+                'macro' => ''
+              },
               'parent' => {}
             },
             {
@@ -602,7 +610,9 @@ $result_trees{'printindex_index_entry_in_copying'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -823,12 +833,15 @@ $result_trees{'printindex_index_entry_in_copying'} = {
       'cmdname' => 'node',
       'contents' => [],
       'extra' => {
+        'isindex' => 1,
         'node_content' => [
           {}
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'chapter'
           }
         ],
@@ -991,7 +1004,6 @@ $result_trees{'printindex_index_entry_in_copying'}{'contents'}[0]{'contents'}[0]
 $result_trees{'printindex_index_entry_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[4]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'printindex_index_entry_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[4]{'contents'}[3];
 $result_trees{'printindex_index_entry_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[4]{'contents'}[3]{'parent'} = $result_trees{'printindex_index_entry_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[4];
 $result_trees{'printindex_index_entry_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[4]{'extra'}{'end_command'} = $result_trees{'printindex_index_entry_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[4]{'contents'}[3];
-$result_trees{'printindex_index_entry_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[4]{'line_nr'} = $result_trees{'printindex_index_entry_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[4]{'contents'}[0]{'line_nr'};
 $result_trees{'printindex_index_entry_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[4]{'parent'} = $result_trees{'printindex_index_entry_in_copying'}{'contents'}[0]{'contents'}[0];
 $result_trees{'printindex_index_entry_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[5]{'parent'} = $result_trees{'printindex_index_entry_in_copying'}{'contents'}[0]{'contents'}[0];
 $result_trees{'printindex_index_entry_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[6]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'printindex_index_entry_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[6]{'args'}[0];
@@ -1017,7 +1029,6 @@ $result_trees{'printindex_index_entry_in_copying'}{'contents'}[0]{'contents'}[0]
 $result_trees{'printindex_index_entry_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[6]{'contents'}[1]{'parent'} = $result_trees{'printindex_index_entry_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[6];
 $result_trees{'printindex_index_entry_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[6]{'extra'}{'command_as_argument'} = $result_trees{'printindex_index_entry_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[6]{'args'}[0]{'contents'}[0];
 $result_trees{'printindex_index_entry_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[6]{'extra'}{'end_command'} = $result_trees{'printindex_index_entry_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[6]{'contents'}[1];
-$result_trees{'printindex_index_entry_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[6]{'line_nr'} = $result_trees{'printindex_index_entry_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[6]{'args'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'printindex_index_entry_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[6]{'parent'} = $result_trees{'printindex_index_entry_in_copying'}{'contents'}[0]{'contents'}[0];
 $result_trees{'printindex_index_entry_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[7]{'parent'} = $result_trees{'printindex_index_entry_in_copying'}{'contents'}[0]{'contents'}[0];
 $result_trees{'printindex_index_entry_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[8]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'printindex_index_entry_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[8]{'args'}[0];
@@ -1034,7 +1045,7 @@ $result_trees{'printindex_index_entry_in_copying'}{'contents'}[0]{'parent'} = $r
 $result_trees{'printindex_index_entry_in_copying'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'printindex_index_entry_in_copying'}{'contents'}[1]{'args'}[0];
 $result_trees{'printindex_index_entry_in_copying'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'printindex_index_entry_in_copying'}{'contents'}[1];
 $result_trees{'printindex_index_entry_in_copying'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'printindex_index_entry_in_copying'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'printindex_index_entry_in_copying'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'printindex_index_entry_in_copying'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'printindex_index_entry_in_copying'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'printindex_index_entry_in_copying'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'printindex_index_entry_in_copying'}{'contents'}[1]{'parent'} = $result_trees{'printindex_index_entry_in_copying'};
 $result_trees{'printindex_index_entry_in_copying'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'printindex_index_entry_in_copying'}{'contents'}[2]{'args'}[0];
 $result_trees{'printindex_index_entry_in_copying'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'printindex_index_entry_in_copying'}{'contents'}[2];
@@ -1066,7 +1077,7 @@ $result_trees{'printindex_index_entry_in_copying'}{'contents'}[2]{'parent'} = $r
 $result_trees{'printindex_index_entry_in_copying'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'printindex_index_entry_in_copying'}{'contents'}[3]{'args'}[0];
 $result_trees{'printindex_index_entry_in_copying'}{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'printindex_index_entry_in_copying'}{'contents'}[3];
 $result_trees{'printindex_index_entry_in_copying'}{'contents'}[3]{'extra'}{'node_content'}[0] = $result_trees{'printindex_index_entry_in_copying'}{'contents'}[3]{'args'}[0]{'contents'}[0];
-$result_trees{'printindex_index_entry_in_copying'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'printindex_index_entry_in_copying'}{'contents'}[3]{'extra'}{'node_content'};
+$result_trees{'printindex_index_entry_in_copying'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'printindex_index_entry_in_copying'}{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'printindex_index_entry_in_copying'}{'contents'}[3]{'parent'} = $result_trees{'printindex_index_entry_in_copying'};
 $result_trees{'printindex_index_entry_in_copying'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'printindex_index_entry_in_copying'}{'contents'}[4]{'args'}[0];
 $result_trees{'printindex_index_entry_in_copying'}{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'printindex_index_entry_in_copying'}{'contents'}[4];
@@ -1156,6 +1167,7 @@ $result_sectioning{'printindex_index_entry_in_copying'} = {
             'associated_node' => {
               'cmdname' => 'node',
               'extra' => {
+                'isindex' => 1,
                 'normalized' => 'chapter',
                 'spaces_before_argument' => ' '
               }
@@ -1202,6 +1214,7 @@ $result_nodes{'printindex_index_entry_in_copying'} = {
         'level' => 1,
         'number' => 1
       },
+      'isindex' => 1,
       'normalized' => 'chapter',
       'spaces_before_argument' => ' '
     },
@@ -1223,23 +1236,11 @@ $result_nodes{'printindex_index_entry_in_copying'} = {
       }
     }
   ],
-  'node_next' => {},
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
-  }
+  'node_next' => {}
 };
 $result_nodes{'printindex_index_entry_in_copying'}{'menu_child'}{'node_prev'} = $result_nodes{'printindex_index_entry_in_copying'};
 $result_nodes{'printindex_index_entry_in_copying'}{'menu_child'}{'node_up'} = $result_nodes{'printindex_index_entry_in_copying'};
 $result_nodes{'printindex_index_entry_in_copying'}{'node_next'} = $result_nodes{'printindex_index_entry_in_copying'}{'menu_child'};
-$result_nodes{'printindex_index_entry_in_copying'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'printindex_index_entry_in_copying'};
 
 $result_menus{'printindex_index_entry_in_copying'} = {
   'cmdname' => 'node',
@@ -1250,6 +1251,7 @@ $result_menus{'printindex_index_entry_in_copying'} = {
   'menu_child' => {
     'cmdname' => 'node',
     'extra' => {
+      'isindex' => 1,
       'normalized' => 'chapter',
       'spaces_before_argument' => ' '
     },
@@ -1264,6 +1266,9 @@ $result_menus{'printindex_index_entry_in_copying'}{'menu_child'}{'menu_up'} = $r
 $result_errors{'printindex_index_entry_in_copying'} = [];
 
 
+$result_floats{'printindex_index_entry_in_copying'} = {};
+
+
 
 $result_converted{'info'}->{'printindex_index_entry_in_copying'} = 'This is , produced from .
 
@@ -1344,6 +1349,11 @@ Node: Top131
 Node: chapter687
 
 End Tag Table
+
+
+Local Variables:
+coding: utf-8
+End:
 ';
 
 
@@ -1397,7 +1407,8 @@ xftable xitem
 
 
 $result_converted{'html_text'}->{'printindex_index_entry_in_copying'} = '
-<span id="Top"></span><div class="header">
+<div class="top" id="Top">
+<div class="header">
 <p>
  &nbsp; [<a href="#Top" title="Index" rel="index">Index</a>]</p>
 </div>
@@ -1407,19 +1418,15 @@ $result_converted{'html_text'}->{'printindex_index_entry_in_copying'} = '
 </p>
 <span id="index-copying-Copying-this-document"></span>
 
-<dl>
-<dt id="index-copying-fun">Function: <strong>fun</strong> <em>arg</em></dt>
-<dt id="index-copying-xf">Function: <strong>xf</strong> <em>arg</em></dt>
+<dl class="def">
+<dt id="index-copying-fun"><span class="category">Function: </span><span><strong>fun</strong> <em>arg</em><a href=\'#index-copying-fun\' class=\'copiable-anchor\'> &para;</a></span></dt>
+<dt id="index-copying-xf"><span class="category">Function: </span><span><strong>xf</strong> <em>arg</em><a href=\'#index-copying-xf\' class=\'copiable-anchor\'> &para;</a></span></dt>
 <dd><p>Defun
 </p></dd></dl>
 
 <dl compact="compact">
-<dt>ftable item
-<span id="index-copying-ftable-item"></span>
-</dt>
-<dt>xftable xitem
-<span id="index-copying-xftable-xitem"></span>
-</dt>
+<dt id=\'index-copying-ftable-item\'><span>ftable item<a href=\'#index-copying-ftable-item\' class=\'copiable-anchor\'> &para;</a></span></dt>
+<dt id=\'index-copying-xftable-xitem\'><span>xftable xitem<a href=\'#index-copying-xftable-xitem\' class=\'copiable-anchor\'> &para;</a></span></dt>
 </dl>
 
 <table><tr><th valign="top">Jump to: &nbsp; </th><td><a class="summary-letter" href="#t_h_fn_letter-C"><b>C</b></a>
@@ -1453,13 +1460,13 @@ $result_converted{'html_text'}->{'printindex_index_entry_in_copying'} = '
 </td></tr></table>
 
 
-<table class="menu" border="0" cellspacing="0">
-<tr><td align="left" valign="top">&bull; <a href="#chapter" accesskey="1">chapter</a></td><td>&nbsp;&nbsp;</td><td align="left" valign="top">
-</td></tr>
-</table>
 
+<ul class="section-toc">
+<li><a href="#chapter" accesskey="1">Chapter</a></li>
+</ul>
 <hr>
-<span id="chapter"></span><div class="header">
+<div class="chapter" id="chapter">
+<div class="header">
 <p>
  &nbsp; [<a href="#Top" title="Index" rel="index">Index</a>]</p>
 </div>
@@ -1468,19 +1475,15 @@ $result_converted{'html_text'}->{'printindex_index_entry_in_copying'} = '
 
 <span id="index-copying-Copying-this-document"></span>
 
-<dl>
-<dt id="index-copying-fun">Function: <strong>fun</strong> <em>arg</em></dt>
-<dt id="index-copying-xf">Function: <strong>xf</strong> <em>arg</em></dt>
+<dl class="def">
+<dt id="index-copying-fun"><span class="category">Function: </span><span><strong>fun</strong> <em>arg</em><a href=\'#index-copying-fun\' class=\'copiable-anchor\'> &para;</a></span></dt>
+<dt id="index-copying-xf"><span class="category">Function: </span><span><strong>xf</strong> <em>arg</em><a href=\'#index-copying-xf\' class=\'copiable-anchor\'> &para;</a></span></dt>
 <dd><p>Defun
 </p></dd></dl>
 
 <dl compact="compact">
-<dt>ftable item
-<span id="index-copying-ftable-item"></span>
-</dt>
-<dt>xftable xitem
-<span id="index-copying-xftable-xitem"></span>
-</dt>
+<dt id=\'index-copying-ftable-item\'><span>ftable item<a href=\'#index-copying-ftable-item\' class=\'copiable-anchor\'> &para;</a></span></dt>
+<dt id=\'index-copying-xftable-xitem\'><span>xftable xitem<a href=\'#index-copying-xftable-xitem\' class=\'copiable-anchor\'> &para;</a></span></dt>
 </dl>
 
 <table><tr><th valign="top">Jump to: &nbsp; </th><td><a class="summary-letter" href="#t_h_fn_letter-C"><b>C</b></a>
@@ -1544,7 +1547,8 @@ $result_converted{'html_text'}->{'printindex_index_entry_in_copying'} = '
  &nbsp; 
 </td></tr></table>
 
-<hr>
+</div>
+</div>
 ';
 
 1;
