@@ -128,12 +128,15 @@ $result_trees{'printindex_with_space_before'} = {
         }
       ],
       'extra' => {
+        'isindex' => 1,
         'node_content' => [
           {}
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -168,7 +171,7 @@ $result_trees{'printindex_with_space_before'}{'contents'}[1]{'contents'}[4]{'arg
 $result_trees{'printindex_with_space_before'}{'contents'}[1]{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'printindex_with_space_before'}{'contents'}[1]{'contents'}[4];
 $result_trees{'printindex_with_space_before'}{'contents'}[1]{'contents'}[4]{'parent'} = $result_trees{'printindex_with_space_before'}{'contents'}[1];
 $result_trees{'printindex_with_space_before'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'printindex_with_space_before'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'printindex_with_space_before'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'printindex_with_space_before'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'printindex_with_space_before'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'printindex_with_space_before'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'printindex_with_space_before'}{'contents'}[1]{'parent'} = $result_trees{'printindex_with_space_before'};
 
 $result_texis{'printindex_with_space_before'} = '@node Top
@@ -190,26 +193,16 @@ $result_sectioning{'printindex_with_space_before'} = {};
 $result_nodes{'printindex_with_space_before'} = {
   'cmdname' => 'node',
   'extra' => {
+    'isindex' => 1,
     'normalized' => 'Top',
     'spaces_before_argument' => ' '
-  },
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
   }
 };
-$result_nodes{'printindex_with_space_before'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'printindex_with_space_before'};
 
 $result_menus{'printindex_with_space_before'} = {
   'cmdname' => 'node',
   'extra' => {
+    'isindex' => 1,
     'normalized' => 'Top',
     'spaces_before_argument' => ' '
   }
@@ -218,6 +211,9 @@ $result_menus{'printindex_with_space_before'} = {
 $result_errors{'printindex_with_space_before'} = [];
 
 
+$result_floats{'printindex_with_space_before'} = {};
+
+
 
 $result_converted{'info'}->{'printindex_with_space_before'} = 'This is , produced from .
 
@@ -237,6 +233,11 @@ Tag Table:
 Node: Top27
 
 End Tag Table
+
+
+Local Variables:
+coding: utf-8
+End:
 ';
 
 
@@ -267,7 +268,6 @@ $result_converted{'html_text'}->{'printindex_with_space_before'} = '<span id="To
 <table><tr><th valign="top">Jump to: &nbsp; </th><td><a class="summary-letter" href="#t_h_cp_letter-I"><b>I</b></a>
  &nbsp; 
 </td></tr></table>
-<hr>
-';
+<hr>';
 
 1;
