@@ -11,27 +11,17 @@ $result_trees{'recursive_synindex'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'aaa'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'defindex',
@@ -39,7 +29,7 @@ $result_trees{'recursive_synindex'} = {
         'misc_args' => [
           'aaa'
         ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'line_nr' => {
         'file_name' => '',
@@ -52,27 +42,17 @@ $result_trees{'recursive_synindex'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'bbb'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'defindex',
@@ -80,7 +60,7 @@ $result_trees{'recursive_synindex'} = {
         'misc_args' => [
           'bbb'
         ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'line_nr' => {
         'file_name' => '',
@@ -93,27 +73,17 @@ $result_trees{'recursive_synindex'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'aaa bbb'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'synindex',
@@ -122,7 +92,7 @@ $result_trees{'recursive_synindex'} = {
           'aaa',
           'bbb'
         ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'line_nr' => {
         'file_name' => '',
@@ -135,26 +105,18 @@ $result_trees{'recursive_synindex'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'bbb aaa'
             }
           ],
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'synindex',
       'extra' => {
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'line_nr' => {
         'file_name' => '',
@@ -166,32 +128,17 @@ $result_trees{'recursive_synindex'} = {
   ],
   'type' => 'text_root'
 };
-$result_trees{'recursive_synindex'}{'contents'}[0]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'recursive_synindex'}{'contents'}[0];
 $result_trees{'recursive_synindex'}{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'recursive_synindex'}{'contents'}[0]{'args'}[0];
-$result_trees{'recursive_synindex'}{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'recursive_synindex'}{'contents'}[0]{'args'}[0];
-$result_trees{'recursive_synindex'}{'contents'}[0]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'recursive_synindex'}{'contents'}[0]{'args'}[0];
 $result_trees{'recursive_synindex'}{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'recursive_synindex'}{'contents'}[0];
-$result_trees{'recursive_synindex'}{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'recursive_synindex'}{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'recursive_synindex'}{'contents'}[0]{'parent'} = $result_trees{'recursive_synindex'};
-$result_trees{'recursive_synindex'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'recursive_synindex'}{'contents'}[1];
 $result_trees{'recursive_synindex'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'recursive_synindex'}{'contents'}[1]{'args'}[0];
-$result_trees{'recursive_synindex'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'recursive_synindex'}{'contents'}[1]{'args'}[0];
-$result_trees{'recursive_synindex'}{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'recursive_synindex'}{'contents'}[1]{'args'}[0];
 $result_trees{'recursive_synindex'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'recursive_synindex'}{'contents'}[1];
-$result_trees{'recursive_synindex'}{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'recursive_synindex'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'recursive_synindex'}{'contents'}[1]{'parent'} = $result_trees{'recursive_synindex'};
-$result_trees{'recursive_synindex'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'recursive_synindex'}{'contents'}[2];
 $result_trees{'recursive_synindex'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'recursive_synindex'}{'contents'}[2]{'args'}[0];
-$result_trees{'recursive_synindex'}{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'recursive_synindex'}{'contents'}[2]{'args'}[0];
-$result_trees{'recursive_synindex'}{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'recursive_synindex'}{'contents'}[2]{'args'}[0];
 $result_trees{'recursive_synindex'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'recursive_synindex'}{'contents'}[2];
-$result_trees{'recursive_synindex'}{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'recursive_synindex'}{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'recursive_synindex'}{'contents'}[2]{'parent'} = $result_trees{'recursive_synindex'};
-$result_trees{'recursive_synindex'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'recursive_synindex'}{'contents'}[3];
 $result_trees{'recursive_synindex'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'recursive_synindex'}{'contents'}[3]{'args'}[0];
-$result_trees{'recursive_synindex'}{'contents'}[3]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'recursive_synindex'}{'contents'}[3]{'args'}[0];
 $result_trees{'recursive_synindex'}{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'recursive_synindex'}{'contents'}[3];
-$result_trees{'recursive_synindex'}{'contents'}[3]{'extra'}{'spaces_after_command'} = $result_trees{'recursive_synindex'}{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'recursive_synindex'}{'contents'}[3]{'parent'} = $result_trees{'recursive_synindex'};
 
 $result_texis{'recursive_synindex'} = '@defindex aaa
@@ -218,9 +165,6 @@ $result_errors{'recursive_synindex'} = [
 $result_indices{'recursive_synindex'} = {
   'index_names' => {
     'aaa' => {
-      'contained_indices' => {
-        'aaa' => 1
-      },
       'in_code' => 0,
       'merged_in' => 'bbb',
       'name' => 'aaa'
@@ -275,11 +219,11 @@ $result_indices{'recursive_synindex'} = {
       'in_code' => 1,
       'name' => 'vr'
     }
-  },
-  'merged_indices' => {
-    'aaa' => 'bbb'
   }
 };
 
 
+$result_floats{'recursive_synindex'} = {};
+
+
 1;
