@@ -1,22 +1,16 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
 $result_trees{'seealso_duplicate'} = {
   'contents' => [
     {
-      'contents' => [
-        {
-          'contents' => [],
-          'parent' => {},
-          'type' => 'preamble_before_content'
-        }
-      ],
+      'contents' => [],
       'parent' => {},
-      'type' => 'before_node_section'
+      'type' => 'text_root'
     },
     {
       'args' => [
@@ -61,12 +55,13 @@ $result_trees{'seealso_duplicate'} = {
                     }
                   ],
                   'cmdname' => 'command',
-                  'parent' => {},
-                  'source_info' => {
+                  'contents' => [],
+                  'line_nr' => {
                     'file_name' => '',
                     'line_nr' => 3,
                     'macro' => ''
-                  }
+                  },
+                  'parent' => {}
                 }
               ],
               'extra' => {
@@ -79,16 +74,16 @@ $result_trees{'seealso_duplicate'} = {
           'cmdname' => 'cindex',
           'extra' => {
             'index_entry' => {
+              'command' => {},
+              'content' => [],
               'content_normalized' => [],
-              'entry_content' => [],
-              'entry_element' => {},
-              'entry_node' => {},
-              'entry_number' => 1,
               'in_code' => 0,
               'index_at_command' => 'cindex',
-              'index_ignore_chars' => {},
               'index_name' => 'cp',
-              'index_type_command' => 'cindex'
+              'index_type_command' => 'cindex',
+              'key' => 'awk',
+              'node' => {},
+              'number' => 1
             },
             'spaces_before_argument' => ' ',
             'subentry' => {
@@ -113,20 +108,20 @@ $result_trees{'seealso_duplicate'} = {
                 'level' => 1,
                 'spaces_before_argument' => ' '
               },
-              'parent' => {},
-              'source_info' => {
+              'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 3,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             }
           },
-          'parent' => {},
-          'source_info' => {
+          'line_nr' => {
             'file_name' => '',
             'line_nr' => 3,
             'macro' => ''
           },
+          'parent' => {},
           'type' => 'index_entry_command'
         },
         {},
@@ -148,12 +143,13 @@ $result_trees{'seealso_duplicate'} = {
                     }
                   ],
                   'cmdname' => 'command',
-                  'parent' => {},
-                  'source_info' => {
+                  'contents' => [],
+                  'line_nr' => {
                     'file_name' => '',
                     'line_nr' => 4,
                     'macro' => ''
-                  }
+                  },
+                  'parent' => {}
                 }
               ],
               'extra' => {
@@ -166,16 +162,16 @@ $result_trees{'seealso_duplicate'} = {
           'cmdname' => 'cindex',
           'extra' => {
             'index_entry' => {
+              'command' => {},
+              'content' => [],
               'content_normalized' => [],
-              'entry_content' => [],
-              'entry_element' => {},
-              'entry_node' => {},
-              'entry_number' => 2,
               'in_code' => 0,
               'index_at_command' => 'cindex',
-              'index_ignore_chars' => {},
               'index_name' => 'cp',
-              'index_type_command' => 'cindex'
+              'index_type_command' => 'cindex',
+              'key' => 'awk',
+              'node' => {},
+              'number' => 2
             },
             'spaces_before_argument' => ' ',
             'subentry' => {
@@ -189,7 +185,7 @@ $result_trees{'seealso_duplicate'} = {
                     {
                       'parent' => {},
                       'text' => ' ',
-                      'type' => 'spaces_at_end'
+                      'type' => 'empty_spaces_before_argument'
                     },
                     {
                       'args' => [
@@ -213,12 +209,13 @@ $result_trees{'seealso_duplicate'} = {
                                 }
                               ],
                               'cmdname' => 'command',
-                              'parent' => {},
-                              'source_info' => {
+                              'contents' => [],
+                              'line_nr' => {
                                 'file_name' => '',
                                 'line_nr' => 4,
                                 'macro' => ''
-                              }
+                              },
+                              'parent' => {}
                             }
                           ],
                           'parent' => {},
@@ -226,12 +223,13 @@ $result_trees{'seealso_duplicate'} = {
                         }
                       ],
                       'cmdname' => 'seealso',
-                      'parent' => {},
-                      'source_info' => {
+                      'contents' => [],
+                      'line_nr' => {
                         'file_name' => '',
                         'line_nr' => 4,
                         'macro' => ''
-                      }
+                      },
+                      'parent' => {}
                     }
                   ],
                   'extra' => {
@@ -248,20 +246,20 @@ $result_trees{'seealso_duplicate'} = {
                 'seealso' => {},
                 'spaces_before_argument' => ' '
               },
-              'parent' => {},
-              'source_info' => {
+              'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 4,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             }
           },
-          'parent' => {},
-          'source_info' => {
+          'line_nr' => {
             'file_name' => '',
             'line_nr' => 4,
             'macro' => ''
           },
+          'parent' => {},
           'type' => 'index_entry_command'
         },
         {},
@@ -295,12 +293,12 @@ $result_trees{'seealso_duplicate'} = {
             ],
             'spaces_before_argument' => ' '
           },
-          'parent' => {},
-          'source_info' => {
+          'line_nr' => {
             'file_name' => '',
             'line_nr' => 6,
             'macro' => ''
-          }
+          },
+          'parent' => {}
         }
       ],
       'extra' => {
@@ -319,17 +317,16 @@ $result_trees{'seealso_duplicate'} = {
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 1,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     }
   ],
   'type' => 'document_root'
 };
-$result_trees{'seealso_duplicate'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'seealso_duplicate'}{'contents'}[0];
 $result_trees{'seealso_duplicate'}{'contents'}[0]{'parent'} = $result_trees{'seealso_duplicate'};
 $result_trees{'seealso_duplicate'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'seealso_duplicate'}{'contents'}[1]{'args'}[0];
 $result_trees{'seealso_duplicate'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'seealso_duplicate'}{'contents'}[1];
@@ -338,10 +335,10 @@ $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'con
 $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[1]{'args'}[0];
 $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[1];
+$result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[1]{'extra'}{'index_entry'}{'command'} = $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[1];
+$result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[1]{'extra'}{'index_entry'}{'content'} = $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'};
 $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[1]{'extra'}{'index_entry'}{'content_normalized'} = $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'};
-$result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[1]{'extra'}{'index_entry'}{'entry_content'} = $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'};
-$result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[1]{'extra'}{'index_entry'}{'entry_element'} = $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[1];
-$result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[1]{'extra'}{'index_entry'}{'entry_node'} = $result_trees{'seealso_duplicate'}{'contents'}[1];
+$result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[1]{'extra'}{'index_entry'}{'node'} = $result_trees{'seealso_duplicate'}{'contents'}[1];
 $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[1]{'extra'}{'subentry'}{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[1]{'extra'}{'subentry'}{'args'}[0];
 $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[1]{'extra'}{'subentry'}{'args'}[0]{'parent'} = $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[1]{'extra'}{'subentry'};
 $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[1]{'extra'}{'subentry'}{'parent'} = $result_trees{'seealso_duplicate'}{'contents'}[1];
@@ -351,10 +348,10 @@ $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[3]{'args'}[0]{'con
 $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[3]{'args'}[0];
 $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[3];
+$result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[3]{'extra'}{'index_entry'}{'command'} = $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[3];
+$result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[3]{'extra'}{'index_entry'}{'content'} = $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'};
 $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[3]{'extra'}{'index_entry'}{'content_normalized'} = $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'};
-$result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[3]{'extra'}{'index_entry'}{'entry_content'} = $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'};
-$result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[3]{'extra'}{'index_entry'}{'entry_element'} = $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[3];
-$result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[3]{'extra'}{'index_entry'}{'entry_node'} = $result_trees{'seealso_duplicate'}{'contents'}[1];
+$result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[3]{'extra'}{'index_entry'}{'node'} = $result_trees{'seealso_duplicate'}{'contents'}[1];
 $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[3]{'extra'}{'subentry'}{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[3]{'extra'}{'subentry'}{'args'}[0];
 $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[3]{'extra'}{'subentry'}{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[3]{'extra'}{'subentry'}{'args'}[0];
 $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[3]{'extra'}{'subentry'}{'args'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'seealso_duplicate'}{'contents'}[1]{'contents'}[3]{'extra'}{'subentry'}{'args'}[0]{'contents'}[2]{'args'}[0];
@@ -389,11 +386,14 @@ $result_texts{'seealso_duplicate'} = '
 
 ';
 
+$result_sectioning{'seealso_duplicate'} = {};
+
 $result_nodes{'seealso_duplicate'} = {
   'cmdname' => 'node',
   'extra' => {
     'isindex' => 1,
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   }
 };
 
@@ -401,7 +401,8 @@ $result_menus{'seealso_duplicate'} = {
   'cmdname' => 'node',
   'extra' => {
     'isindex' => 1,
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   }
 };
 
@@ -411,14 +412,6 @@ $result_errors{'seealso_duplicate'} = [];
 $result_floats{'seealso_duplicate'} = {};
 
 
-$result_indices_sort_strings{'seealso_duplicate'} = {
-  'cp' => [
-    'awk',
-    'awk'
-  ]
-};
-
-
 
 $result_converted{'info'}->{'seealso_duplicate'} = 'This is , produced from .
 
@@ -453,86 +446,25 @@ $result_converted{'plaintext'}->{'seealso_duplicate'} = '* Menu:
 ';
 
 
-$result_converted{'html_text'}->{'seealso_duplicate'} = '<h1 class="node" id="Top">Top</h1>
+$result_converted{'html_text'}->{'seealso_duplicate'} = '<span id="Top"></span><h1 class="node-heading">Top</h1>
 
-<a class="index-entry-id" id="index-awk"></a>
-<a class="index-entry-id" id="index-awk-1"></a>
+<span id="index-awk"></span>
+<span id="index-awk-1"></span>
 
-<div class="printindex cp-printindex">
-<table class="cp-entries-printindex" border="0">
-<tr><td></td><th class="entries-header-printindex">Index Entry</th><td>&nbsp;</td><th class="sections-header-printindex"> Section</th></tr>
+<table><tr><th valign="top">Jump to: &nbsp; </th><td><a class="summary-letter" href="#t_h_cp_letter-A"><b>A</b></a>
+ &nbsp; 
+</td></tr></table>
+<table class="index-cp" border="0">
+<tr><td></td><th align="left">Index Entry</th><td>&nbsp;</td><th align="left"> Section</th></tr>
 <tr><td colspan="4"> <hr></td></tr>
-<tr><th id="t_i_cp_letter-A">A</th><td></td><td></td></tr>
-<tr><td></td><td class="printindex-index-entry"><a href="#index-awk"><code class="command">awk</code>, POSIX and</a>:</td><td>&nbsp;</td><td class="printindex-index-section"><a href="#Top">Top</a></td></tr>
-<tr><td></td><td class="printindex-index-entry"><a href="#index-awk-1"><code class="command">awk</code>, POSIX and</a>:</td><td>&nbsp;</td><td class="printindex-index-section"><a href="#Top">Top</a></td></tr>
+<tr><th id="t_h_cp_letter-A">A</th><td></td><td></td></tr>
+<tr><td></td><td valign="top"><a href="#index-awk"><code>awk</code>, POSIX and</a>:</td><td>&nbsp;</td><td valign="top"><a href="#Top">Top</a></td></tr>
+<tr><td></td><td valign="top"><a href="#index-awk-1"><code>awk</code>, POSIX and</a>:</td><td>&nbsp;</td><td valign="top"><a href="#Top">Top</a></td></tr>
 <tr><td colspan="4"> <hr></td></tr>
 </table>
-</div>
-';
-
-
-$result_converted{'xml'}->{'seealso_duplicate'} = '<node name="Top" spaces=" "><nodename>Top</nodename></node>
-
-<cindex index="cp" spaces=" "><indexterm index="cp" number="1"><command>awk</command></indexterm></cindex> <subentry spaces=" ">POSIX and</subentry>
-<cindex index="cp" spaces=" "><indexterm index="cp" number="2"><command>awk</command></indexterm></cindex> <subentry spaces=" ">POSIX and <seealso>POSIX <command>awk</command></seealso></subentry>
-
-<printindex spaces=" " value="cp" line="cp"></printindex>
-';
-
-
-$result_converted{'latex'}->{'seealso_duplicate'} = '\\documentclass{book}
-\\usepackage{imakeidx}
-\\usepackage{amsfonts}
-\\usepackage{amsmath}
-\\usepackage[gen]{eurosym}
-\\usepackage[T1]{fontenc}
-\\usepackage{textcomp}
-\\usepackage{graphicx}
-\\usepackage{etoolbox}
-\\usepackage{titleps}
-\\usepackage{float}
-% use hidelinks to remove boxes around links to be similar to Texinfo TeX
-\\usepackage[hidelinks]{hyperref}
-\\usepackage[utf8]{inputenc}
-
-\\makeatletter
-\\newcommand{\\Texinfosettitle}{No Title}%
-
-% no index headers or page break
-\\indexsetup{level=\\relax,toclevel=section,noclearpage}%
-\\makeindex[name=cp,title=]%
-
-% redefine the \\mainmatter command such that it does not clear page
-% as if in double page
-\\renewcommand\\mainmatter{\\clearpage\\@mainmattertrue\\pagenumbering{arabic}}
-\\newenvironment{Texinfopreformatted}{%
-  \\par\\GNUTobeylines\\obeyspaces\\frenchspacing\\parskip=\\z@\\parindent=\\z@}{}
-{\\catcode`\\^^M=13 \\gdef\\GNUTobeylines{\\catcode`\\^^M=13 \\def^^M{\\null\\par}}}
-\\newenvironment{Texinfoindented}{\\begin{list}{}{}\\item\\relax}{\\end{list}}
-
-% used for substitutions in commands
-\\newcommand{\\Texinfoplaceholder}[1]{}
-
-\\newpagestyle{single}{\\sethead[\\chaptername{} \\thechapter{} \\chaptertitle{}][][\\thepage]
-                              {\\chaptername{} \\thechapter{} \\chaptertitle{}}{}{\\thepage}}
-
-% allow line breaking at underscore
-\\let\\Texinfounderscore\\_
-\\renewcommand{\\_}{\\Texinfounderscore\\discretionary{}{}{}}
-\\renewcommand{\\includegraphics}[1]{\\fbox{FIG \\detokenize{#1}}}
-
-\\makeatother
-% set default for @setchapternewpage
-\\makeatletter
-\\patchcmd{\\chapter}{\\if@openright\\cleardoublepage\\else\\clearpage\\fi}{\\Texinfoplaceholder{setchapternewpage placeholder}\\clearpage}{}{}
-\\makeatother
-\\pagestyle{single}%
-
-\\begin{document}
-\\label{anchor:Top}%
-
-(`Top\' node ignored)
-\\end{document}
-';
+<table><tr><th valign="top">Jump to: &nbsp; </th><td><a class="summary-letter" href="#t_h_cp_letter-A"><b>A</b></a>
+ &nbsp; 
+</td></tr></table>
+<hr>';
 
 1;
