@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
@@ -10,24 +10,17 @@ $result_trees{'unknown_index_entry'} = {
     {
       'contents' => [
         {
-          'contents' => [
-            {
-              'parent' => {},
-              'text' => ' someindex entry.
-'
-            }
-          ],
           'parent' => {},
-          'type' => 'paragraph'
+          'text' => ' someindex entry.
+'
         }
       ],
       'parent' => {},
-      'type' => 'before_node_section'
+      'type' => 'paragraph'
     }
   ],
-  'type' => 'document_root'
+  'type' => 'text_root'
 };
-$result_trees{'unknown_index_entry'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'unknown_index_entry'}{'contents'}[0]{'contents'}[0];
 $result_trees{'unknown_index_entry'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'unknown_index_entry'}{'contents'}[0];
 $result_trees{'unknown_index_entry'}{'contents'}[0]{'parent'} = $result_trees{'unknown_index_entry'};
 
@@ -40,7 +33,7 @@ $result_texts{'unknown_index_entry'} = ' someindex entry.
 
 $result_errors{'unknown_index_entry'} = [
   {
-    'error_line' => 'unknown command `someindex\'
+    'error_line' => ':1: unknown command `someindex\'
 ',
     'file_name' => '',
     'line_nr' => 1,
