@@ -565,6 +565,9 @@ Second anchor in text after anchor.
 $result_errors{'center_flush'} = [];
 
 
+$result_floats{'center_flush'} = {};
+
+
 
 $result_converted{'info'}->{'center_flush'} = 'This is , produced from .
 
@@ -600,6 +603,11 @@ Ref: anchor in flushright607
 Ref: second anchor in flushright677
 
 End Tag Table
+
+
+Local Variables:
+coding: utf-8
+End:
 ';
 
 $result_converted_errors{'info'}->{'center_flush'} = [
