@@ -58,6 +58,9 @@ $result_trees{'file_only_png'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
               'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 3,
@@ -84,7 +87,14 @@ $result_trees{'file_only_png'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'line_nr' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 3,
+                'macro' => ''
+              },
               'parent' => {}
             },
             {
@@ -103,7 +113,9 @@ $result_trees{'file_only_png'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -131,12 +143,11 @@ $result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'par
 $result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1];
 $result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[3]{'args'}[0];
 $result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[3];
-$result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[3]{'line_nr'} = $result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'line_nr'};
 $result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1];
 $result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'contents'}[4]{'parent'} = $result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1];
 $result_trees{'file_only_png'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'file_only_png'}{'contents'}[1];
 $result_trees{'file_only_png'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'file_only_png'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'file_only_png'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'file_only_png'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'file_only_png'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'file_only_png'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'file_only_png'}{'contents'}[1]{'parent'} = $result_trees{'file_only_png'};
 
 $result_texis{'file_only_png'} = '@node Top
@@ -156,20 +167,8 @@ $result_nodes{'file_only_png'} = {
   'extra' => {
     'normalized' => 'Top',
     'spaces_before_argument' => ' '
-  },
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
   }
 };
-$result_nodes{'file_only_png'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'file_only_png'};
 
 $result_menus{'file_only_png'} = {
   'cmdname' => 'node',
@@ -182,6 +181,9 @@ $result_menus{'file_only_png'} = {
 $result_errors{'file_only_png'} = [];
 
 
+$result_floats{'file_only_png'} = {};
+
+
 
 $result_converted{'info'}->{'file_only_png'} = 'This is , produced from .
 
@@ -196,6 +198,11 @@ Tag Table:
 Node: Top27
 
 End Tag Table
+
+
+Local Variables:
+coding: utf-8
+End:
 ';
 
 1;
