@@ -1,15 +1,16 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
 $result_trees{'image_and_punctuation'} = {
   'contents' => [
     {
+      'contents' => [],
       'parent' => {},
-      'type' => 'before_node_section'
+      'type' => 'text_root'
     },
     {
       'args' => [
@@ -56,15 +57,16 @@ $result_trees{'image_and_punctuation'} = {
                 }
               ],
               'cmdname' => 'image',
+              'contents' => [],
               'extra' => {
                 'input_perl_encoding' => 'utf-8'
               },
-              'parent' => {},
-              'source_info' => {
+              'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 3,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             },
             {
               'parent' => {},
@@ -101,15 +103,16 @@ $result_trees{'image_and_punctuation'} = {
                 }
               ],
               'cmdname' => 'image',
+              'contents' => [],
               'extra' => {
                 'input_perl_encoding' => 'utf-8'
               },
-              'parent' => {},
-              'source_info' => {
+              'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 5,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             },
             {
               'parent' => {},
@@ -147,15 +150,16 @@ $result_trees{'image_and_punctuation'} = {
                 }
               ],
               'cmdname' => 'image',
+              'contents' => [],
               'extra' => {
                 'input_perl_encoding' => 'utf-8'
               },
-              'parent' => {},
-              'source_info' => {
+              'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 8,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             },
             {
               'parent' => {},
@@ -192,15 +196,16 @@ $result_trees{'image_and_punctuation'} = {
                 }
               ],
               'cmdname' => 'image',
+              'contents' => [],
               'extra' => {
                 'input_perl_encoding' => 'utf-8'
               },
-              'parent' => {},
-              'source_info' => {
+              'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 10,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             },
             {
               'parent' => {},
@@ -237,15 +242,16 @@ $result_trees{'image_and_punctuation'} = {
                 }
               ],
               'cmdname' => 'image',
+              'contents' => [],
               'extra' => {
                 'input_perl_encoding' => 'utf-8'
               },
-              'parent' => {},
-              'source_info' => {
+              'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 12,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             },
             {
               'parent' => {},
@@ -283,15 +289,16 @@ $result_trees{'image_and_punctuation'} = {
                 }
               ],
               'cmdname' => 'image',
+              'contents' => [],
               'extra' => {
                 'input_perl_encoding' => 'utf-8'
               },
-              'parent' => {},
-              'source_info' => {
+              'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 15,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             },
             {
               'parent' => {},
@@ -318,12 +325,12 @@ $result_trees{'image_and_punctuation'} = {
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 1,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     }
   ],
   'type' => 'document_root'
@@ -411,17 +418,21 @@ End line.
 words.
 ';
 
+$result_sectioning{'image_and_punctuation'} = {};
+
 $result_nodes{'image_and_punctuation'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   }
 };
 
 $result_menus{'image_and_punctuation'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   }
 };
 
