@@ -52,7 +52,9 @@ $result_trees{'image_and_spaces_formatting'} = {
           ],
           'cmdname' => 'image',
           'contents' => [],
-          'extra' => {},
+          'extra' => {
+            'input_perl_encoding' => 'utf-8'
+          },
           'line_nr' => {
             'file_name' => '',
             'line_nr' => 3,
@@ -79,8 +81,14 @@ $result_trees{'image_and_spaces_formatting'} = {
           ],
           'cmdname' => 'image',
           'contents' => [],
-          'extra' => {},
-          'line_nr' => {},
+          'extra' => {
+            'input_perl_encoding' => 'utf-8'
+          },
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 3,
+            'macro' => ''
+          },
           'parent' => {}
         },
         {
@@ -102,8 +110,14 @@ $result_trees{'image_and_spaces_formatting'} = {
           ],
           'cmdname' => 'image',
           'contents' => [],
-          'extra' => {},
-          'line_nr' => {},
+          'extra' => {
+            'input_perl_encoding' => 'utf-8'
+          },
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 3,
+            'macro' => ''
+          },
           'parent' => {}
         },
         {
@@ -125,8 +139,14 @@ $result_trees{'image_and_spaces_formatting'} = {
           ],
           'cmdname' => 'image',
           'contents' => [],
-          'extra' => {},
-          'line_nr' => {},
+          'extra' => {
+            'input_perl_encoding' => 'utf-8'
+          },
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 3,
+            'macro' => ''
+          },
           'parent' => {}
         },
         {
@@ -148,8 +168,14 @@ $result_trees{'image_and_spaces_formatting'} = {
           ],
           'cmdname' => 'image',
           'contents' => [],
-          'extra' => {},
-          'line_nr' => {},
+          'extra' => {
+            'input_perl_encoding' => 'utf-8'
+          },
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 3,
+            'macro' => ''
+          },
           'parent' => {}
         },
         {
@@ -171,8 +197,14 @@ $result_trees{'image_and_spaces_formatting'} = {
           ],
           'cmdname' => 'image',
           'contents' => [],
-          'extra' => {},
-          'line_nr' => {},
+          'extra' => {
+            'input_perl_encoding' => 'utf-8'
+          },
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 3,
+            'macro' => ''
+          },
           'parent' => {}
         },
         {
@@ -194,8 +226,14 @@ $result_trees{'image_and_spaces_formatting'} = {
           ],
           'cmdname' => 'image',
           'contents' => [],
-          'extra' => {},
-          'line_nr' => {},
+          'extra' => {
+            'input_perl_encoding' => 'utf-8'
+          },
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 3,
+            'macro' => ''
+          },
           'parent' => {}
         },
         {
@@ -230,7 +268,9 @@ $result_trees{'image_and_spaces_formatting'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
               'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 5,
@@ -257,8 +297,14 @@ $result_trees{'image_and_spaces_formatting'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
-              'line_nr' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 5,
+                'macro' => ''
+              },
               'parent' => {}
             },
             {
@@ -280,8 +326,14 @@ $result_trees{'image_and_spaces_formatting'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
-              'line_nr' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 5,
+                'macro' => ''
+              },
               'parent' => {}
             },
             {
@@ -303,8 +355,14 @@ $result_trees{'image_and_spaces_formatting'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
-              'line_nr' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 5,
+                'macro' => ''
+              },
               'parent' => {}
             },
             {
@@ -326,8 +384,14 @@ $result_trees{'image_and_spaces_formatting'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
-              'line_nr' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 5,
+                'macro' => ''
+              },
               'parent' => {}
             },
             {
@@ -349,8 +413,14 @@ $result_trees{'image_and_spaces_formatting'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
-              'line_nr' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 5,
+                'macro' => ''
+              },
               'parent' => {}
             },
             {
@@ -372,8 +442,14 @@ $result_trees{'image_and_spaces_formatting'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
-              'line_nr' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 5,
+                'macro' => ''
+              },
               'parent' => {}
             },
             {
@@ -412,7 +488,9 @@ $result_trees{'image_and_spaces_formatting'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
               'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 7,
@@ -439,8 +517,14 @@ $result_trees{'image_and_spaces_formatting'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
-              'line_nr' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 7,
+                'macro' => ''
+              },
               'parent' => {}
             },
             {
@@ -462,8 +546,14 @@ $result_trees{'image_and_spaces_formatting'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
-              'line_nr' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 7,
+                'macro' => ''
+              },
               'parent' => {}
             },
             {
@@ -485,8 +575,14 @@ $result_trees{'image_and_spaces_formatting'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
-              'line_nr' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 7,
+                'macro' => ''
+              },
               'parent' => {}
             },
             {
@@ -508,8 +604,14 @@ $result_trees{'image_and_spaces_formatting'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
-              'line_nr' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 7,
+                'macro' => ''
+              },
               'parent' => {}
             },
             {
@@ -531,8 +633,14 @@ $result_trees{'image_and_spaces_formatting'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
-              'line_nr' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 7,
+                'macro' => ''
+              },
               'parent' => {}
             },
             {
@@ -554,8 +662,14 @@ $result_trees{'image_and_spaces_formatting'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
-              'line_nr' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 7,
+                'macro' => ''
+              },
               'parent' => {}
             },
             {
@@ -594,7 +708,9 @@ $result_trees{'image_and_spaces_formatting'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
               'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 9,
@@ -638,7 +754,9 @@ $result_trees{'image_and_spaces_formatting'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
               'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 11,
@@ -682,7 +800,9 @@ $result_trees{'image_and_spaces_formatting'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
               'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 13,
@@ -709,8 +829,14 @@ $result_trees{'image_and_spaces_formatting'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
-              'line_nr' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 13,
+                'macro' => ''
+              },
               'parent' => {}
             },
             {
@@ -735,7 +861,9 @@ $result_trees{'image_and_spaces_formatting'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -762,32 +890,26 @@ $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[1]{'pare
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[3]{'args'}[0];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[3];
-$result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[3]{'line_nr'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[1]{'line_nr'};
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[4]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[5]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[5]{'args'}[0];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[5]{'args'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[5];
-$result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[5]{'line_nr'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[1]{'line_nr'};
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[5]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[6]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[7]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[7]{'args'}[0];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[7]{'args'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[7];
-$result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[7]{'line_nr'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[1]{'line_nr'};
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[7]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[8]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[9]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[9]{'args'}[0];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[9]{'args'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[9];
-$result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[9]{'line_nr'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[1]{'line_nr'};
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[9]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[10]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[11]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[11]{'args'}[0];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[11]{'args'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[11];
-$result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[11]{'line_nr'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[1]{'line_nr'};
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[11]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[12]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[13]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[13]{'args'}[0];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[13]{'args'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[13];
-$result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[13]{'line_nr'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[1]{'line_nr'};
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[13]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[14]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[15]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1];
@@ -798,32 +920,26 @@ $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'con
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[2]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[3]{'args'}[0];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[3];
-$result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[3]{'line_nr'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[1]{'line_nr'};
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[3]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[4]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[5]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[5]{'args'}[0];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[5]{'args'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[5];
-$result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[5]{'line_nr'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[1]{'line_nr'};
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[5]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[6]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[7]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[7]{'args'}[0];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[7]{'args'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[7];
-$result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[7]{'line_nr'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[1]{'line_nr'};
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[7]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[8]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[9]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[9]{'args'}[0];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[9]{'args'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[9];
-$result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[9]{'line_nr'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[1]{'line_nr'};
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[9]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[10]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[11]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[11]{'args'}[0];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[11]{'args'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[11];
-$result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[11]{'line_nr'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[1]{'line_nr'};
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[11]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[12]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[13]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[13]{'args'}[0];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[13]{'args'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[13];
-$result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[13]{'line_nr'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[1]{'line_nr'};
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[13]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'contents'}[14]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[16]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1];
@@ -835,32 +951,26 @@ $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'con
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[2]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[3]{'args'}[0];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[3];
-$result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[3]{'line_nr'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[1]{'line_nr'};
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[3]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[4]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[5]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[5]{'args'}[0];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[5]{'args'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[5];
-$result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[5]{'line_nr'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[1]{'line_nr'};
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[5]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[6]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[7]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[7]{'args'}[0];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[7]{'args'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[7];
-$result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[7]{'line_nr'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[1]{'line_nr'};
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[7]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[8]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[9]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[9]{'args'}[0];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[9]{'args'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[9];
-$result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[9]{'line_nr'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[1]{'line_nr'};
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[9]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[10]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[11]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[11]{'args'}[0];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[11]{'args'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[11];
-$result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[11]{'line_nr'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[1]{'line_nr'};
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[11]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[12]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[13]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[13]{'args'}[0];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[13]{'args'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[13];
-$result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[13]{'line_nr'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[1]{'line_nr'};
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[13]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'contents'}[14]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[18]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1];
@@ -886,13 +996,12 @@ $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[24]{'con
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[24]{'contents'}[2]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[24];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[24]{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[24]{'contents'}[3]{'args'}[0];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[24]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[24]{'contents'}[3];
-$result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[24]{'contents'}[3]{'line_nr'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[24]{'contents'}[1]{'line_nr'};
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[24]{'contents'}[3]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[24];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[24]{'contents'}[4]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[24];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[24]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'contents'}[25]{'parent'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'image_and_spaces_formatting'}{'contents'}[1]{'parent'} = $result_trees{'image_and_spaces_formatting'};
 
 $result_texis{'image_and_spaces_formatting'} = '@node Top
@@ -934,20 +1043,8 @@ $result_nodes{'image_and_spaces_formatting'} = {
   'extra' => {
     'normalized' => 'Top',
     'spaces_before_argument' => ' '
-  },
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
   }
 };
-$result_nodes{'image_and_spaces_formatting'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'image_and_spaces_formatting'};
 
 $result_menus{'image_and_spaces_formatting'} = {
   'cmdname' => 'node',
@@ -960,13 +1057,17 @@ $result_menus{'image_and_spaces_formatting'} = {
 $result_errors{'image_and_spaces_formatting'} = [];
 
 
+$result_floats{'image_and_spaces_formatting'} = {};
+
+
 
 $result_converted{'info'}->{'image_and_spaces_formatting'} = 'This is , produced from .
 
 
 File: ,  Node: Top,  Up: (dir)
 
-This is an image words.This is an image words.This is an image words.This is an image words.This is an image words.This is an image words.This is an image words.
+This is an image words. This is an image words. This is an image words. This is an image words. This is an image words. This is an image words. This is an image words.
+
 Some text This is an image words. This is an image words. This is an image words. This is an image words. This is an image words. This is an image words. This is an image words..
 
    Some text This is an image words. text aaaaaaaaa This is an image words. text bbbbbbbbbbb This is an image words. text ccccccccccccc This is an image words. text
@@ -976,7 +1077,7 @@ ddddddddddddd This is an image words. text eeeeeeeeeeeeeee This is an image word
 
    AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAABBBBBBBB
 This is an image words.
-   Text. This is an image words.  This is an image words..
+   Text.  This is an image words.  This is an image words..
 
 
 
@@ -984,6 +1085,11 @@ Tag Table:
 Node: Top27
 
 End Tag Table
+
+
+Local Variables:
+coding: utf-8
+End:
 ';
 
 1;
