@@ -77,7 +77,9 @@ $result_trees{'image_extension'} = {
           ],
           'cmdname' => 'image',
           'contents' => [],
-          'extra' => {},
+          'extra' => {
+            'input_perl_encoding' => 'utf-8'
+          },
           'line_nr' => {
             'file_name' => '',
             'line_nr' => 3,
@@ -130,7 +132,9 @@ $result_trees{'image_extension'} = {
           ],
           'cmdname' => 'image',
           'contents' => [],
-          'extra' => {},
+          'extra' => {
+            'input_perl_encoding' => 'utf-8'
+          },
           'line_nr' => {
             'file_name' => '',
             'line_nr' => 4,
@@ -183,7 +187,9 @@ $result_trees{'image_extension'} = {
           ],
           'cmdname' => 'image',
           'contents' => [],
-          'extra' => {},
+          'extra' => {
+            'input_perl_encoding' => 'utf-8'
+          },
           'line_nr' => {
             'file_name' => '',
             'line_nr' => 5,
@@ -203,7 +209,9 @@ $result_trees{'image_extension'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -252,7 +260,7 @@ $result_trees{'image_extension'}{'contents'}[1]{'contents'}[5]{'args'}[4]{'paren
 $result_trees{'image_extension'}{'contents'}[1]{'contents'}[5]{'parent'} = $result_trees{'image_extension'}{'contents'}[1];
 $result_trees{'image_extension'}{'contents'}[1]{'contents'}[6]{'parent'} = $result_trees{'image_extension'}{'contents'}[1];
 $result_trees{'image_extension'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'image_extension'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'image_extension'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'image_extension'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'image_extension'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'image_extension'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'image_extension'}{'contents'}[1]{'parent'} = $result_trees{'image_extension'};
 
 $result_texis{'image_extension'} = '@node Top
@@ -276,20 +284,8 @@ $result_nodes{'image_extension'} = {
   'extra' => {
     'normalized' => 'Top',
     'spaces_before_argument' => ' '
-  },
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
   }
 };
-$result_nodes{'image_extension'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'image_extension'};
 
 $result_menus{'image_extension'} = {
   'cmdname' => 'node',
@@ -302,6 +298,9 @@ $result_menus{'image_extension'} = {
 $result_errors{'image_extension'} = [];
 
 
+$result_floats{'image_extension'} = {};
+
+
 
 $result_converted{'info'}->{'image_extension'} = 'This is , produced from .
 
@@ -309,14 +308,22 @@ $result_converted{'info'}->{'image_extension'} = 'This is , produced from .
 File: ,  Node: Top,  Up: (dir)
 
  [image src="fextext" text="t" ]
+
  [image src="fdotext.ext" text="t" ]
+
  [image src="f--ile.png" text="Image description\\"\\"\\\\." ]
 
+
 
 Tag Table:
 Node: Top27
 
 End Tag Table
+
+
+Local Variables:
+coding: utf-8
+End:
 ';
 
 1;
