@@ -79,7 +79,9 @@ $result_trees{'image_in_paragraph'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
               'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 4,
@@ -103,7 +105,9 @@ $result_trees{'image_in_paragraph'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -135,7 +139,7 @@ $result_trees{'image_in_paragraph'}{'contents'}[1]{'contents'}[1]{'contents'}[1]
 $result_trees{'image_in_paragraph'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'image_in_paragraph'}{'contents'}[1]{'contents'}[1];
 $result_trees{'image_in_paragraph'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'image_in_paragraph'}{'contents'}[1];
 $result_trees{'image_in_paragraph'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'image_in_paragraph'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'image_in_paragraph'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'image_in_paragraph'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'image_in_paragraph'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'image_in_paragraph'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'image_in_paragraph'}{'contents'}[1]{'parent'} = $result_trees{'image_in_paragraph'};
 
 $result_texis{'image_in_paragraph'} = '@node Top
@@ -157,20 +161,8 @@ $result_nodes{'image_in_paragraph'} = {
   'extra' => {
     'normalized' => 'Top',
     'spaces_before_argument' => ' '
-  },
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
   }
 };
-$result_nodes{'image_in_paragraph'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'image_in_paragraph'};
 
 $result_menus{'image_in_paragraph'} = {
   'cmdname' => 'node',
@@ -183,19 +175,27 @@ $result_menus{'image_in_paragraph'} = {
 $result_errors{'image_in_paragraph'} = [];
 
 
+$result_floats{'image_in_paragraph'} = {};
+
+
 
 $result_converted{'info'}->{'image_in_paragraph'} = 'This is , produced from .
 
 
 File: ,  Node: Top,  Up: (dir)
 
-Para.  [image src="f--ile.png" alt="alt\\"\\"\\\\" text="Image description\\"\\"\\\\." ].  End para.
+Para.   [image src="f--ile.png" alt="alt\\"\\"\\\\" text="Image description\\"\\"\\\\." ].  End para.
 
 
 Tag Table:
 Node: Top27
 
 End Tag Table
+
+
+Local Variables:
+coding: utf-8
+End:
 ';
 
 1;
