@@ -46,6 +46,9 @@ $result_trees{'image_not_found'} = {
           ],
           'cmdname' => 'image',
           'contents' => [],
+          'extra' => {
+            'input_perl_encoding' => 'utf-8'
+          },
           'line_nr' => {
             'file_name' => '',
             'line_nr' => 2,
@@ -65,7 +68,9 @@ $result_trees{'image_not_found'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -90,7 +95,7 @@ $result_trees{'image_not_found'}{'contents'}[1]{'contents'}[0]{'args'}[0]{'paren
 $result_trees{'image_not_found'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'image_not_found'}{'contents'}[1];
 $result_trees{'image_not_found'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'image_not_found'}{'contents'}[1];
 $result_trees{'image_not_found'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'image_not_found'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'image_not_found'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'image_not_found'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'image_not_found'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'image_not_found'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'image_not_found'}{'contents'}[1]{'parent'} = $result_trees{'image_not_found'};
 
 $result_texis{'image_not_found'} = '@node Top
@@ -108,20 +113,8 @@ $result_nodes{'image_not_found'} = {
   'extra' => {
     'normalized' => 'Top',
     'spaces_before_argument' => ' '
-  },
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
   }
 };
-$result_nodes{'image_not_found'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'image_not_found'};
 
 $result_menus{'image_not_found'} = {
   'cmdname' => 'node',
@@ -134,6 +127,9 @@ $result_menus{'image_not_found'} = {
 $result_errors{'image_not_found'} = [];
 
 
+$result_floats{'image_not_found'} = {};
+
+
 
 $result_converted{'info'}->{'image_not_found'} = 'This is , produced from .
 
@@ -141,11 +137,17 @@ $result_converted{'info'}->{'image_not_found'} = 'This is , produced from .
 File: ,  Node: Top,  Up: (dir)
 
 [n_f_image]
+
 
 Tag Table:
 Node: Top27
 
 End Tag Table
+
+
+Local Variables:
+coding: utf-8
+End:
 ';
 
 $result_converted_errors{'info'}->{'image_not_found'} = [
