@@ -94,7 +94,9 @@ $result_trees{'image_quotes'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -124,7 +126,7 @@ $result_trees{'image_quotes'}{'contents'}[1]{'contents'}[1]{'args'}[3]{'parent'}
 $result_trees{'image_quotes'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'image_quotes'}{'contents'}[1];
 $result_trees{'image_quotes'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'image_quotes'}{'contents'}[1];
 $result_trees{'image_quotes'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'image_quotes'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'image_quotes'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'image_quotes'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'image_quotes'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'image_quotes'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'image_quotes'}{'contents'}[1]{'parent'} = $result_trees{'image_quotes'};
 
 $result_texis{'image_quotes'} = '@node Top
@@ -158,6 +160,9 @@ $result_menus{'image_quotes'} = {
 $result_errors{'image_quotes'} = [];
 
 
+$result_floats{'image_quotes'} = {};
+
+
 
 $result_converted{'info'}->{'image_quotes'} = 'This is , produced from .
 
@@ -166,6 +171,7 @@ File: ,  Node: Top,  Up: (dir)
 
  [image src="f--ile.png" alt="alt\\"\\"\\\\" text="Image description\\"\\"\\\\." ]
 
+
 
 Tag Table:
 Node: Top27
