@@ -37,7 +37,9 @@ $result_trees{'index_entry_at_end_node'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -292,7 +294,9 @@ $result_trees{'index_entry_at_end_node'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'chapter'
           }
         ],
@@ -423,12 +427,15 @@ $result_trees{'index_entry_at_end_node'} = {
       'cmdname' => 'node',
       'contents' => [],
       'extra' => {
+        'isindex' => 1,
         'node_content' => [
           {}
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'indices'
           }
         ],
@@ -518,7 +525,7 @@ $result_trees{'index_entry_at_end_node'}{'contents'}[0]{'parent'} = $result_tree
 $result_trees{'index_entry_at_end_node'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[1]{'args'}[0];
 $result_trees{'index_entry_at_end_node'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[1];
 $result_trees{'index_entry_at_end_node'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'index_entry_at_end_node'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'index_entry_at_end_node'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'index_entry_at_end_node'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'index_entry_at_end_node'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'index_entry_at_end_node'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'index_entry_at_end_node'}{'contents'}[1]{'parent'} = $result_trees{'index_entry_at_end_node'};
 $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'args'}[0];
 $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[2];
@@ -556,7 +563,7 @@ $result_trees{'index_entry_at_end_node'}{'contents'}[2]{'parent'} = $result_tree
 $result_trees{'index_entry_at_end_node'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[3]{'args'}[0];
 $result_trees{'index_entry_at_end_node'}{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[3];
 $result_trees{'index_entry_at_end_node'}{'contents'}[3]{'extra'}{'node_content'}[0] = $result_trees{'index_entry_at_end_node'}{'contents'}[3]{'args'}[0]{'contents'}[0];
-$result_trees{'index_entry_at_end_node'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'index_entry_at_end_node'}{'contents'}[3]{'extra'}{'node_content'};
+$result_trees{'index_entry_at_end_node'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'index_entry_at_end_node'}{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'index_entry_at_end_node'}{'contents'}[3]{'parent'} = $result_trees{'index_entry_at_end_node'};
 $result_trees{'index_entry_at_end_node'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[4]{'args'}[0];
 $result_trees{'index_entry_at_end_node'}{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[4];
@@ -575,7 +582,7 @@ $result_trees{'index_entry_at_end_node'}{'contents'}[4]{'parent'} = $result_tree
 $result_trees{'index_entry_at_end_node'}{'contents'}[5]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[5]{'args'}[0];
 $result_trees{'index_entry_at_end_node'}{'contents'}[5]{'args'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[5];
 $result_trees{'index_entry_at_end_node'}{'contents'}[5]{'extra'}{'node_content'}[0] = $result_trees{'index_entry_at_end_node'}{'contents'}[5]{'args'}[0]{'contents'}[0];
-$result_trees{'index_entry_at_end_node'}{'contents'}[5]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'index_entry_at_end_node'}{'contents'}[5]{'extra'}{'node_content'};
+$result_trees{'index_entry_at_end_node'}{'contents'}[5]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'index_entry_at_end_node'}{'contents'}[5]{'args'}[0]{'contents'}[0];
 $result_trees{'index_entry_at_end_node'}{'contents'}[5]{'parent'} = $result_trees{'index_entry_at_end_node'};
 $result_trees{'index_entry_at_end_node'}{'contents'}[6]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[6]{'args'}[0];
 $result_trees{'index_entry_at_end_node'}{'contents'}[6]{'args'}[0]{'parent'} = $result_trees{'index_entry_at_end_node'}{'contents'}[6];
@@ -667,6 +674,7 @@ $result_sectioning{'index_entry_at_end_node'} = {
             'associated_node' => {
               'cmdname' => 'node',
               'extra' => {
+                'isindex' => 1,
                 'normalized' => 'indices',
                 'spaces_before_argument' => ' '
               }
@@ -732,6 +740,7 @@ $result_nodes{'index_entry_at_end_node'} = {
           'level' => 1,
           'number' => 'A'
         },
+        'isindex' => 1,
         'normalized' => 'indices',
         'spaces_before_argument' => ' '
       },
@@ -756,25 +765,13 @@ $result_nodes{'index_entry_at_end_node'} = {
       }
     }
   ],
-  'node_next' => {},
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
-  }
+  'node_next' => {}
 };
 $result_nodes{'index_entry_at_end_node'}{'menu_child'}{'node_next'}{'node_prev'} = $result_nodes{'index_entry_at_end_node'}{'menu_child'};
 $result_nodes{'index_entry_at_end_node'}{'menu_child'}{'node_next'}{'node_up'} = $result_nodes{'index_entry_at_end_node'};
 $result_nodes{'index_entry_at_end_node'}{'menu_child'}{'node_prev'} = $result_nodes{'index_entry_at_end_node'};
 $result_nodes{'index_entry_at_end_node'}{'menu_child'}{'node_up'} = $result_nodes{'index_entry_at_end_node'};
 $result_nodes{'index_entry_at_end_node'}{'node_next'} = $result_nodes{'index_entry_at_end_node'}{'menu_child'};
-$result_nodes{'index_entry_at_end_node'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'index_entry_at_end_node'};
 
 $result_menus{'index_entry_at_end_node'} = {
   'cmdname' => 'node',
@@ -791,6 +788,7 @@ $result_menus{'index_entry_at_end_node'} = {
     'menu_next' => {
       'cmdname' => 'node',
       'extra' => {
+        'isindex' => 1,
         'normalized' => 'indices',
         'spaces_before_argument' => ' '
       },
@@ -813,6 +811,9 @@ $result_menus{'index_entry_at_end_node'}{'menu_child'}{'menu_up'} = $result_menu
 $result_errors{'index_entry_at_end_node'} = [];
 
 
+$result_floats{'index_entry_at_end_node'} = {};
+
+
 
 $result_converted{'info'}->{'index_entry_at_end_node'} = 'This is , produced from .
 
@@ -852,6 +853,11 @@ Node: chapter128
 Node: indices213
 
 End Tag Table
+
+
+Local Variables:
+coding: utf-8
+End:
 ';
 
 1;
