@@ -88,7 +88,9 @@ $result_trees{'known_encoding'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -115,7 +117,7 @@ $result_trees{'known_encoding'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent
 $result_trees{'known_encoding'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'known_encoding'}{'contents'}[1];
 $result_trees{'known_encoding'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'known_encoding'}{'contents'}[1];
 $result_trees{'known_encoding'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'known_encoding'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'known_encoding'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'known_encoding'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'known_encoding'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'known_encoding'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'known_encoding'}{'contents'}[1]{'parent'} = $result_trees{'known_encoding'};
 
 $result_texis{'known_encoding'} = '
@@ -138,20 +140,8 @@ $result_nodes{'known_encoding'} = {
   'extra' => {
     'normalized' => 'Top',
     'spaces_before_argument' => ' '
-  },
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
   }
 };
-$result_nodes{'known_encoding'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'known_encoding'};
 
 $result_menus{'known_encoding'} = {
   'cmdname' => 'node',
@@ -174,6 +164,9 @@ $result_errors{'known_encoding'} = [
 ];
 
 
+$result_floats{'known_encoding'} = {};
+
+
 
 $result_converted{'info'}->{'known_encoding'} = 'This is , produced from .
 
