@@ -13,27 +13,17 @@ $result_trees{'nested_footnotes_separate'} = {
           'args' => [
             {
               'contents' => [
-                {
-                  'extra' => {
-                    'command' => {}
-                  },
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_after_command'
-                },
                 {
                   'parent' => {},
                   'text' => 'separate'
-                },
-                {
-                  'parent' => {},
-                  'text' => '
-',
-                  'type' => 'spaces_at_end'
                 }
               ],
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
               'parent' => {},
-              'type' => 'misc_line_arg'
+              'type' => 'line_arg'
             }
           ],
           'cmdname' => 'footnotestyle',
@@ -41,7 +31,7 @@ $result_trees{'nested_footnotes_separate'} = {
             'misc_args' => [
               'separate'
             ],
-            'spaces_after_command' => {}
+            'spaces_before_argument' => ' '
           },
           'line_nr' => {
             'file_name' => '',
@@ -58,27 +48,17 @@ $result_trees{'nested_footnotes_separate'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'Top'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'node',
@@ -189,12 +169,14 @@ $result_trees{'nested_footnotes_separate'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
         'normalized' => 'Top',
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'line_nr' => {
         'file_name' => '',
@@ -206,18 +188,11 @@ $result_trees{'nested_footnotes_separate'} = {
   ],
   'type' => 'document_root'
 };
-$result_trees{'nested_footnotes_separate'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'nested_footnotes_separate'}{'contents'}[0]{'contents'}[0];
 $result_trees{'nested_footnotes_separate'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'nested_footnotes_separate'}{'contents'}[0]{'contents'}[0]{'args'}[0];
-$result_trees{'nested_footnotes_separate'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'nested_footnotes_separate'}{'contents'}[0]{'contents'}[0]{'args'}[0];
-$result_trees{'nested_footnotes_separate'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'nested_footnotes_separate'}{'contents'}[0]{'contents'}[0]{'args'}[0];
 $result_trees{'nested_footnotes_separate'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'nested_footnotes_separate'}{'contents'}[0]{'contents'}[0];
-$result_trees{'nested_footnotes_separate'}{'contents'}[0]{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'nested_footnotes_separate'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'nested_footnotes_separate'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'nested_footnotes_separate'}{'contents'}[0];
 $result_trees{'nested_footnotes_separate'}{'contents'}[0]{'parent'} = $result_trees{'nested_footnotes_separate'};
-$result_trees{'nested_footnotes_separate'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'nested_footnotes_separate'}{'contents'}[1];
 $result_trees{'nested_footnotes_separate'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'nested_footnotes_separate'}{'contents'}[1]{'args'}[0];
-$result_trees{'nested_footnotes_separate'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'nested_footnotes_separate'}{'contents'}[1]{'args'}[0];
-$result_trees{'nested_footnotes_separate'}{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'nested_footnotes_separate'}{'contents'}[1]{'args'}[0];
 $result_trees{'nested_footnotes_separate'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'nested_footnotes_separate'}{'contents'}[1];
 $result_trees{'nested_footnotes_separate'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'nested_footnotes_separate'}{'contents'}[1];
 $result_trees{'nested_footnotes_separate'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'nested_footnotes_separate'}{'contents'}[1]{'contents'}[1];
@@ -235,9 +210,8 @@ $result_trees{'nested_footnotes_separate'}{'contents'}[1]{'contents'}[1]{'conten
 $result_trees{'nested_footnotes_separate'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'nested_footnotes_separate'}{'contents'}[1]{'contents'}[1];
 $result_trees{'nested_footnotes_separate'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'nested_footnotes_separate'}{'contents'}[1]{'contents'}[1];
 $result_trees{'nested_footnotes_separate'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'nested_footnotes_separate'}{'contents'}[1];
-$result_trees{'nested_footnotes_separate'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'nested_footnotes_separate'}{'contents'}[1]{'args'}[0]{'contents'}[1];
-$result_trees{'nested_footnotes_separate'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'nested_footnotes_separate'}{'contents'}[1]{'extra'}{'node_content'};
-$result_trees{'nested_footnotes_separate'}{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'nested_footnotes_separate'}{'contents'}[1]{'args'}[0]{'contents'}[0];
+$result_trees{'nested_footnotes_separate'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'nested_footnotes_separate'}{'contents'}[1]{'args'}[0]{'contents'}[0];
+$result_trees{'nested_footnotes_separate'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'nested_footnotes_separate'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'nested_footnotes_separate'}{'contents'}[1]{'parent'} = $result_trees{'nested_footnotes_separate'};
 
 $result_texis{'nested_footnotes_separate'} = '@footnotestyle separate
@@ -259,32 +233,25 @@ $result_sectioning{'nested_footnotes_separate'} = {};
 $result_nodes{'nested_footnotes_separate'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top'
-  },
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   }
 };
-$result_nodes{'nested_footnotes_separate'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'nested_footnotes_separate'};
 
 $result_menus{'nested_footnotes_separate'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   }
 };
 
 $result_errors{'nested_footnotes_separate'} = [];
 
 
+$result_floats{'nested_footnotes_separate'} = {};
+
+
 
 $result_converted{'info'}->{'nested_footnotes_separate'} = 'This is , produced from .
 
@@ -311,6 +278,11 @@ Ref: Top-Footnote-1134
 Ref: Top-Footnote-2189
 
 End Tag Table
+
+
+Local Variables:
+coding: utf-8
+End:
 ';
 
 1;
