@@ -308,7 +308,9 @@ $result_trees{'note_in_strong'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -373,7 +375,7 @@ $result_trees{'note_in_strong'}{'contents'}[1]{'contents'}[13]{'contents'}[1]{'p
 $result_trees{'note_in_strong'}{'contents'}[1]{'contents'}[13]{'contents'}[2]{'parent'} = $result_trees{'note_in_strong'}{'contents'}[1]{'contents'}[13];
 $result_trees{'note_in_strong'}{'contents'}[1]{'contents'}[13]{'parent'} = $result_trees{'note_in_strong'}{'contents'}[1];
 $result_trees{'note_in_strong'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'note_in_strong'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'note_in_strong'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'note_in_strong'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'note_in_strong'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'note_in_strong'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'note_in_strong'}{'contents'}[1]{'parent'} = $result_trees{'note_in_strong'};
 
 $result_texis{'note_in_strong'} = '@node Top
@@ -417,20 +419,8 @@ $result_nodes{'note_in_strong'} = {
   'extra' => {
     'normalized' => 'Top',
     'spaces_before_argument' => ' '
-  },
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
   }
 };
-$result_nodes{'note_in_strong'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'note_in_strong'};
 
 $result_menus{'note_in_strong'} = {
   'cmdname' => 'node',
@@ -443,6 +433,9 @@ $result_menus{'note_in_strong'} = {
 $result_errors{'note_in_strong'} = [];
 
 
+$result_floats{'note_in_strong'} = {};
+
+
 
 $result_converted{'info'}->{'note_in_strong'} = 'This is , produced from .
 
@@ -466,6 +459,11 @@ Tag Table:
 Node: Top27
 
 End Tag Table
+
+
+Local Variables:
+coding: utf-8
+End:
 ';
 
 $result_converted_errors{'info'}->{'note_in_strong'} = [
