@@ -145,7 +145,11 @@ $result_trees{'novalidate_empty_refs'} = {
                   'normalized' => '-'
                 }
               },
-              'line_nr' => {},
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 7,
+                'macro' => ''
+              },
               'parent' => {}
             },
             {
@@ -170,7 +174,9 @@ $result_trees{'novalidate_empty_refs'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -303,7 +309,11 @@ $result_trees{'novalidate_empty_refs'} = {
         ],
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {},
+      'line_nr' => {
+        'file_name' => '',
+        'line_nr' => 11,
+        'macro' => ''
+      },
       'parent' => {}
     }
   ],
@@ -327,13 +337,12 @@ $result_trees{'novalidate_empty_refs'}{'contents'}[1]{'contents'}[1]{'contents'}
 $result_trees{'novalidate_empty_refs'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'novalidate_empty_refs'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0];
 $result_trees{'novalidate_empty_refs'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'novalidate_empty_refs'}{'contents'}[1]{'contents'}[1]{'contents'}[2];
 $result_trees{'novalidate_empty_refs'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'extra'}{'node_argument'}{'node_content'}[0] = $result_trees{'novalidate_empty_refs'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0];
-$result_trees{'novalidate_empty_refs'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'line_nr'} = $result_trees{'novalidate_empty_refs'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'novalidate_empty_refs'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'novalidate_empty_refs'}{'contents'}[1]{'contents'}[1];
 $result_trees{'novalidate_empty_refs'}{'contents'}[1]{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'novalidate_empty_refs'}{'contents'}[1]{'contents'}[1];
 $result_trees{'novalidate_empty_refs'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'novalidate_empty_refs'}{'contents'}[1];
 $result_trees{'novalidate_empty_refs'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'novalidate_empty_refs'}{'contents'}[1];
 $result_trees{'novalidate_empty_refs'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'novalidate_empty_refs'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'novalidate_empty_refs'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'novalidate_empty_refs'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'novalidate_empty_refs'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'novalidate_empty_refs'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'novalidate_empty_refs'}{'contents'}[1]{'parent'} = $result_trees{'novalidate_empty_refs'};
 $result_trees{'novalidate_empty_refs'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'novalidate_empty_refs'}{'contents'}[2]{'args'}[0];
 $result_trees{'novalidate_empty_refs'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'novalidate_empty_refs'}{'contents'}[2];
@@ -348,7 +357,6 @@ $result_trees{'novalidate_empty_refs'}{'contents'}[4]{'args'}[0]{'contents'}[0]{
 $result_trees{'novalidate_empty_refs'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'novalidate_empty_refs'}{'contents'}[4]{'args'}[0];
 $result_trees{'novalidate_empty_refs'}{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'novalidate_empty_refs'}{'contents'}[4];
 $result_trees{'novalidate_empty_refs'}{'contents'}[4]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'novalidate_empty_refs'}{'contents'}[4]{'args'}[0]{'contents'}[0];
-$result_trees{'novalidate_empty_refs'}{'contents'}[4]{'line_nr'} = $result_trees{'novalidate_empty_refs'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'novalidate_empty_refs'}{'contents'}[4]{'parent'} = $result_trees{'novalidate_empty_refs'};
 
 $result_texis{'novalidate_empty_refs'} = '
@@ -380,20 +388,8 @@ $result_nodes{'novalidate_empty_refs'} = {
   'extra' => {
     'normalized' => 'Top',
     'spaces_before_argument' => ' '
-  },
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
   }
 };
-$result_nodes{'novalidate_empty_refs'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'novalidate_empty_refs'};
 
 $result_menus{'novalidate_empty_refs'} = {
   'cmdname' => 'node',
@@ -436,6 +432,9 @@ $result_errors{'novalidate_empty_refs'} = [
 ];
 
 
+$result_floats{'novalidate_empty_refs'} = {};
+
+
 
 $result_converted{'info'}->{'novalidate_empty_refs'} = 'This is , produced from .
 
@@ -450,6 +449,11 @@ Tag Table:
 Node: Top27
 
 End Tag Table
+
+
+Local Variables:
+coding: utf-8
+End:
 ';
 
 1;
