@@ -84,7 +84,9 @@ $result_trees{'split_test_before_first_node_no_empty_line'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -293,7 +295,9 @@ $result_trees{'split_test_before_first_node_no_empty_line'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'chap1'
           }
         ],
@@ -375,7 +379,7 @@ $result_trees{'split_test_before_first_node_no_empty_line'}{'contents'}[0]{'pare
 $result_trees{'split_test_before_first_node_no_empty_line'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_test_before_first_node_no_empty_line'}{'contents'}[1]{'args'}[0];
 $result_trees{'split_test_before_first_node_no_empty_line'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'split_test_before_first_node_no_empty_line'}{'contents'}[1];
 $result_trees{'split_test_before_first_node_no_empty_line'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'split_test_before_first_node_no_empty_line'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'split_test_before_first_node_no_empty_line'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'split_test_before_first_node_no_empty_line'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'split_test_before_first_node_no_empty_line'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'split_test_before_first_node_no_empty_line'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'split_test_before_first_node_no_empty_line'}{'contents'}[1]{'parent'} = $result_trees{'split_test_before_first_node_no_empty_line'};
 $result_trees{'split_test_before_first_node_no_empty_line'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_test_before_first_node_no_empty_line'}{'contents'}[2]{'args'}[0];
 $result_trees{'split_test_before_first_node_no_empty_line'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'split_test_before_first_node_no_empty_line'}{'contents'}[2];
@@ -405,7 +409,7 @@ $result_trees{'split_test_before_first_node_no_empty_line'}{'contents'}[2]{'pare
 $result_trees{'split_test_before_first_node_no_empty_line'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_test_before_first_node_no_empty_line'}{'contents'}[3]{'args'}[0];
 $result_trees{'split_test_before_first_node_no_empty_line'}{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'split_test_before_first_node_no_empty_line'}{'contents'}[3];
 $result_trees{'split_test_before_first_node_no_empty_line'}{'contents'}[3]{'extra'}{'node_content'}[0] = $result_trees{'split_test_before_first_node_no_empty_line'}{'contents'}[3]{'args'}[0]{'contents'}[0];
-$result_trees{'split_test_before_first_node_no_empty_line'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'split_test_before_first_node_no_empty_line'}{'contents'}[3]{'extra'}{'node_content'};
+$result_trees{'split_test_before_first_node_no_empty_line'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'split_test_before_first_node_no_empty_line'}{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'split_test_before_first_node_no_empty_line'}{'contents'}[3]{'parent'} = $result_trees{'split_test_before_first_node_no_empty_line'};
 $result_trees{'split_test_before_first_node_no_empty_line'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_test_before_first_node_no_empty_line'}{'contents'}[4]{'args'}[0];
 $result_trees{'split_test_before_first_node_no_empty_line'}{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'split_test_before_first_node_no_empty_line'}{'contents'}[4];
@@ -570,4 +574,7 @@ $result_menus{'split_test_before_first_node_no_empty_line'}{'menu_child'}{'menu_
 $result_errors{'split_test_before_first_node_no_empty_line'} = [];
 
 
+$result_floats{'split_test_before_first_node_no_empty_line'} = {};
+
+
 1;
