@@ -98,7 +98,11 @@ $result_trees{'top_node_normalization'} = {
                   'normalized' => 'Top'
                 }
               },
-              'line_nr' => {},
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 3,
+                'macro' => ''
+              },
               'parent' => {}
             },
             {
@@ -233,7 +237,9 @@ $result_trees{'top_node_normalization'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -264,7 +270,6 @@ $result_trees{'top_node_normalization'}{'contents'}[1]{'contents'}[1]{'contents'
 $result_trees{'top_node_normalization'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'top_node_normalization'}{'contents'}[1]{'contents'}[1]{'contents'}[2];
 $result_trees{'top_node_normalization'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'extra'}{'label'} = $result_trees{'top_node_normalization'}{'contents'}[1];
 $result_trees{'top_node_normalization'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'extra'}{'node_argument'}{'node_content'}[0] = $result_trees{'top_node_normalization'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0];
-$result_trees{'top_node_normalization'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'line_nr'} = $result_trees{'top_node_normalization'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'line_nr'};
 $result_trees{'top_node_normalization'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'top_node_normalization'}{'contents'}[1]{'contents'}[1];
 $result_trees{'top_node_normalization'}{'contents'}[1]{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'top_node_normalization'}{'contents'}[1]{'contents'}[1];
 $result_trees{'top_node_normalization'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'top_node_normalization'}{'contents'}[1];
@@ -287,7 +292,7 @@ $result_trees{'top_node_normalization'}{'contents'}[1]{'contents'}[3]{'contents'
 $result_trees{'top_node_normalization'}{'contents'}[1]{'contents'}[3]{'extra'}{'end_command'} = $result_trees{'top_node_normalization'}{'contents'}[1]{'contents'}[3]{'contents'}[2];
 $result_trees{'top_node_normalization'}{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'top_node_normalization'}{'contents'}[1];
 $result_trees{'top_node_normalization'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'top_node_normalization'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'top_node_normalization'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'top_node_normalization'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'top_node_normalization'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'top_node_normalization'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'top_node_normalization'}{'contents'}[1]{'parent'} = $result_trees{'top_node_normalization'};
 
 $result_texis{'top_node_normalization'} = '@node ToP
@@ -331,23 +336,11 @@ $result_nodes{'top_node_normalization'} = {
     }
   ],
   'node_next' => {},
-  'node_prev' => {},
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
-  }
+  'node_prev' => {}
 };
 $result_nodes{'top_node_normalization'}{'menu_child'} = $result_nodes{'top_node_normalization'};
 $result_nodes{'top_node_normalization'}{'node_next'} = $result_nodes{'top_node_normalization'};
 $result_nodes{'top_node_normalization'}{'node_prev'} = $result_nodes{'top_node_normalization'};
-$result_nodes{'top_node_normalization'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'top_node_normalization'};
 
 $result_menus{'top_node_normalization'} = {
   'cmdname' => 'node',
@@ -391,19 +384,13 @@ $result_errors{'top_node_normalization'} = [
     'macro' => '',
     'text' => '@menu entry node name `tOP\' different from node name `ToP\'',
     'type' => 'warning'
-  },
-  {
-    'error_line' => ':1: warning: for `ToP\', up in menu `ToP\' and up `(dir)\' don\'t match
-',
-    'file_name' => '',
-    'line_nr' => 1,
-    'macro' => '',
-    'text' => 'for `ToP\', up in menu `ToP\' and up `(dir)\' don\'t match',
-    'type' => 'warning'
   }
 ];
 
 
+$result_floats{'top_node_normalization'} = {};
+
+
 
 $result_converted{'info'}->{'top_node_normalization'} = 'This is , produced from .
 
@@ -421,6 +408,11 @@ Tag Table:
 Node: Top27
 
 End Tag Table
+
+
+Local Variables:
+coding: utf-8
+End:
 ';
 
 1;
