@@ -183,7 +183,11 @@ $result_trees{'def_in_style_command'} = {
         'end_command' => {},
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {},
+      'line_nr' => {
+        'file_name' => '',
+        'line_nr' => 2,
+        'macro' => ''
+      },
       'parent' => {}
     }
   ],
@@ -214,7 +218,6 @@ $result_trees{'def_in_style_command'}{'contents'}[1]{'contents'}[2]{'args'}[0]{'
 $result_trees{'def_in_style_command'}{'contents'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'def_in_style_command'}{'contents'}[1]{'contents'}[2];
 $result_trees{'def_in_style_command'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'def_in_style_command'}{'contents'}[1];
 $result_trees{'def_in_style_command'}{'contents'}[1]{'extra'}{'end_command'} = $result_trees{'def_in_style_command'}{'contents'}[1]{'contents'}[2];
-$result_trees{'def_in_style_command'}{'contents'}[1]{'line_nr'} = $result_trees{'def_in_style_command'}{'contents'}[1]{'contents'}[0]{'line_nr'};
 $result_trees{'def_in_style_command'}{'contents'}[1]{'parent'} = $result_trees{'def_in_style_command'};
 
 $result_texis{'def_in_style_command'} = '@code{
@@ -269,4 +272,7 @@ $result_errors{'def_in_style_command'} = [
 ];
 
 
+$result_floats{'def_in_style_command'} = {};
+
+
 1;
