@@ -45,14 +45,6 @@ $result_trees{'multitable_in_style_command'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'contents' => [
                 {
@@ -76,13 +68,12 @@ $result_trees{'multitable_in_style_command'} = {
               ],
               'parent' => {},
               'type' => 'bracketed'
-            },
-            {
-              'parent' => {},
-              'text' => '
-'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
           'type' => 'block_line_arg'
         }
@@ -96,14 +87,6 @@ $result_trees{'multitable_in_style_command'} = {
                 {
                   'cmdname' => 'item',
                   'contents' => [
-                    {
-                      'extra' => {
-                        'command' => {}
-                      },
-                      'parent' => {},
-                      'text' => ' ',
-                      'type' => 'empty_spaces_after_command'
-                    },
                     {
                       'contents' => [
                         {
@@ -117,7 +100,7 @@ $result_trees{'multitable_in_style_command'} = {
                   ],
                   'extra' => {
                     'cell_number' => 1,
-                    'spaces_after_command' => {}
+                    'spaces_before_argument' => ' '
                   },
                   'line_nr' => {
                     'file_name' => '',
@@ -129,14 +112,6 @@ $result_trees{'multitable_in_style_command'} = {
                 {
                   'cmdname' => 'tab',
                   'contents' => [
-                    {
-                      'extra' => {
-                        'command' => {}
-                      },
-                      'parent' => {},
-                      'text' => ' ',
-                      'type' => 'empty_spaces_after_command'
-                    },
                     {
                       'contents' => [
                         {
@@ -151,9 +126,13 @@ $result_trees{'multitable_in_style_command'} = {
                   ],
                   'extra' => {
                     'cell_number' => 2,
-                    'spaces_after_command' => {}
+                    'spaces_before_argument' => ' '
+                  },
+                  'line_nr' => {
+                    'file_name' => '',
+                    'line_nr' => 4,
+                    'macro' => ''
                   },
-                  'line_nr' => {},
                   'parent' => {}
                 }
               ],
@@ -171,34 +150,23 @@ $result_trees{'multitable_in_style_command'} = {
           'args' => [
             {
               'contents' => [
-                {
-                  'extra' => {
-                    'command' => {}
-                  },
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_after_command'
-                },
                 {
                   'parent' => {},
                   'text' => 'multitable'
-                },
-                {
-                  'parent' => {},
-                  'text' => '
-',
-                  'type' => 'spaces_at_end'
                 }
               ],
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
               'parent' => {},
-              'type' => 'misc_line_arg'
+              'type' => 'line_arg'
             }
           ],
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
             'command_argument' => 'multitable',
-            'spaces_after_command' => {},
+            'spaces_before_argument' => ' ',
             'text_arg' => 'multitable'
           },
           'line_nr' => {
@@ -211,38 +179,22 @@ $result_trees{'multitable_in_style_command'} = {
       ],
       'extra' => {
         'end_command' => {},
-        'invalid_nesting' => 1,
         'max_columns' => 2,
         'prototypes' => [
           {
-            'contents' => [],
-            'parent' => {},
+            'contents' => [
+              {}
+            ],
             'type' => 'bracketed_multitable_prototype'
           },
           {
-            'contents' => [],
-            'parent' => {},
+            'contents' => [
+              {}
+            ],
             'type' => 'bracketed_multitable_prototype'
           }
         ],
-        'prototypes_line' => [
-          {
-            'text' => ' ',
-            'type' => 'prototype_space'
-          },
-          {},
-          {
-            'text' => ' ',
-            'type' => 'prototype_space'
-          },
-          {},
-          {
-            'text' => '
-',
-            'type' => 'prototype_space'
-          }
-        ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'line_nr' => {
         'file_name' => '',
@@ -259,46 +211,26 @@ $result_trees{'multitable_in_style_command'}{'contents'}[0]{'contents'}[0]{'args
 $result_trees{'multitable_in_style_command'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'multitable_in_style_command'}{'contents'}[0]{'contents'}[0];
 $result_trees{'multitable_in_style_command'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'multitable_in_style_command'}{'contents'}[0];
 $result_trees{'multitable_in_style_command'}{'contents'}[0]{'parent'} = $result_trees{'multitable_in_style_command'};
-$result_trees{'multitable_in_style_command'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'multitable_in_style_command'}{'contents'}[1];
+$result_trees{'multitable_in_style_command'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'multitable_in_style_command'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'args'}[0];
-$result_trees{'multitable_in_style_command'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'args'}[0]{'contents'}[1];
 $result_trees{'multitable_in_style_command'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'args'}[0];
+$result_trees{'multitable_in_style_command'}{'contents'}[1]{'args'}[0]{'contents'}[2]{'contents'}[0]{'parent'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'args'}[0]{'contents'}[2];
 $result_trees{'multitable_in_style_command'}{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'args'}[0];
-$result_trees{'multitable_in_style_command'}{'contents'}[1]{'args'}[0]{'contents'}[3]{'contents'}[0]{'parent'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'args'}[0]{'contents'}[3];
-$result_trees{'multitable_in_style_command'}{'contents'}[1]{'args'}[0]{'contents'}[3]{'parent'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'args'}[0];
-$result_trees{'multitable_in_style_command'}{'contents'}[1]{'args'}[0]{'contents'}[4]{'parent'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'args'}[0];
 $result_trees{'multitable_in_style_command'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'multitable_in_style_command'}{'contents'}[1];
-$result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0];
+$result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[0];
 $result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0];
-$result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1];
-$result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0];
-$result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[0];
 $result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0]{'contents'}[0];
-$result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'contents'}[0]{'extra'}{'command'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[1];
+$result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'contents'}[0];
 $result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[1];
-$result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'contents'}[1];
-$result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[1];
-$result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'contents'}[0];
-$result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'line_nr'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0]{'contents'}[0];
 $result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0];
 $result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'multitable_in_style_command'}{'contents'}[1];
-$result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[1];
 $result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[1]{'args'}[0];
-$result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[1]{'args'}[0];
-$result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[1]{'args'}[0];
 $result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[1];
-$result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[1]{'extra'}{'command'} = $result_trees{'multitable_in_style_command'}{'contents'}[1];
-$result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'multitable_in_style_command'}{'contents'}[1];
 $result_trees{'multitable_in_style_command'}{'contents'}[1]{'extra'}{'end_command'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'contents'}[1];
-$result_trees{'multitable_in_style_command'}{'contents'}[1]{'extra'}{'prototypes'}[0]{'contents'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'contents'};
-$result_trees{'multitable_in_style_command'}{'contents'}[1]{'extra'}{'prototypes'}[0]{'parent'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'args'}[0];
-$result_trees{'multitable_in_style_command'}{'contents'}[1]{'extra'}{'prototypes'}[1]{'contents'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'args'}[0]{'contents'}[3]{'contents'};
-$result_trees{'multitable_in_style_command'}{'contents'}[1]{'extra'}{'prototypes'}[1]{'parent'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'args'}[0];
-$result_trees{'multitable_in_style_command'}{'contents'}[1]{'extra'}{'prototypes_line'}[1] = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'args'}[0]{'contents'}[1];
-$result_trees{'multitable_in_style_command'}{'contents'}[1]{'extra'}{'prototypes_line'}[3] = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'args'}[0]{'contents'}[3];
-$result_trees{'multitable_in_style_command'}{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'args'}[0]{'contents'}[0];
+$result_trees{'multitable_in_style_command'}{'contents'}[1]{'extra'}{'prototypes'}[0]{'contents'}[0] = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'contents'}[0];
+$result_trees{'multitable_in_style_command'}{'contents'}[1]{'extra'}{'prototypes'}[1]{'contents'}[0] = $result_trees{'multitable_in_style_command'}{'contents'}[1]{'args'}[0]{'contents'}[2]{'contents'}[0];
 $result_trees{'multitable_in_style_command'}{'contents'}[1]{'parent'} = $result_trees{'multitable_in_style_command'};
 
 $result_texis{'multitable_in_style_command'} = '@code{
@@ -315,15 +247,6 @@ truc machin
 ';
 
 $result_errors{'multitable_in_style_command'} = [
-  {
-    'error_line' => ':1: @code missing close brace
-',
-    'file_name' => '',
-    'line_nr' => 1,
-    'macro' => '',
-    'text' => '@code missing close brace',
-    'type' => 'error'
-  },
   {
     'error_line' => ':3: warning: @multitable should not appear in @code
 ',
@@ -333,6 +256,15 @@ $result_errors{'multitable_in_style_command'} = [
     'text' => '@multitable should not appear in @code',
     'type' => 'warning'
   },
+  {
+    'error_line' => ':1: @code missing closing brace
+',
+    'file_name' => '',
+    'line_nr' => 1,
+    'macro' => '',
+    'text' => '@code missing closing brace',
+    'type' => 'error'
+  },
   {
     'error_line' => ':6: misplaced }
 ',
@@ -345,4 +277,7 @@ $result_errors{'multitable_in_style_command'} = [
 ];
 
 
+$result_floats{'multitable_in_style_command'} = {};
+
+
 1;
