@@ -1,15 +1,16 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
 $result_trees{'on_section_line'} = {
   'contents' => [
     {
+      'contents' => [],
       'parent' => {},
-      'type' => 'before_node_section'
+      'type' => 'text_root'
     },
     {
       'args' => [
@@ -17,17 +18,20 @@ $result_trees{'on_section_line'} = {
           'contents' => [
             {
               'cmdname' => 'noindent',
-              'parent' => {},
-              'source_info' => {
+              'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 1,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             },
             {
+              'extra' => {
+                'command' => {}
+              },
               'parent' => {},
               'text' => ' ',
-              'type' => 'ignorable_spaces_after_command'
+              'type' => 'empty_spaces_after_command'
             },
             {
               'parent' => {},
@@ -47,12 +51,13 @@ $result_trees{'on_section_line'} = {
                 }
               ],
               'cmdname' => 'titlefont',
-              'parent' => {},
-              'source_info' => {
+              'contents' => [],
+              'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 1,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             },
             {
               'parent' => {},
@@ -72,18 +77,19 @@ $result_trees{'on_section_line'} = {
                 }
               ],
               'cmdname' => 'anchor',
+              'contents' => [],
               'extra' => {
                 'node_content' => [
                   {}
                 ],
                 'normalized' => 'in-anchor'
               },
-              'parent' => {},
-              'source_info' => {
+              'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 1,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             },
             {
               'args' => [
@@ -105,12 +111,13 @@ $result_trees{'on_section_line'} = {
                 }
               ],
               'cmdname' => 'footnote',
-              'parent' => {},
-              'source_info' => {
+              'contents' => [],
+              'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 1,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             },
             {
               'parent' => {},
@@ -137,12 +144,12 @@ $result_trees{'on_section_line'} = {
               'extra' => {
                 'spaces_before_argument' => ' '
               },
-              'parent' => {},
-              'source_info' => {
+              'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 1,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             }
           ],
           'parent' => {},
@@ -150,21 +157,25 @@ $result_trees{'on_section_line'} = {
         }
       ],
       'cmdname' => 'section',
+      'contents' => [],
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 2,
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 1,
         'macro' => ''
-      }
+      },
+      'number' => 1,
+      'parent' => {}
     }
   ],
   'type' => 'document_root'
 };
 $result_trees{'on_section_line'}{'contents'}[0]{'parent'} = $result_trees{'on_section_line'};
 $result_trees{'on_section_line'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'on_section_line'}{'contents'}[1]{'args'}[0];
+$result_trees{'on_section_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'extra'}{'command'} = $result_trees{'on_section_line'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'on_section_line'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'on_section_line'}{'contents'}[1]{'args'}[0];
 $result_trees{'on_section_line'}{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'on_section_line'}{'contents'}[1]{'args'}[0];
 $result_trees{'on_section_line'}{'contents'}[1]{'args'}[0]{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'on_section_line'}{'contents'}[1]{'args'}[0]{'contents'}[3]{'args'}[0];
@@ -195,26 +206,24 @@ $result_texts{'on_section_line'} = '1 Text in titlefont  exdent
 ';
 
 $result_sectioning{'on_section_line'} = {
-  'structure' => {
-    'section_childs' => [
-      {
-        'cmdname' => 'section',
-        'extra' => {},
-        'structure' => {
-          'section_level' => 2,
-          'section_number' => 1,
-          'section_up' => {}
-        }
-      }
-    ],
-    'section_level' => 1
-  }
+  'level' => 1,
+  'section_childs' => [
+    {
+      'cmdname' => 'section',
+      'extra' => {
+        'spaces_before_argument' => ' '
+      },
+      'level' => 2,
+      'number' => 1,
+      'section_up' => {}
+    }
+  ]
 };
-$result_sectioning{'on_section_line'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'on_section_line'};
+$result_sectioning{'on_section_line'}{'section_childs'}[0]{'section_up'} = $result_sectioning{'on_section_line'};
 
 $result_errors{'on_section_line'} = [
   {
-    'error_line' => 'warning: @noindent should not appear in @section
+    'error_line' => ':1: warning: @noindent should not appear in @section
 ',
     'file_name' => '',
     'line_nr' => 1,
@@ -223,7 +232,7 @@ $result_errors{'on_section_line'} = [
     'type' => 'warning'
   },
   {
-    'error_line' => 'warning: @titlefont should not appear in @section
+    'error_line' => ':1: warning: @titlefont should not appear in @section
 ',
     'file_name' => '',
     'line_nr' => 1,
@@ -232,7 +241,7 @@ $result_errors{'on_section_line'} = [
     'type' => 'warning'
   },
   {
-    'error_line' => 'warning: @anchor should not appear in @section
+    'error_line' => ':1: warning: @anchor should not appear in @section
 ',
     'file_name' => '',
     'line_nr' => 1,
@@ -241,7 +250,7 @@ $result_errors{'on_section_line'} = [
     'type' => 'warning'
   },
   {
-    'error_line' => 'warning: @footnote should not appear in @section
+    'error_line' => ':1: warning: @footnote should not appear in @section
 ',
     'file_name' => '',
     'line_nr' => 1,
@@ -250,7 +259,7 @@ $result_errors{'on_section_line'} = [
     'type' => 'warning'
   },
   {
-    'error_line' => 'warning: @exdent should only appear at the beginning of a line
+    'error_line' => ':1: warning: @exdent should only appear at the beginning of a line
 ',
     'file_name' => '',
     'line_nr' => 1,
@@ -259,7 +268,7 @@ $result_errors{'on_section_line'} = [
     'type' => 'warning'
   },
   {
-    'error_line' => 'warning: @exdent should not appear in @section
+    'error_line' => ':1: warning: @exdent should not appear in @section
 ',
     'file_name' => '',
     'line_nr' => 1,
