@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
@@ -10,18 +10,17 @@ $result_trees{'section_in_copying'} = {
     {
       'contents' => [
         {
-          'args' => [
-            {
-              'extra' => {
-                'spaces_after_argument' => '
-'
-              },
-              'parent' => {},
-              'type' => 'block_line_arg'
-            }
-          ],
           'cmdname' => 'copying',
           'contents' => [
+            {
+              'extra' => {
+                'command' => {}
+              },
+              'parent' => {},
+              'text' => '
+',
+              'type' => 'empty_line_after_command'
+            },
             {
               'parent' => {},
               'text' => '
@@ -46,16 +45,16 @@ $result_trees{'section_in_copying'} = {
               'type' => 'empty_line'
             }
           ],
-          'parent' => {},
-          'source_info' => {
+          'line_nr' => {
             'file_name' => '',
             'line_nr' => 1,
             'macro' => ''
-          }
+          },
+          'parent' => {}
         }
       ],
       'parent' => {},
-      'type' => 'before_node_section'
+      'type' => 'text_root'
     },
     {
       'args' => [
@@ -75,24 +74,28 @@ $result_trees{'section_in_copying'} = {
         }
       ],
       'cmdname' => 'section',
+      'contents' => [],
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 2,
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 5,
         'macro' => ''
-      }
+      },
+      'number' => 1,
+      'parent' => {}
     }
   ],
   'type' => 'document_root'
 };
-$result_trees{'section_in_copying'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'section_in_copying'}{'contents'}[0]{'contents'}[0];
+$result_trees{'section_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'section_in_copying'}{'contents'}[0]{'contents'}[0];
 $result_trees{'section_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'section_in_copying'}{'contents'}[0]{'contents'}[0];
-$result_trees{'section_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'section_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[1];
 $result_trees{'section_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'section_in_copying'}{'contents'}[0]{'contents'}[0];
+$result_trees{'section_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[2]{'contents'}[0]{'parent'} = $result_trees{'section_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[2];
 $result_trees{'section_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'section_in_copying'}{'contents'}[0]{'contents'}[0];
+$result_trees{'section_in_copying'}{'contents'}[0]{'contents'}[0]{'contents'}[3]{'parent'} = $result_trees{'section_in_copying'}{'contents'}[0]{'contents'}[0];
 $result_trees{'section_in_copying'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'section_in_copying'}{'contents'}[0];
 $result_trees{'section_in_copying'}{'contents'}[0]{'parent'} = $result_trees{'section_in_copying'};
 $result_trees{'section_in_copying'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'section_in_copying'}{'contents'}[1]{'args'}[0];
@@ -112,26 +115,24 @@ $result_texts{'section_in_copying'} = '1 section
 ';
 
 $result_sectioning{'section_in_copying'} = {
-  'structure' => {
-    'section_childs' => [
-      {
-        'cmdname' => 'section',
-        'extra' => {},
-        'structure' => {
-          'section_level' => 2,
-          'section_number' => 1,
-          'section_up' => {}
-        }
-      }
-    ],
-    'section_level' => 1
-  }
+  'level' => 1,
+  'section_childs' => [
+    {
+      'cmdname' => 'section',
+      'extra' => {
+        'spaces_before_argument' => ' '
+      },
+      'level' => 2,
+      'number' => 1,
+      'section_up' => {}
+    }
+  ]
 };
-$result_sectioning{'section_in_copying'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'section_in_copying'};
+$result_sectioning{'section_in_copying'}{'section_childs'}[0]{'section_up'} = $result_sectioning{'section_in_copying'};
 
 $result_errors{'section_in_copying'} = [
   {
-    'error_line' => '@section seen before @end copying
+    'error_line' => ':5: @section seen before @end copying
 ',
     'file_name' => '',
     'line_nr' => 5,
