@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
@@ -37,16 +37,17 @@ $result_trees{'section_in_footnote'} = {
                 }
               ],
               'cmdname' => 'footnote',
+              'contents' => [],
               'extra' => {
                 'spaces_before_argument' => '
 '
               },
-              'parent' => {},
-              'source_info' => {
+              'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 2,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             }
           ],
           'parent' => {},
@@ -54,7 +55,7 @@ $result_trees{'section_in_footnote'} = {
         }
       ],
       'parent' => {},
-      'type' => 'before_node_section'
+      'type' => 'text_root'
     },
     {
       'args' => [
@@ -74,15 +75,18 @@ $result_trees{'section_in_footnote'} = {
         }
       ],
       'cmdname' => 'section',
+      'contents' => [],
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 2,
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 4,
         'macro' => ''
-      }
+      },
+      'number' => 1,
+      'parent' => {}
     }
   ],
   'type' => 'document_root'
@@ -111,26 +115,24 @@ Text1 a section
 ';
 
 $result_sectioning{'section_in_footnote'} = {
-  'structure' => {
-    'section_childs' => [
-      {
-        'cmdname' => 'section',
-        'extra' => {},
-        'structure' => {
-          'section_level' => 2,
-          'section_number' => 1,
-          'section_up' => {}
-        }
-      }
-    ],
-    'section_level' => 1
-  }
+  'level' => 1,
+  'section_childs' => [
+    {
+      'cmdname' => 'section',
+      'extra' => {
+        'spaces_before_argument' => ' '
+      },
+      'level' => 2,
+      'number' => 1,
+      'section_up' => {}
+    }
+  ]
 };
-$result_sectioning{'section_in_footnote'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'section_in_footnote'};
+$result_sectioning{'section_in_footnote'}{'section_childs'}[0]{'section_up'} = $result_sectioning{'section_in_footnote'};
 
 $result_errors{'section_in_footnote'} = [
   {
-    'error_line' => '@section seen before @footnote closing brace
+    'error_line' => ':2: @section seen before @footnote closing brace
 ',
     'file_name' => '',
     'line_nr' => 2,
