@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
@@ -43,12 +43,12 @@ $result_trees{'section_in_math'} = {
                           'type' => 'empty_line'
                         }
                       ],
-                      'parent' => {},
-                      'source_info' => {
+                      'line_nr' => {
                         'file_name' => '',
                         'line_nr' => 2,
                         'macro' => ''
                       },
+                      'parent' => {},
                       'type' => 'bracketed'
                     }
                   ],
@@ -57,12 +57,13 @@ $result_trees{'section_in_math'} = {
                 }
               ],
               'cmdname' => 'math',
-              'parent' => {},
-              'source_info' => {
+              'contents' => [],
+              'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 2,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             }
           ],
           'parent' => {},
@@ -70,7 +71,7 @@ $result_trees{'section_in_math'} = {
         }
       ],
       'parent' => {},
-      'type' => 'before_node_section'
+      'type' => 'text_root'
     },
     {
       'args' => [
@@ -124,15 +125,16 @@ $result_trees{'section_in_math'} = {
                 }
               ],
               'cmdname' => 'math',
+              'contents' => [],
               'extra' => {
                 'spaces_before_argument' => ' '
               },
-              'parent' => {},
-              'source_info' => {
+              'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 6,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             }
           ],
           'parent' => {},
@@ -142,12 +144,14 @@ $result_trees{'section_in_math'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 2,
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 4,
         'macro' => ''
-      }
+      },
+      'number' => 1,
+      'parent' => {}
     },
     {
       'args' => [
@@ -167,15 +171,18 @@ $result_trees{'section_in_math'} = {
         }
       ],
       'cmdname' => 'section',
+      'contents' => [],
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 2,
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 8,
         'macro' => ''
-      }
+      },
+      'number' => 2,
+      'parent' => {}
     }
   ],
   'type' => 'document_root'
@@ -228,40 +235,38 @@ More in math
 ';
 
 $result_sectioning{'section_in_math'} = {
-  'structure' => {
-    'section_childs' => [
-      {
-        'cmdname' => 'section',
-        'extra' => {},
-        'structure' => {
-          'section_level' => 2,
-          'section_number' => 1,
-          'section_up' => {}
-        }
+  'level' => 1,
+  'section_childs' => [
+    {
+      'cmdname' => 'section',
+      'extra' => {
+        'spaces_before_argument' => ' '
       },
-      {
-        'cmdname' => 'section',
-        'extra' => {},
-        'structure' => {
-          'section_level' => 2,
-          'section_number' => 2,
-          'section_prev' => {},
-          'section_up' => {},
-          'toplevel_prev' => {}
-        }
-      }
-    ],
-    'section_level' => 1
-  }
+      'level' => 2,
+      'number' => 1,
+      'section_up' => {}
+    },
+    {
+      'cmdname' => 'section',
+      'extra' => {
+        'spaces_before_argument' => ' '
+      },
+      'level' => 2,
+      'number' => 2,
+      'section_prev' => {},
+      'section_up' => {},
+      'toplevel_prev' => {}
+    }
+  ]
 };
-$result_sectioning{'section_in_math'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'section_in_math'};
-$result_sectioning{'section_in_math'}{'structure'}{'section_childs'}[1]{'structure'}{'section_prev'} = $result_sectioning{'section_in_math'}{'structure'}{'section_childs'}[0];
-$result_sectioning{'section_in_math'}{'structure'}{'section_childs'}[1]{'structure'}{'section_up'} = $result_sectioning{'section_in_math'};
-$result_sectioning{'section_in_math'}{'structure'}{'section_childs'}[1]{'structure'}{'toplevel_prev'} = $result_sectioning{'section_in_math'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'section_in_math'}{'section_childs'}[0]{'section_up'} = $result_sectioning{'section_in_math'};
+$result_sectioning{'section_in_math'}{'section_childs'}[1]{'section_prev'} = $result_sectioning{'section_in_math'}{'section_childs'}[0];
+$result_sectioning{'section_in_math'}{'section_childs'}[1]{'section_up'} = $result_sectioning{'section_in_math'};
+$result_sectioning{'section_in_math'}{'section_childs'}[1]{'toplevel_prev'} = $result_sectioning{'section_in_math'}{'section_childs'}[0];
 
 $result_errors{'section_in_math'} = [
   {
-    'error_line' => 'misplaced {
+    'error_line' => ':2: misplaced {
 ',
     'file_name' => '',
     'line_nr' => 2,
@@ -270,7 +275,7 @@ $result_errors{'section_in_math'} = [
     'type' => 'error'
   },
   {
-    'error_line' => '@section seen before @math closing brace
+    'error_line' => ':2: @section seen before @math closing brace
 ',
     'file_name' => '',
     'line_nr' => 2,
@@ -279,7 +284,7 @@ $result_errors{'section_in_math'} = [
     'type' => 'error'
   },
   {
-    'error_line' => 'warning: @section should not appear in @math
+    'error_line' => ':8: warning: @section should not appear in @math
 ',
     'file_name' => '',
     'line_nr' => 8,
@@ -288,7 +293,7 @@ $result_errors{'section_in_math'} = [
     'type' => 'warning'
   },
   {
-    'error_line' => '@section seen before @math closing brace
+    'error_line' => ':6: @section seen before @math closing brace
 ',
     'file_name' => '',
     'line_nr' => 6,
