@@ -144,7 +144,11 @@ $result_trees{'section_on_defx_line'} = {
           'extra' => {
             'spaces_before_argument' => ' '
           },
-          'line_nr' => {},
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 1,
+            'macro' => ''
+          },
           'parent' => {}
         }
       ],
@@ -198,7 +202,11 @@ $result_trees{'section_on_defx_line'} = {
         'spaces_before_argument' => ' '
       },
       'level' => 2,
-      'line_nr' => {},
+      'line_nr' => {
+        'file_name' => '',
+        'line_nr' => 2,
+        'macro' => ''
+      },
       'number' => 1,
       'parent' => {}
     }
@@ -223,7 +231,6 @@ $result_trees{'section_on_defx_line'}{'contents'}[0]{'contents'}[0]{'contents'}[
 $result_trees{'section_on_defx_line'}{'contents'}[0]{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'section_on_defx_line'}{'contents'}[0]{'contents'}[0]{'contents'}[1]{'args'}[0];
 $result_trees{'section_on_defx_line'}{'contents'}[0]{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'section_on_defx_line'}{'contents'}[0]{'contents'}[0]{'contents'}[1];
 $result_trees{'section_on_defx_line'}{'contents'}[0]{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'section_on_defx_line'}{'contents'}[0]{'contents'}[0];
-$result_trees{'section_on_defx_line'}{'contents'}[0]{'contents'}[0]{'line_nr'} = $result_trees{'section_on_defx_line'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'section_on_defx_line'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'section_on_defx_line'}{'contents'}[0];
 $result_trees{'section_on_defx_line'}{'contents'}[0]{'parent'} = $result_trees{'section_on_defx_line'};
 $result_trees{'section_on_defx_line'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'section_on_defx_line'}{'contents'}[1]{'args'}[0];
@@ -232,7 +239,6 @@ $result_trees{'section_on_defx_line'}{'contents'}[1]{'contents'}[0]{'parent'} =
 $result_trees{'section_on_defx_line'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'section_on_defx_line'}{'contents'}[1]{'contents'}[1];
 $result_trees{'section_on_defx_line'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'section_on_defx_line'}{'contents'}[1];
 $result_trees{'section_on_defx_line'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'section_on_defx_line'}{'contents'}[1];
-$result_trees{'section_on_defx_line'}{'contents'}[1]{'line_nr'} = $result_trees{'section_on_defx_line'}{'contents'}[0]{'contents'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'section_on_defx_line'}{'contents'}[1]{'parent'} = $result_trees{'section_on_defx_line'};
 
 $result_texis{'section_on_defx_line'} = '@deffn h j k l 
@@ -316,4 +322,7 @@ $result_errors{'section_on_defx_line'} = [
 ];
 
 
+$result_floats{'section_on_defx_line'} = {};
+
+
 1;
