@@ -85,7 +85,9 @@ $result_trees{'style_not_closed_before_first_node'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -113,7 +115,7 @@ $result_trees{'style_not_closed_before_first_node'}{'contents'}[1]{'args'}[0]{'p
 $result_trees{'style_not_closed_before_first_node'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'style_not_closed_before_first_node'}{'contents'}[1]{'contents'}[0];
 $result_trees{'style_not_closed_before_first_node'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'style_not_closed_before_first_node'}{'contents'}[1];
 $result_trees{'style_not_closed_before_first_node'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'style_not_closed_before_first_node'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'style_not_closed_before_first_node'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'style_not_closed_before_first_node'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'style_not_closed_before_first_node'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'style_not_closed_before_first_node'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'style_not_closed_before_first_node'}{'contents'}[1]{'parent'} = $result_trees{'style_not_closed_before_first_node'};
 
 $result_texis{'style_not_closed_before_first_node'} = '@code{in code
@@ -135,20 +137,8 @@ $result_nodes{'style_not_closed_before_first_node'} = {
   'extra' => {
     'normalized' => 'Top',
     'spaces_before_argument' => ' '
-  },
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
   }
 };
-$result_nodes{'style_not_closed_before_first_node'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'style_not_closed_before_first_node'};
 
 $result_menus{'style_not_closed_before_first_node'} = {
   'cmdname' => 'node',
@@ -171,4 +161,7 @@ $result_errors{'style_not_closed_before_first_node'} = [
 ];
 
 
+$result_floats{'style_not_closed_before_first_node'} = {};
+
+
 1;
