@@ -37,7 +37,9 @@ $result_trees{'style_not_closed_no_newline_root_commands'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -258,7 +260,9 @@ $result_trees{'style_not_closed_no_newline_root_commands'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'chapter'
           }
         ],
@@ -358,7 +362,7 @@ $result_trees{'style_not_closed_no_newline_root_commands'}{'contents'}[0]{'paren
 $result_trees{'style_not_closed_no_newline_root_commands'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'style_not_closed_no_newline_root_commands'}{'contents'}[1]{'args'}[0];
 $result_trees{'style_not_closed_no_newline_root_commands'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'style_not_closed_no_newline_root_commands'}{'contents'}[1];
 $result_trees{'style_not_closed_no_newline_root_commands'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'style_not_closed_no_newline_root_commands'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'style_not_closed_no_newline_root_commands'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'style_not_closed_no_newline_root_commands'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'style_not_closed_no_newline_root_commands'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'style_not_closed_no_newline_root_commands'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'style_not_closed_no_newline_root_commands'}{'contents'}[1]{'parent'} = $result_trees{'style_not_closed_no_newline_root_commands'};
 $result_trees{'style_not_closed_no_newline_root_commands'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'style_not_closed_no_newline_root_commands'}{'contents'}[2]{'args'}[0];
 $result_trees{'style_not_closed_no_newline_root_commands'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'style_not_closed_no_newline_root_commands'}{'contents'}[2];
@@ -389,7 +393,7 @@ $result_trees{'style_not_closed_no_newline_root_commands'}{'contents'}[2]{'paren
 $result_trees{'style_not_closed_no_newline_root_commands'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'style_not_closed_no_newline_root_commands'}{'contents'}[3]{'args'}[0];
 $result_trees{'style_not_closed_no_newline_root_commands'}{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'style_not_closed_no_newline_root_commands'}{'contents'}[3];
 $result_trees{'style_not_closed_no_newline_root_commands'}{'contents'}[3]{'extra'}{'node_content'}[0] = $result_trees{'style_not_closed_no_newline_root_commands'}{'contents'}[3]{'args'}[0]{'contents'}[0];
-$result_trees{'style_not_closed_no_newline_root_commands'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'style_not_closed_no_newline_root_commands'}{'contents'}[3]{'extra'}{'node_content'};
+$result_trees{'style_not_closed_no_newline_root_commands'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'style_not_closed_no_newline_root_commands'}{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'style_not_closed_no_newline_root_commands'}{'contents'}[3]{'parent'} = $result_trees{'style_not_closed_no_newline_root_commands'};
 $result_trees{'style_not_closed_no_newline_root_commands'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'style_not_closed_no_newline_root_commands'}{'contents'}[4]{'args'}[0];
 $result_trees{'style_not_closed_no_newline_root_commands'}{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'style_not_closed_no_newline_root_commands'}{'contents'}[4];
@@ -520,23 +524,11 @@ $result_nodes{'style_not_closed_no_newline_root_commands'} = {
       }
     }
   ],
-  'node_next' => {},
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
-  }
+  'node_next' => {}
 };
 $result_nodes{'style_not_closed_no_newline_root_commands'}{'menu_child'}{'node_prev'} = $result_nodes{'style_not_closed_no_newline_root_commands'};
 $result_nodes{'style_not_closed_no_newline_root_commands'}{'menu_child'}{'node_up'} = $result_nodes{'style_not_closed_no_newline_root_commands'};
 $result_nodes{'style_not_closed_no_newline_root_commands'}{'node_next'} = $result_nodes{'style_not_closed_no_newline_root_commands'}{'menu_child'};
-$result_nodes{'style_not_closed_no_newline_root_commands'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'style_not_closed_no_newline_root_commands'};
 
 $result_menus{'style_not_closed_no_newline_root_commands'} = {
   'cmdname' => 'node',
@@ -598,4 +590,7 @@ $result_errors{'style_not_closed_no_newline_root_commands'} = [
 ];
 
 
+$result_floats{'style_not_closed_no_newline_root_commands'} = {};
+
+
 1;
