@@ -16,27 +16,17 @@ $result_trees{'verbatim_in_ref'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'Top'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'node',
@@ -62,27 +52,17 @@ $result_trees{'verbatim_in_ref'} = {
                   'type' => 'brace_command_arg'
                 },
                 {
-                  'contents' => [
-                    {
-                      'parent' => {},
-                      'text' => ' 
-',
-                      'type' => 'empty_spaces_before_argument'
-                    }
-                  ],
+                  'contents' => [],
+                  'extra' => {
+                    'spaces_before_argument' => ' 
+'
+                  },
                   'parent' => {},
                   'type' => 'brace_command_arg'
                 }
               ],
               'cmdname' => 'xref',
               'contents' => [],
-              'extra' => {
-                'brace_command_contents' => [
-                  [
-                    {}
-                  ]
-                ]
-              },
               'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 3,
@@ -113,10 +93,6 @@ $result_trees{'verbatim_in_ref'} = {
               'type' => 'raw'
             }
           ],
-          'extra' => {
-            'invalid_nesting' => 1,
-            'spaces_after_command' => {}
-          },
           'line_nr' => {
             'file_name' => '',
             'line_nr' => 4,
@@ -125,9 +101,6 @@ $result_trees{'verbatim_in_ref'} = {
           'parent' => {}
         },
         {
-          'extra' => {
-            'command' => {}
-          },
           'parent' => {},
           'text' => '
 ',
@@ -156,12 +129,14 @@ $result_trees{'verbatim_in_ref'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
         'normalized' => 'Top',
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'line_nr' => {
         'file_name' => '',
@@ -174,32 +149,24 @@ $result_trees{'verbatim_in_ref'} = {
   'type' => 'document_root'
 };
 $result_trees{'verbatim_in_ref'}{'contents'}[0]{'parent'} = $result_trees{'verbatim_in_ref'};
-$result_trees{'verbatim_in_ref'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'verbatim_in_ref'}{'contents'}[1];
 $result_trees{'verbatim_in_ref'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'verbatim_in_ref'}{'contents'}[1]{'args'}[0];
-$result_trees{'verbatim_in_ref'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'verbatim_in_ref'}{'contents'}[1]{'args'}[0];
-$result_trees{'verbatim_in_ref'}{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'verbatim_in_ref'}{'contents'}[1]{'args'}[0];
 $result_trees{'verbatim_in_ref'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'verbatim_in_ref'}{'contents'}[1];
 $result_trees{'verbatim_in_ref'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'verbatim_in_ref'}{'contents'}[1];
 $result_trees{'verbatim_in_ref'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'verbatim_in_ref'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[0];
 $result_trees{'verbatim_in_ref'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'verbatim_in_ref'}{'contents'}[1]{'contents'}[1]{'contents'}[0];
-$result_trees{'verbatim_in_ref'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'verbatim_in_ref'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[1];
 $result_trees{'verbatim_in_ref'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[1]{'parent'} = $result_trees{'verbatim_in_ref'}{'contents'}[1]{'contents'}[1]{'contents'}[0];
-$result_trees{'verbatim_in_ref'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'verbatim_in_ref'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'verbatim_in_ref'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'verbatim_in_ref'}{'contents'}[1]{'contents'}[1];
 $result_trees{'verbatim_in_ref'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'verbatim_in_ref'}{'contents'}[1];
 $result_trees{'verbatim_in_ref'}{'contents'}[1]{'contents'}[2]{'contents'}[0]{'extra'}{'command'} = $result_trees{'verbatim_in_ref'}{'contents'}[1]{'contents'}[2];
 $result_trees{'verbatim_in_ref'}{'contents'}[1]{'contents'}[2]{'contents'}[0]{'parent'} = $result_trees{'verbatim_in_ref'}{'contents'}[1]{'contents'}[2];
 $result_trees{'verbatim_in_ref'}{'contents'}[1]{'contents'}[2]{'contents'}[1]{'parent'} = $result_trees{'verbatim_in_ref'}{'contents'}[1]{'contents'}[2];
-$result_trees{'verbatim_in_ref'}{'contents'}[1]{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'verbatim_in_ref'}{'contents'}[1]{'contents'}[2]{'contents'}[0];
 $result_trees{'verbatim_in_ref'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'verbatim_in_ref'}{'contents'}[1];
-$result_trees{'verbatim_in_ref'}{'contents'}[1]{'contents'}[3]{'extra'}{'command'} = $result_trees{'verbatim_in_ref'}{'contents'}[1]{'contents'}[2];
 $result_trees{'verbatim_in_ref'}{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'verbatim_in_ref'}{'contents'}[1];
 $result_trees{'verbatim_in_ref'}{'contents'}[1]{'contents'}[4]{'parent'} = $result_trees{'verbatim_in_ref'}{'contents'}[1];
 $result_trees{'verbatim_in_ref'}{'contents'}[1]{'contents'}[5]{'contents'}[0]{'parent'} = $result_trees{'verbatim_in_ref'}{'contents'}[1]{'contents'}[5];
 $result_trees{'verbatim_in_ref'}{'contents'}[1]{'contents'}[5]{'parent'} = $result_trees{'verbatim_in_ref'}{'contents'}[1];
-$result_trees{'verbatim_in_ref'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'verbatim_in_ref'}{'contents'}[1]{'args'}[0]{'contents'}[1];
-$result_trees{'verbatim_in_ref'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'verbatim_in_ref'}{'contents'}[1]{'extra'}{'node_content'};
-$result_trees{'verbatim_in_ref'}{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'verbatim_in_ref'}{'contents'}[1]{'args'}[0]{'contents'}[0];
+$result_trees{'verbatim_in_ref'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'verbatim_in_ref'}{'contents'}[1]{'args'}[0]{'contents'}[0];
+$result_trees{'verbatim_in_ref'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'verbatim_in_ref'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'verbatim_in_ref'}{'contents'}[1]{'parent'} = $result_trees{'verbatim_in_ref'};
 
 $result_texis{'verbatim_in_ref'} = '@node Top
@@ -221,39 +188,20 @@ $result_sectioning{'verbatim_in_ref'} = {};
 $result_nodes{'verbatim_in_ref'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top'
-  },
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   }
 };
-$result_nodes{'verbatim_in_ref'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'verbatim_in_ref'};
 
 $result_menus{'verbatim_in_ref'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   }
 };
 
 $result_errors{'verbatim_in_ref'} = [
-  {
-    'error_line' => ':3: @xref missing closing brace
-',
-    'file_name' => '',
-    'line_nr' => 3,
-    'macro' => '',
-    'text' => '@xref missing closing brace',
-    'type' => 'error'
-  },
   {
     'error_line' => ':4: warning: @verbatim should not appear in @xref
 ',
@@ -263,6 +211,15 @@ $result_errors{'verbatim_in_ref'} = [
     'text' => '@verbatim should not appear in @xref',
     'type' => 'warning'
   },
+  {
+    'error_line' => ':3: @xref missing closing brace
+',
+    'file_name' => '',
+    'line_nr' => 3,
+    'macro' => '',
+    'text' => '@xref missing closing brace',
+    'type' => 'error'
+  },
   {
     'error_line' => ':8: misplaced }
 ',
@@ -275,4 +232,7 @@ $result_errors{'verbatim_in_ref'} = [
 ];
 
 
+$result_floats{'verbatim_in_ref'} = {};
+
+
 1;
