@@ -10,16 +10,15 @@ $result_trees{'comment_first_on_itemize_line'} = {
     {
       'args' => [
         {
-          'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
-            {
+          'cmdname' => 'bullet',
+          'contents' => [],
+          'parent' => {},
+          'type' => 'command_as_argument_inserted'
+        },
+        {
+          'contents' => [],
+          'extra' => {
+            'comment_at_end' => {
               'args' => [
                 {
                   'parent' => {},
@@ -37,7 +36,7 @@ $result_trees{'comment_first_on_itemize_line'} = {
               },
               'parent' => {}
             }
-          ],
+          },
           'parent' => {},
           'type' => 'block_line_arg'
         }
@@ -47,14 +46,6 @@ $result_trees{'comment_first_on_itemize_line'} = {
         {
           'cmdname' => 'item',
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'contents' => [
                 {
@@ -69,7 +60,7 @@ $result_trees{'comment_first_on_itemize_line'} = {
           ],
           'extra' => {
             'item_number' => 1,
-            'spaces_after_command' => {}
+            'spaces_before_argument' => ' '
           },
           'line_nr' => {
             'file_name' => '',
@@ -82,34 +73,23 @@ $result_trees{'comment_first_on_itemize_line'} = {
           'args' => [
             {
               'contents' => [
-                {
-                  'extra' => {
-                    'command' => {}
-                  },
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_after_command'
-                },
                 {
                   'parent' => {},
                   'text' => 'itemize'
-                },
-                {
-                  'parent' => {},
-                  'text' => '
-',
-                  'type' => 'spaces_at_end'
                 }
               ],
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
               'parent' => {},
-              'type' => 'misc_line_arg'
+              'type' => 'line_arg'
             }
           ],
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
             'command_argument' => 'itemize',
-            'spaces_after_command' => {},
+            'spaces_before_argument' => ' ',
             'text_arg' => 'itemize'
           },
           'line_nr' => {
@@ -121,19 +101,9 @@ $result_trees{'comment_first_on_itemize_line'} = {
         }
       ],
       'extra' => {
-        'block_command_line_contents' => [
-          [
-            {
-              'cmdname' => 'bullet',
-              'contents' => [],
-              'parent' => {},
-              'type' => 'command_as_argument'
-            }
-          ]
-        ],
         'command_as_argument' => {},
         'end_command' => {},
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'line_nr' => {
         'file_name' => '',
@@ -145,29 +115,18 @@ $result_trees{'comment_first_on_itemize_line'} = {
   ],
   'type' => 'text_root'
 };
-$result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'comment_first_on_itemize_line'}{'contents'}[0];
-$result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'args'}[0];
-$result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'args'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'args'}[0]{'contents'}[1];
-$result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'args'}[0];
 $result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'comment_first_on_itemize_line'}{'contents'}[0];
-$result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'contents'}[0];
+$result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'args'}[1]{'extra'}{'comment_at_end'}{'args'}[0]{'parent'} = $result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'args'}[1]{'extra'}{'comment_at_end'};
+$result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'args'}[1]{'extra'}{'comment_at_end'}{'parent'} = $result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'args'}[1];
+$result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'args'}[1]{'parent'} = $result_trees{'comment_first_on_itemize_line'}{'contents'}[0];
+$result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'contents'}[0]{'contents'}[0];
 $result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'contents'}[0];
-$result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'contents'}[0]{'contents'}[1];
-$result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'contents'}[0];
-$result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'contents'}[0]{'contents'}[0];
 $result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'comment_first_on_itemize_line'}{'contents'}[0];
-$result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'contents'}[1];
 $result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'contents'}[1]{'args'}[0];
 $result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'contents'}[1];
-$result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'contents'}[1]{'extra'}{'command'} = $result_trees{'comment_first_on_itemize_line'}{'contents'}[0];
-$result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'comment_first_on_itemize_line'}{'contents'}[0];
-$result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'extra'}{'block_command_line_contents'}[0][0]{'parent'} = $result_trees{'comment_first_on_itemize_line'}{'contents'}[0];
-$result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'extra'}{'command_as_argument'} = $result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'extra'}{'block_command_line_contents'}[0][0];
+$result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'extra'}{'command_as_argument'} = $result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'args'}[0];
 $result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'extra'}{'end_command'} = $result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'contents'}[1];
-$result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'comment_first_on_itemize_line'}{'contents'}[0]{'parent'} = $result_trees{'comment_first_on_itemize_line'};
 
 $result_texis{'comment_first_on_itemize_line'} = '@itemize @c comment on itemize line
@@ -182,6 +141,9 @@ $result_texts{'comment_first_on_itemize_line'} = 'first
 $result_errors{'comment_first_on_itemize_line'} = [];
 
 
+$result_floats{'comment_first_on_itemize_line'} = {};
+
+
 
 $result_converted{'plaintext'}->{'comment_first_on_itemize_line'} = '   * first
 ';
