@@ -17,15 +17,18 @@ $result_texts{'lone_end_itemize'} = '';
 
 $result_errors{'lone_end_itemize'} = [
   {
-    'error_line' => ':1: Unmatched `@end itemize\'
+    'error_line' => ':1: unmatched `@end itemize\'
 ',
     'file_name' => '',
     'line_nr' => 1,
     'macro' => '',
-    'text' => 'Unmatched `@end itemize\'',
+    'text' => 'unmatched `@end itemize\'',
     'type' => 'error'
   }
 ];
 
 
+$result_floats{'lone_end_itemize'} = {};
+
+
 1;
