@@ -73,7 +73,9 @@ $result_trees{'unknown_language'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -268,7 +270,7 @@ $result_trees{'unknown_language'}{'contents'}[0]{'parent'} = $result_trees{'unkn
 $result_trees{'unknown_language'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'unknown_language'}{'contents'}[1]{'args'}[0];
 $result_trees{'unknown_language'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'unknown_language'}{'contents'}[1];
 $result_trees{'unknown_language'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'unknown_language'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'unknown_language'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'unknown_language'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'unknown_language'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'unknown_language'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'unknown_language'}{'contents'}[1]{'parent'} = $result_trees{'unknown_language'};
 $result_trees{'unknown_language'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'unknown_language'}{'contents'}[2]{'args'}[0];
 $result_trees{'unknown_language'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'unknown_language'}{'contents'}[2];
@@ -353,20 +355,8 @@ $result_nodes{'unknown_language'} = {
     },
     'normalized' => 'Top',
     'spaces_before_argument' => ' '
-  },
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
   }
 };
-$result_nodes{'unknown_language'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'unknown_language'};
 
 $result_menus{'unknown_language'} = {
   'cmdname' => 'node',
@@ -407,6 +397,9 @@ $result_errors{'unknown_language'} = [
 ];
 
 
+$result_floats{'unknown_language'} = {};
+
+
 
 $result_converted{'plaintext'}->{'unknown_language'} = 'unknkown language
 *****************
@@ -434,6 +427,11 @@ Tag Table:
 Node: Top27
 
 End Tag Table
+
+
+Local Variables:
+coding: utf-8
+End:
 ';
 
 
@@ -448,14 +446,16 @@ $result_converted{'html'}->{'unknown_language'} = '<!DOCTYPE html PUBLIC "-//W3C
 <meta name="keywords" content="unknkown language">
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
+<meta name="viewport" content="width=device-width,initial-scale=1">
+
 <link href="#Top" rel="start" title="Top">
 <style type="text/css">
 <!--
+a.copiable-anchor {visibility: hidden; text-decoration: none; line-height: 0em}
 a.summary-letter {text-decoration: none}
 blockquote.indentedblock {margin-right: 0em}
 div.display {margin-left: 3.2em}
 div.example {margin-left: 3.2em}
-div.lisp {margin-left: 3.2em}
 kbd {font-style: oblique}
 pre.display {font-family: inherit}
 pre.format {font-family: inherit}
@@ -464,6 +464,7 @@ pre.menu-preformatted {font-family: serif}
 span.nolinebreak {white-space: nowrap}
 span.roman {font-family: initial; font-weight: normal}
 span.sansserif {font-family: sans-serif; font-weight: normal}
+span:hover a.copiable-anchor {visibility: visible}
 ul.no-bullet {list-style: none}
 -->
 </style>
@@ -473,13 +474,14 @@ ul.no-bullet {list-style: none}
 
 <body lang="another_UNKNOWN">
 
-<span id="Top"></span><span id="unknkown-language"></span><h1 class="top">unknkown language</h1>
+<div class="top" id="Top">
+<span id="unknkown-language"></span><h1 class="top">unknkown language</h1>
 
-<p>Unknown language. See <a href="#Top">Top</a>.
+<p>Unknown language. See <a href="#Top">unknkown language</a>.
 </p>
 
-<p>Another unknown language. See <a href="#Top">Top</a>.
-</p><hr>
+<p>Another unknown language. See <a href="#Top">unknkown language</a>.
+</p><hr></div>
 
 
 
