@@ -97,7 +97,9 @@ $result_trees{'navigation_chapter_vertical'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -289,7 +291,9 @@ $result_trees{'navigation_chapter_vertical'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'chapter'
           }
         ],
@@ -482,7 +486,9 @@ $result_trees{'navigation_chapter_vertical'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'section'
           }
         ],
@@ -901,7 +907,9 @@ $result_trees{'navigation_chapter_vertical'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'subsection'
           }
         ],
@@ -1003,7 +1011,7 @@ $result_trees{'navigation_chapter_vertical'}{'contents'}[0]{'parent'} = $result_
 $result_trees{'navigation_chapter_vertical'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'navigation_chapter_vertical'}{'contents'}[1]{'args'}[0];
 $result_trees{'navigation_chapter_vertical'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'navigation_chapter_vertical'}{'contents'}[1];
 $result_trees{'navigation_chapter_vertical'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'navigation_chapter_vertical'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'navigation_chapter_vertical'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'navigation_chapter_vertical'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'navigation_chapter_vertical'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'navigation_chapter_vertical'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'navigation_chapter_vertical'}{'contents'}[1]{'parent'} = $result_trees{'navigation_chapter_vertical'};
 $result_trees{'navigation_chapter_vertical'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'navigation_chapter_vertical'}{'contents'}[2]{'args'}[0];
 $result_trees{'navigation_chapter_vertical'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'navigation_chapter_vertical'}{'contents'}[2];
@@ -1030,7 +1038,7 @@ $result_trees{'navigation_chapter_vertical'}{'contents'}[2]{'parent'} = $result_
 $result_trees{'navigation_chapter_vertical'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'navigation_chapter_vertical'}{'contents'}[3]{'args'}[0];
 $result_trees{'navigation_chapter_vertical'}{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'navigation_chapter_vertical'}{'contents'}[3];
 $result_trees{'navigation_chapter_vertical'}{'contents'}[3]{'extra'}{'node_content'}[0] = $result_trees{'navigation_chapter_vertical'}{'contents'}[3]{'args'}[0]{'contents'}[0];
-$result_trees{'navigation_chapter_vertical'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'navigation_chapter_vertical'}{'contents'}[3]{'extra'}{'node_content'};
+$result_trees{'navigation_chapter_vertical'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'navigation_chapter_vertical'}{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'navigation_chapter_vertical'}{'contents'}[3]{'parent'} = $result_trees{'navigation_chapter_vertical'};
 $result_trees{'navigation_chapter_vertical'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'navigation_chapter_vertical'}{'contents'}[4]{'args'}[0];
 $result_trees{'navigation_chapter_vertical'}{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'navigation_chapter_vertical'}{'contents'}[4];
@@ -1057,7 +1065,7 @@ $result_trees{'navigation_chapter_vertical'}{'contents'}[4]{'parent'} = $result_
 $result_trees{'navigation_chapter_vertical'}{'contents'}[5]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'navigation_chapter_vertical'}{'contents'}[5]{'args'}[0];
 $result_trees{'navigation_chapter_vertical'}{'contents'}[5]{'args'}[0]{'parent'} = $result_trees{'navigation_chapter_vertical'}{'contents'}[5];
 $result_trees{'navigation_chapter_vertical'}{'contents'}[5]{'extra'}{'node_content'}[0] = $result_trees{'navigation_chapter_vertical'}{'contents'}[5]{'args'}[0]{'contents'}[0];
-$result_trees{'navigation_chapter_vertical'}{'contents'}[5]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'navigation_chapter_vertical'}{'contents'}[5]{'extra'}{'node_content'};
+$result_trees{'navigation_chapter_vertical'}{'contents'}[5]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'navigation_chapter_vertical'}{'contents'}[5]{'args'}[0]{'contents'}[0];
 $result_trees{'navigation_chapter_vertical'}{'contents'}[5]{'parent'} = $result_trees{'navigation_chapter_vertical'};
 $result_trees{'navigation_chapter_vertical'}{'contents'}[6]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'navigation_chapter_vertical'}{'contents'}[6]{'args'}[0];
 $result_trees{'navigation_chapter_vertical'}{'contents'}[6]{'args'}[0]{'parent'} = $result_trees{'navigation_chapter_vertical'}{'contents'}[6];
@@ -1124,7 +1132,7 @@ $result_trees{'navigation_chapter_vertical'}{'contents'}[6]{'parent'} = $result_
 $result_trees{'navigation_chapter_vertical'}{'contents'}[7]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'navigation_chapter_vertical'}{'contents'}[7]{'args'}[0];
 $result_trees{'navigation_chapter_vertical'}{'contents'}[7]{'args'}[0]{'parent'} = $result_trees{'navigation_chapter_vertical'}{'contents'}[7];
 $result_trees{'navigation_chapter_vertical'}{'contents'}[7]{'extra'}{'node_content'}[0] = $result_trees{'navigation_chapter_vertical'}{'contents'}[7]{'args'}[0]{'contents'}[0];
-$result_trees{'navigation_chapter_vertical'}{'contents'}[7]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'navigation_chapter_vertical'}{'contents'}[7]{'extra'}{'node_content'};
+$result_trees{'navigation_chapter_vertical'}{'contents'}[7]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'navigation_chapter_vertical'}{'contents'}[7]{'args'}[0]{'contents'}[0];
 $result_trees{'navigation_chapter_vertical'}{'contents'}[7]{'parent'} = $result_trees{'navigation_chapter_vertical'};
 $result_trees{'navigation_chapter_vertical'}{'contents'}[8]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'navigation_chapter_vertical'}{'contents'}[8]{'args'}[0];
 $result_trees{'navigation_chapter_vertical'}{'contents'}[8]{'args'}[0]{'parent'} = $result_trees{'navigation_chapter_vertical'}{'contents'}[8];
@@ -1491,4 +1499,7 @@ $result_menus{'navigation_chapter_vertical'}{'menu_child'}{'menu_up'} = $result_
 $result_errors{'navigation_chapter_vertical'} = [];
 
 
+$result_floats{'navigation_chapter_vertical'} = {};
+
+
 1;
