@@ -97,7 +97,9 @@ $result_trees{'navigation_node_no_header'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -289,7 +291,9 @@ $result_trees{'navigation_node_no_header'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'chapter'
           }
         ],
@@ -482,7 +486,9 @@ $result_trees{'navigation_node_no_header'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'section'
           }
         ],
@@ -901,7 +907,9 @@ $result_trees{'navigation_node_no_header'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'subsection'
           }
         ],
@@ -1003,7 +1011,7 @@ $result_trees{'navigation_node_no_header'}{'contents'}[0]{'parent'} = $result_tr
 $result_trees{'navigation_node_no_header'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'navigation_node_no_header'}{'contents'}[1]{'args'}[0];
 $result_trees{'navigation_node_no_header'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'navigation_node_no_header'}{'contents'}[1];
 $result_trees{'navigation_node_no_header'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'navigation_node_no_header'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'navigation_node_no_header'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'navigation_node_no_header'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'navigation_node_no_header'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'navigation_node_no_header'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'navigation_node_no_header'}{'contents'}[1]{'parent'} = $result_trees{'navigation_node_no_header'};
 $result_trees{'navigation_node_no_header'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'navigation_node_no_header'}{'contents'}[2]{'args'}[0];
 $result_trees{'navigation_node_no_header'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'navigation_node_no_header'}{'contents'}[2];
@@ -1030,7 +1038,7 @@ $result_trees{'navigation_node_no_header'}{'contents'}[2]{'parent'} = $result_tr
 $result_trees{'navigation_node_no_header'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'navigation_node_no_header'}{'contents'}[3]{'args'}[0];
 $result_trees{'navigation_node_no_header'}{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'navigation_node_no_header'}{'contents'}[3];
 $result_trees{'navigation_node_no_header'}{'contents'}[3]{'extra'}{'node_content'}[0] = $result_trees{'navigation_node_no_header'}{'contents'}[3]{'args'}[0]{'contents'}[0];
-$result_trees{'navigation_node_no_header'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'navigation_node_no_header'}{'contents'}[3]{'extra'}{'node_content'};
+$result_trees{'navigation_node_no_header'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'navigation_node_no_header'}{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'navigation_node_no_header'}{'contents'}[3]{'parent'} = $result_trees{'navigation_node_no_header'};
 $result_trees{'navigation_node_no_header'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'navigation_node_no_header'}{'contents'}[4]{'args'}[0];
 $result_trees{'navigation_node_no_header'}{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'navigation_node_no_header'}{'contents'}[4];
@@ -1057,7 +1065,7 @@ $result_trees{'navigation_node_no_header'}{'contents'}[4]{'parent'} = $result_tr
 $result_trees{'navigation_node_no_header'}{'contents'}[5]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'navigation_node_no_header'}{'contents'}[5]{'args'}[0];
 $result_trees{'navigation_node_no_header'}{'contents'}[5]{'args'}[0]{'parent'} = $result_trees{'navigation_node_no_header'}{'contents'}[5];
 $result_trees{'navigation_node_no_header'}{'contents'}[5]{'extra'}{'node_content'}[0] = $result_trees{'navigation_node_no_header'}{'contents'}[5]{'args'}[0]{'contents'}[0];
-$result_trees{'navigation_node_no_header'}{'contents'}[5]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'navigation_node_no_header'}{'contents'}[5]{'extra'}{'node_content'};
+$result_trees{'navigation_node_no_header'}{'contents'}[5]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'navigation_node_no_header'}{'contents'}[5]{'args'}[0]{'contents'}[0];
 $result_trees{'navigation_node_no_header'}{'contents'}[5]{'parent'} = $result_trees{'navigation_node_no_header'};
 $result_trees{'navigation_node_no_header'}{'contents'}[6]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'navigation_node_no_header'}{'contents'}[6]{'args'}[0];
 $result_trees{'navigation_node_no_header'}{'contents'}[6]{'args'}[0]{'parent'} = $result_trees{'navigation_node_no_header'}{'contents'}[6];
@@ -1124,7 +1132,7 @@ $result_trees{'navigation_node_no_header'}{'contents'}[6]{'parent'} = $result_tr
 $result_trees{'navigation_node_no_header'}{'contents'}[7]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'navigation_node_no_header'}{'contents'}[7]{'args'}[0];
 $result_trees{'navigation_node_no_header'}{'contents'}[7]{'args'}[0]{'parent'} = $result_trees{'navigation_node_no_header'}{'contents'}[7];
 $result_trees{'navigation_node_no_header'}{'contents'}[7]{'extra'}{'node_content'}[0] = $result_trees{'navigation_node_no_header'}{'contents'}[7]{'args'}[0]{'contents'}[0];
-$result_trees{'navigation_node_no_header'}{'contents'}[7]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'navigation_node_no_header'}{'contents'}[7]{'extra'}{'node_content'};
+$result_trees{'navigation_node_no_header'}{'contents'}[7]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'navigation_node_no_header'}{'contents'}[7]{'args'}[0]{'contents'}[0];
 $result_trees{'navigation_node_no_header'}{'contents'}[7]{'parent'} = $result_trees{'navigation_node_no_header'};
 $result_trees{'navigation_node_no_header'}{'contents'}[8]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'navigation_node_no_header'}{'contents'}[8]{'args'}[0];
 $result_trees{'navigation_node_no_header'}{'contents'}[8]{'args'}[0]{'parent'} = $result_trees{'navigation_node_no_header'}{'contents'}[8];
@@ -1436,25 +1444,13 @@ $result_nodes{'navigation_node_no_header'} = {
       }
     }
   ],
-  'node_next' => {},
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
-  }
+  'node_next' => {}
 };
 $result_nodes{'navigation_node_no_header'}{'menu_child'}{'menu_child'}{'menu_child'}{'node_up'} = $result_nodes{'navigation_node_no_header'}{'menu_child'}{'menu_child'};
 $result_nodes{'navigation_node_no_header'}{'menu_child'}{'menu_child'}{'node_up'} = $result_nodes{'navigation_node_no_header'}{'menu_child'};
 $result_nodes{'navigation_node_no_header'}{'menu_child'}{'node_prev'} = $result_nodes{'navigation_node_no_header'};
 $result_nodes{'navigation_node_no_header'}{'menu_child'}{'node_up'} = $result_nodes{'navigation_node_no_header'};
 $result_nodes{'navigation_node_no_header'}{'node_next'} = $result_nodes{'navigation_node_no_header'}{'menu_child'};
-$result_nodes{'navigation_node_no_header'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'navigation_node_no_header'};
 
 $result_menus{'navigation_node_no_header'} = {
   'cmdname' => 'node',
@@ -1503,4 +1499,7 @@ $result_menus{'navigation_node_no_header'}{'menu_child'}{'menu_up'} = $result_me
 $result_errors{'navigation_node_no_header'} = [];
 
 
+$result_floats{'navigation_node_no_header'} = {};
+
+
 1;
