@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
@@ -17,66 +17,60 @@ $result_trees{'no_monolithic'} = {
                   'parent' => {},
                   'text' => '\\input texinfo @c -*-texinfo-*-
 ',
-                  'type' => 'text_before_beginning'
+                  'type' => 'preamble_text'
                 },
                 {
                   'parent' => {},
                   'text' => '
 ',
-                  'type' => 'text_before_beginning'
+                  'type' => 'preamble_text'
                 }
               ],
               'parent' => {},
-              'type' => 'preamble_before_beginning'
+              'type' => 'preamble'
             }
           ],
           'parent' => {},
           'type' => 'preamble_before_setfilename'
         },
         {
-          'contents' => [
+          'args' => [
             {
-              'args' => [
+              'contents' => [
                 {
-                  'contents' => [
-                    {
-                      'parent' => {},
-                      'text' => 'no_monolithic.info'
-                    }
-                  ],
-                  'extra' => {
-                    'spaces_after_argument' => '
-'
-                  },
                   'parent' => {},
-                  'type' => 'line_arg'
+                  'text' => 'no_monolithic.info'
                 }
               ],
-              'cmdname' => 'setfilename',
               'extra' => {
-                'spaces_before_argument' => ' ',
-                'text_arg' => 'no_monolithic.info'
+                'spaces_after_argument' => '
+'
               },
               'parent' => {},
-              'source_info' => {
-                'file_name' => 'no_monolithic.texi',
-                'line_nr' => 3,
-                'macro' => ''
-              }
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'empty_line'
+              'type' => 'line_arg'
             }
           ],
+          'cmdname' => 'setfilename',
+          'extra' => {
+            'spaces_before_argument' => ' ',
+            'text_arg' => 'no_monolithic.info'
+          },
+          'line_nr' => {
+            'file_name' => 'no_monolithic.texi',
+            'line_nr' => 3,
+            'macro' => ''
+          },
+          'parent' => {}
+        },
+        {
           'parent' => {},
-          'type' => 'preamble_before_content'
+          'text' => '
+',
+          'type' => 'empty_line'
         }
       ],
       'parent' => {},
-      'type' => 'before_node_section'
+      'type' => 'text_root'
     },
     {
       'args' => [
@@ -96,6 +90,7 @@ $result_trees{'no_monolithic'} = {
         }
       ],
       'cmdname' => 'node',
+      'contents' => [],
       'extra' => {
         'node_content' => [
           {}
@@ -111,12 +106,12 @@ $result_trees{'no_monolithic'} = {
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'line_nr' => {
         'file_name' => 'no_monolithic.texi',
         'line_nr' => 5,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     },
     {
       'args' => [
@@ -169,12 +164,13 @@ $result_trees{'no_monolithic'} = {
                 }
               ],
               'cmdname' => 'footnote',
-              'parent' => {},
-              'source_info' => {
+              'contents' => [],
+              'line_nr' => {
                 'file_name' => 'no_monolithic.texi',
                 'line_nr' => 8,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             },
             {
               'parent' => {},
@@ -211,25 +207,25 @@ $result_trees{'no_monolithic'} = {
           'cmdname' => 'cindex',
           'extra' => {
             'index_entry' => {
+              'command' => {},
+              'content' => [],
               'content_normalized' => [],
-              'entry_content' => [],
-              'entry_element' => {},
-              'entry_node' => {},
-              'entry_number' => 1,
               'in_code' => 0,
               'index_at_command' => 'cindex',
-              'index_ignore_chars' => {},
               'index_name' => 'cp',
-              'index_type_command' => 'cindex'
+              'index_type_command' => 'cindex',
+              'key' => 'top',
+              'node' => {},
+              'number' => 1
             },
             'spaces_before_argument' => ' '
           },
-          'parent' => {},
-          'source_info' => {
+          'line_nr' => {
             'file_name' => 'no_monolithic.texi',
             'line_nr' => 10,
             'macro' => ''
           },
+          'parent' => {},
           'type' => 'index_entry_command'
         },
         {
@@ -239,18 +235,17 @@ $result_trees{'no_monolithic'} = {
           'type' => 'empty_line'
         },
         {
-          'args' => [
-            {
-              'extra' => {
-                'spaces_after_argument' => '
-'
-              },
-              'parent' => {},
-              'type' => 'block_line_arg'
-            }
-          ],
           'cmdname' => 'menu',
           'contents' => [
+            {
+              'extra' => {
+                'command' => {}
+              },
+              'parent' => {},
+              'text' => '
+',
+              'type' => 'empty_line_after_command'
+            },
             {
               'args' => [
                 {
@@ -300,12 +295,12 @@ $result_trees{'no_monolithic'} = {
                   'normalized' => 'chapter'
                 }
               },
-              'parent' => {},
-              'source_info' => {
+              'line_nr' => {
                 'file_name' => 'no_monolithic.texi',
                 'line_nr' => 13,
                 'macro' => ''
               },
+              'parent' => {},
               'type' => 'menu_entry'
             },
             {
@@ -327,23 +322,27 @@ $result_trees{'no_monolithic'} = {
               ],
               'cmdname' => 'end',
               'extra' => {
+                'command_argument' => 'menu',
                 'spaces_before_argument' => ' ',
                 'text_arg' => 'menu'
               },
-              'parent' => {},
-              'source_info' => {
+              'line_nr' => {
                 'file_name' => 'no_monolithic.texi',
                 'line_nr' => 14,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             }
           ],
-          'parent' => {},
-          'source_info' => {
+          'extra' => {
+            'end_command' => {}
+          },
+          'line_nr' => {
             'file_name' => 'no_monolithic.texi',
             'line_nr' => 12,
             'macro' => ''
-          }
+          },
+          'parent' => {}
         },
         {
           'parent' => {},
@@ -355,12 +354,13 @@ $result_trees{'no_monolithic'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 0,
+      'line_nr' => {
         'file_name' => 'no_monolithic.texi',
         'line_nr' => 6,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     },
     {
       'args' => [
@@ -380,6 +380,7 @@ $result_trees{'no_monolithic'} = {
         }
       ],
       'cmdname' => 'node',
+      'contents' => [],
       'extra' => {
         'isindex' => 1,
         'node_content' => [
@@ -396,12 +397,12 @@ $result_trees{'no_monolithic'} = {
         'normalized' => 'chapter',
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'line_nr' => {
         'file_name' => 'no_monolithic.texi',
         'line_nr' => 16,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     },
     {
       'args' => [
@@ -455,12 +456,12 @@ $result_trees{'no_monolithic'} = {
             }
           ],
           'cmdname' => 'contents',
-          'parent' => {},
-          'source_info' => {
+          'line_nr' => {
             'file_name' => 'no_monolithic.texi',
             'line_nr' => 21,
             'macro' => ''
-          }
+          },
+          'parent' => {}
         },
         {
           'args' => [
@@ -472,12 +473,12 @@ $result_trees{'no_monolithic'} = {
             }
           ],
           'cmdname' => 'shortcontents',
-          'parent' => {},
-          'source_info' => {
+          'line_nr' => {
             'file_name' => 'no_monolithic.texi',
             'line_nr' => 22,
             'macro' => ''
-          }
+          },
+          'parent' => {}
         },
         {
           'parent' => {},
@@ -509,23 +510,25 @@ $result_trees{'no_monolithic'} = {
             ],
             'spaces_before_argument' => ' '
           },
-          'parent' => {},
-          'source_info' => {
+          'line_nr' => {
             'file_name' => 'no_monolithic.texi',
             'line_nr' => 24,
             'macro' => ''
-          }
+          },
+          'parent' => {}
         }
       ],
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 1,
+      'line_nr' => {
         'file_name' => 'no_monolithic.texi',
         'line_nr' => 17,
         'macro' => ''
-      }
+      },
+      'number' => 1,
+      'parent' => {}
     },
     {
       'args' => [
@@ -546,11 +549,10 @@ $result_trees{'no_monolithic'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'con
 $result_trees{'no_monolithic'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[0]{'contents'}[0]{'contents'}[0];
 $result_trees{'no_monolithic'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[0]{'contents'}[0];
 $result_trees{'no_monolithic'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[0];
-$result_trees{'no_monolithic'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0];
-$result_trees{'no_monolithic'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[0]{'contents'}[1]{'contents'}[0];
-$result_trees{'no_monolithic'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[0]{'contents'}[1];
-$result_trees{'no_monolithic'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[0]{'contents'}[1];
+$result_trees{'no_monolithic'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[0]{'contents'}[1]{'args'}[0];
+$result_trees{'no_monolithic'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[0]{'contents'}[1];
 $result_trees{'no_monolithic'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[0];
+$result_trees{'no_monolithic'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[0];
 $result_trees{'no_monolithic'}{'contents'}[0]{'parent'} = $result_trees{'no_monolithic'};
 $result_trees{'no_monolithic'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[1]{'args'}[0];
 $result_trees{'no_monolithic'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[1];
@@ -570,26 +572,28 @@ $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[1]{'parent'} = $result
 $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[2]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[2];
 $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[3]{'args'}[0];
 $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[3];
+$result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[3]{'extra'}{'index_entry'}{'command'} = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[3];
+$result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[3]{'extra'}{'index_entry'}{'content'} = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[3]{'args'}[0]{'contents'};
 $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[3]{'extra'}{'index_entry'}{'content_normalized'} = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[3]{'args'}[0]{'contents'};
-$result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[3]{'extra'}{'index_entry'}{'entry_content'} = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[3]{'args'}[0]{'contents'};
-$result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[3]{'extra'}{'index_entry'}{'entry_element'} = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[3];
-$result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[3]{'extra'}{'index_entry'}{'entry_node'} = $result_trees{'no_monolithic'}{'contents'}[1];
+$result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[3]{'extra'}{'index_entry'}{'node'} = $result_trees{'no_monolithic'}{'contents'}[1];
 $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[3]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[2];
 $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[4]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[2];
-$result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'args'}[0]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5];
-$result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[0];
-$result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[0]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[0]{'args'}[1];
-$result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[0]{'args'}[1]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[0];
-$result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[0]{'args'}[2]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[0];
-$result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[0]{'args'}[3]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[0]{'args'}[3]{'contents'}[0];
-$result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[0]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[0]{'args'}[3];
-$result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[0]{'args'}[3]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[0];
-$result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[0]{'extra'}{'menu_entry_description'} = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[0]{'args'}[3];
-$result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[0]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[0]{'args'}[1]{'contents'}[0];
+$result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[0]{'extra'}{'command'} = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5];
 $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[0]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5];
-$result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[1]{'args'}[0];
 $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[1];
+$result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[1]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[1]{'args'}[1];
+$result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[1]{'args'}[1]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[1];
+$result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[1]{'args'}[2]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[1];
+$result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[1]{'args'}[3]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[1]{'args'}[3]{'contents'}[0];
+$result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[1]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[1]{'args'}[3];
+$result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[1]{'args'}[3]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[1];
+$result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[1]{'extra'}{'menu_entry_description'} = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[1]{'args'}[3];
+$result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[1]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[1]{'args'}[1]{'contents'}[0];
 $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[1]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5];
+$result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[2]{'args'}[0];
+$result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[2];
+$result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[2]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5];
+$result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'extra'}{'end_command'} = $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'contents'}[2];
 $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[5]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[2];
 $result_trees{'no_monolithic'}{'contents'}[2]{'contents'}[6]{'parent'} = $result_trees{'no_monolithic'}{'contents'}[2];
 $result_trees{'no_monolithic'}{'contents'}[2]{'parent'} = $result_trees{'no_monolithic'};
@@ -662,118 +666,123 @@ Chapter.
 ';
 
 $result_sectioning{'no_monolithic'} = {
-  'structure' => {
-    'section_childs' => [
-      {
-        'cmdname' => 'top',
-        'extra' => {
-          'associated_node' => {
-            'cmdname' => 'node',
-            'extra' => {
-              'normalized' => 'Top'
-            },
-            'structure' => {}
+  'level' => -1,
+  'section_childs' => [
+    {
+      'cmdname' => 'top',
+      'extra' => {
+        'associated_node' => {
+          'cmdname' => 'node',
+          'extra' => {
+            'normalized' => 'Top',
+            'spaces_before_argument' => ' '
           }
         },
-        'structure' => {
-          'section_childs' => [
-            {
-              'cmdname' => 'chapter',
+        'spaces_before_argument' => ' '
+      },
+      'level' => 0,
+      'section_childs' => [
+        {
+          'cmdname' => 'chapter',
+          'extra' => {
+            'associated_node' => {
+              'cmdname' => 'node',
               'extra' => {
-                'associated_node' => {
-                  'cmdname' => 'node',
-                  'extra' => {
-                    'isindex' => 1,
-                    'normalized' => 'chapter'
-                  },
-                  'structure' => {}
-                }
-              },
-              'structure' => {
-                'section_level' => 1,
-                'section_number' => 1,
-                'section_up' => {},
-                'toplevel_prev' => {},
-                'toplevel_up' => {}
+                'isindex' => 1,
+                'normalized' => 'chapter',
+                'spaces_before_argument' => ' '
               }
-            }
-          ],
-          'section_level' => 0,
-          'section_up' => {}
+            },
+            'spaces_before_argument' => ' '
+          },
+          'level' => 1,
+          'number' => 1,
+          'section_up' => {},
+          'toplevel_prev' => {},
+          'toplevel_up' => {}
         }
-      }
-    ],
-    'section_level' => -1
-  }
+      ],
+      'section_up' => {}
+    }
+  ]
 };
-$result_sectioning{'no_monolithic'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'no_monolithic'}{'structure'}{'section_childs'}[0];
-$result_sectioning{'no_monolithic'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'toplevel_prev'} = $result_sectioning{'no_monolithic'}{'structure'}{'section_childs'}[0];
-$result_sectioning{'no_monolithic'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'toplevel_up'} = $result_sectioning{'no_monolithic'}{'structure'}{'section_childs'}[0];
-$result_sectioning{'no_monolithic'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'no_monolithic'};
+$result_sectioning{'no_monolithic'}{'section_childs'}[0]{'section_childs'}[0]{'section_up'} = $result_sectioning{'no_monolithic'}{'section_childs'}[0];
+$result_sectioning{'no_monolithic'}{'section_childs'}[0]{'section_childs'}[0]{'toplevel_prev'} = $result_sectioning{'no_monolithic'}{'section_childs'}[0];
+$result_sectioning{'no_monolithic'}{'section_childs'}[0]{'section_childs'}[0]{'toplevel_up'} = $result_sectioning{'no_monolithic'}{'section_childs'}[0];
+$result_sectioning{'no_monolithic'}{'section_childs'}[0]{'section_up'} = $result_sectioning{'no_monolithic'};
 
 $result_nodes{'no_monolithic'} = {
   'cmdname' => 'node',
   'extra' => {
     'associated_section' => {
       'cmdname' => 'top',
-      'extra' => {},
-      'structure' => {}
-    },
-    'menus' => [
-      {
-        'cmdname' => 'menu'
-      }
-    ],
-    'normalized' => 'Top'
-  },
-  'structure' => {
-    'menu_child' => {
-      'cmdname' => 'node',
       'extra' => {
-        'associated_section' => {
-          'cmdname' => 'chapter',
-          'extra' => {},
-          'structure' => {
-            'section_number' => 1
-          }
-        },
-        'isindex' => 1,
-        'normalized' => 'chapter'
+        'spaces_before_argument' => ' '
       },
-      'structure' => {
-        'node_prev' => {},
-        'node_up' => {}
-      }
+      'level' => 0
     },
-    'node_next' => {}
-  }
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
+  },
+  'menu_child' => {
+    'cmdname' => 'node',
+    'extra' => {
+      'associated_section' => {
+        'cmdname' => 'chapter',
+        'extra' => {
+          'spaces_before_argument' => ' '
+        },
+        'level' => 1,
+        'number' => 1
+      },
+      'isindex' => 1,
+      'normalized' => 'chapter',
+      'spaces_before_argument' => ' '
+    },
+    'node_prev' => {},
+    'node_up' => {}
+  },
+  'menus' => [
+    {
+      'cmdname' => 'menu',
+      'extra' => {
+        'end_command' => {
+          'cmdname' => 'end',
+          'extra' => {
+            'command_argument' => 'menu',
+            'spaces_before_argument' => ' ',
+            'text_arg' => 'menu'
+          }
+        }
+      }
+    }
+  ],
+  'node_next' => {}
 };
-$result_nodes{'no_monolithic'}{'structure'}{'menu_child'}{'structure'}{'node_prev'} = $result_nodes{'no_monolithic'};
-$result_nodes{'no_monolithic'}{'structure'}{'menu_child'}{'structure'}{'node_up'} = $result_nodes{'no_monolithic'};
-$result_nodes{'no_monolithic'}{'structure'}{'node_next'} = $result_nodes{'no_monolithic'}{'structure'}{'menu_child'};
+$result_nodes{'no_monolithic'}{'menu_child'}{'node_prev'} = $result_nodes{'no_monolithic'};
+$result_nodes{'no_monolithic'}{'menu_child'}{'node_up'} = $result_nodes{'no_monolithic'};
+$result_nodes{'no_monolithic'}{'node_next'} = $result_nodes{'no_monolithic'}{'menu_child'};
 
 $result_menus{'no_monolithic'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   },
-  'structure' => {
-    'menu_child' => {
-      'cmdname' => 'node',
-      'extra' => {
-        'isindex' => 1,
-        'normalized' => 'chapter'
-      },
-      'structure' => {
-        'menu_up' => {},
-        'menu_up_hash' => {
-          'Top' => 1
-        }
-      }
+  'menu_child' => {
+    'cmdname' => 'node',
+    'extra' => {
+      'isindex' => 1,
+      'normalized' => 'chapter',
+      'spaces_before_argument' => ' '
+    },
+    'menu_up' => {},
+    'menu_up_hash' => {
+      'Top' => 1
     }
   }
 };
-$result_menus{'no_monolithic'}{'structure'}{'menu_child'}{'structure'}{'menu_up'} = $result_menus{'no_monolithic'};
+$result_menus{'no_monolithic'}{'menu_child'}{'menu_up'} = $result_menus{'no_monolithic'};
 
 $result_errors{'no_monolithic'} = [];
 
@@ -781,11 +790,4 @@ $result_errors{'no_monolithic'} = [];
 $result_floats{'no_monolithic'} = {};
 
 
-$result_indices_sort_strings{'no_monolithic'} = {
-  'cp' => [
-    'top'
-  ]
-};
-
-
 1;
