@@ -46,9 +46,6 @@ $result_trees{'arg_not_closed'} = {
       'parent' => {}
     },
     {
-      'extra' => {
-        'command' => {}
-      },
       'parent' => {},
       'text' => '
 ',
@@ -79,7 +76,6 @@ $result_trees{'arg_not_closed'}{'contents'}[0]{'args'}[1]{'parent'} = $result_tr
 $result_trees{'arg_not_closed'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'arg_not_closed'}{'contents'}[0];
 $result_trees{'arg_not_closed'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'arg_not_closed'}{'contents'}[0];
 $result_trees{'arg_not_closed'}{'contents'}[0]{'parent'} = $result_trees{'arg_not_closed'};
-$result_trees{'arg_not_closed'}{'contents'}[1]{'extra'}{'command'} = $result_trees{'arg_not_closed'}{'contents'}[0];
 $result_trees{'arg_not_closed'}{'contents'}[1]{'parent'} = $result_trees{'arg_not_closed'};
 $result_trees{'arg_not_closed'}{'contents'}[2]{'parent'} = $result_trees{'arg_not_closed'};
 $result_trees{'arg_not_closed'}{'contents'}[3]{'contents'}[0]{'parent'} = $result_trees{'arg_not_closed'}{'contents'}[3];
@@ -110,4 +106,7 @@ $result_errors{'arg_not_closed'} = [
 ];
 
 
+$result_floats{'arg_not_closed'} = {};
+
+
 1;
