@@ -284,12 +284,15 @@ $result_trees{'backslash_in_arg'} = {
         }
       ],
       'extra' => {
+        'isindex' => 1,
         'node_content' => [
           {}
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -349,7 +352,7 @@ $result_trees{'backslash_in_arg'}{'contents'}[1]{'contents'}[8]{'args'}[0]{'cont
 $result_trees{'backslash_in_arg'}{'contents'}[1]{'contents'}[8]{'args'}[0]{'parent'} = $result_trees{'backslash_in_arg'}{'contents'}[1]{'contents'}[8];
 $result_trees{'backslash_in_arg'}{'contents'}[1]{'contents'}[8]{'parent'} = $result_trees{'backslash_in_arg'}{'contents'}[1];
 $result_trees{'backslash_in_arg'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'backslash_in_arg'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'backslash_in_arg'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'backslash_in_arg'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'backslash_in_arg'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'backslash_in_arg'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'backslash_in_arg'}{'contents'}[1]{'parent'} = $result_trees{'backslash_in_arg'};
 
 $result_texis{'backslash_in_arg'} = '@node Top
@@ -375,26 +378,16 @@ $result_sectioning{'backslash_in_arg'} = {};
 $result_nodes{'backslash_in_arg'} = {
   'cmdname' => 'node',
   'extra' => {
+    'isindex' => 1,
     'normalized' => 'Top',
     'spaces_before_argument' => ' '
-  },
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
   }
 };
-$result_nodes{'backslash_in_arg'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'backslash_in_arg'};
 
 $result_menus{'backslash_in_arg'} = {
   'cmdname' => 'node',
   'extra' => {
+    'isindex' => 1,
     'normalized' => 'Top',
     'spaces_before_argument' => ' '
   }
@@ -403,4 +396,7 @@ $result_menus{'backslash_in_arg'} = {
 $result_errors{'backslash_in_arg'} = [];
 
 
+$result_floats{'backslash_in_arg'} = {};
+
+
 1;
