@@ -48,22 +48,7 @@ $result_trees{'bad_formal_arg'} = {
       'extra' => {
         'arg_line' => ' bad  { , not_empty}
 ',
-        'args_index' => {
-          '' => 0,
-          'not_empty' => 1
-        },
-        'invalid_syntax' => 1,
-        'macrobody' => 'in bad macro
-',
-        'spaces_after_command' => {
-          'extra' => {
-            'command' => {}
-          },
-          'parent' => {},
-          'text' => '
-',
-          'type' => 'empty_line_after_command'
-        }
+        'invalid_syntax' => 1
       },
       'line_nr' => {
         'file_name' => '',
@@ -72,7 +57,12 @@ $result_trees{'bad_formal_arg'} = {
       },
       'parent' => {}
     },
-    {},
+    {
+      'parent' => {},
+      'text' => '
+',
+      'type' => 'empty_line_after_command'
+    },
     {
       'parent' => {},
       'text' => '
@@ -114,22 +104,7 @@ $result_trees{'bad_formal_arg'} = {
       'extra' => {
         'arg_line' => ' badspace{first, in 2arg}
 ',
-        'args_index' => {
-          'first' => 0,
-          'in 2arg' => 1
-        },
-        'invalid_syntax' => 1,
-        'macrobody' => 'bad space
-',
-        'spaces_after_command' => {
-          'extra' => {
-            'command' => {}
-          },
-          'parent' => {},
-          'text' => '
-',
-          'type' => 'empty_line_after_command'
-        }
+        'invalid_syntax' => 1
       },
       'line_nr' => {
         'file_name' => '',
@@ -138,7 +113,12 @@ $result_trees{'bad_formal_arg'} = {
       },
       'parent' => {}
     },
-    {},
+    {
+      'parent' => {},
+      'text' => '
+',
+      'type' => 'empty_line_after_command'
+    },
     {
       'parent' => {},
       'text' => '
@@ -183,42 +163,21 @@ $result_trees{'bad_formal_arg'} = {
           ],
           'extra' => {
             'arg_line' => ' foo {? aaa}
-',
-            'spaces_after_command' => {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'empty_line_after_command'
-            }
+'
           },
           'parent' => {}
         },
-        {}
-      ],
-      'extra' => {
-        'arg_line' => ' abar {:::}
-',
-        'args_index' => {
-          ':::' => 0
-        },
-        'invalid_syntax' => 1,
-        'macrobody' => 'in bar
-@macro foo {? aaa}
-in macro foo
-@end macro
-',
-        'spaces_after_command' => {
-          'extra' => {
-            'command' => {}
-          },
+        {
           'parent' => {},
           'text' => '
 ',
           'type' => 'empty_line_after_command'
         }
+      ],
+      'extra' => {
+        'arg_line' => ' abar {:::}
+',
+        'invalid_syntax' => 1
       },
       'line_nr' => {
         'file_name' => '',
@@ -227,7 +186,12 @@ in macro foo
       },
       'parent' => {}
     },
-    {}
+    {
+      'parent' => {},
+      'text' => '
+',
+      'type' => 'empty_line_after_command'
+    }
   ],
   'type' => 'text_root'
 };
@@ -237,34 +201,26 @@ $result_trees{'bad_formal_arg'}{'contents'}[1]{'args'}[1]{'parent'} = $result_tr
 $result_trees{'bad_formal_arg'}{'contents'}[1]{'args'}[2]{'parent'} = $result_trees{'bad_formal_arg'}{'contents'}[1];
 $result_trees{'bad_formal_arg'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'bad_formal_arg'}{'contents'}[1];
 $result_trees{'bad_formal_arg'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'bad_formal_arg'}{'contents'}[1];
-$result_trees{'bad_formal_arg'}{'contents'}[1]{'extra'}{'spaces_after_command'}{'extra'}{'command'} = $result_trees{'bad_formal_arg'}{'contents'}[1];
-$result_trees{'bad_formal_arg'}{'contents'}[1]{'extra'}{'spaces_after_command'}{'parent'} = $result_trees{'bad_formal_arg'};
 $result_trees{'bad_formal_arg'}{'contents'}[1]{'parent'} = $result_trees{'bad_formal_arg'};
-$result_trees{'bad_formal_arg'}{'contents'}[2] = $result_trees{'bad_formal_arg'}{'contents'}[1]{'extra'}{'spaces_after_command'};
+$result_trees{'bad_formal_arg'}{'contents'}[2]{'parent'} = $result_trees{'bad_formal_arg'};
 $result_trees{'bad_formal_arg'}{'contents'}[3]{'parent'} = $result_trees{'bad_formal_arg'};
 $result_trees{'bad_formal_arg'}{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'bad_formal_arg'}{'contents'}[4];
 $result_trees{'bad_formal_arg'}{'contents'}[4]{'args'}[1]{'parent'} = $result_trees{'bad_formal_arg'}{'contents'}[4];
 $result_trees{'bad_formal_arg'}{'contents'}[4]{'args'}[2]{'parent'} = $result_trees{'bad_formal_arg'}{'contents'}[4];
 $result_trees{'bad_formal_arg'}{'contents'}[4]{'contents'}[0]{'parent'} = $result_trees{'bad_formal_arg'}{'contents'}[4];
 $result_trees{'bad_formal_arg'}{'contents'}[4]{'contents'}[1]{'parent'} = $result_trees{'bad_formal_arg'}{'contents'}[4];
-$result_trees{'bad_formal_arg'}{'contents'}[4]{'extra'}{'spaces_after_command'}{'extra'}{'command'} = $result_trees{'bad_formal_arg'}{'contents'}[4];
-$result_trees{'bad_formal_arg'}{'contents'}[4]{'extra'}{'spaces_after_command'}{'parent'} = $result_trees{'bad_formal_arg'};
 $result_trees{'bad_formal_arg'}{'contents'}[4]{'parent'} = $result_trees{'bad_formal_arg'};
-$result_trees{'bad_formal_arg'}{'contents'}[5] = $result_trees{'bad_formal_arg'}{'contents'}[4]{'extra'}{'spaces_after_command'};
+$result_trees{'bad_formal_arg'}{'contents'}[5]{'parent'} = $result_trees{'bad_formal_arg'};
 $result_trees{'bad_formal_arg'}{'contents'}[6]{'parent'} = $result_trees{'bad_formal_arg'};
 $result_trees{'bad_formal_arg'}{'contents'}[7]{'args'}[0]{'parent'} = $result_trees{'bad_formal_arg'}{'contents'}[7];
 $result_trees{'bad_formal_arg'}{'contents'}[7]{'args'}[1]{'parent'} = $result_trees{'bad_formal_arg'}{'contents'}[7];
 $result_trees{'bad_formal_arg'}{'contents'}[7]{'contents'}[0]{'parent'} = $result_trees{'bad_formal_arg'}{'contents'}[7];
 $result_trees{'bad_formal_arg'}{'contents'}[7]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'bad_formal_arg'}{'contents'}[7]{'contents'}[1];
 $result_trees{'bad_formal_arg'}{'contents'}[7]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'bad_formal_arg'}{'contents'}[7]{'contents'}[1];
-$result_trees{'bad_formal_arg'}{'contents'}[7]{'contents'}[1]{'extra'}{'spaces_after_command'}{'extra'}{'command'} = $result_trees{'bad_formal_arg'}{'contents'}[7]{'contents'}[1];
-$result_trees{'bad_formal_arg'}{'contents'}[7]{'contents'}[1]{'extra'}{'spaces_after_command'}{'parent'} = $result_trees{'bad_formal_arg'}{'contents'}[7];
 $result_trees{'bad_formal_arg'}{'contents'}[7]{'contents'}[1]{'parent'} = $result_trees{'bad_formal_arg'}{'contents'}[7];
-$result_trees{'bad_formal_arg'}{'contents'}[7]{'contents'}[2] = $result_trees{'bad_formal_arg'}{'contents'}[7]{'contents'}[1]{'extra'}{'spaces_after_command'};
-$result_trees{'bad_formal_arg'}{'contents'}[7]{'extra'}{'spaces_after_command'}{'extra'}{'command'} = $result_trees{'bad_formal_arg'}{'contents'}[7];
-$result_trees{'bad_formal_arg'}{'contents'}[7]{'extra'}{'spaces_after_command'}{'parent'} = $result_trees{'bad_formal_arg'};
+$result_trees{'bad_formal_arg'}{'contents'}[7]{'contents'}[2]{'parent'} = $result_trees{'bad_formal_arg'}{'contents'}[7];
 $result_trees{'bad_formal_arg'}{'contents'}[7]{'parent'} = $result_trees{'bad_formal_arg'};
-$result_trees{'bad_formal_arg'}{'contents'}[8] = $result_trees{'bad_formal_arg'}{'contents'}[7]{'extra'}{'spaces_after_command'};
+$result_trees{'bad_formal_arg'}{'contents'}[8]{'parent'} = $result_trees{'bad_formal_arg'};
 
 $result_texis{'bad_formal_arg'} = '
 @macro bad  { , not_empty}
@@ -320,4 +276,7 @@ $result_errors{'bad_formal_arg'} = [
 ];
 
 
+$result_floats{'bad_formal_arg'} = {};
+
+
 1;
