@@ -11,8 +11,18 @@ $result_trees{'bad_macro_name_with_underscore'} = {
       'args' => [
         {
           'parent' => {},
-          'text' => 'the',
+          'text' => 'the_macro',
           'type' => 'macro_name'
+        },
+        {
+          'parent' => {},
+          'text' => 'arg1',
+          'type' => 'macro_arg'
+        },
+        {
+          'parent' => {},
+          'text' => 'arg2',
+          'type' => 'macro_arg'
         }
       ],
       'cmdname' => 'macro',
@@ -31,8 +41,7 @@ $result_trees{'bad_macro_name_with_underscore'} = {
       ],
       'extra' => {
         'arg_line' => ' the_macro {arg1, arg2}
-',
-        'invalid_syntax' => 1
+'
       },
       'line_nr' => {
         'file_name' => '',
@@ -42,9 +51,6 @@ $result_trees{'bad_macro_name_with_underscore'} = {
       'parent' => {}
     },
     {
-      'extra' => {
-        'command' => {}
-      },
       'parent' => {},
       'text' => '
 ',
@@ -54,10 +60,11 @@ $result_trees{'bad_macro_name_with_underscore'} = {
   'type' => 'text_root'
 };
 $result_trees{'bad_macro_name_with_underscore'}{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'bad_macro_name_with_underscore'}{'contents'}[0];
+$result_trees{'bad_macro_name_with_underscore'}{'contents'}[0]{'args'}[1]{'parent'} = $result_trees{'bad_macro_name_with_underscore'}{'contents'}[0];
+$result_trees{'bad_macro_name_with_underscore'}{'contents'}[0]{'args'}[2]{'parent'} = $result_trees{'bad_macro_name_with_underscore'}{'contents'}[0];
 $result_trees{'bad_macro_name_with_underscore'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'bad_macro_name_with_underscore'}{'contents'}[0];
 $result_trees{'bad_macro_name_with_underscore'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'bad_macro_name_with_underscore'}{'contents'}[0];
 $result_trees{'bad_macro_name_with_underscore'}{'contents'}[0]{'parent'} = $result_trees{'bad_macro_name_with_underscore'};
-$result_trees{'bad_macro_name_with_underscore'}{'contents'}[1]{'extra'}{'command'} = $result_trees{'bad_macro_name_with_underscore'}{'contents'}[0];
 $result_trees{'bad_macro_name_with_underscore'}{'contents'}[1]{'parent'} = $result_trees{'bad_macro_name_with_underscore'};
 
 $result_texis{'bad_macro_name_with_underscore'} = '@macro the_macro {arg1, arg2}
@@ -68,17 +75,10 @@ In macro
 
 $result_texts{'bad_macro_name_with_underscore'} = '';
 
-$result_errors{'bad_macro_name_with_underscore'} = [
-  {
-    'error_line' => ':1: bad syntax for @macro argument: _macro {arg1, arg2}
-',
-    'file_name' => '',
-    'line_nr' => 1,
-    'macro' => '',
-    'text' => 'bad syntax for @macro argument: _macro {arg1, arg2}',
-    'type' => 'error'
-  }
-];
+$result_errors{'bad_macro_name_with_underscore'} = [];
+
+
+$result_floats{'bad_macro_name_with_underscore'} = {};
 
 
 1;
