@@ -58,9 +58,6 @@ $result_trees{'ifset_in_macro'} = {
       'parent' => {}
     },
     {
-      'extra' => {
-        'command' => {}
-      },
       'parent' => {},
       'text' => '
 ',
@@ -82,7 +79,6 @@ $result_trees{'ifset_in_macro'}{'contents'}[0]{'contents'}[1]{'parent'} = $resul
 $result_trees{'ifset_in_macro'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'ifset_in_macro'}{'contents'}[0];
 $result_trees{'ifset_in_macro'}{'contents'}[0]{'contents'}[3]{'parent'} = $result_trees{'ifset_in_macro'}{'contents'}[0];
 $result_trees{'ifset_in_macro'}{'contents'}[0]{'parent'} = $result_trees{'ifset_in_macro'};
-$result_trees{'ifset_in_macro'}{'contents'}[1]{'extra'}{'command'} = $result_trees{'ifset_in_macro'}{'contents'}[0];
 $result_trees{'ifset_in_macro'}{'contents'}[1]{'parent'} = $result_trees{'ifset_in_macro'};
 $result_trees{'ifset_in_macro'}{'contents'}[2]{'parent'} = $result_trees{'ifset_in_macro'};
 
@@ -101,4 +97,7 @@ $result_texts{'ifset_in_macro'} = '
 $result_errors{'ifset_in_macro'} = [];
 
 
+$result_floats{'ifset_in_macro'} = {};
+
+
 1;
