@@ -46,9 +46,6 @@ $result_trees{'macro_expands_to_empty'} = {
       'parent' => {}
     },
     {
-      'extra' => {
-        'command' => {}
-      },
       'parent' => {},
       'text' => '
 ',
@@ -85,7 +82,6 @@ $result_trees{'macro_expands_to_empty'}{'contents'}[0]{'args'}[1]{'parent'} = $r
 $result_trees{'macro_expands_to_empty'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'macro_expands_to_empty'}{'contents'}[0];
 $result_trees{'macro_expands_to_empty'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'macro_expands_to_empty'}{'contents'}[0];
 $result_trees{'macro_expands_to_empty'}{'contents'}[0]{'parent'} = $result_trees{'macro_expands_to_empty'};
-$result_trees{'macro_expands_to_empty'}{'contents'}[1]{'extra'}{'command'} = $result_trees{'macro_expands_to_empty'}{'contents'}[0];
 $result_trees{'macro_expands_to_empty'}{'contents'}[1]{'parent'} = $result_trees{'macro_expands_to_empty'};
 $result_trees{'macro_expands_to_empty'}{'contents'}[2]{'parent'} = $result_trees{'macro_expands_to_empty'};
 $result_trees{'macro_expands_to_empty'}{'contents'}[3]{'parent'} = $result_trees{'macro_expands_to_empty'};
@@ -109,4 +105,7 @@ aa
 $result_errors{'macro_expands_to_empty'} = [];
 
 
+$result_floats{'macro_expands_to_empty'} = {};
+
+
 1;
