@@ -46,9 +46,6 @@ $result_trees{'macro_with_error_at_end_line_after_macro'} = {
       'parent' => {}
     },
     {
-      'extra' => {
-        'command' => {}
-      },
       'parent' => {},
       'text' => '
 ',
@@ -63,25 +60,18 @@ $result_trees{'macro_with_error_at_end_line_after_macro'} = {
     {
       'args' => [
         {
-          'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'empty_line_after_command'
-            }
-          ],
+          'contents' => [],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'center',
       'extra' => {
-        'missing_argument' => 1,
-        'spaces_after_command' => {}
+        'missing_argument' => 1
       },
       'line_nr' => {
         'file_name' => '',
@@ -98,13 +88,9 @@ $result_trees{'macro_with_error_at_end_line_after_macro'}{'contents'}[0]{'args'}
 $result_trees{'macro_with_error_at_end_line_after_macro'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'macro_with_error_at_end_line_after_macro'}{'contents'}[0];
 $result_trees{'macro_with_error_at_end_line_after_macro'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'macro_with_error_at_end_line_after_macro'}{'contents'}[0];
 $result_trees{'macro_with_error_at_end_line_after_macro'}{'contents'}[0]{'parent'} = $result_trees{'macro_with_error_at_end_line_after_macro'};
-$result_trees{'macro_with_error_at_end_line_after_macro'}{'contents'}[1]{'extra'}{'command'} = $result_trees{'macro_with_error_at_end_line_after_macro'}{'contents'}[0];
 $result_trees{'macro_with_error_at_end_line_after_macro'}{'contents'}[1]{'parent'} = $result_trees{'macro_with_error_at_end_line_after_macro'};
 $result_trees{'macro_with_error_at_end_line_after_macro'}{'contents'}[2]{'parent'} = $result_trees{'macro_with_error_at_end_line_after_macro'};
-$result_trees{'macro_with_error_at_end_line_after_macro'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'macro_with_error_at_end_line_after_macro'}{'contents'}[3];
-$result_trees{'macro_with_error_at_end_line_after_macro'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'macro_with_error_at_end_line_after_macro'}{'contents'}[3]{'args'}[0];
 $result_trees{'macro_with_error_at_end_line_after_macro'}{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'macro_with_error_at_end_line_after_macro'}{'contents'}[3];
-$result_trees{'macro_with_error_at_end_line_after_macro'}{'contents'}[3]{'extra'}{'spaces_after_command'} = $result_trees{'macro_with_error_at_end_line_after_macro'}{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'macro_with_error_at_end_line_after_macro'}{'contents'}[3]{'parent'} = $result_trees{'macro_with_error_at_end_line_after_macro'};
 
 $result_texis{'macro_with_error_at_end_line_after_macro'} = '@macro witherror{string}
@@ -132,4 +118,7 @@ $result_errors{'macro_with_error_at_end_line_after_macro'} = [
 ];
 
 
+$result_floats{'macro_with_error_at_end_line_after_macro'} = {};
+
+
 1;
