@@ -51,9 +51,6 @@ $result_trees{'protect_in_body'} = {
       'parent' => {}
     },
     {
-      'extra' => {
-        'command' => {}
-      },
       'parent' => {},
       'text' => '
 ',
@@ -104,7 +101,11 @@ $result_trees{'protect_in_body'} = {
           ],
           'cmdname' => 'emph',
           'contents' => [],
-          'line_nr' => {},
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 5,
+            'macro' => 'macroone'
+          },
           'parent' => {}
         },
         {
@@ -126,7 +127,11 @@ $result_trees{'protect_in_body'} = {
           ],
           'cmdname' => 'emph',
           'contents' => [],
-          'line_nr' => {},
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 5,
+            'macro' => 'macroone'
+          },
           'parent' => {}
         },
         {
@@ -147,7 +152,6 @@ $result_trees{'protect_in_body'}{'contents'}[0]{'args'}[2]{'parent'} = $result_t
 $result_trees{'protect_in_body'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'protect_in_body'}{'contents'}[0];
 $result_trees{'protect_in_body'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'protect_in_body'}{'contents'}[0];
 $result_trees{'protect_in_body'}{'contents'}[0]{'parent'} = $result_trees{'protect_in_body'};
-$result_trees{'protect_in_body'}{'contents'}[1]{'extra'}{'command'} = $result_trees{'protect_in_body'}{'contents'}[0];
 $result_trees{'protect_in_body'}{'contents'}[1]{'parent'} = $result_trees{'protect_in_body'};
 $result_trees{'protect_in_body'}{'contents'}[2]{'parent'} = $result_trees{'protect_in_body'};
 $result_trees{'protect_in_body'}{'contents'}[3]{'contents'}[0]{'parent'} = $result_trees{'protect_in_body'}{'contents'}[3];
@@ -155,12 +159,10 @@ $result_trees{'protect_in_body'}{'contents'}[3]{'contents'}[1]{'args'}[0]{'conte
 $result_trees{'protect_in_body'}{'contents'}[3]{'contents'}[1]{'args'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'protect_in_body'}{'contents'}[3]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'protect_in_body'}{'contents'}[3]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'protect_in_body'}{'contents'}[3]{'contents'}[1]{'args'}[0];
 $result_trees{'protect_in_body'}{'contents'}[3]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'protect_in_body'}{'contents'}[3]{'contents'}[1];
-$result_trees{'protect_in_body'}{'contents'}[3]{'contents'}[1]{'line_nr'} = $result_trees{'protect_in_body'}{'contents'}[3]{'contents'}[1]{'args'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'protect_in_body'}{'contents'}[3]{'contents'}[1]{'parent'} = $result_trees{'protect_in_body'}{'contents'}[3];
 $result_trees{'protect_in_body'}{'contents'}[3]{'contents'}[2]{'parent'} = $result_trees{'protect_in_body'}{'contents'}[3];
 $result_trees{'protect_in_body'}{'contents'}[3]{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'protect_in_body'}{'contents'}[3]{'contents'}[3]{'args'}[0];
 $result_trees{'protect_in_body'}{'contents'}[3]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'protect_in_body'}{'contents'}[3]{'contents'}[3];
-$result_trees{'protect_in_body'}{'contents'}[3]{'contents'}[3]{'line_nr'} = $result_trees{'protect_in_body'}{'contents'}[3]{'contents'}[1]{'args'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'protect_in_body'}{'contents'}[3]{'contents'}[3]{'parent'} = $result_trees{'protect_in_body'}{'contents'}[3];
 $result_trees{'protect_in_body'}{'contents'}[3]{'contents'}[4]{'parent'} = $result_trees{'protect_in_body'}{'contents'}[3];
 $result_trees{'protect_in_body'}{'contents'}[3]{'parent'} = $result_trees{'protect_in_body'};
@@ -180,4 +182,7 @@ the result: f\\irst arg protected \\ -> \\arg1\\ second arg  after macro.
 $result_errors{'protect_in_body'} = [];
 
 
+$result_floats{'protect_in_body'} = {};
+
+
 1;
