@@ -51,9 +51,6 @@ $result_trees{'protect_in_body_one_arg'} = {
       'parent' => {}
     },
     {
-      'extra' => {
-        'command' => {}
-      },
       'parent' => {},
       'text' => '
 ',
@@ -104,7 +101,11 @@ $result_trees{'protect_in_body_one_arg'} = {
           ],
           'cmdname' => 'emph',
           'contents' => [],
-          'line_nr' => {},
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 5,
+            'macro' => 'macroone'
+          },
           'parent' => {}
         },
         {
@@ -121,7 +122,11 @@ $result_trees{'protect_in_body_one_arg'} = {
           ],
           'cmdname' => 'emph',
           'contents' => [],
-          'line_nr' => {},
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 5,
+            'macro' => 'macroone'
+          },
           'parent' => {}
         },
         {
@@ -142,7 +147,6 @@ $result_trees{'protect_in_body_one_arg'}{'contents'}[0]{'args'}[2]{'parent'} = $
 $result_trees{'protect_in_body_one_arg'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'protect_in_body_one_arg'}{'contents'}[0];
 $result_trees{'protect_in_body_one_arg'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'protect_in_body_one_arg'}{'contents'}[0];
 $result_trees{'protect_in_body_one_arg'}{'contents'}[0]{'parent'} = $result_trees{'protect_in_body_one_arg'};
-$result_trees{'protect_in_body_one_arg'}{'contents'}[1]{'extra'}{'command'} = $result_trees{'protect_in_body_one_arg'}{'contents'}[0];
 $result_trees{'protect_in_body_one_arg'}{'contents'}[1]{'parent'} = $result_trees{'protect_in_body_one_arg'};
 $result_trees{'protect_in_body_one_arg'}{'contents'}[2]{'parent'} = $result_trees{'protect_in_body_one_arg'};
 $result_trees{'protect_in_body_one_arg'}{'contents'}[3]{'contents'}[0]{'parent'} = $result_trees{'protect_in_body_one_arg'}{'contents'}[3];
@@ -150,11 +154,9 @@ $result_trees{'protect_in_body_one_arg'}{'contents'}[3]{'contents'}[1]{'args'}[0
 $result_trees{'protect_in_body_one_arg'}{'contents'}[3]{'contents'}[1]{'args'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'protect_in_body_one_arg'}{'contents'}[3]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'protect_in_body_one_arg'}{'contents'}[3]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'protect_in_body_one_arg'}{'contents'}[3]{'contents'}[1]{'args'}[0];
 $result_trees{'protect_in_body_one_arg'}{'contents'}[3]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'protect_in_body_one_arg'}{'contents'}[3]{'contents'}[1];
-$result_trees{'protect_in_body_one_arg'}{'contents'}[3]{'contents'}[1]{'line_nr'} = $result_trees{'protect_in_body_one_arg'}{'contents'}[3]{'contents'}[1]{'args'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'protect_in_body_one_arg'}{'contents'}[3]{'contents'}[1]{'parent'} = $result_trees{'protect_in_body_one_arg'}{'contents'}[3];
 $result_trees{'protect_in_body_one_arg'}{'contents'}[3]{'contents'}[2]{'parent'} = $result_trees{'protect_in_body_one_arg'}{'contents'}[3];
 $result_trees{'protect_in_body_one_arg'}{'contents'}[3]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'protect_in_body_one_arg'}{'contents'}[3]{'contents'}[3];
-$result_trees{'protect_in_body_one_arg'}{'contents'}[3]{'contents'}[3]{'line_nr'} = $result_trees{'protect_in_body_one_arg'}{'contents'}[3]{'contents'}[1]{'args'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'protect_in_body_one_arg'}{'contents'}[3]{'contents'}[3]{'parent'} = $result_trees{'protect_in_body_one_arg'}{'contents'}[3];
 $result_trees{'protect_in_body_one_arg'}{'contents'}[3]{'contents'}[4]{'parent'} = $result_trees{'protect_in_body_one_arg'}{'contents'}[3];
 $result_trees{'protect_in_body_one_arg'}{'contents'}[3]{'parent'} = $result_trees{'protect_in_body_one_arg'};
@@ -174,4 +176,7 @@ result: f\\irst arg protected \\ -> \\arg1\\
 $result_errors{'protect_in_body_one_arg'} = [];
 
 
+$result_floats{'protect_in_body_one_arg'} = {};
+
+
 1;
