@@ -47,9 +47,6 @@ $result_trees{'text_before_after'} = {
           'parent' => {}
         },
         {
-          'extra' => {
-            'command' => {}
-          },
           'parent' => {},
           'text' => ' ',
           'type' => 'empty_spaces_after_command'
@@ -71,7 +68,6 @@ $result_trees{'text_before_after'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'par
 $result_trees{'text_before_after'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'text_before_after'}{'contents'}[0]{'contents'}[1];
 $result_trees{'text_before_after'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'text_before_after'}{'contents'}[0]{'contents'}[1];
 $result_trees{'text_before_after'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'text_before_after'}{'contents'}[0];
-$result_trees{'text_before_after'}{'contents'}[0]{'contents'}[2]{'extra'}{'command'} = $result_trees{'text_before_after'}{'contents'}[0]{'contents'}[1];
 $result_trees{'text_before_after'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'text_before_after'}{'contents'}[0];
 $result_trees{'text_before_after'}{'contents'}[0]{'contents'}[3]{'parent'} = $result_trees{'text_before_after'}{'contents'}[0];
 $result_trees{'text_before_after'}{'contents'}[0]{'parent'} = $result_trees{'text_before_after'};
@@ -107,4 +103,7 @@ $result_errors{'text_before_after'} = [
 ];
 
 
+$result_floats{'text_before_after'} = {};
+
+
 1;
