@@ -57,9 +57,6 @@ $result_trees{'too_much_args'} = {
       'parent' => {}
     },
     {
-      'extra' => {
-        'command' => {}
-      },
       'parent' => {},
       'text' => '
 ',
@@ -97,7 +94,6 @@ $result_trees{'too_much_args'}{'contents'}[0]{'contents'}[0]{'parent'} = $result
 $result_trees{'too_much_args'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'too_much_args'}{'contents'}[0];
 $result_trees{'too_much_args'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'too_much_args'}{'contents'}[0];
 $result_trees{'too_much_args'}{'contents'}[0]{'parent'} = $result_trees{'too_much_args'};
-$result_trees{'too_much_args'}{'contents'}[1]{'extra'}{'command'} = $result_trees{'too_much_args'}{'contents'}[0];
 $result_trees{'too_much_args'}{'contents'}[1]{'parent'} = $result_trees{'too_much_args'};
 $result_trees{'too_much_args'}{'contents'}[2]{'parent'} = $result_trees{'too_much_args'};
 $result_trees{'too_much_args'}{'contents'}[3]{'contents'}[0]{'parent'} = $result_trees{'too_much_args'}{'contents'}[3];
@@ -132,4 +128,7 @@ $result_errors{'too_much_args'} = [
 ];
 
 
+$result_floats{'too_much_args'} = {};
+
+
 1;
