@@ -36,9 +36,6 @@ $result_trees{'menu_no_closed_entry_beginning'} = {
           'type' => 'menu_comment'
         }
       ],
-      'extra' => {
-        'spaces_after_command' => {}
-      },
       'line_nr' => {
         'file_name' => '',
         'line_nr' => 1,
@@ -54,7 +51,6 @@ $result_trees{'menu_no_closed_entry_beginning'}{'contents'}[0]{'contents'}[0]{'p
 $result_trees{'menu_no_closed_entry_beginning'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'menu_no_closed_entry_beginning'}{'contents'}[0]{'contents'}[1]{'contents'}[0];
 $result_trees{'menu_no_closed_entry_beginning'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'menu_no_closed_entry_beginning'}{'contents'}[0]{'contents'}[1];
 $result_trees{'menu_no_closed_entry_beginning'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'menu_no_closed_entry_beginning'}{'contents'}[0];
-$result_trees{'menu_no_closed_entry_beginning'}{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'menu_no_closed_entry_beginning'}{'contents'}[0]{'contents'}[0];
 $result_trees{'menu_no_closed_entry_beginning'}{'contents'}[0]{'parent'} = $result_trees{'menu_no_closed_entry_beginning'};
 
 $result_texis{'menu_no_closed_entry_beginning'} = '@menu
@@ -64,24 +60,6 @@ $result_texis{'menu_no_closed_entry_beginning'} = '@menu
 $result_texts{'menu_no_closed_entry_beginning'} = '* node';
 
 $result_errors{'menu_no_closed_entry_beginning'} = [
-  {
-    'error_line' => ':1: @menu seen before first @node
-',
-    'file_name' => '',
-    'line_nr' => 1,
-    'macro' => '',
-    'text' => '@menu seen before first @node',
-    'type' => 'error'
-  },
-  {
-    'error_line' => ':1: perhaps your @top node should be wrapped in @ifnottex rather than @ifinfo?
-',
-    'file_name' => '',
-    'line_nr' => 1,
-    'macro' => '',
-    'text' => 'perhaps your @top node should be wrapped in @ifnottex rather than @ifinfo?',
-    'type' => 'error continuation'
-  },
   {
     'error_line' => ':2: no matching `@end menu\'
 ',
@@ -94,4 +72,7 @@ $result_errors{'menu_no_closed_entry_beginning'} = [
 ];
 
 
+$result_floats{'menu_no_closed_entry_beginning'} = {};
+
+
 1;
