@@ -177,7 +177,9 @@ $result_trees{'menu_title_before_entries'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -216,7 +218,9 @@ $result_trees{'menu_title_before_entries'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'subnode'
           }
         ],
@@ -259,12 +263,12 @@ $result_trees{'menu_title_before_entries'}{'contents'}[1]{'contents'}[1]{'extra'
 $result_trees{'menu_title_before_entries'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'menu_title_before_entries'}{'contents'}[1];
 $result_trees{'menu_title_before_entries'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'menu_title_before_entries'}{'contents'}[1];
 $result_trees{'menu_title_before_entries'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'menu_title_before_entries'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'menu_title_before_entries'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'menu_title_before_entries'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'menu_title_before_entries'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'menu_title_before_entries'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'menu_title_before_entries'}{'contents'}[1]{'parent'} = $result_trees{'menu_title_before_entries'};
 $result_trees{'menu_title_before_entries'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'menu_title_before_entries'}{'contents'}[2]{'args'}[0];
 $result_trees{'menu_title_before_entries'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'menu_title_before_entries'}{'contents'}[2];
 $result_trees{'menu_title_before_entries'}{'contents'}[2]{'extra'}{'node_content'}[0] = $result_trees{'menu_title_before_entries'}{'contents'}[2]{'args'}[0]{'contents'}[0];
-$result_trees{'menu_title_before_entries'}{'contents'}[2]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'menu_title_before_entries'}{'contents'}[2]{'extra'}{'node_content'};
+$result_trees{'menu_title_before_entries'}{'contents'}[2]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'menu_title_before_entries'}{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'menu_title_before_entries'}{'contents'}[2]{'parent'} = $result_trees{'menu_title_before_entries'};
 
 $result_texis{'menu_title_before_entries'} = '@node Top
@@ -316,23 +320,11 @@ $result_nodes{'menu_title_before_entries'} = {
       }
     }
   ],
-  'node_next' => {},
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
-  }
+  'node_next' => {}
 };
 $result_nodes{'menu_title_before_entries'}{'menu_child'}{'node_prev'} = $result_nodes{'menu_title_before_entries'};
 $result_nodes{'menu_title_before_entries'}{'menu_child'}{'node_up'} = $result_nodes{'menu_title_before_entries'};
 $result_nodes{'menu_title_before_entries'}{'node_next'} = $result_nodes{'menu_title_before_entries'}{'menu_child'};
-$result_nodes{'menu_title_before_entries'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'menu_title_before_entries'};
 
 $result_menus{'menu_title_before_entries'} = {
   'cmdname' => 'node',
@@ -357,6 +349,9 @@ $result_menus{'menu_title_before_entries'}{'menu_child'}{'menu_up'} = $result_me
 $result_errors{'menu_title_before_entries'} = [];
 
 
+$result_floats{'menu_title_before_entries'} = {};
+
+
 
 $result_converted{'plaintext'}->{'menu_title_before_entries'} = '* Menu:
 
@@ -377,14 +372,16 @@ $result_converted{'html'}->{'menu_title_before_entries'} = '<!DOCTYPE html PUBLI
 <meta name="keywords" content="Untitled Document">
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
+<meta name="viewport" content="width=device-width,initial-scale=1">
+
 <link href="#Top" rel="start" title="Top">
 <style type="text/css">
 <!--
+a.copiable-anchor {visibility: hidden; text-decoration: none; line-height: 0em}
 a.summary-letter {text-decoration: none}
 blockquote.indentedblock {margin-right: 0em}
 div.display {margin-left: 3.2em}
 div.example {margin-left: 3.2em}
-div.lisp {margin-left: 3.2em}
 kbd {font-style: oblique}
 pre.display {font-family: inherit}
 pre.format {font-family: inherit}
@@ -393,6 +390,7 @@ pre.menu-preformatted {font-family: serif}
 span.nolinebreak {white-space: nowrap}
 span.roman {font-family: initial; font-weight: normal}
 span.sansserif {font-family: sans-serif; font-weight: normal}
+span:hover a.copiable-anchor {visibility: visible}
 ul.no-bullet {list-style: none}
 -->
 </style>
@@ -403,13 +401,13 @@ ul.no-bullet {list-style: none}
 <body lang="en">
 <span id="Top"></span><div class="header">
 <p>
-Next: <a href="#subnode" accesskey="n" rel="next">subnode</a>, Up: <a href="dir.html#Top" accesskey="u" rel="up">(dir)</a> &nbsp; </p>
+Next: <a href="#subnode" accesskey="n" rel="next">subnode</a> &nbsp; </p>
 </div>
 <h1 class="node-heading">Top</h1>
 
 <table class="menu" border="0" cellspacing="0">
 <tr><th colspan="3" align="left" valign="top"><pre class="menu-comment">Horizontal space
-</pre></th></tr><tr><td align="left" valign="top">&bull; <a href="#subnode" accesskey="1">subnode</a></td><td>&nbsp;&nbsp;</td><td align="left" valign="top">
+</pre></th></tr><tr><td align="left" valign="top">&bull; <a href="#subnode" accesskey="1">subnode</a>:</td><td>&nbsp;&nbsp;</td><td align="left" valign="top">
 </td></tr>
 </table>
 
@@ -419,7 +417,6 @@ Next: <a href="#subnode" accesskey="n" rel="next">subnode</a>, Up: <a href="dir.
 Previous: <a href="#Top" accesskey="p" rel="prev">Top</a>, Up: <a href="#Top" accesskey="u" rel="up">Top</a> &nbsp; </p>
 </div>
 <h4 class="node-heading">subnode</h4>
-<hr>
 
 
 
@@ -438,7 +435,7 @@ $result_converted_errors{'html'}->{'menu_title_before_entries'} = [
 
 
 
-$result_converted{'xml'}->{'menu_title_before_entries'} = '<node name="Top" spaces=" "><nodename>Top</nodename><nodenext automatic="on">subnode</nodenext><nodeup automatic="on">(dir)</nodeup></node>
+$result_converted{'xml'}->{'menu_title_before_entries'} = '<node name="Top" spaces=" "><nodename>Top</nodename><nodenext automatic="on">subnode</nodenext></node>
 
 <menu endspaces=" ">
 <menucomment><pre xml:space="preserve">Horizontal space
