@@ -300,7 +300,9 @@ $result_trees{'multiple_menus'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -365,7 +367,7 @@ $result_trees{'multiple_menus'}{'contents'}[1]{'contents'}[3]{'contents'}[2]{'pa
 $result_trees{'multiple_menus'}{'contents'}[1]{'contents'}[3]{'extra'}{'end_command'} = $result_trees{'multiple_menus'}{'contents'}[1]{'contents'}[3]{'contents'}[2];
 $result_trees{'multiple_menus'}{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'multiple_menus'}{'contents'}[1];
 $result_trees{'multiple_menus'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'multiple_menus'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'multiple_menus'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'multiple_menus'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'multiple_menus'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'multiple_menus'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'multiple_menus'}{'contents'}[1]{'parent'} = $result_trees{'multiple_menus'};
 
 $result_texis{'multiple_menus'} = '@node Top
@@ -432,21 +434,9 @@ $result_nodes{'multiple_menus'} = {
       }
     }
   ],
-  'node_next' => {},
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
-  }
+  'node_next' => {}
 };
 $result_nodes{'multiple_menus'}{'node_next'} = $result_nodes{'multiple_menus'}{'menu_child'};
-$result_nodes{'multiple_menus'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'multiple_menus'};
 
 $result_menus{'multiple_menus'} = {
   'cmdname' => 'node',
@@ -479,4 +469,7 @@ $result_errors{'multiple_menus'} = [
 ];
 
 
+$result_floats{'multiple_menus'} = {};
+
+
 1;
