@@ -37,7 +37,9 @@ $result_trees{'verb_in_menu_description'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -268,7 +270,7 @@ $result_trees{'verb_in_menu_description'}{'contents'}[0]{'parent'} = $result_tre
 $result_trees{'verb_in_menu_description'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'verb_in_menu_description'}{'contents'}[1]{'args'}[0];
 $result_trees{'verb_in_menu_description'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'verb_in_menu_description'}{'contents'}[1];
 $result_trees{'verb_in_menu_description'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'verb_in_menu_description'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'verb_in_menu_description'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'verb_in_menu_description'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'verb_in_menu_description'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'verb_in_menu_description'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'verb_in_menu_description'}{'contents'}[1]{'parent'} = $result_trees{'verb_in_menu_description'};
 $result_trees{'verb_in_menu_description'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'verb_in_menu_description'}{'contents'}[2]{'args'}[0];
 $result_trees{'verb_in_menu_description'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'verb_in_menu_description'}{'contents'}[2];
@@ -384,21 +386,9 @@ $result_nodes{'verb_in_menu_description'} = {
       }
     }
   ],
-  'node_next' => {},
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
-  }
+  'node_next' => {}
 };
 $result_nodes{'verb_in_menu_description'}{'node_next'} = $result_nodes{'verb_in_menu_description'}{'menu_child'};
-$result_nodes{'verb_in_menu_description'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'verb_in_menu_description'};
 
 $result_menus{'verb_in_menu_description'} = {
   'cmdname' => 'node',
@@ -420,6 +410,9 @@ $result_menus{'verb_in_menu_description'} = {
 $result_errors{'verb_in_menu_description'} = [];
 
 
+$result_floats{'verb_in_menu_description'} = {};
+
+
 
 $result_converted{'plaintext'}->{'verb_in_menu_description'} = 'top
 ***
@@ -445,14 +438,16 @@ $result_converted{'html'}->{'verb_in_menu_description'} = '<!DOCTYPE html PUBLIC
 <meta name="keywords" content="top">
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
+<meta name="viewport" content="width=device-width,initial-scale=1">
+
 <link href="#Top" rel="start" title="Top">
 <style type="text/css">
 <!--
+a.copiable-anchor {visibility: hidden; text-decoration: none; line-height: 0em}
 a.summary-letter {text-decoration: none}
 blockquote.indentedblock {margin-right: 0em}
 div.display {margin-left: 3.2em}
 div.example {margin-left: 3.2em}
-div.lisp {margin-left: 3.2em}
 kbd {font-style: oblique}
 pre.display {font-family: inherit}
 pre.format {font-family: inherit}
@@ -461,6 +456,7 @@ pre.menu-preformatted {font-family: serif}
 span.nolinebreak {white-space: nowrap}
 span.roman {font-family: initial; font-weight: normal}
 span.sansserif {font-family: sans-serif; font-weight: normal}
+span:hover a.copiable-anchor {visibility: visible}
 ul.no-bullet {list-style: none}
 -->
 </style>
@@ -469,10 +465,11 @@ ul.no-bullet {list-style: none}
 </head>
 
 <body lang="en">
-<span id="Top"></span><span id="top"></span><h1 class="top">top</h1>
+<div class="top" id="Top">
+<span id="top"></span><h1 class="top">top</h1>
 
 <table class="menu" border="0" cellspacing="0">
-<tr><td align="left" valign="top">&bull; <a href="manual.html#Top" accesskey="1">(manual)</a></td><td>&nbsp;&nbsp;</td><td align="left" valign="top">
+<tr><td align="left" valign="top">&bull; <a href="manual.html#Top" accesskey="1">(manual)</a>:</td><td>&nbsp;&nbsp;</td><td align="left" valign="top">
 <tt> in verb
 
 </tt>
@@ -480,7 +477,7 @@ ul.no-bullet {list-style: none}
 <tr><th colspan="3" align="left" valign="top"><pre class="menu-comment">
 
 </pre></th></tr></table>
-<hr>
+<hr></div>
 
 
 
@@ -489,7 +486,7 @@ ul.no-bullet {list-style: none}
 ';
 
 
-$result_converted{'xml'}->{'verb_in_menu_description'} = '<node name="Top" spaces=" "><nodename>Top</nodename><nodenext automatic="on">(manual)</nodenext><nodeup automatic="on">(dir)</nodeup></node>
+$result_converted{'xml'}->{'verb_in_menu_description'} = '<node name="Top" spaces=" "><nodename>Top</nodename><nodenext automatic="on">(manual)</nodenext></node>
 <top spaces=" "><sectiontitle>top</sectiontitle>
 
 <menu endspaces=" ">
