@@ -49,16 +49,6 @@ $result_trees{'also_not_line'} = {
         },
         {
           'cmdname' => 'noindent',
-          'extra' => {
-            'spaces_after_command' => {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            }
-          },
           'line_nr' => {
             'file_name' => '',
             'line_nr' => 4,
@@ -66,7 +56,14 @@ $result_trees{'also_not_line'} = {
           },
           'parent' => {}
         },
-        {},
+        {
+          'extra' => {
+            'command' => {}
+          },
+          'parent' => {},
+          'text' => ' ',
+          'type' => 'empty_spaces_after_command'
+        },
         {
           'parent' => {},
           'text' => 'refill '
@@ -92,16 +89,6 @@ $result_trees{'also_not_line'} = {
     },
     {
       'cmdname' => 'noindent',
-      'extra' => {
-        'spaces_after_command' => {
-          'extra' => {
-            'command' => {}
-          },
-          'parent' => {},
-          'text' => '     ',
-          'type' => 'empty_spaces_after_command'
-        }
-      },
       'line_nr' => {
         'file_name' => '',
         'line_nr' => 6,
@@ -109,7 +96,14 @@ $result_trees{'also_not_line'} = {
       },
       'parent' => {}
     },
-    {},
+    {
+      'extra' => {
+        'command' => {}
+      },
+      'parent' => {},
+      'text' => '     ',
+      'type' => 'empty_spaces_after_command'
+    },
     {
       'contents' => [
         {
@@ -119,17 +113,6 @@ $result_trees{'also_not_line'} = {
         },
         {
           'cmdname' => 'noindent',
-          'extra' => {
-            'spaces_after_command' => {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => '  
-',
-              'type' => 'empty_line_after_command'
-            }
-          },
           'line_nr' => {
             'file_name' => '',
             'line_nr' => 7,
@@ -137,7 +120,15 @@ $result_trees{'also_not_line'} = {
           },
           'parent' => {}
         },
-        {},
+        {
+          'extra' => {
+            'command' => {}
+          },
+          'parent' => {},
+          'text' => '  
+',
+          'type' => 'empty_line_after_command'
+        },
         {
           'parent' => {},
           'text' => 'noindent on the preceding line
@@ -149,16 +140,6 @@ $result_trees{'also_not_line'} = {
         },
         {
           'cmdname' => 'noindent',
-          'extra' => {
-            'spaces_after_command' => {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => '    ',
-              'type' => 'empty_spaces_after_command'
-            }
-          },
           'line_nr' => {
             'file_name' => '',
             'line_nr' => 9,
@@ -166,7 +147,14 @@ $result_trees{'also_not_line'} = {
           },
           'parent' => {}
         },
-        {},
+        {
+          'extra' => {
+            'command' => {}
+          },
+          'parent' => {},
+          'text' => '    ',
+          'type' => 'empty_spaces_after_command'
+        },
         {
           'parent' => {},
           'text' => 'noindent after space at beginning of line
@@ -250,16 +238,6 @@ $result_trees{'also_not_line'} = {
         },
         {
           'cmdname' => 'noindent',
-          'extra' => {
-            'spaces_after_command' => {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => '    ',
-              'type' => 'empty_spaces_after_command'
-            }
-          },
           'line_nr' => {
             'file_name' => '',
             'line_nr' => 15,
@@ -267,7 +245,14 @@ $result_trees{'also_not_line'} = {
           },
           'parent' => {}
         },
-        {},
+        {
+          'extra' => {
+            'command' => {}
+          },
+          'parent' => {},
+          'text' => '    ',
+          'type' => 'empty_spaces_after_command'
+        },
         {
           'parent' => {},
           'text' => 'refill '
@@ -316,35 +301,22 @@ $result_trees{'also_not_line'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'special'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'subheading',
       'extra' => {
-        'misc_content' => [
-          {}
-        ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'level' => 3,
       'line_nr' => {
@@ -388,22 +360,6 @@ $result_trees{'also_not_line'} = {
             ]
           },
           'parent' => {}
-        },
-        {
-          'parent' => {},
-          'text' => 'cropmarks '
-        },
-        {
-          'args' => [
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'misc_arg'
-            }
-          ],
-          'cmdname' => 'cropmarks',
-          'parent' => {}
         }
       ],
       'parent' => {},
@@ -429,39 +385,26 @@ $result_trees{'also_not_line'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'line after exdent'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'exdent',
       'extra' => {
-        'misc_content' => [
-          {}
-        ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'line_nr' => {
         'file_name' => '',
-        'line_nr' => 24,
+        'line_nr' => 23,
         'macro' => ''
       },
       'parent' => {}
@@ -476,30 +419,26 @@ $result_trees{'also_not_line'}{'contents'}[2]{'parent'} = $result_trees{'also_no
 $result_trees{'also_not_line'}{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[3];
 $result_trees{'also_not_line'}{'contents'}[3]{'parent'} = $result_trees{'also_not_line'};
 $result_trees{'also_not_line'}{'contents'}[4]{'contents'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[4];
-$result_trees{'also_not_line'}{'contents'}[4]{'contents'}[1]{'extra'}{'spaces_after_command'}{'extra'}{'command'} = $result_trees{'also_not_line'}{'contents'}[4]{'contents'}[1];
-$result_trees{'also_not_line'}{'contents'}[4]{'contents'}[1]{'extra'}{'spaces_after_command'}{'parent'} = $result_trees{'also_not_line'}{'contents'}[4];
 $result_trees{'also_not_line'}{'contents'}[4]{'contents'}[1]{'parent'} = $result_trees{'also_not_line'}{'contents'}[4];
-$result_trees{'also_not_line'}{'contents'}[4]{'contents'}[2] = $result_trees{'also_not_line'}{'contents'}[4]{'contents'}[1]{'extra'}{'spaces_after_command'};
+$result_trees{'also_not_line'}{'contents'}[4]{'contents'}[2]{'extra'}{'command'} = $result_trees{'also_not_line'}{'contents'}[4]{'contents'}[1];
+$result_trees{'also_not_line'}{'contents'}[4]{'contents'}[2]{'parent'} = $result_trees{'also_not_line'}{'contents'}[4];
 $result_trees{'also_not_line'}{'contents'}[4]{'contents'}[3]{'parent'} = $result_trees{'also_not_line'}{'contents'}[4];
 $result_trees{'also_not_line'}{'contents'}[4]{'contents'}[4]{'parent'} = $result_trees{'also_not_line'}{'contents'}[4];
 $result_trees{'also_not_line'}{'contents'}[4]{'contents'}[5]{'parent'} = $result_trees{'also_not_line'}{'contents'}[4];
 $result_trees{'also_not_line'}{'contents'}[4]{'parent'} = $result_trees{'also_not_line'};
 $result_trees{'also_not_line'}{'contents'}[5]{'parent'} = $result_trees{'also_not_line'};
-$result_trees{'also_not_line'}{'contents'}[6]{'extra'}{'spaces_after_command'}{'extra'}{'command'} = $result_trees{'also_not_line'}{'contents'}[6];
-$result_trees{'also_not_line'}{'contents'}[6]{'extra'}{'spaces_after_command'}{'parent'} = $result_trees{'also_not_line'};
 $result_trees{'also_not_line'}{'contents'}[6]{'parent'} = $result_trees{'also_not_line'};
-$result_trees{'also_not_line'}{'contents'}[7] = $result_trees{'also_not_line'}{'contents'}[6]{'extra'}{'spaces_after_command'};
+$result_trees{'also_not_line'}{'contents'}[7]{'extra'}{'command'} = $result_trees{'also_not_line'}{'contents'}[6];
+$result_trees{'also_not_line'}{'contents'}[7]{'parent'} = $result_trees{'also_not_line'};
 $result_trees{'also_not_line'}{'contents'}[8]{'contents'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[8];
-$result_trees{'also_not_line'}{'contents'}[8]{'contents'}[1]{'extra'}{'spaces_after_command'}{'extra'}{'command'} = $result_trees{'also_not_line'}{'contents'}[8]{'contents'}[1];
-$result_trees{'also_not_line'}{'contents'}[8]{'contents'}[1]{'extra'}{'spaces_after_command'}{'parent'} = $result_trees{'also_not_line'}{'contents'}[8];
 $result_trees{'also_not_line'}{'contents'}[8]{'contents'}[1]{'parent'} = $result_trees{'also_not_line'}{'contents'}[8];
-$result_trees{'also_not_line'}{'contents'}[8]{'contents'}[2] = $result_trees{'also_not_line'}{'contents'}[8]{'contents'}[1]{'extra'}{'spaces_after_command'};
+$result_trees{'also_not_line'}{'contents'}[8]{'contents'}[2]{'extra'}{'command'} = $result_trees{'also_not_line'}{'contents'}[8]{'contents'}[1];
+$result_trees{'also_not_line'}{'contents'}[8]{'contents'}[2]{'parent'} = $result_trees{'also_not_line'}{'contents'}[8];
 $result_trees{'also_not_line'}{'contents'}[8]{'contents'}[3]{'parent'} = $result_trees{'also_not_line'}{'contents'}[8];
 $result_trees{'also_not_line'}{'contents'}[8]{'contents'}[4]{'parent'} = $result_trees{'also_not_line'}{'contents'}[8];
-$result_trees{'also_not_line'}{'contents'}[8]{'contents'}[5]{'extra'}{'spaces_after_command'}{'extra'}{'command'} = $result_trees{'also_not_line'}{'contents'}[8]{'contents'}[5];
-$result_trees{'also_not_line'}{'contents'}[8]{'contents'}[5]{'extra'}{'spaces_after_command'}{'parent'} = $result_trees{'also_not_line'}{'contents'}[8];
 $result_trees{'also_not_line'}{'contents'}[8]{'contents'}[5]{'parent'} = $result_trees{'also_not_line'}{'contents'}[8];
-$result_trees{'also_not_line'}{'contents'}[8]{'contents'}[6] = $result_trees{'also_not_line'}{'contents'}[8]{'contents'}[5]{'extra'}{'spaces_after_command'};
+$result_trees{'also_not_line'}{'contents'}[8]{'contents'}[6]{'extra'}{'command'} = $result_trees{'also_not_line'}{'contents'}[8]{'contents'}[5];
+$result_trees{'also_not_line'}{'contents'}[8]{'contents'}[6]{'parent'} = $result_trees{'also_not_line'}{'contents'}[8];
 $result_trees{'also_not_line'}{'contents'}[8]{'contents'}[7]{'parent'} = $result_trees{'also_not_line'}{'contents'}[8];
 $result_trees{'also_not_line'}{'contents'}[8]{'parent'} = $result_trees{'also_not_line'};
 $result_trees{'also_not_line'}{'contents'}[9]{'args'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[9];
@@ -514,10 +453,9 @@ $result_trees{'also_not_line'}{'contents'}[13]{'parent'} = $result_trees{'also_n
 $result_trees{'also_not_line'}{'contents'}[14]{'args'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[14];
 $result_trees{'also_not_line'}{'contents'}[14]{'parent'} = $result_trees{'also_not_line'};
 $result_trees{'also_not_line'}{'contents'}[15]{'contents'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[15];
-$result_trees{'also_not_line'}{'contents'}[15]{'contents'}[1]{'extra'}{'spaces_after_command'}{'extra'}{'command'} = $result_trees{'also_not_line'}{'contents'}[15]{'contents'}[1];
-$result_trees{'also_not_line'}{'contents'}[15]{'contents'}[1]{'extra'}{'spaces_after_command'}{'parent'} = $result_trees{'also_not_line'}{'contents'}[15];
 $result_trees{'also_not_line'}{'contents'}[15]{'contents'}[1]{'parent'} = $result_trees{'also_not_line'}{'contents'}[15];
-$result_trees{'also_not_line'}{'contents'}[15]{'contents'}[2] = $result_trees{'also_not_line'}{'contents'}[15]{'contents'}[1]{'extra'}{'spaces_after_command'};
+$result_trees{'also_not_line'}{'contents'}[15]{'contents'}[2]{'extra'}{'command'} = $result_trees{'also_not_line'}{'contents'}[15]{'contents'}[1];
+$result_trees{'also_not_line'}{'contents'}[15]{'contents'}[2]{'parent'} = $result_trees{'also_not_line'}{'contents'}[15];
 $result_trees{'also_not_line'}{'contents'}[15]{'contents'}[3]{'parent'} = $result_trees{'also_not_line'}{'contents'}[15];
 $result_trees{'also_not_line'}{'contents'}[15]{'contents'}[4]{'parent'} = $result_trees{'also_not_line'}{'contents'}[15];
 $result_trees{'also_not_line'}{'contents'}[15]{'contents'}[5]{'parent'} = $result_trees{'also_not_line'}{'contents'}[15];
@@ -526,33 +464,20 @@ $result_trees{'also_not_line'}{'contents'}[15]{'contents'}[7]{'args'}[0]{'parent
 $result_trees{'also_not_line'}{'contents'}[15]{'contents'}[7]{'parent'} = $result_trees{'also_not_line'}{'contents'}[15];
 $result_trees{'also_not_line'}{'contents'}[15]{'parent'} = $result_trees{'also_not_line'};
 $result_trees{'also_not_line'}{'contents'}[16]{'parent'} = $result_trees{'also_not_line'};
-$result_trees{'also_not_line'}{'contents'}[17]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'also_not_line'}{'contents'}[17];
 $result_trees{'also_not_line'}{'contents'}[17]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[17]{'args'}[0];
-$result_trees{'also_not_line'}{'contents'}[17]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'also_not_line'}{'contents'}[17]{'args'}[0];
-$result_trees{'also_not_line'}{'contents'}[17]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'also_not_line'}{'contents'}[17]{'args'}[0];
 $result_trees{'also_not_line'}{'contents'}[17]{'args'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[17];
-$result_trees{'also_not_line'}{'contents'}[17]{'extra'}{'misc_content'}[0] = $result_trees{'also_not_line'}{'contents'}[17]{'args'}[0]{'contents'}[1];
-$result_trees{'also_not_line'}{'contents'}[17]{'extra'}{'spaces_after_command'} = $result_trees{'also_not_line'}{'contents'}[17]{'args'}[0]{'contents'}[0];
 $result_trees{'also_not_line'}{'contents'}[17]{'parent'} = $result_trees{'also_not_line'};
 $result_trees{'also_not_line'}{'contents'}[18]{'parent'} = $result_trees{'also_not_line'};
 $result_trees{'also_not_line'}{'contents'}[19]{'contents'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[19];
 $result_trees{'also_not_line'}{'contents'}[19]{'contents'}[1]{'parent'} = $result_trees{'also_not_line'}{'contents'}[19];
 $result_trees{'also_not_line'}{'contents'}[19]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[19]{'contents'}[2];
 $result_trees{'also_not_line'}{'contents'}[19]{'contents'}[2]{'parent'} = $result_trees{'also_not_line'}{'contents'}[19];
-$result_trees{'also_not_line'}{'contents'}[19]{'contents'}[3]{'parent'} = $result_trees{'also_not_line'}{'contents'}[19];
-$result_trees{'also_not_line'}{'contents'}[19]{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[19]{'contents'}[4];
-$result_trees{'also_not_line'}{'contents'}[19]{'contents'}[4]{'parent'} = $result_trees{'also_not_line'}{'contents'}[19];
 $result_trees{'also_not_line'}{'contents'}[19]{'parent'} = $result_trees{'also_not_line'};
 $result_trees{'also_not_line'}{'contents'}[20]{'parent'} = $result_trees{'also_not_line'};
 $result_trees{'also_not_line'}{'contents'}[21]{'contents'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[21];
 $result_trees{'also_not_line'}{'contents'}[21]{'parent'} = $result_trees{'also_not_line'};
-$result_trees{'also_not_line'}{'contents'}[22]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'also_not_line'}{'contents'}[22];
 $result_trees{'also_not_line'}{'contents'}[22]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[22]{'args'}[0];
-$result_trees{'also_not_line'}{'contents'}[22]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'also_not_line'}{'contents'}[22]{'args'}[0];
-$result_trees{'also_not_line'}{'contents'}[22]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'also_not_line'}{'contents'}[22]{'args'}[0];
 $result_trees{'also_not_line'}{'contents'}[22]{'args'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[22];
-$result_trees{'also_not_line'}{'contents'}[22]{'extra'}{'misc_content'}[0] = $result_trees{'also_not_line'}{'contents'}[22]{'args'}[0]{'contents'}[1];
-$result_trees{'also_not_line'}{'contents'}[22]{'extra'}{'spaces_after_command'} = $result_trees{'also_not_line'}{'contents'}[22]{'args'}[0]{'contents'}[0];
 $result_trees{'also_not_line'}{'contents'}[22]{'parent'} = $result_trees{'also_not_line'};
 
 $result_texis{'also_not_line'} = '
@@ -576,7 +501,6 @@ novalidate @novalidate something
 
 Only valid between iftex:
 vskip @vskip 
-cropmarks @cropmarks
 
 exdent @exdent line after exdent
 ';
@@ -597,7 +521,7 @@ special
 -------
 
 Only valid between iftex:
-vskip cropmarks 
+vskip 
 exdent line after exdent
 ';
 
@@ -611,6 +535,15 @@ $result_errors{'also_not_line'} = [
     'text' => '@page should only appear at the beginning of a line',
     'type' => 'warning'
   },
+  {
+    'error_line' => ':4: warning: @refill is obsolete.
+',
+    'file_name' => '',
+    'line_nr' => 4,
+    'macro' => '',
+    'text' => '@refill is obsolete.',
+    'type' => 'warning'
+  },
   {
     'error_line' => ':14: warning: @page should only appear at the beginning of a line
 ',
@@ -620,6 +553,15 @@ $result_errors{'also_not_line'} = [
     'text' => '@page should only appear at the beginning of a line',
     'type' => 'warning'
   },
+  {
+    'error_line' => ':15: warning: @refill is obsolete.
+',
+    'file_name' => '',
+    'line_nr' => 15,
+    'macro' => '',
+    'text' => '@refill is obsolete.',
+    'type' => 'warning'
+  },
   {
     'error_line' => ':16: warning: @novalidate should only appear at the beginning of a line
 ',
@@ -630,19 +572,10 @@ $result_errors{'also_not_line'} = [
     'type' => 'warning'
   },
   {
-    'error_line' => ':22: warning: @cropmarks should only appear at the beginning of a line
+    'error_line' => ':23: warning: @exdent should only appear at the beginning of a line
 ',
     'file_name' => '',
-    'line_nr' => 22,
-    'macro' => '',
-    'text' => '@cropmarks should only appear at the beginning of a line',
-    'type' => 'warning'
-  },
-  {
-    'error_line' => ':24: warning: @exdent should only appear at the beginning of a line
-',
-    'file_name' => '',
-    'line_nr' => 24,
+    'line_nr' => 23,
     'macro' => '',
     'text' => '@exdent should only appear at the beginning of a line',
     'type' => 'warning'
@@ -650,4 +583,7 @@ $result_errors{'also_not_line'} = [
 ];
 
 
+$result_floats{'also_not_line'} = {};
+
+
 1;
