@@ -17,27 +17,17 @@ $result_trees{'definfoenclose_with_empty_arg'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'headword, , :'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'definfoenclose',
@@ -47,7 +37,7 @@ $result_trees{'definfoenclose_with_empty_arg'} = {
           '',
           ':'
         ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'line_nr' => {
         'file_name' => '',
@@ -109,12 +99,8 @@ $result_trees{'definfoenclose_with_empty_arg'} = {
   'type' => 'text_root'
 };
 $result_trees{'definfoenclose_with_empty_arg'}{'contents'}[0]{'parent'} = $result_trees{'definfoenclose_with_empty_arg'};
-$result_trees{'definfoenclose_with_empty_arg'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'definfoenclose_with_empty_arg'}{'contents'}[1];
 $result_trees{'definfoenclose_with_empty_arg'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'definfoenclose_with_empty_arg'}{'contents'}[1]{'args'}[0];
-$result_trees{'definfoenclose_with_empty_arg'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'definfoenclose_with_empty_arg'}{'contents'}[1]{'args'}[0];
-$result_trees{'definfoenclose_with_empty_arg'}{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'definfoenclose_with_empty_arg'}{'contents'}[1]{'args'}[0];
 $result_trees{'definfoenclose_with_empty_arg'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'definfoenclose_with_empty_arg'}{'contents'}[1];
-$result_trees{'definfoenclose_with_empty_arg'}{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'definfoenclose_with_empty_arg'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'definfoenclose_with_empty_arg'}{'contents'}[1]{'parent'} = $result_trees{'definfoenclose_with_empty_arg'};
 $result_trees{'definfoenclose_with_empty_arg'}{'contents'}[2]{'parent'} = $result_trees{'definfoenclose_with_empty_arg'};
 $result_trees{'definfoenclose_with_empty_arg'}{'contents'}[3]{'contents'}[0]{'parent'} = $result_trees{'definfoenclose_with_empty_arg'}{'contents'}[3];
@@ -139,7 +125,20 @@ My something.
 
 ';
 
-$result_errors{'definfoenclose_with_empty_arg'} = [];
+$result_errors{'definfoenclose_with_empty_arg'} = [
+  {
+    'error_line' => ':2: warning: @definfoenclose is obsolete.
+',
+    'file_name' => '',
+    'line_nr' => 2,
+    'macro' => '',
+    'text' => '@definfoenclose is obsolete.',
+    'type' => 'warning'
+  }
+];
+
+
+$result_floats{'definfoenclose_with_empty_arg'} = {};
 
 
 
@@ -156,7 +155,7 @@ $result_converted{'html_text'}->{'definfoenclose_with_empty_arg'} = '
 
 
 $result_converted{'xml'}->{'definfoenclose_with_empty_arg'} = '
-<definfoenclose command="headword" open="" close=":" line=" headword, , :"></definfoenclose>
+<definfoenclose command="headword" open="" close=":" line="headword, , :"></definfoenclose>
 
 <para>My <infoenclose command="headword" begin="" end=":">something</infoenclose>.
 </para>
