@@ -274,17 +274,20 @@ $result_errors{'invalid_clickstyle'} = [
     'type' => 'warning'
   },
   {
-    'error_line' => ':10: @clickstyle should only accept a @-command as argument, not ` something
+    'error_line' => ':10: @clickstyle should only accept an @-command as argument, not ` something
 \'
 ',
     'file_name' => '',
     'line_nr' => 10,
     'macro' => '',
-    'text' => '@clickstyle should only accept a @-command as argument, not ` something
+    'text' => '@clickstyle should only accept an @-command as argument, not ` something
 \'',
     'type' => 'error'
   }
 ];
 
 
+$result_floats{'invalid_clickstyle'} = {};
+
+
 1;
