@@ -95,9 +95,6 @@ $result_trees{'kbdinputstyle'} = {
       'parent' => {}
     },
     {
-      'extra' => {
-        'command' => {}
-      },
       'parent' => {},
       'text' => '
 ',
@@ -134,27 +131,17 @@ $result_trees{'kbdinputstyle'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'code'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'kbdinputstyle',
@@ -162,7 +149,7 @@ $result_trees{'kbdinputstyle'} = {
         'misc_args' => [
           'code'
         ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'line_nr' => {
         'file_name' => '',
@@ -216,7 +203,11 @@ $result_trees{'kbdinputstyle'} = {
           ],
           'cmdname' => 'code',
           'contents' => [],
-          'line_nr' => {},
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 18,
+            'macro' => 'codekbdmacro'
+          },
           'parent' => {}
         },
         {
@@ -294,7 +285,11 @@ $result_trees{'kbdinputstyle'} = {
           ],
           'cmdname' => 'code',
           'contents' => [],
-          'line_nr' => {},
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 18,
+            'macro' => 'codekbdmacro'
+          },
           'parent' => {}
         },
         {
@@ -374,7 +369,11 @@ $result_trees{'kbdinputstyle'} = {
               ],
               'cmdname' => 'code',
               'contents' => [],
-              'line_nr' => {},
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 18,
+                'macro' => 'codekbdmacro'
+              },
               'parent' => {}
             },
             {
@@ -456,7 +455,11 @@ $result_trees{'kbdinputstyle'} = {
               ],
               'cmdname' => 'code',
               'contents' => [],
-              'line_nr' => {},
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 18,
+                'macro' => 'codekbdmacro'
+              },
               'parent' => {}
             },
             {
@@ -472,34 +475,23 @@ $result_trees{'kbdinputstyle'} = {
           'args' => [
             {
               'contents' => [
-                {
-                  'extra' => {
-                    'command' => {}
-                  },
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_after_command'
-                },
                 {
                   'parent' => {},
                   'text' => 'example'
-                },
-                {
-                  'parent' => {},
-                  'text' => '
-',
-                  'type' => 'spaces_at_end'
                 }
               ],
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
               'parent' => {},
-              'type' => 'misc_line_arg'
+              'type' => 'line_arg'
             }
           ],
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
             'command_argument' => 'example',
-            'spaces_after_command' => {},
+            'spaces_before_argument' => ' ',
             'text_arg' => 'example'
           },
           'line_nr' => {
@@ -511,8 +503,7 @@ $result_trees{'kbdinputstyle'} = {
         }
       ],
       'extra' => {
-        'end_command' => {},
-        'spaces_after_command' => {}
+        'end_command' => {}
       },
       'line_nr' => {
         'file_name' => '',
@@ -552,27 +543,17 @@ $result_trees{'kbdinputstyle'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'example'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'kbdinputstyle',
@@ -580,7 +561,7 @@ $result_trees{'kbdinputstyle'} = {
         'misc_args' => [
           'example'
         ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'line_nr' => {
         'file_name' => '',
@@ -634,7 +615,11 @@ $result_trees{'kbdinputstyle'} = {
           ],
           'cmdname' => 'code',
           'contents' => [],
-          'line_nr' => {},
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 24,
+            'macro' => 'codekbdmacro'
+          },
           'parent' => {}
         },
         {
@@ -709,7 +694,11 @@ $result_trees{'kbdinputstyle'} = {
           ],
           'cmdname' => 'code',
           'contents' => [],
-          'line_nr' => {},
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 24,
+            'macro' => 'codekbdmacro'
+          },
           'parent' => {}
         },
         {
@@ -789,7 +778,11 @@ $result_trees{'kbdinputstyle'} = {
               ],
               'cmdname' => 'code',
               'contents' => [],
-              'line_nr' => {},
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 24,
+                'macro' => 'codekbdmacro'
+              },
               'parent' => {}
             },
             {
@@ -871,7 +864,11 @@ $result_trees{'kbdinputstyle'} = {
               ],
               'cmdname' => 'code',
               'contents' => [],
-              'line_nr' => {},
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 24,
+                'macro' => 'codekbdmacro'
+              },
               'parent' => {}
             },
             {
@@ -887,34 +884,23 @@ $result_trees{'kbdinputstyle'} = {
           'args' => [
             {
               'contents' => [
-                {
-                  'extra' => {
-                    'command' => {}
-                  },
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_after_command'
-                },
                 {
                   'parent' => {},
                   'text' => 'example'
-                },
-                {
-                  'parent' => {},
-                  'text' => '
-',
-                  'type' => 'spaces_at_end'
                 }
               ],
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
               'parent' => {},
-              'type' => 'misc_line_arg'
+              'type' => 'line_arg'
             }
           ],
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
             'command_argument' => 'example',
-            'spaces_after_command' => {},
+            'spaces_before_argument' => ' ',
             'text_arg' => 'example'
           },
           'line_nr' => {
@@ -926,8 +912,7 @@ $result_trees{'kbdinputstyle'} = {
         }
       ],
       'extra' => {
-        'end_command' => {},
-        'spaces_after_command' => {}
+        'end_command' => {}
       },
       'line_nr' => {
         'file_name' => '',
@@ -967,27 +952,17 @@ $result_trees{'kbdinputstyle'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'distinct'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'kbdinputstyle',
@@ -995,7 +970,7 @@ $result_trees{'kbdinputstyle'} = {
         'misc_args' => [
           'distinct'
         ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'line_nr' => {
         'file_name' => '',
@@ -1049,7 +1024,11 @@ $result_trees{'kbdinputstyle'} = {
           ],
           'cmdname' => 'code',
           'contents' => [],
-          'line_nr' => {},
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 30,
+            'macro' => 'codekbdmacro'
+          },
           'parent' => {}
         },
         {
@@ -1121,7 +1100,11 @@ $result_trees{'kbdinputstyle'} = {
           ],
           'cmdname' => 'code',
           'contents' => [],
-          'line_nr' => {},
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 30,
+            'macro' => 'codekbdmacro'
+          },
           'parent' => {}
         },
         {
@@ -1201,7 +1184,11 @@ $result_trees{'kbdinputstyle'} = {
               ],
               'cmdname' => 'code',
               'contents' => [],
-              'line_nr' => {},
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 30,
+                'macro' => 'codekbdmacro'
+              },
               'parent' => {}
             },
             {
@@ -1277,7 +1264,11 @@ $result_trees{'kbdinputstyle'} = {
               ],
               'cmdname' => 'code',
               'contents' => [],
-              'line_nr' => {},
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 30,
+                'macro' => 'codekbdmacro'
+              },
               'parent' => {}
             },
             {
@@ -1293,34 +1284,23 @@ $result_trees{'kbdinputstyle'} = {
           'args' => [
             {
               'contents' => [
-                {
-                  'extra' => {
-                    'command' => {}
-                  },
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_after_command'
-                },
                 {
                   'parent' => {},
                   'text' => 'example'
-                },
-                {
-                  'parent' => {},
-                  'text' => '
-',
-                  'type' => 'spaces_at_end'
                 }
               ],
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
               'parent' => {},
-              'type' => 'misc_line_arg'
+              'type' => 'line_arg'
             }
           ],
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
             'command_argument' => 'example',
-            'spaces_after_command' => {},
+            'spaces_before_argument' => ' ',
             'text_arg' => 'example'
           },
           'line_nr' => {
@@ -1332,8 +1312,7 @@ $result_trees{'kbdinputstyle'} = {
         }
       ],
       'extra' => {
-        'end_command' => {},
-        'spaces_after_command' => {}
+        'end_command' => {}
       },
       'line_nr' => {
         'file_name' => '',
@@ -1358,19 +1337,14 @@ $result_trees{'kbdinputstyle'}{'contents'}[0]{'contents'}[8]{'parent'} = $result
 $result_trees{'kbdinputstyle'}{'contents'}[0]{'contents'}[9]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[0]{'contents'}[10]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[0]{'parent'} = $result_trees{'kbdinputstyle'};
-$result_trees{'kbdinputstyle'}{'contents'}[1]{'extra'}{'command'} = $result_trees{'kbdinputstyle'}{'contents'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[1]{'parent'} = $result_trees{'kbdinputstyle'};
 $result_trees{'kbdinputstyle'}{'contents'}[2]{'parent'} = $result_trees{'kbdinputstyle'};
 $result_trees{'kbdinputstyle'}{'contents'}[3]{'contents'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[3];
 $result_trees{'kbdinputstyle'}{'contents'}[3]{'contents'}[1]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[3];
 $result_trees{'kbdinputstyle'}{'contents'}[3]{'parent'} = $result_trees{'kbdinputstyle'};
 $result_trees{'kbdinputstyle'}{'contents'}[4]{'parent'} = $result_trees{'kbdinputstyle'};
-$result_trees{'kbdinputstyle'}{'contents'}[5]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'kbdinputstyle'}{'contents'}[5];
 $result_trees{'kbdinputstyle'}{'contents'}[5]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[5]{'args'}[0];
-$result_trees{'kbdinputstyle'}{'contents'}[5]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[5]{'args'}[0];
-$result_trees{'kbdinputstyle'}{'contents'}[5]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[5]{'args'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[5]{'args'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[5];
-$result_trees{'kbdinputstyle'}{'contents'}[5]{'extra'}{'spaces_after_command'} = $result_trees{'kbdinputstyle'}{'contents'}[5]{'args'}[0]{'contents'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[5]{'parent'} = $result_trees{'kbdinputstyle'};
 $result_trees{'kbdinputstyle'}{'contents'}[6]{'parent'} = $result_trees{'kbdinputstyle'};
 $result_trees{'kbdinputstyle'}{'contents'}[7]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[7]{'contents'}[0]{'args'}[0];
@@ -1378,7 +1352,6 @@ $result_trees{'kbdinputstyle'}{'contents'}[7]{'contents'}[0]{'args'}[0]{'content
 $result_trees{'kbdinputstyle'}{'contents'}[7]{'contents'}[0]{'args'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[7]{'contents'}[0]{'args'}[0]{'contents'}[1];
 $result_trees{'kbdinputstyle'}{'contents'}[7]{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[7]{'contents'}[0]{'args'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[7]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[7]{'contents'}[0];
-$result_trees{'kbdinputstyle'}{'contents'}[7]{'contents'}[0]{'line_nr'} = $result_trees{'kbdinputstyle'}{'contents'}[7]{'contents'}[0]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'kbdinputstyle'}{'contents'}[7]{'contents'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[7];
 $result_trees{'kbdinputstyle'}{'contents'}[7]{'contents'}[1]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[7];
 $result_trees{'kbdinputstyle'}{'contents'}[7]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[7]{'contents'}[2]{'args'}[0];
@@ -1390,7 +1363,6 @@ $result_trees{'kbdinputstyle'}{'contents'}[7]{'contents'}[4]{'args'}[0]{'content
 $result_trees{'kbdinputstyle'}{'contents'}[7]{'contents'}[4]{'args'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[7]{'contents'}[4]{'args'}[0]{'contents'}[1];
 $result_trees{'kbdinputstyle'}{'contents'}[7]{'contents'}[4]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[7]{'contents'}[4]{'args'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[7]{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[7]{'contents'}[4];
-$result_trees{'kbdinputstyle'}{'contents'}[7]{'contents'}[4]{'line_nr'} = $result_trees{'kbdinputstyle'}{'contents'}[7]{'contents'}[4]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'kbdinputstyle'}{'contents'}[7]{'contents'}[4]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[7];
 $result_trees{'kbdinputstyle'}{'contents'}[7]{'contents'}[5]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[7];
 $result_trees{'kbdinputstyle'}{'contents'}[7]{'parent'} = $result_trees{'kbdinputstyle'};
@@ -1404,7 +1376,6 @@ $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[1]{'contents'}[0]{'ar
 $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[1];
 $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[1]{'contents'}[0]{'args'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[1]{'contents'}[0];
-$result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[1]{'contents'}[0]{'line_nr'} = $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[1];
 $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[1];
 $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[1]{'contents'}[2]{'args'}[0];
@@ -1417,32 +1388,21 @@ $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[1]{'contents'}[4]{'ar
 $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[1]{'contents'}[4]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[1]{'contents'}[4]{'args'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[1]{'contents'}[4]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[1]{'contents'}[4]{'args'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[1]{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[1]{'contents'}[4];
-$result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[1]{'contents'}[4]{'line_nr'} = $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[1]{'contents'}[4]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[1]{'contents'}[4]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[1];
 $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[1]{'contents'}[5]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[1];
 $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[1]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[10];
-$result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[2];
 $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[2]{'args'}[0];
-$result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[2]{'args'}[0];
-$result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[2]{'args'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[2];
-$result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[2]{'extra'}{'command'} = $result_trees{'kbdinputstyle'}{'contents'}[10];
-$result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[2]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[10];
 $result_trees{'kbdinputstyle'}{'contents'}[10]{'extra'}{'end_command'} = $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[2];
-$result_trees{'kbdinputstyle'}{'contents'}[10]{'extra'}{'spaces_after_command'} = $result_trees{'kbdinputstyle'}{'contents'}[10]{'contents'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[10]{'parent'} = $result_trees{'kbdinputstyle'};
 $result_trees{'kbdinputstyle'}{'contents'}[11]{'parent'} = $result_trees{'kbdinputstyle'};
 $result_trees{'kbdinputstyle'}{'contents'}[12]{'contents'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[12];
 $result_trees{'kbdinputstyle'}{'contents'}[12]{'contents'}[1]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[12];
 $result_trees{'kbdinputstyle'}{'contents'}[12]{'parent'} = $result_trees{'kbdinputstyle'};
 $result_trees{'kbdinputstyle'}{'contents'}[13]{'parent'} = $result_trees{'kbdinputstyle'};
-$result_trees{'kbdinputstyle'}{'contents'}[14]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'kbdinputstyle'}{'contents'}[14];
 $result_trees{'kbdinputstyle'}{'contents'}[14]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[14]{'args'}[0];
-$result_trees{'kbdinputstyle'}{'contents'}[14]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[14]{'args'}[0];
-$result_trees{'kbdinputstyle'}{'contents'}[14]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[14]{'args'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[14]{'args'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[14];
-$result_trees{'kbdinputstyle'}{'contents'}[14]{'extra'}{'spaces_after_command'} = $result_trees{'kbdinputstyle'}{'contents'}[14]{'args'}[0]{'contents'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[14]{'parent'} = $result_trees{'kbdinputstyle'};
 $result_trees{'kbdinputstyle'}{'contents'}[15]{'parent'} = $result_trees{'kbdinputstyle'};
 $result_trees{'kbdinputstyle'}{'contents'}[16]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[16]{'contents'}[0]{'args'}[0];
@@ -1450,7 +1410,6 @@ $result_trees{'kbdinputstyle'}{'contents'}[16]{'contents'}[0]{'args'}[0]{'conten
 $result_trees{'kbdinputstyle'}{'contents'}[16]{'contents'}[0]{'args'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[16]{'contents'}[0]{'args'}[0]{'contents'}[1];
 $result_trees{'kbdinputstyle'}{'contents'}[16]{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[16]{'contents'}[0]{'args'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[16]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[16]{'contents'}[0];
-$result_trees{'kbdinputstyle'}{'contents'}[16]{'contents'}[0]{'line_nr'} = $result_trees{'kbdinputstyle'}{'contents'}[16]{'contents'}[0]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'kbdinputstyle'}{'contents'}[16]{'contents'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[16];
 $result_trees{'kbdinputstyle'}{'contents'}[16]{'contents'}[1]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[16];
 $result_trees{'kbdinputstyle'}{'contents'}[16]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[16]{'contents'}[2]{'args'}[0];
@@ -1462,7 +1421,6 @@ $result_trees{'kbdinputstyle'}{'contents'}[16]{'contents'}[4]{'args'}[0]{'conten
 $result_trees{'kbdinputstyle'}{'contents'}[16]{'contents'}[4]{'args'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[16]{'contents'}[4]{'args'}[0]{'contents'}[1];
 $result_trees{'kbdinputstyle'}{'contents'}[16]{'contents'}[4]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[16]{'contents'}[4]{'args'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[16]{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[16]{'contents'}[4];
-$result_trees{'kbdinputstyle'}{'contents'}[16]{'contents'}[4]{'line_nr'} = $result_trees{'kbdinputstyle'}{'contents'}[16]{'contents'}[4]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'kbdinputstyle'}{'contents'}[16]{'contents'}[4]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[16];
 $result_trees{'kbdinputstyle'}{'contents'}[16]{'contents'}[5]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[16];
 $result_trees{'kbdinputstyle'}{'contents'}[16]{'parent'} = $result_trees{'kbdinputstyle'};
@@ -1476,7 +1434,6 @@ $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[1]{'contents'}[0]{'ar
 $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[1];
 $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[1]{'contents'}[0]{'args'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[1]{'contents'}[0];
-$result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[1]{'contents'}[0]{'line_nr'} = $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[1];
 $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[1];
 $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[1]{'contents'}[2]{'args'}[0];
@@ -1489,32 +1446,21 @@ $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[1]{'contents'}[4]{'ar
 $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[1]{'contents'}[4]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[1]{'contents'}[4]{'args'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[1]{'contents'}[4]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[1]{'contents'}[4]{'args'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[1]{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[1]{'contents'}[4];
-$result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[1]{'contents'}[4]{'line_nr'} = $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[1]{'contents'}[4]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[1]{'contents'}[4]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[1];
 $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[1]{'contents'}[5]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[1];
 $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[1]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[19];
-$result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[2];
 $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[2]{'args'}[0];
-$result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[2]{'args'}[0];
-$result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[2]{'args'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[2];
-$result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[2]{'extra'}{'command'} = $result_trees{'kbdinputstyle'}{'contents'}[19];
-$result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[2]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[19];
 $result_trees{'kbdinputstyle'}{'contents'}[19]{'extra'}{'end_command'} = $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[2];
-$result_trees{'kbdinputstyle'}{'contents'}[19]{'extra'}{'spaces_after_command'} = $result_trees{'kbdinputstyle'}{'contents'}[19]{'contents'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[19]{'parent'} = $result_trees{'kbdinputstyle'};
 $result_trees{'kbdinputstyle'}{'contents'}[20]{'parent'} = $result_trees{'kbdinputstyle'};
 $result_trees{'kbdinputstyle'}{'contents'}[21]{'contents'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[21];
 $result_trees{'kbdinputstyle'}{'contents'}[21]{'contents'}[1]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[21];
 $result_trees{'kbdinputstyle'}{'contents'}[21]{'parent'} = $result_trees{'kbdinputstyle'};
 $result_trees{'kbdinputstyle'}{'contents'}[22]{'parent'} = $result_trees{'kbdinputstyle'};
-$result_trees{'kbdinputstyle'}{'contents'}[23]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'kbdinputstyle'}{'contents'}[23];
 $result_trees{'kbdinputstyle'}{'contents'}[23]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[23]{'args'}[0];
-$result_trees{'kbdinputstyle'}{'contents'}[23]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[23]{'args'}[0];
-$result_trees{'kbdinputstyle'}{'contents'}[23]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[23]{'args'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[23]{'args'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[23];
-$result_trees{'kbdinputstyle'}{'contents'}[23]{'extra'}{'spaces_after_command'} = $result_trees{'kbdinputstyle'}{'contents'}[23]{'args'}[0]{'contents'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[23]{'parent'} = $result_trees{'kbdinputstyle'};
 $result_trees{'kbdinputstyle'}{'contents'}[24]{'parent'} = $result_trees{'kbdinputstyle'};
 $result_trees{'kbdinputstyle'}{'contents'}[25]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[25]{'contents'}[0]{'args'}[0];
@@ -1522,7 +1468,6 @@ $result_trees{'kbdinputstyle'}{'contents'}[25]{'contents'}[0]{'args'}[0]{'conten
 $result_trees{'kbdinputstyle'}{'contents'}[25]{'contents'}[0]{'args'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[25]{'contents'}[0]{'args'}[0]{'contents'}[1];
 $result_trees{'kbdinputstyle'}{'contents'}[25]{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[25]{'contents'}[0]{'args'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[25]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[25]{'contents'}[0];
-$result_trees{'kbdinputstyle'}{'contents'}[25]{'contents'}[0]{'line_nr'} = $result_trees{'kbdinputstyle'}{'contents'}[25]{'contents'}[0]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'kbdinputstyle'}{'contents'}[25]{'contents'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[25];
 $result_trees{'kbdinputstyle'}{'contents'}[25]{'contents'}[1]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[25];
 $result_trees{'kbdinputstyle'}{'contents'}[25]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[25]{'contents'}[2]{'args'}[0];
@@ -1534,7 +1479,6 @@ $result_trees{'kbdinputstyle'}{'contents'}[25]{'contents'}[4]{'args'}[0]{'conten
 $result_trees{'kbdinputstyle'}{'contents'}[25]{'contents'}[4]{'args'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[25]{'contents'}[4]{'args'}[0]{'contents'}[1];
 $result_trees{'kbdinputstyle'}{'contents'}[25]{'contents'}[4]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[25]{'contents'}[4]{'args'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[25]{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[25]{'contents'}[4];
-$result_trees{'kbdinputstyle'}{'contents'}[25]{'contents'}[4]{'line_nr'} = $result_trees{'kbdinputstyle'}{'contents'}[25]{'contents'}[4]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'kbdinputstyle'}{'contents'}[25]{'contents'}[4]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[25];
 $result_trees{'kbdinputstyle'}{'contents'}[25]{'contents'}[5]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[25];
 $result_trees{'kbdinputstyle'}{'contents'}[25]{'parent'} = $result_trees{'kbdinputstyle'};
@@ -1548,7 +1492,6 @@ $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[1]{'contents'}[0]{'ar
 $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[1];
 $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[1]{'contents'}[0]{'args'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[1]{'contents'}[0];
-$result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[1]{'contents'}[0]{'line_nr'} = $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[1];
 $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[1];
 $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[1]{'contents'}[2]{'args'}[0];
@@ -1561,20 +1504,13 @@ $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[1]{'contents'}[4]{'ar
 $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[1]{'contents'}[4]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[1]{'contents'}[4]{'args'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[1]{'contents'}[4]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[1]{'contents'}[4]{'args'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[1]{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[1]{'contents'}[4];
-$result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[1]{'contents'}[4]{'line_nr'} = $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[1]{'contents'}[4]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[1]{'contents'}[4]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[1];
 $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[1]{'contents'}[5]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[1];
 $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[1]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[28];
-$result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[2];
 $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[2]{'args'}[0];
-$result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[2]{'args'}[0];
-$result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[2]{'args'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[2];
-$result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[2]{'extra'}{'command'} = $result_trees{'kbdinputstyle'}{'contents'}[28];
-$result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[2]{'parent'} = $result_trees{'kbdinputstyle'}{'contents'}[28];
 $result_trees{'kbdinputstyle'}{'contents'}[28]{'extra'}{'end_command'} = $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[2];
-$result_trees{'kbdinputstyle'}{'contents'}[28]{'extra'}{'spaces_after_command'} = $result_trees{'kbdinputstyle'}{'contents'}[28]{'contents'}[0];
 $result_trees{'kbdinputstyle'}{'contents'}[28]{'parent'} = $result_trees{'kbdinputstyle'};
 
 $result_texis{'kbdinputstyle'} = '@macro codekbdmacro
@@ -1678,4 +1614,7 @@ kbd in code in example.
 $result_errors{'kbdinputstyle'} = [];
 
 
+$result_floats{'kbdinputstyle'} = {};
+
+
 1;
