@@ -179,7 +179,11 @@ $result_trees{'setfilename'} = {
         'missing_argument' => 1,
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {},
+      'line_nr' => {
+        'file_name' => '',
+        'line_nr' => 4,
+        'macro' => ''
+      },
       'parent' => {}
     },
     {
@@ -210,7 +214,6 @@ $result_trees{'setfilename'}{'contents'}[3]{'args'}[0]{'contents'}[1]{'args'}[0]
 $result_trees{'setfilename'}{'contents'}[3]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'setfilename'}{'contents'}[3]{'args'}[0];
 $result_trees{'setfilename'}{'contents'}[3]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'setfilename'}{'contents'}[3]{'args'}[0];
 $result_trees{'setfilename'}{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'setfilename'}{'contents'}[3];
-$result_trees{'setfilename'}{'contents'}[3]{'line_nr'} = $result_trees{'setfilename'}{'contents'}[3]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'setfilename'}{'contents'}[3]{'parent'} = $result_trees{'setfilename'};
 $result_trees{'setfilename'}{'contents'}[4]{'parent'} = $result_trees{'setfilename'};
 
@@ -274,6 +277,9 @@ $result_errors{'setfilename'} = [
 ];
 
 
+$result_floats{'setfilename'} = {};
+
+
 
 $result_converted{'plaintext'}->{'setfilename'} = '';
 
