@@ -27,27 +27,17 @@ $result_trees{'sp'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => '1'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'sp',
@@ -55,7 +45,7 @@ $result_trees{'sp'} = {
         'misc_args' => [
           '1'
         ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'line_nr' => {
         'file_name' => '',
@@ -68,27 +58,17 @@ $result_trees{'sp'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => '2'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'sp',
@@ -96,7 +76,7 @@ $result_trees{'sp'} = {
         'misc_args' => [
           '2'
         ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'line_nr' => {
         'file_name' => '',
@@ -119,27 +99,17 @@ $result_trees{'sp'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => '1'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'sp',
@@ -147,7 +117,7 @@ $result_trees{'sp'} = {
         'misc_args' => [
           '1'
         ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'line_nr' => {
         'file_name' => '',
@@ -171,32 +141,22 @@ $result_trees{'sp'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => '2 a number after sp'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'sp',
       'extra' => {
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'line_nr' => {
         'file_name' => '',
@@ -211,37 +171,21 @@ $result_trees{'sp'} = {
 $result_trees{'sp'}{'contents'}[0]{'parent'} = $result_trees{'sp'};
 $result_trees{'sp'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'sp'}{'contents'}[1];
 $result_trees{'sp'}{'contents'}[1]{'parent'} = $result_trees{'sp'};
-$result_trees{'sp'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'sp'}{'contents'}[2];
 $result_trees{'sp'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'sp'}{'contents'}[2]{'args'}[0];
-$result_trees{'sp'}{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'sp'}{'contents'}[2]{'args'}[0];
-$result_trees{'sp'}{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'sp'}{'contents'}[2]{'args'}[0];
 $result_trees{'sp'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'sp'}{'contents'}[2];
-$result_trees{'sp'}{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'sp'}{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'sp'}{'contents'}[2]{'parent'} = $result_trees{'sp'};
-$result_trees{'sp'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'sp'}{'contents'}[3];
 $result_trees{'sp'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'sp'}{'contents'}[3]{'args'}[0];
-$result_trees{'sp'}{'contents'}[3]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'sp'}{'contents'}[3]{'args'}[0];
-$result_trees{'sp'}{'contents'}[3]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'sp'}{'contents'}[3]{'args'}[0];
 $result_trees{'sp'}{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'sp'}{'contents'}[3];
-$result_trees{'sp'}{'contents'}[3]{'extra'}{'spaces_after_command'} = $result_trees{'sp'}{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'sp'}{'contents'}[3]{'parent'} = $result_trees{'sp'};
 $result_trees{'sp'}{'contents'}[4]{'contents'}[0]{'parent'} = $result_trees{'sp'}{'contents'}[4];
 $result_trees{'sp'}{'contents'}[4]{'parent'} = $result_trees{'sp'};
-$result_trees{'sp'}{'contents'}[5]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'sp'}{'contents'}[5];
 $result_trees{'sp'}{'contents'}[5]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'sp'}{'contents'}[5]{'args'}[0];
-$result_trees{'sp'}{'contents'}[5]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'sp'}{'contents'}[5]{'args'}[0];
-$result_trees{'sp'}{'contents'}[5]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'sp'}{'contents'}[5]{'args'}[0];
 $result_trees{'sp'}{'contents'}[5]{'args'}[0]{'parent'} = $result_trees{'sp'}{'contents'}[5];
-$result_trees{'sp'}{'contents'}[5]{'extra'}{'spaces_after_command'} = $result_trees{'sp'}{'contents'}[5]{'args'}[0]{'contents'}[0];
 $result_trees{'sp'}{'contents'}[5]{'parent'} = $result_trees{'sp'};
 $result_trees{'sp'}{'contents'}[6]{'contents'}[0]{'parent'} = $result_trees{'sp'}{'contents'}[6];
 $result_trees{'sp'}{'contents'}[6]{'parent'} = $result_trees{'sp'};
-$result_trees{'sp'}{'contents'}[7]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'sp'}{'contents'}[7];
 $result_trees{'sp'}{'contents'}[7]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'sp'}{'contents'}[7]{'args'}[0];
-$result_trees{'sp'}{'contents'}[7]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'sp'}{'contents'}[7]{'args'}[0];
-$result_trees{'sp'}{'contents'}[7]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'sp'}{'contents'}[7]{'args'}[0];
 $result_trees{'sp'}{'contents'}[7]{'args'}[0]{'parent'} = $result_trees{'sp'}{'contents'}[7];
-$result_trees{'sp'}{'contents'}[7]{'extra'}{'spaces_after_command'} = $result_trees{'sp'}{'contents'}[7]{'args'}[0]{'contents'}[0];
 $result_trees{'sp'}{'contents'}[7]{'parent'} = $result_trees{'sp'};
 
 $result_texis{'sp'} = '
@@ -274,4 +218,7 @@ $result_errors{'sp'} = [
 ];
 
 
+$result_floats{'sp'} = {};
+
+
 1;
