@@ -97,7 +97,9 @@ $result_trees{'split_chapter_index'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -354,7 +356,9 @@ $result_trees{'split_chapter_index'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'first'
           }
         ],
@@ -941,7 +945,9 @@ $result_trees{'split_chapter_index'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'section-1'
           }
         ],
@@ -1228,7 +1234,9 @@ $result_trees{'split_chapter_index'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'subsection-1'
           }
         ],
@@ -1371,7 +1379,7 @@ $result_trees{'split_chapter_index'}{'contents'}[0]{'parent'} = $result_trees{'s
 $result_trees{'split_chapter_index'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_chapter_index'}{'contents'}[1]{'args'}[0];
 $result_trees{'split_chapter_index'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'split_chapter_index'}{'contents'}[1];
 $result_trees{'split_chapter_index'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'split_chapter_index'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'split_chapter_index'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'split_chapter_index'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'split_chapter_index'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'split_chapter_index'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'split_chapter_index'}{'contents'}[1]{'parent'} = $result_trees{'split_chapter_index'};
 $result_trees{'split_chapter_index'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_chapter_index'}{'contents'}[2]{'args'}[0];
 $result_trees{'split_chapter_index'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'split_chapter_index'}{'contents'}[2];
@@ -1409,7 +1417,7 @@ $result_trees{'split_chapter_index'}{'contents'}[2]{'parent'} = $result_trees{'s
 $result_trees{'split_chapter_index'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_chapter_index'}{'contents'}[3]{'args'}[0];
 $result_trees{'split_chapter_index'}{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'split_chapter_index'}{'contents'}[3];
 $result_trees{'split_chapter_index'}{'contents'}[3]{'extra'}{'node_content'}[0] = $result_trees{'split_chapter_index'}{'contents'}[3]{'args'}[0]{'contents'}[0];
-$result_trees{'split_chapter_index'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'split_chapter_index'}{'contents'}[3]{'extra'}{'node_content'};
+$result_trees{'split_chapter_index'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'split_chapter_index'}{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'split_chapter_index'}{'contents'}[3]{'parent'} = $result_trees{'split_chapter_index'};
 $result_trees{'split_chapter_index'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_chapter_index'}{'contents'}[4]{'args'}[0];
 $result_trees{'split_chapter_index'}{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'split_chapter_index'}{'contents'}[4];
@@ -1501,7 +1509,7 @@ $result_trees{'split_chapter_index'}{'contents'}[4]{'parent'} = $result_trees{'s
 $result_trees{'split_chapter_index'}{'contents'}[5]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_chapter_index'}{'contents'}[5]{'args'}[0];
 $result_trees{'split_chapter_index'}{'contents'}[5]{'args'}[0]{'parent'} = $result_trees{'split_chapter_index'}{'contents'}[5];
 $result_trees{'split_chapter_index'}{'contents'}[5]{'extra'}{'node_content'}[0] = $result_trees{'split_chapter_index'}{'contents'}[5]{'args'}[0]{'contents'}[0];
-$result_trees{'split_chapter_index'}{'contents'}[5]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'split_chapter_index'}{'contents'}[5]{'extra'}{'node_content'};
+$result_trees{'split_chapter_index'}{'contents'}[5]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'split_chapter_index'}{'contents'}[5]{'args'}[0]{'contents'}[0];
 $result_trees{'split_chapter_index'}{'contents'}[5]{'parent'} = $result_trees{'split_chapter_index'};
 $result_trees{'split_chapter_index'}{'contents'}[6]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_chapter_index'}{'contents'}[6]{'args'}[0];
 $result_trees{'split_chapter_index'}{'contents'}[6]{'args'}[0]{'parent'} = $result_trees{'split_chapter_index'}{'contents'}[6];
@@ -1544,7 +1552,7 @@ $result_trees{'split_chapter_index'}{'contents'}[6]{'parent'} = $result_trees{'s
 $result_trees{'split_chapter_index'}{'contents'}[7]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_chapter_index'}{'contents'}[7]{'args'}[0];
 $result_trees{'split_chapter_index'}{'contents'}[7]{'args'}[0]{'parent'} = $result_trees{'split_chapter_index'}{'contents'}[7];
 $result_trees{'split_chapter_index'}{'contents'}[7]{'extra'}{'node_content'}[0] = $result_trees{'split_chapter_index'}{'contents'}[7]{'args'}[0]{'contents'}[0];
-$result_trees{'split_chapter_index'}{'contents'}[7]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'split_chapter_index'}{'contents'}[7]{'extra'}{'node_content'};
+$result_trees{'split_chapter_index'}{'contents'}[7]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'split_chapter_index'}{'contents'}[7]{'args'}[0]{'contents'}[0];
 $result_trees{'split_chapter_index'}{'contents'}[7]{'parent'} = $result_trees{'split_chapter_index'};
 $result_trees{'split_chapter_index'}{'contents'}[8]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'split_chapter_index'}{'contents'}[8]{'args'}[0];
 $result_trees{'split_chapter_index'}{'contents'}[8]{'args'}[0]{'parent'} = $result_trees{'split_chapter_index'}{'contents'}[8];
@@ -1904,4 +1912,7 @@ $result_menus{'split_chapter_index'}{'menu_child'}{'menu_up'} = $result_menus{'s
 $result_errors{'split_chapter_index'} = [];
 
 
+$result_floats{'split_chapter_index'} = {};
+
+
 1;
