@@ -97,7 +97,9 @@ $result_trees{'more_sections_than_nodes'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -441,7 +443,9 @@ $result_trees{'more_sections_than_nodes'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'n-c2'
           }
         ],
@@ -593,7 +597,9 @@ $result_trees{'more_sections_than_nodes'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'n-c3'
           },
           {
@@ -842,7 +848,9 @@ $result_trees{'more_sections_than_nodes'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'n-c3-s-2'
           }
         ],
@@ -1096,7 +1104,9 @@ $result_trees{'more_sections_than_nodes'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'n-c3-s1-s2'
           },
           undef,
@@ -1226,7 +1236,7 @@ $result_trees{'more_sections_than_nodes'}{'contents'}[0]{'parent'} = $result_tre
 $result_trees{'more_sections_than_nodes'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[1]{'args'}[0];
 $result_trees{'more_sections_than_nodes'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[1];
 $result_trees{'more_sections_than_nodes'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'more_sections_than_nodes'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'more_sections_than_nodes'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'more_sections_than_nodes'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'more_sections_than_nodes'}{'contents'}[1]{'parent'} = $result_trees{'more_sections_than_nodes'};
 $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'args'}[0];
 $result_trees{'more_sections_than_nodes'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[2];
@@ -1277,7 +1287,7 @@ $result_trees{'more_sections_than_nodes'}{'contents'}[3]{'parent'} = $result_tre
 $result_trees{'more_sections_than_nodes'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[4]{'args'}[0];
 $result_trees{'more_sections_than_nodes'}{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[4];
 $result_trees{'more_sections_than_nodes'}{'contents'}[4]{'extra'}{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[4]{'args'}[0]{'contents'}[0];
-$result_trees{'more_sections_than_nodes'}{'contents'}[4]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'more_sections_than_nodes'}{'contents'}[4]{'extra'}{'node_content'};
+$result_trees{'more_sections_than_nodes'}{'contents'}[4]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[4]{'args'}[0]{'contents'}[0];
 $result_trees{'more_sections_than_nodes'}{'contents'}[4]{'parent'} = $result_trees{'more_sections_than_nodes'};
 $result_trees{'more_sections_than_nodes'}{'contents'}[5]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[5]{'args'}[0];
 $result_trees{'more_sections_than_nodes'}{'contents'}[5]{'args'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[5];
@@ -1296,7 +1306,7 @@ $result_trees{'more_sections_than_nodes'}{'contents'}[7]{'args'}[2]{'parent'} =
 $result_trees{'more_sections_than_nodes'}{'contents'}[7]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[7]{'args'}[3];
 $result_trees{'more_sections_than_nodes'}{'contents'}[7]{'args'}[3]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[7];
 $result_trees{'more_sections_than_nodes'}{'contents'}[7]{'extra'}{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[7]{'args'}[0]{'contents'}[0];
-$result_trees{'more_sections_than_nodes'}{'contents'}[7]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'more_sections_than_nodes'}{'contents'}[7]{'extra'}{'node_content'};
+$result_trees{'more_sections_than_nodes'}{'contents'}[7]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[7]{'args'}[0]{'contents'}[0];
 $result_trees{'more_sections_than_nodes'}{'contents'}[7]{'extra'}{'nodes_manuals'}[1]{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[7]{'args'}[1]{'contents'}[0];
 $result_trees{'more_sections_than_nodes'}{'contents'}[7]{'extra'}{'nodes_manuals'}[2]{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[7]{'args'}[2]{'contents'}[0];
 $result_trees{'more_sections_than_nodes'}{'contents'}[7]{'extra'}{'nodes_manuals'}[3]{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[7]{'args'}[3]{'contents'}[0];
@@ -1330,7 +1340,7 @@ $result_trees{'more_sections_than_nodes'}{'contents'}[9]{'parent'} = $result_tre
 $result_trees{'more_sections_than_nodes'}{'contents'}[10]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[10]{'args'}[0];
 $result_trees{'more_sections_than_nodes'}{'contents'}[10]{'args'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[10];
 $result_trees{'more_sections_than_nodes'}{'contents'}[10]{'extra'}{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[10]{'args'}[0]{'contents'}[0];
-$result_trees{'more_sections_than_nodes'}{'contents'}[10]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'more_sections_than_nodes'}{'contents'}[10]{'extra'}{'node_content'};
+$result_trees{'more_sections_than_nodes'}{'contents'}[10]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[10]{'args'}[0]{'contents'}[0];
 $result_trees{'more_sections_than_nodes'}{'contents'}[10]{'parent'} = $result_trees{'more_sections_than_nodes'};
 $result_trees{'more_sections_than_nodes'}{'contents'}[11]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[11]{'args'}[0];
 $result_trees{'more_sections_than_nodes'}{'contents'}[11]{'args'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[11];
@@ -1360,7 +1370,7 @@ $result_trees{'more_sections_than_nodes'}{'contents'}[16]{'args'}[2]{'parent'} =
 $result_trees{'more_sections_than_nodes'}{'contents'}[16]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[16]{'args'}[3];
 $result_trees{'more_sections_than_nodes'}{'contents'}[16]{'args'}[3]{'parent'} = $result_trees{'more_sections_than_nodes'}{'contents'}[16];
 $result_trees{'more_sections_than_nodes'}{'contents'}[16]{'extra'}{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[16]{'args'}[0]{'contents'}[0];
-$result_trees{'more_sections_than_nodes'}{'contents'}[16]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'more_sections_than_nodes'}{'contents'}[16]{'extra'}{'node_content'};
+$result_trees{'more_sections_than_nodes'}{'contents'}[16]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[16]{'args'}[0]{'contents'}[0];
 $result_trees{'more_sections_than_nodes'}{'contents'}[16]{'extra'}{'nodes_manuals'}[2]{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[16]{'args'}[2]{'contents'}[0];
 $result_trees{'more_sections_than_nodes'}{'contents'}[16]{'extra'}{'nodes_manuals'}[3]{'node_content'}[0] = $result_trees{'more_sections_than_nodes'}{'contents'}[16]{'args'}[3]{'contents'}[0];
 $result_trees{'more_sections_than_nodes'}{'contents'}[16]{'parent'} = $result_trees{'more_sections_than_nodes'};
@@ -1870,4 +1880,7 @@ $result_menus{'more_sections_than_nodes'}{'menu_child'}{'menu_up'} = $result_men
 $result_errors{'more_sections_than_nodes'} = [];
 
 
+$result_floats{'more_sections_than_nodes'} = {};
+
+
 1;
