@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
@@ -17,72 +17,66 @@ $result_trees{'nodes_after_top_before_chapter'} = {
                   'parent' => {},
                   'text' => '\\input texinfo @c -*-texinfo-*-
 ',
-                  'type' => 'text_before_beginning'
+                  'type' => 'preamble_text'
                 },
                 {
                   'parent' => {},
                   'text' => '
 ',
-                  'type' => 'text_before_beginning'
+                  'type' => 'preamble_text'
                 }
               ],
               'parent' => {},
-              'type' => 'preamble_before_beginning'
+              'type' => 'preamble'
             }
           ],
           'parent' => {},
           'type' => 'preamble_before_setfilename'
         },
         {
-          'contents' => [
+          'args' => [
             {
-              'args' => [
+              'contents' => [
                 {
-                  'contents' => [
-                    {
-                      'parent' => {},
-                      'text' => 'nodes_after_top_before_chapter.info'
-                    }
-                  ],
-                  'extra' => {
-                    'spaces_after_argument' => '
-'
-                  },
                   'parent' => {},
-                  'type' => 'line_arg'
+                  'text' => 'nodes_after_top_before_chapter.info'
                 }
               ],
-              'cmdname' => 'setfilename',
               'extra' => {
-                'spaces_before_argument' => ' ',
-                'text_arg' => 'nodes_after_top_before_chapter.info'
+                'spaces_after_argument' => '
+'
               },
               'parent' => {},
-              'source_info' => {
-                'file_name' => 'nodes_after_top_before_chapter.texi',
-                'line_nr' => 3,
-                'macro' => ''
-              }
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'empty_line'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'empty_line'
+              'type' => 'line_arg'
             }
           ],
+          'cmdname' => 'setfilename',
+          'extra' => {
+            'spaces_before_argument' => ' ',
+            'text_arg' => 'nodes_after_top_before_chapter.info'
+          },
+          'line_nr' => {
+            'file_name' => 'nodes_after_top_before_chapter.texi',
+            'line_nr' => 3,
+            'macro' => ''
+          },
+          'parent' => {}
+        },
+        {
           'parent' => {},
-          'type' => 'preamble_before_content'
+          'text' => '
+',
+          'type' => 'empty_line'
+        },
+        {
+          'parent' => {},
+          'text' => '
+',
+          'type' => 'empty_line'
         }
       ],
       'parent' => {},
-      'type' => 'before_node_section'
+      'type' => 'text_root'
     },
     {
       'args' => [
@@ -115,18 +109,17 @@ $result_trees{'nodes_after_top_before_chapter'} = {
           'type' => 'paragraph'
         },
         {
-          'args' => [
-            {
-              'extra' => {
-                'spaces_after_argument' => '
-'
-              },
-              'parent' => {},
-              'type' => 'block_line_arg'
-            }
-          ],
           'cmdname' => 'menu',
           'contents' => [
+            {
+              'extra' => {
+                'command' => {}
+              },
+              'parent' => {},
+              'text' => '
+',
+              'type' => 'empty_line_after_command'
+            },
             {
               'args' => [
                 {
@@ -176,12 +169,12 @@ $result_trees{'nodes_after_top_before_chapter'} = {
                   'normalized' => 'second-node'
                 }
               },
-              'parent' => {},
-              'source_info' => {
+              'line_nr' => {
                 'file_name' => 'nodes_after_top_before_chapter.texi',
                 'line_nr' => 9,
                 'macro' => ''
               },
+              'parent' => {},
               'type' => 'menu_entry'
             },
             {
@@ -233,12 +226,12 @@ $result_trees{'nodes_after_top_before_chapter'} = {
                   'normalized' => 'third-node'
                 }
               },
-              'parent' => {},
-              'source_info' => {
+              'line_nr' => {
                 'file_name' => 'nodes_after_top_before_chapter.texi',
                 'line_nr' => 10,
                 'macro' => ''
               },
+              'parent' => {},
               'type' => 'menu_entry'
             },
             {
@@ -260,23 +253,27 @@ $result_trees{'nodes_after_top_before_chapter'} = {
               ],
               'cmdname' => 'end',
               'extra' => {
+                'command_argument' => 'menu',
                 'spaces_before_argument' => ' ',
                 'text_arg' => 'menu'
               },
-              'parent' => {},
-              'source_info' => {
+              'line_nr' => {
                 'file_name' => 'nodes_after_top_before_chapter.texi',
                 'line_nr' => 11,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             }
           ],
-          'parent' => {},
-          'source_info' => {
+          'extra' => {
+            'end_command' => {}
+          },
+          'line_nr' => {
             'file_name' => 'nodes_after_top_before_chapter.texi',
             'line_nr' => 8,
             'macro' => ''
-          }
+          },
+          'parent' => {}
         },
         {
           'parent' => {},
@@ -300,12 +297,12 @@ $result_trees{'nodes_after_top_before_chapter'} = {
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'line_nr' => {
         'file_name' => 'nodes_after_top_before_chapter.texi',
         'line_nr' => 6,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     },
     {
       'args' => [
@@ -416,12 +413,12 @@ $result_trees{'nodes_after_top_before_chapter'} = {
         'normalized' => 'second-node',
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'line_nr' => {
         'file_name' => 'nodes_after_top_before_chapter.texi',
         'line_nr' => 13,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     },
     {
       'args' => [
@@ -436,6 +433,7 @@ $result_trees{'nodes_after_top_before_chapter'} = {
           'type' => 'line_arg'
         },
         {
+          'contents' => [],
           'parent' => {},
           'type' => 'line_arg'
         },
@@ -465,6 +463,7 @@ $result_trees{'nodes_after_top_before_chapter'} = {
         }
       ],
       'cmdname' => 'node',
+      'contents' => [],
       'extra' => {
         'node_content' => [
           {}
@@ -493,12 +492,12 @@ $result_trees{'nodes_after_top_before_chapter'} = {
         'normalized' => 'third-node',
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'line_nr' => {
         'file_name' => 'nodes_after_top_before_chapter.texi',
         'line_nr' => 17,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     },
     {
       'args' => [
@@ -535,12 +534,14 @@ $result_trees{'nodes_after_top_before_chapter'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 1,
+      'line_nr' => {
         'file_name' => 'nodes_after_top_before_chapter.texi',
         'line_nr' => 18,
         'macro' => ''
-      }
+      },
+      'number' => 1,
+      'parent' => {}
     },
     {
       'args' => [
@@ -561,27 +562,17 @@ $result_trees{'nodes_after_top_before_chapter'}{'contents'}[0]{'contents'}[0]{'c
 $result_trees{'nodes_after_top_before_chapter'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[0]{'contents'}[0]{'contents'}[0];
 $result_trees{'nodes_after_top_before_chapter'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[0]{'contents'}[0];
 $result_trees{'nodes_after_top_before_chapter'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[0];
-$result_trees{'nodes_after_top_before_chapter'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0];
-$result_trees{'nodes_after_top_before_chapter'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[0]{'contents'}[1]{'contents'}[0];
-$result_trees{'nodes_after_top_before_chapter'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[0]{'contents'}[1];
-$result_trees{'nodes_after_top_before_chapter'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[0]{'contents'}[1];
-$result_trees{'nodes_after_top_before_chapter'}{'contents'}[0]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[0]{'contents'}[1];
+$result_trees{'nodes_after_top_before_chapter'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[0]{'contents'}[1]{'args'}[0];
+$result_trees{'nodes_after_top_before_chapter'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[0]{'contents'}[1];
 $result_trees{'nodes_after_top_before_chapter'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[0];
+$result_trees{'nodes_after_top_before_chapter'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[0];
+$result_trees{'nodes_after_top_before_chapter'}{'contents'}[0]{'contents'}[3]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[0];
 $result_trees{'nodes_after_top_before_chapter'}{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_chapter'};
 $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'args'}[0];
 $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1];
 $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[0];
 $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1];
-$result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1];
-$result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[0];
-$result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[1];
-$result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[1]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[0];
-$result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[2]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[0];
-$result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[3]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[3]{'contents'}[0];
-$result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[3];
-$result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[3]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[0];
-$result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'extra'}{'menu_entry_description'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[3];
-$result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[1]{'contents'}[0];
+$result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'extra'}{'command'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1];
 $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1];
 $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
 $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[1];
@@ -593,9 +584,20 @@ $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'c
 $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'extra'}{'menu_entry_description'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[3];
 $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[1]{'contents'}[0];
 $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1];
-$result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0];
 $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[2];
+$result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[1];
+$result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[1]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[2];
+$result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[2]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[2];
+$result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[3]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[3]{'contents'}[0];
+$result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[3];
+$result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[3]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[2];
+$result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'extra'}{'menu_entry_description'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[3];
+$result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[1]{'contents'}[0];
 $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1];
+$result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[3]{'args'}[0];
+$result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[3];
+$result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1];
+$result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'extra'}{'end_command'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'contents'}[3];
 $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1];
 $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1];
 $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'nodes_after_top_before_chapter'}{'contents'}[1]{'args'}[0]{'contents'}[0];
@@ -679,114 +681,116 @@ second node
 ';
 
 $result_sectioning{'nodes_after_top_before_chapter'} = {
-  'structure' => {
-    'section_childs' => [
-      {
-        'cmdname' => 'chapter',
-        'extra' => {
-          'associated_node' => {
-            'cmdname' => 'node',
-            'extra' => {
-              'normalized' => 'third-node'
-            },
-            'structure' => {}
+  'level' => 0,
+  'section_childs' => [
+    {
+      'cmdname' => 'chapter',
+      'extra' => {
+        'associated_node' => {
+          'cmdname' => 'node',
+          'extra' => {
+            'normalized' => 'third-node',
+            'spaces_before_argument' => ' '
           }
         },
-        'structure' => {
-          'section_level' => 1,
-          'section_number' => 1,
-          'section_up' => {}
-        }
-      }
-    ],
-    'section_level' => 0
-  }
+        'spaces_before_argument' => ' '
+      },
+      'level' => 1,
+      'number' => 1,
+      'section_up' => {}
+    }
+  ]
 };
-$result_sectioning{'nodes_after_top_before_chapter'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'nodes_after_top_before_chapter'};
+$result_sectioning{'nodes_after_top_before_chapter'}{'section_childs'}[0]{'section_up'} = $result_sectioning{'nodes_after_top_before_chapter'};
 
 $result_nodes{'nodes_after_top_before_chapter'} = {
   'cmdname' => 'node',
   'extra' => {
-    'menus' => [
-      {
-        'cmdname' => 'menu'
-      }
-    ],
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   },
-  'structure' => {
-    'menu_child' => {
+  'menu_child' => {
+    'cmdname' => 'node',
+    'extra' => {
+      'normalized' => 'second-node',
+      'spaces_before_argument' => ' '
+    },
+    'node_next' => {
       'cmdname' => 'node',
       'extra' => {
-        'normalized' => 'second-node'
-      },
-      'structure' => {
-        'node_next' => {
-          'cmdname' => 'node',
+        'associated_section' => {
+          'cmdname' => 'chapter',
           'extra' => {
-            'associated_section' => {
-              'cmdname' => 'chapter',
-              'extra' => {},
-              'structure' => {
-                'section_number' => 1
-              }
-            },
-            'normalized' => 'third-node'
+            'spaces_before_argument' => ' '
           },
-          'structure' => {
-            'node_prev' => {},
-            'node_up' => {}
-          }
+          'level' => 1,
+          'number' => 1
         },
-        'node_prev' => {},
-        'node_up' => {}
-      }
+        'normalized' => 'third-node',
+        'spaces_before_argument' => ' '
+      },
+      'node_prev' => {},
+      'node_up' => {}
     },
-    'node_next' => {}
-  }
+    'node_prev' => {},
+    'node_up' => {}
+  },
+  'menus' => [
+    {
+      'cmdname' => 'menu',
+      'extra' => {
+        'end_command' => {
+          'cmdname' => 'end',
+          'extra' => {
+            'command_argument' => 'menu',
+            'spaces_before_argument' => ' ',
+            'text_arg' => 'menu'
+          }
+        }
+      }
+    }
+  ],
+  'node_next' => {}
 };
-$result_nodes{'nodes_after_top_before_chapter'}{'structure'}{'menu_child'}{'structure'}{'node_next'}{'structure'}{'node_prev'} = $result_nodes{'nodes_after_top_before_chapter'}{'structure'}{'menu_child'};
-$result_nodes{'nodes_after_top_before_chapter'}{'structure'}{'menu_child'}{'structure'}{'node_next'}{'structure'}{'node_up'} = $result_nodes{'nodes_after_top_before_chapter'};
-$result_nodes{'nodes_after_top_before_chapter'}{'structure'}{'menu_child'}{'structure'}{'node_prev'} = $result_nodes{'nodes_after_top_before_chapter'};
-$result_nodes{'nodes_after_top_before_chapter'}{'structure'}{'menu_child'}{'structure'}{'node_up'} = $result_nodes{'nodes_after_top_before_chapter'};
-$result_nodes{'nodes_after_top_before_chapter'}{'structure'}{'node_next'} = $result_nodes{'nodes_after_top_before_chapter'}{'structure'}{'menu_child'};
+$result_nodes{'nodes_after_top_before_chapter'}{'menu_child'}{'node_next'}{'node_prev'} = $result_nodes{'nodes_after_top_before_chapter'}{'menu_child'};
+$result_nodes{'nodes_after_top_before_chapter'}{'menu_child'}{'node_next'}{'node_up'} = $result_nodes{'nodes_after_top_before_chapter'};
+$result_nodes{'nodes_after_top_before_chapter'}{'menu_child'}{'node_prev'} = $result_nodes{'nodes_after_top_before_chapter'};
+$result_nodes{'nodes_after_top_before_chapter'}{'menu_child'}{'node_up'} = $result_nodes{'nodes_after_top_before_chapter'};
+$result_nodes{'nodes_after_top_before_chapter'}{'node_next'} = $result_nodes{'nodes_after_top_before_chapter'}{'menu_child'};
 
 $result_menus{'nodes_after_top_before_chapter'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   },
-  'structure' => {
-    'menu_child' => {
+  'menu_child' => {
+    'cmdname' => 'node',
+    'extra' => {
+      'normalized' => 'second-node',
+      'spaces_before_argument' => ' '
+    },
+    'menu_next' => {
       'cmdname' => 'node',
       'extra' => {
-        'normalized' => 'second-node'
+        'normalized' => 'third-node',
+        'spaces_before_argument' => ' '
       },
-      'structure' => {
-        'menu_next' => {
-          'cmdname' => 'node',
-          'extra' => {
-            'normalized' => 'third-node'
-          },
-          'structure' => {
-            'menu_prev' => {},
-            'menu_up' => {},
-            'menu_up_hash' => {
-              'Top' => 1
-            }
-          }
-        },
-        'menu_up' => {},
-        'menu_up_hash' => {
-          'Top' => 1
-        }
+      'menu_prev' => {},
+      'menu_up' => {},
+      'menu_up_hash' => {
+        'Top' => 1
       }
+    },
+    'menu_up' => {},
+    'menu_up_hash' => {
+      'Top' => 1
     }
   }
 };
-$result_menus{'nodes_after_top_before_chapter'}{'structure'}{'menu_child'}{'structure'}{'menu_next'}{'structure'}{'menu_prev'} = $result_menus{'nodes_after_top_before_chapter'}{'structure'}{'menu_child'};
-$result_menus{'nodes_after_top_before_chapter'}{'structure'}{'menu_child'}{'structure'}{'menu_next'}{'structure'}{'menu_up'} = $result_menus{'nodes_after_top_before_chapter'};
-$result_menus{'nodes_after_top_before_chapter'}{'structure'}{'menu_child'}{'structure'}{'menu_up'} = $result_menus{'nodes_after_top_before_chapter'};
+$result_menus{'nodes_after_top_before_chapter'}{'menu_child'}{'menu_next'}{'menu_prev'} = $result_menus{'nodes_after_top_before_chapter'}{'menu_child'};
+$result_menus{'nodes_after_top_before_chapter'}{'menu_child'}{'menu_next'}{'menu_up'} = $result_menus{'nodes_after_top_before_chapter'};
+$result_menus{'nodes_after_top_before_chapter'}{'menu_child'}{'menu_up'} = $result_menus{'nodes_after_top_before_chapter'};
 
 $result_errors{'nodes_after_top_before_chapter'} = [];
 
@@ -796,9 +800,8 @@ $result_floats{'nodes_after_top_before_chapter'} = {};
 
 $result_converted_errors{'file_html'}->{'nodes_after_top_before_chapter'} = [
   {
-    'error_line' => 'warning: must specify a title with a title command or @top
+    'error_line' => 'nodes_after_top_before_chapter.texi: warning: must specify a title with a title command or @top
 ',
-    'file_name' => 'nodes_after_top_before_chapter.texi',
     'text' => 'must specify a title with a title command or @top',
     'type' => 'warning'
   }
