@@ -288,7 +288,9 @@ $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -384,7 +386,9 @@ $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'second-node'
           },
           {
@@ -466,7 +470,9 @@ $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'third-node'
           },
           undef,
@@ -595,7 +601,7 @@ $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[1]
 $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[1];
 $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[1];
 $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[1]{'parent'} = $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'};
 $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[2]{'args'}[0];
 $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[2];
@@ -610,7 +616,7 @@ $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[2]
 $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[2]{'contents'}[1]{'parent'} = $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[2];
 $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[2]{'contents'}[2]{'parent'} = $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[2];
 $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[2]{'extra'}{'node_content'}[0] = $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[2]{'args'}[0]{'contents'}[0];
-$result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[2]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[2]{'extra'}{'node_content'};
+$result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[2]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[2]{'extra'}{'nodes_manuals'}[1]{'node_content'}[0] = $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[2]{'args'}[1]{'contents'}[0];
 $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[2]{'extra'}{'nodes_manuals'}[2]{'node_content'}[0] = $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[2]{'args'}[2]{'contents'}[0];
 $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[2]{'extra'}{'nodes_manuals'}[3]{'node_content'}[0] = $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[2]{'args'}[3]{'contents'}[0];
@@ -623,7 +629,7 @@ $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[3]
 $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[3]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[3]{'args'}[3];
 $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[3]{'args'}[3]{'parent'} = $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[3];
 $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[3]{'extra'}{'node_content'}[0] = $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[3]{'args'}[0]{'contents'}[0];
-$result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[3]{'extra'}{'node_content'};
+$result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[3]{'extra'}{'nodes_manuals'}[2]{'node_content'}[0] = $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[3]{'args'}[2]{'contents'}[0];
 $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[3]{'extra'}{'nodes_manuals'}[3]{'node_content'}[0] = $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[3]{'args'}[3]{'contents'}[0];
 $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'}{'contents'}[3]{'parent'} = $result_trees{'nodes_after_top_before_chapter_use_nodes_chapter'};
@@ -744,25 +750,13 @@ $result_nodes{'nodes_after_top_before_chapter_use_nodes_chapter'} = {
       }
     }
   ],
-  'node_next' => {},
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
-  }
+  'node_next' => {}
 };
 $result_nodes{'nodes_after_top_before_chapter_use_nodes_chapter'}{'menu_child'}{'node_next'}{'node_prev'} = $result_nodes{'nodes_after_top_before_chapter_use_nodes_chapter'}{'menu_child'};
 $result_nodes{'nodes_after_top_before_chapter_use_nodes_chapter'}{'menu_child'}{'node_next'}{'node_up'} = $result_nodes{'nodes_after_top_before_chapter_use_nodes_chapter'};
 $result_nodes{'nodes_after_top_before_chapter_use_nodes_chapter'}{'menu_child'}{'node_prev'} = $result_nodes{'nodes_after_top_before_chapter_use_nodes_chapter'};
 $result_nodes{'nodes_after_top_before_chapter_use_nodes_chapter'}{'menu_child'}{'node_up'} = $result_nodes{'nodes_after_top_before_chapter_use_nodes_chapter'};
 $result_nodes{'nodes_after_top_before_chapter_use_nodes_chapter'}{'node_next'} = $result_nodes{'nodes_after_top_before_chapter_use_nodes_chapter'}{'menu_child'};
-$result_nodes{'nodes_after_top_before_chapter_use_nodes_chapter'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'nodes_after_top_before_chapter_use_nodes_chapter'};
 
 $result_menus{'nodes_after_top_before_chapter_use_nodes_chapter'} = {
   'cmdname' => 'node',
@@ -801,6 +795,9 @@ $result_menus{'nodes_after_top_before_chapter_use_nodes_chapter'}{'menu_child'}{
 $result_errors{'nodes_after_top_before_chapter_use_nodes_chapter'} = [];
 
 
+$result_floats{'nodes_after_top_before_chapter_use_nodes_chapter'} = {};
+
+
 $result_converted_errors{'file_html'}->{'nodes_after_top_before_chapter_use_nodes_chapter'} = [
   {
     'error_line' => 'nodes_after_top_before_chapter.texi: warning: must specify a title with a title command or @top
