@@ -288,7 +288,9 @@ $result_trees{'nodes_after_top_before_section'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -384,7 +386,9 @@ $result_trees{'nodes_after_top_before_section'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'second-node'
           },
           {
@@ -466,7 +470,9 @@ $result_trees{'nodes_after_top_before_section'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'third-node'
           },
           undef,
@@ -595,7 +601,7 @@ $result_trees{'nodes_after_top_before_section'}{'contents'}[1]{'contents'}[1]{'e
 $result_trees{'nodes_after_top_before_section'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'nodes_after_top_before_section'}{'contents'}[1];
 $result_trees{'nodes_after_top_before_section'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'nodes_after_top_before_section'}{'contents'}[1];
 $result_trees{'nodes_after_top_before_section'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'nodes_after_top_before_section'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'nodes_after_top_before_section'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'nodes_after_top_before_section'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'nodes_after_top_before_section'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'nodes_after_top_before_section'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section'}{'contents'}[1]{'parent'} = $result_trees{'nodes_after_top_before_section'};
 $result_trees{'nodes_after_top_before_section'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section'}{'contents'}[2]{'args'}[0];
 $result_trees{'nodes_after_top_before_section'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section'}{'contents'}[2];
@@ -610,7 +616,7 @@ $result_trees{'nodes_after_top_before_section'}{'contents'}[2]{'contents'}[1]{'c
 $result_trees{'nodes_after_top_before_section'}{'contents'}[2]{'contents'}[1]{'parent'} = $result_trees{'nodes_after_top_before_section'}{'contents'}[2];
 $result_trees{'nodes_after_top_before_section'}{'contents'}[2]{'contents'}[2]{'parent'} = $result_trees{'nodes_after_top_before_section'}{'contents'}[2];
 $result_trees{'nodes_after_top_before_section'}{'contents'}[2]{'extra'}{'node_content'}[0] = $result_trees{'nodes_after_top_before_section'}{'contents'}[2]{'args'}[0]{'contents'}[0];
-$result_trees{'nodes_after_top_before_section'}{'contents'}[2]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'nodes_after_top_before_section'}{'contents'}[2]{'extra'}{'node_content'};
+$result_trees{'nodes_after_top_before_section'}{'contents'}[2]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'nodes_after_top_before_section'}{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section'}{'contents'}[2]{'extra'}{'nodes_manuals'}[1]{'node_content'}[0] = $result_trees{'nodes_after_top_before_section'}{'contents'}[2]{'args'}[1]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section'}{'contents'}[2]{'extra'}{'nodes_manuals'}[2]{'node_content'}[0] = $result_trees{'nodes_after_top_before_section'}{'contents'}[2]{'args'}[2]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section'}{'contents'}[2]{'extra'}{'nodes_manuals'}[3]{'node_content'}[0] = $result_trees{'nodes_after_top_before_section'}{'contents'}[2]{'args'}[3]{'contents'}[0];
@@ -623,7 +629,7 @@ $result_trees{'nodes_after_top_before_section'}{'contents'}[3]{'args'}[2]{'paren
 $result_trees{'nodes_after_top_before_section'}{'contents'}[3]{'args'}[3]{'contents'}[0]{'parent'} = $result_trees{'nodes_after_top_before_section'}{'contents'}[3]{'args'}[3];
 $result_trees{'nodes_after_top_before_section'}{'contents'}[3]{'args'}[3]{'parent'} = $result_trees{'nodes_after_top_before_section'}{'contents'}[3];
 $result_trees{'nodes_after_top_before_section'}{'contents'}[3]{'extra'}{'node_content'}[0] = $result_trees{'nodes_after_top_before_section'}{'contents'}[3]{'args'}[0]{'contents'}[0];
-$result_trees{'nodes_after_top_before_section'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'nodes_after_top_before_section'}{'contents'}[3]{'extra'}{'node_content'};
+$result_trees{'nodes_after_top_before_section'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'nodes_after_top_before_section'}{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section'}{'contents'}[3]{'extra'}{'nodes_manuals'}[2]{'node_content'}[0] = $result_trees{'nodes_after_top_before_section'}{'contents'}[3]{'args'}[2]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section'}{'contents'}[3]{'extra'}{'nodes_manuals'}[3]{'node_content'}[0] = $result_trees{'nodes_after_top_before_section'}{'contents'}[3]{'args'}[3]{'contents'}[0];
 $result_trees{'nodes_after_top_before_section'}{'contents'}[3]{'parent'} = $result_trees{'nodes_after_top_before_section'};
@@ -789,6 +795,9 @@ $result_menus{'nodes_after_top_before_section'}{'menu_child'}{'menu_up'} = $resu
 $result_errors{'nodes_after_top_before_section'} = [];
 
 
+$result_floats{'nodes_after_top_before_section'} = {};
+
+
 $result_converted_errors{'file_html'}->{'nodes_after_top_before_section'} = [
   {
     'error_line' => 'nodes_after_top_before_section.texi: warning: must specify a title with a title command or @top
