@@ -194,7 +194,9 @@ $result_trees{'top_node_up_explicit'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           },
           {
@@ -418,7 +420,9 @@ $result_trees{'top_node_up_explicit'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Chap'
           }
         ],
@@ -530,7 +534,7 @@ $result_trees{'top_node_up_explicit'}{'contents'}[1]{'args'}[3]{'contents'}[1]{'
 $result_trees{'top_node_up_explicit'}{'contents'}[1]{'args'}[3]{'contents'}[2]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[1]{'args'}[3];
 $result_trees{'top_node_up_explicit'}{'contents'}[1]{'args'}[3]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[1];
 $result_trees{'top_node_up_explicit'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'top_node_up_explicit'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'top_node_up_explicit'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'top_node_up_explicit'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'top_node_up_explicit'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'top_node_up_explicit'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'top_node_up_explicit'}{'contents'}[1]{'extra'}{'nodes_manuals'}[1]{'manual_content'}[0] = $result_trees{'top_node_up_explicit'}{'contents'}[1]{'args'}[1]{'contents'}[1];
 $result_trees{'top_node_up_explicit'}{'contents'}[1]{'extra'}{'nodes_manuals'}[2]{'manual_content'}[0] = $result_trees{'top_node_up_explicit'}{'contents'}[1]{'args'}[2]{'contents'}[1];
 $result_trees{'top_node_up_explicit'}{'contents'}[1]{'extra'}{'nodes_manuals'}[3]{'manual_content'}[0] = $result_trees{'top_node_up_explicit'}{'contents'}[1]{'args'}[3]{'contents'}[1];
@@ -563,7 +567,7 @@ $result_trees{'top_node_up_explicit'}{'contents'}[2]{'parent'} = $result_trees{'
 $result_trees{'top_node_up_explicit'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[3]{'args'}[0];
 $result_trees{'top_node_up_explicit'}{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[3];
 $result_trees{'top_node_up_explicit'}{'contents'}[3]{'extra'}{'node_content'}[0] = $result_trees{'top_node_up_explicit'}{'contents'}[3]{'args'}[0]{'contents'}[0];
-$result_trees{'top_node_up_explicit'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'top_node_up_explicit'}{'contents'}[3]{'extra'}{'node_content'};
+$result_trees{'top_node_up_explicit'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'top_node_up_explicit'}{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'top_node_up_explicit'}{'contents'}[3]{'parent'} = $result_trees{'top_node_up_explicit'};
 $result_trees{'top_node_up_explicit'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[4]{'args'}[0];
 $result_trees{'top_node_up_explicit'}{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'top_node_up_explicit'}{'contents'}[4];
@@ -757,4 +761,7 @@ $result_menus{'top_node_up_explicit'}{'menu_child'}{'menu_up'} = $result_menus{'
 $result_errors{'top_node_up_explicit'} = [];
 
 
+$result_floats{'top_node_up_explicit'} = {};
+
+
 1;
