@@ -11,14 +11,6 @@ $result_trees{'prototype_brace_no_brace_comment'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'contents' => [
                 {
@@ -32,8 +24,10 @@ $result_trees{'prototype_brace_no_brace_comment'} = {
             {
               'parent' => {},
               'text' => ' bb'
-            },
-            {
+            }
+          ],
+          'extra' => {
+            'comment_at_end' => {
               'args' => [
                 {
                   'parent' => {},
@@ -51,7 +45,7 @@ $result_trees{'prototype_brace_no_brace_comment'} = {
               },
               'parent' => {}
             }
-          ],
+          },
           'parent' => {},
           'type' => 'block_line_arg'
         }
@@ -62,34 +56,23 @@ $result_trees{'prototype_brace_no_brace_comment'} = {
           'args' => [
             {
               'contents' => [
-                {
-                  'extra' => {
-                    'command' => {}
-                  },
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_after_command'
-                },
                 {
                   'parent' => {},
                   'text' => 'multitable'
-                },
-                {
-                  'parent' => {},
-                  'text' => '
-',
-                  'type' => 'spaces_at_end'
                 }
               ],
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
               'parent' => {},
-              'type' => 'misc_line_arg'
+              'type' => 'line_arg'
             }
           ],
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
             'command_argument' => 'multitable',
-            'spaces_after_command' => {},
+            'spaces_before_argument' => ' ',
             'text_arg' => 'multitable'
           },
           'line_nr' => {
@@ -105,7 +88,9 @@ $result_trees{'prototype_brace_no_brace_comment'} = {
         'max_columns' => 2,
         'prototypes' => [
           {
-            'contents' => [],
+            'contents' => [
+              {}
+            ],
             'type' => 'bracketed_multitable_prototype'
           },
           {
@@ -114,10 +99,6 @@ $result_trees{'prototype_brace_no_brace_comment'} = {
           }
         ],
         'prototypes_line' => [
-          {
-            'text' => ' ',
-            'type' => 'prototype_space'
-          },
           {},
           {
             'text' => ' ',
@@ -128,7 +109,7 @@ $result_trees{'prototype_brace_no_brace_comment'} = {
             'type' => 'row_prototype'
           }
         ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'line_nr' => {
         'file_name' => '',
@@ -140,26 +121,18 @@ $result_trees{'prototype_brace_no_brace_comment'} = {
   ],
   'type' => 'text_root'
 };
-$result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0];
+$result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'args'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'args'}[0];
-$result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'args'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'args'}[0]{'contents'}[1];
 $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'args'}[0];
-$result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'args'}[0];
-$result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'args'}[0]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'args'}[0]{'contents'}[3];
-$result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'args'}[0]{'contents'}[3]{'parent'} = $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'args'}[0];
+$result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'args'}[0]{'extra'}{'comment_at_end'}{'args'}[0]{'parent'} = $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'args'}[0]{'extra'}{'comment_at_end'};
+$result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'args'}[0]{'extra'}{'comment_at_end'}{'parent'} = $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'args'}[0];
 $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0];
-$result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'contents'}[0];
 $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'contents'}[0]{'args'}[0];
-$result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'contents'}[0]{'args'}[0];
-$result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'contents'}[0]{'args'}[0];
 $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'contents'}[0];
-$result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0];
-$result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0];
 $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'extra'}{'end_command'} = $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'contents'}[0];
-$result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'extra'}{'prototypes'}[0]{'contents'} = $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'args'}[0]{'contents'}[1]{'contents'};
-$result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'extra'}{'prototypes_line'}[1] = $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'args'}[0]{'contents'}[1];
-$result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'args'}[0]{'contents'}[0];
+$result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'extra'}{'prototypes'}[0]{'contents'}[0] = $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'args'}[0]{'contents'}[0]{'contents'}[0];
+$result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'extra'}{'prototypes_line'}[0] = $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'prototype_brace_no_brace_comment'}{'contents'}[0]{'parent'} = $result_trees{'prototype_brace_no_brace_comment'};
 
 $result_texis{'prototype_brace_no_brace_comment'} = '@multitable {aa} bb@comment cc
@@ -172,6 +145,9 @@ $result_texts{'prototype_brace_no_brace_comment'} = '';
 $result_errors{'prototype_brace_no_brace_comment'} = [];
 
 
+$result_floats{'prototype_brace_no_brace_comment'} = {};
+
+
 
 $result_converted{'plaintext'}->{'prototype_brace_no_brace_comment'} = '';
 
