@@ -59,7 +59,7 @@ $result_trees{'image_in_paragraph'} = {
               'contents' => [
                 {
                   'parent' => {},
-                  'text' => 'ee'
+                  'text' => '.ee'
                 }
               ],
               'parent' => {},
@@ -68,7 +68,9 @@ $result_trees{'image_in_paragraph'} = {
           ],
           'cmdname' => 'image',
           'contents' => [],
-          'extra' => {},
+          'extra' => {
+            'input_perl_encoding' => 'utf-8'
+          },
           'line_nr' => {
             'file_name' => '',
             'line_nr' => 1,
@@ -103,7 +105,7 @@ $result_trees{'image_in_paragraph'}{'contents'}[0]{'contents'}[1]{'parent'} = $r
 $result_trees{'image_in_paragraph'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'image_in_paragraph'}{'contents'}[0];
 $result_trees{'image_in_paragraph'}{'contents'}[0]{'parent'} = $result_trees{'image_in_paragraph'};
 
-$result_texis{'image_in_paragraph'} = 'Para. @image{aa,bb,cc,dd,ee}. After image.
+$result_texis{'image_in_paragraph'} = 'Para. @image{aa,bb,cc,dd,.ee}. After image.
 ';
 
 
@@ -113,8 +115,11 @@ $result_texts{'image_in_paragraph'} = 'Para. aa. After image.
 $result_errors{'image_in_paragraph'} = [];
 
 
+$result_floats{'image_in_paragraph'} = {};
 
-$result_converted{'plaintext'}->{'image_in_paragraph'} = 'Para. Text for image out of paragraph..  After image.
+
+
+$result_converted{'plaintext'}->{'image_in_paragraph'} = 'Para.  Text for image out of paragraph..  After image.
 ';
 
 
