@@ -31,17 +31,6 @@ $result_trees{'no_paragraph_commands'} = {
       ],
       'cmdname' => 'titlefont',
       'contents' => [],
-      'extra' => {
-        'brace_command_contents' => [
-          [
-            {}
-          ]
-        ],
-        'spaces_before_argument' => {
-          'text' => '',
-          'type' => 'empty_spaces_before_argument'
-        }
-      },
       'line_nr' => {
         'file_name' => '',
         'line_nr' => 2,
@@ -100,7 +89,7 @@ $result_trees{'no_paragraph_commands'} = {
           'contents' => [
             {
               'parent' => {},
-              'text' => 'ee'
+              'text' => '.ee'
             }
           ],
           'parent' => {},
@@ -110,27 +99,7 @@ $result_trees{'no_paragraph_commands'} = {
       'cmdname' => 'image',
       'contents' => [],
       'extra' => {
-        'brace_command_contents' => [
-          [
-            {}
-          ],
-          [
-            {}
-          ],
-          [
-            {}
-          ],
-          [
-            {}
-          ],
-          [
-            {}
-          ]
-        ],
-        'spaces_before_argument' => {
-          'text' => '',
-          'type' => 'empty_spaces_before_argument'
-        }
+        'input_perl_encoding' => 'utf-8'
       },
       'line_nr' => {
         'file_name' => '',
@@ -151,7 +120,6 @@ $result_trees{'no_paragraph_commands'}{'contents'}[0]{'parent'} = $result_trees{
 $result_trees{'no_paragraph_commands'}{'contents'}[1]{'parent'} = $result_trees{'no_paragraph_commands'};
 $result_trees{'no_paragraph_commands'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'no_paragraph_commands'}{'contents'}[2]{'args'}[0];
 $result_trees{'no_paragraph_commands'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'no_paragraph_commands'}{'contents'}[2];
-$result_trees{'no_paragraph_commands'}{'contents'}[2]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'no_paragraph_commands'}{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'no_paragraph_commands'}{'contents'}[2]{'parent'} = $result_trees{'no_paragraph_commands'};
 $result_trees{'no_paragraph_commands'}{'contents'}[3]{'parent'} = $result_trees{'no_paragraph_commands'};
 $result_trees{'no_paragraph_commands'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'no_paragraph_commands'}{'contents'}[4]{'args'}[0];
@@ -164,17 +132,12 @@ $result_trees{'no_paragraph_commands'}{'contents'}[4]{'args'}[3]{'contents'}[0]{
 $result_trees{'no_paragraph_commands'}{'contents'}[4]{'args'}[3]{'parent'} = $result_trees{'no_paragraph_commands'}{'contents'}[4];
 $result_trees{'no_paragraph_commands'}{'contents'}[4]{'args'}[4]{'contents'}[0]{'parent'} = $result_trees{'no_paragraph_commands'}{'contents'}[4]{'args'}[4];
 $result_trees{'no_paragraph_commands'}{'contents'}[4]{'args'}[4]{'parent'} = $result_trees{'no_paragraph_commands'}{'contents'}[4];
-$result_trees{'no_paragraph_commands'}{'contents'}[4]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'no_paragraph_commands'}{'contents'}[4]{'args'}[0]{'contents'}[0];
-$result_trees{'no_paragraph_commands'}{'contents'}[4]{'extra'}{'brace_command_contents'}[1][0] = $result_trees{'no_paragraph_commands'}{'contents'}[4]{'args'}[1]{'contents'}[0];
-$result_trees{'no_paragraph_commands'}{'contents'}[4]{'extra'}{'brace_command_contents'}[2][0] = $result_trees{'no_paragraph_commands'}{'contents'}[4]{'args'}[2]{'contents'}[0];
-$result_trees{'no_paragraph_commands'}{'contents'}[4]{'extra'}{'brace_command_contents'}[3][0] = $result_trees{'no_paragraph_commands'}{'contents'}[4]{'args'}[3]{'contents'}[0];
-$result_trees{'no_paragraph_commands'}{'contents'}[4]{'extra'}{'brace_command_contents'}[4][0] = $result_trees{'no_paragraph_commands'}{'contents'}[4]{'args'}[4]{'contents'}[0];
 $result_trees{'no_paragraph_commands'}{'contents'}[4]{'parent'} = $result_trees{'no_paragraph_commands'};
 $result_trees{'no_paragraph_commands'}{'contents'}[5]{'parent'} = $result_trees{'no_paragraph_commands'};
 
 $result_texis{'no_paragraph_commands'} = '@*
 @titlefont{title font}
-@image{aa,bb,cc,dd,ee}
+@image{aa,bb,cc,dd,.ee}
 ';
 
 
@@ -187,11 +150,16 @@ aa
 $result_errors{'no_paragraph_commands'} = [];
 
 
+$result_floats{'no_paragraph_commands'} = {};
+
+
 
 $result_converted{'plaintext'}->{'no_paragraph_commands'} = '
+
 title font
 **********
-Text for image out of paragraph.';
+Text for image out of paragraph.
+';
 
 
 $result_converted{'html_text'}->{'no_paragraph_commands'} = '<br>
