@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
@@ -10,31 +10,24 @@ $result_trees{'two_lines'} = {
     {
       'contents' => [
         {
-          'contents' => [
-            {
-              'parent' => {},
-              'text' => 'text l 1
-'
-            },
-            {
-              'parent' => {},
-              'text' => 'text l 2
-'
-            }
-          ],
           'parent' => {},
-          'type' => 'paragraph'
+          'text' => 'text l 1
+'
+        },
+        {
+          'parent' => {},
+          'text' => 'text l 2
+'
         }
       ],
       'parent' => {},
-      'type' => 'before_node_section'
+      'type' => 'paragraph'
     }
   ],
-  'type' => 'document_root'
+  'type' => 'text_root'
 };
-$result_trees{'two_lines'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'two_lines'}{'contents'}[0]{'contents'}[0];
-$result_trees{'two_lines'}{'contents'}[0]{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'two_lines'}{'contents'}[0]{'contents'}[0];
 $result_trees{'two_lines'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'two_lines'}{'contents'}[0];
+$result_trees{'two_lines'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'two_lines'}{'contents'}[0];
 $result_trees{'two_lines'}{'contents'}[0]{'parent'} = $result_trees{'two_lines'};
 
 $result_texis{'two_lines'} = 'text l 1
