@@ -40,19 +40,10 @@ $result_trees{'anchor_and_empty_lines'} = {
       'cmdname' => 'anchor',
       'contents' => [],
       'extra' => {
-        'brace_command_contents' => [
-          [
-            {}
-          ]
-        ],
         'node_content' => [
           {}
         ],
-        'normalized' => 'in-anchor',
-        'spaces_before_argument' => {
-          'text' => '',
-          'type' => 'empty_spaces_before_argument'
-        }
+        'normalized' => 'in-anchor'
       },
       'line_nr' => {
         'file_name' => '',
@@ -62,6 +53,7 @@ $result_trees{'anchor_and_empty_lines'} = {
       'parent' => {}
     },
     {
+      'parent' => {},
       'text' => '
 ',
       'type' => 'empty_spaces_after_close_brace'
@@ -91,9 +83,9 @@ $result_trees{'anchor_and_empty_lines'}{'contents'}[0]{'parent'} = $result_trees
 $result_trees{'anchor_and_empty_lines'}{'contents'}[1]{'parent'} = $result_trees{'anchor_and_empty_lines'};
 $result_trees{'anchor_and_empty_lines'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'anchor_and_empty_lines'}{'contents'}[2]{'args'}[0];
 $result_trees{'anchor_and_empty_lines'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'anchor_and_empty_lines'}{'contents'}[2];
-$result_trees{'anchor_and_empty_lines'}{'contents'}[2]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'anchor_and_empty_lines'}{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'anchor_and_empty_lines'}{'contents'}[2]{'extra'}{'node_content'}[0] = $result_trees{'anchor_and_empty_lines'}{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'anchor_and_empty_lines'}{'contents'}[2]{'parent'} = $result_trees{'anchor_and_empty_lines'};
+$result_trees{'anchor_and_empty_lines'}{'contents'}[3]{'parent'} = $result_trees{'anchor_and_empty_lines'};
 $result_trees{'anchor_and_empty_lines'}{'contents'}[4]{'parent'} = $result_trees{'anchor_and_empty_lines'};
 $result_trees{'anchor_and_empty_lines'}{'contents'}[5]{'contents'}[0]{'parent'} = $result_trees{'anchor_and_empty_lines'}{'contents'}[5];
 $result_trees{'anchor_and_empty_lines'}{'contents'}[5]{'parent'} = $result_trees{'anchor_and_empty_lines'};
@@ -115,6 +107,9 @@ text 2.
 $result_errors{'anchor_and_empty_lines'} = [];
 
 
+$result_floats{'anchor_and_empty_lines'} = {};
+
+
 
 $result_converted{'plaintext'}->{'anchor_and_empty_lines'} = 'text 1.
 
