@@ -8,6 +8,14 @@ use utf8;
 $result_trees{'long_uref_after_item'} = {
   'contents' => [
     {
+      'args' => [
+        {
+          'cmdname' => 'bullet',
+          'contents' => [],
+          'parent' => {},
+          'type' => 'command_as_argument_inserted'
+        }
+      ],
       'cmdname' => 'itemize',
       'contents' => [
         {
@@ -48,13 +56,6 @@ $result_trees{'long_uref_after_item'} = {
                   ],
                   'cmdname' => 'uref',
                   'contents' => [],
-                  'extra' => {
-                    'brace_command_contents' => [
-                      [
-                        {}
-                      ]
-                    ]
-                  },
                   'line_nr' => {
                     'file_name' => '',
                     'line_nr' => 3,
@@ -73,8 +74,7 @@ $result_trees{'long_uref_after_item'} = {
             }
           ],
           'extra' => {
-            'item_number' => 1,
-            'spaces_after_command' => {}
+            'item_number' => 1
           },
           'line_nr' => {
             'file_name' => '',
@@ -87,34 +87,23 @@ $result_trees{'long_uref_after_item'} = {
           'args' => [
             {
               'contents' => [
-                {
-                  'extra' => {
-                    'command' => {}
-                  },
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_after_command'
-                },
                 {
                   'parent' => {},
                   'text' => 'itemize'
-                },
-                {
-                  'parent' => {},
-                  'text' => '
-',
-                  'type' => 'spaces_at_end'
                 }
               ],
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
               'parent' => {},
-              'type' => 'misc_line_arg'
+              'type' => 'line_arg'
             }
           ],
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
             'command_argument' => 'itemize',
-            'spaces_after_command' => {},
+            'spaces_before_argument' => ' ',
             'text_arg' => 'itemize'
           },
           'line_nr' => {
@@ -126,19 +115,8 @@ $result_trees{'long_uref_after_item'} = {
         }
       ],
       'extra' => {
-        'block_command_line_contents' => [
-          [
-            {
-              'cmdname' => 'bullet',
-              'contents' => [],
-              'parent' => {},
-              'type' => 'command_as_argument'
-            }
-          ]
-        ],
         'command_as_argument' => {},
-        'end_command' => {},
-        'spaces_after_command' => {}
+        'end_command' => {}
       },
       'line_nr' => {
         'file_name' => '',
@@ -150,30 +128,22 @@ $result_trees{'long_uref_after_item'} = {
   ],
   'type' => 'text_root'
 };
+$result_trees{'long_uref_after_item'}{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'long_uref_after_item'}{'contents'}[0];
 $result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'long_uref_after_item'}{'contents'}[0];
 $result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'long_uref_after_item'}{'contents'}[0];
 $result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'extra'}{'command'} = $result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[1];
 $result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[1];
 $result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[0];
 $result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[0];
-$result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[0]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[1]{'contents'}[1];
 $result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[1]{'contents'}[1];
 $result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[1];
-$result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[1]{'contents'}[0];
 $result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'long_uref_after_item'}{'contents'}[0];
-$result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[2];
 $result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[2]{'args'}[0];
-$result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[2]{'args'}[0];
-$result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[2]{'args'}[0];
 $result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[2];
-$result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[2]{'extra'}{'command'} = $result_trees{'long_uref_after_item'}{'contents'}[0];
-$result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'long_uref_after_item'}{'contents'}[0];
-$result_trees{'long_uref_after_item'}{'contents'}[0]{'extra'}{'block_command_line_contents'}[0][0]{'parent'} = $result_trees{'long_uref_after_item'}{'contents'}[0];
-$result_trees{'long_uref_after_item'}{'contents'}[0]{'extra'}{'command_as_argument'} = $result_trees{'long_uref_after_item'}{'contents'}[0]{'extra'}{'block_command_line_contents'}[0][0];
+$result_trees{'long_uref_after_item'}{'contents'}[0]{'extra'}{'command_as_argument'} = $result_trees{'long_uref_after_item'}{'contents'}[0]{'args'}[0];
 $result_trees{'long_uref_after_item'}{'contents'}[0]{'extra'}{'end_command'} = $result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[2];
-$result_trees{'long_uref_after_item'}{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'long_uref_after_item'}{'contents'}[0]{'contents'}[0];
 $result_trees{'long_uref_after_item'}{'contents'}[0]{'parent'} = $result_trees{'long_uref_after_item'};
 
 $result_texis{'long_uref_after_item'} = '@itemize
@@ -189,6 +159,9 @@ $result_texts{'long_uref_after_item'} = 'http://foo.org/some/long/url/which/goes
 $result_errors{'long_uref_after_item'} = [];
 
 
+$result_floats{'long_uref_after_item'} = {};
+
+
 
 $result_converted{'plaintext'}->{'long_uref_after_item'} = '   * 
      <http://foo.org/some/long/url/which/goes/past/eighty/columns/and/has/no/alternative/text.html>
