@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
@@ -22,7 +22,7 @@ $result_trees{'no_empty_line_after_section'} = {
         }
       ],
       'parent' => {},
-      'type' => 'before_node_section'
+      'type' => 'text_root'
     },
     {
       'args' => [
@@ -64,12 +64,13 @@ $result_trees{'no_empty_line_after_section'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 0,
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 2,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     },
     {
       'args' => [
@@ -147,12 +148,14 @@ $result_trees{'no_empty_line_after_section'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 1,
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 5,
         'macro' => ''
-      }
+      },
+      'number' => 1,
+      'parent' => {}
     },
     {
       'args' => [
@@ -189,12 +192,13 @@ $result_trees{'no_empty_line_after_section'} = {
                 }
               ],
               'cmdname' => 'uref',
-              'parent' => {},
-              'source_info' => {
+              'contents' => [],
+              'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 11,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             },
             {
               'parent' => {},
@@ -235,23 +239,25 @@ $result_trees{'no_empty_line_after_section'} = {
             ],
             'spaces_before_argument' => ' '
           },
-          'parent' => {},
-          'source_info' => {
+          'line_nr' => {
             'file_name' => '',
             'line_nr' => 13,
             'macro' => ''
-          }
+          },
+          'parent' => {}
         }
       ],
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 2,
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 10,
         'macro' => ''
-      }
+      },
+      'number' => '1.1',
+      'parent' => {}
     },
     {
       'args' => [
@@ -274,18 +280,21 @@ $result_trees{'no_empty_line_after_section'} = {
       'contents' => [
         {
           'cmdname' => 'indent',
-          'parent' => {},
-          'source_info' => {
+          'line_nr' => {
             'file_name' => '',
             'line_nr' => 15,
             'macro' => ''
-          }
+          },
+          'parent' => {}
         },
         {
+          'extra' => {
+            'command' => {}
+          },
           'parent' => {},
           'text' => '
 ',
-          'type' => 'ignorable_spaces_after_command'
+          'type' => 'empty_line_after_command'
         },
         {
           'contents' => [
@@ -311,12 +320,14 @@ $result_trees{'no_empty_line_after_section'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 2,
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 14,
         'macro' => ''
-      }
+      },
+      'number' => '1.2',
+      'parent' => {}
     }
   ],
   'type' => 'document_root'
@@ -355,6 +366,7 @@ $result_trees{'no_empty_line_after_section'}{'contents'}[3]{'parent'} = $result_
 $result_trees{'no_empty_line_after_section'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'no_empty_line_after_section'}{'contents'}[4]{'args'}[0];
 $result_trees{'no_empty_line_after_section'}{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'no_empty_line_after_section'}{'contents'}[4];
 $result_trees{'no_empty_line_after_section'}{'contents'}[4]{'contents'}[0]{'parent'} = $result_trees{'no_empty_line_after_section'}{'contents'}[4];
+$result_trees{'no_empty_line_after_section'}{'contents'}[4]{'contents'}[1]{'extra'}{'command'} = $result_trees{'no_empty_line_after_section'}{'contents'}[4]{'contents'}[0];
 $result_trees{'no_empty_line_after_section'}{'contents'}[4]{'contents'}[1]{'parent'} = $result_trees{'no_empty_line_after_section'}{'contents'}[4];
 $result_trees{'no_empty_line_after_section'}{'contents'}[4]{'contents'}[2]{'contents'}[0]{'parent'} = $result_trees{'no_empty_line_after_section'}{'contents'}[4]{'contents'}[2];
 $result_trees{'no_empty_line_after_section'}{'contents'}[4]{'contents'}[2]{'parent'} = $result_trees{'no_empty_line_after_section'}{'contents'}[4];
@@ -404,61 +416,59 @@ Para indented.
 ';
 
 $result_sectioning{'no_empty_line_after_section'} = {
-  'structure' => {
-    'section_childs' => [
-      {
-        'cmdname' => 'top',
-        'extra' => {},
-        'structure' => {
+  'level' => -1,
+  'section_childs' => [
+    {
+      'cmdname' => 'top',
+      'extra' => {
+        'spaces_before_argument' => ' '
+      },
+      'level' => 0,
+      'section_childs' => [
+        {
+          'cmdname' => 'chapter',
+          'extra' => {
+            'spaces_before_argument' => ' '
+          },
+          'level' => 1,
+          'number' => 1,
           'section_childs' => [
             {
-              'cmdname' => 'chapter',
-              'extra' => {},
-              'structure' => {
-                'section_childs' => [
-                  {
-                    'cmdname' => 'section',
-                    'extra' => {},
-                    'structure' => {
-                      'section_level' => 2,
-                      'section_number' => '1.1',
-                      'section_up' => {}
-                    }
-                  },
-                  {
-                    'cmdname' => 'section',
-                    'extra' => {},
-                    'structure' => {
-                      'section_level' => 2,
-                      'section_number' => '1.2',
-                      'section_prev' => {},
-                      'section_up' => {}
-                    }
-                  }
-                ],
-                'section_level' => 1,
-                'section_number' => 1,
-                'section_up' => {},
-                'toplevel_prev' => {},
-                'toplevel_up' => {}
-              }
+              'cmdname' => 'section',
+              'extra' => {
+                'spaces_before_argument' => ' '
+              },
+              'level' => 2,
+              'number' => '1.1',
+              'section_up' => {}
+            },
+            {
+              'cmdname' => 'section',
+              'extra' => {
+                'spaces_before_argument' => ' '
+              },
+              'level' => 2,
+              'number' => '1.2',
+              'section_prev' => {},
+              'section_up' => {}
             }
           ],
-          'section_level' => 0,
-          'section_up' => {}
+          'section_up' => {},
+          'toplevel_prev' => {},
+          'toplevel_up' => {}
         }
-      }
-    ],
-    'section_level' => -1
-  }
+      ],
+      'section_up' => {}
+    }
+  ]
 };
-$result_sectioning{'no_empty_line_after_section'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'no_empty_line_after_section'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0];
-$result_sectioning{'no_empty_line_after_section'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[1]{'structure'}{'section_prev'} = $result_sectioning{'no_empty_line_after_section'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0];
-$result_sectioning{'no_empty_line_after_section'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[1]{'structure'}{'section_up'} = $result_sectioning{'no_empty_line_after_section'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0];
-$result_sectioning{'no_empty_line_after_section'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'no_empty_line_after_section'}{'structure'}{'section_childs'}[0];
-$result_sectioning{'no_empty_line_after_section'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'toplevel_prev'} = $result_sectioning{'no_empty_line_after_section'}{'structure'}{'section_childs'}[0];
-$result_sectioning{'no_empty_line_after_section'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'toplevel_up'} = $result_sectioning{'no_empty_line_after_section'}{'structure'}{'section_childs'}[0];
-$result_sectioning{'no_empty_line_after_section'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'no_empty_line_after_section'};
+$result_sectioning{'no_empty_line_after_section'}{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[0]{'section_up'} = $result_sectioning{'no_empty_line_after_section'}{'section_childs'}[0]{'section_childs'}[0];
+$result_sectioning{'no_empty_line_after_section'}{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[1]{'section_prev'} = $result_sectioning{'no_empty_line_after_section'}{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[0];
+$result_sectioning{'no_empty_line_after_section'}{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[1]{'section_up'} = $result_sectioning{'no_empty_line_after_section'}{'section_childs'}[0]{'section_childs'}[0];
+$result_sectioning{'no_empty_line_after_section'}{'section_childs'}[0]{'section_childs'}[0]{'section_up'} = $result_sectioning{'no_empty_line_after_section'}{'section_childs'}[0];
+$result_sectioning{'no_empty_line_after_section'}{'section_childs'}[0]{'section_childs'}[0]{'toplevel_prev'} = $result_sectioning{'no_empty_line_after_section'}{'section_childs'}[0];
+$result_sectioning{'no_empty_line_after_section'}{'section_childs'}[0]{'section_childs'}[0]{'toplevel_up'} = $result_sectioning{'no_empty_line_after_section'}{'section_childs'}[0];
+$result_sectioning{'no_empty_line_after_section'}{'section_childs'}[0]{'section_up'} = $result_sectioning{'no_empty_line_after_section'};
 
 $result_errors{'no_empty_line_after_section'} = [];
 
