@@ -24,13 +24,6 @@ $result_trees{'punctuation_abbr_acronym'} = {
           ],
           'cmdname' => 'abbr',
           'contents' => [],
-          'extra' => {
-            'brace_command_contents' => [
-              [
-                {}
-              ]
-            ]
-          },
           'line_nr' => {
             'file_name' => '',
             'line_nr' => 1,
@@ -57,14 +50,11 @@ $result_trees{'punctuation_abbr_acronym'} = {
           ],
           'cmdname' => 'acronym',
           'contents' => [],
-          'extra' => {
-            'brace_command_contents' => [
-              [
-                {}
-              ]
-            ]
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 1,
+            'macro' => ''
           },
-          'line_nr' => {},
           'parent' => {}
         },
         {
@@ -86,14 +76,11 @@ $result_trees{'punctuation_abbr_acronym'} = {
           ],
           'cmdname' => 'abbr',
           'contents' => [],
-          'extra' => {
-            'brace_command_contents' => [
-              [
-                {}
-              ]
-            ]
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 1,
+            'macro' => ''
           },
-          'line_nr' => {},
           'parent' => {}
         },
         {
@@ -115,14 +102,11 @@ $result_trees{'punctuation_abbr_acronym'} = {
           ],
           'cmdname' => 'acronym',
           'contents' => [],
-          'extra' => {
-            'brace_command_contents' => [
-              [
-                {}
-              ]
-            ]
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 1,
+            'macro' => ''
           },
-          'line_nr' => {},
           'parent' => {}
         },
         {
@@ -144,32 +128,20 @@ $result_trees{'punctuation_abbr_acronym'} = {
             },
             {
               'contents' => [
-                {
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_before_argument'
-                },
                 {
                   'parent' => {},
                   'text' => 'expL'
                 }
               ],
+              'extra' => {
+                'spaces_before_argument' => ' '
+              },
               'parent' => {},
               'type' => 'brace_command_arg'
             }
           ],
           'cmdname' => 'abbr',
           'contents' => [],
-          'extra' => {
-            'brace_command_contents' => [
-              [
-                {}
-              ],
-              [
-                {}
-              ]
-            ]
-          },
           'line_nr' => {
             'file_name' => '',
             'line_nr' => 2,
@@ -195,33 +167,25 @@ $result_trees{'punctuation_abbr_acronym'} = {
             },
             {
               'contents' => [
-                {
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_before_argument'
-                },
                 {
                   'parent' => {},
                   'text' => 'explA'
                 }
               ],
+              'extra' => {
+                'spaces_before_argument' => ' '
+              },
               'parent' => {},
               'type' => 'brace_command_arg'
             }
           ],
           'cmdname' => 'acronym',
           'contents' => [],
-          'extra' => {
-            'brace_command_contents' => [
-              [
-                {}
-              ],
-              [
-                {}
-              ]
-            ]
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 2,
+            'macro' => ''
           },
-          'line_nr' => {},
           'parent' => {}
         },
         {
@@ -242,33 +206,25 @@ $result_trees{'punctuation_abbr_acronym'} = {
             },
             {
               'contents' => [
-                {
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_before_argument'
-                },
                 {
                   'parent' => {},
                   'text' => 'expl'
                 }
               ],
+              'extra' => {
+                'spaces_before_argument' => ' '
+              },
               'parent' => {},
               'type' => 'brace_command_arg'
             }
           ],
           'cmdname' => 'abbr',
           'contents' => [],
-          'extra' => {
-            'brace_command_contents' => [
-              [
-                {}
-              ],
-              [
-                {}
-              ]
-            ]
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 2,
+            'macro' => ''
           },
-          'line_nr' => {},
           'parent' => {}
         },
         {
@@ -290,32 +246,20 @@ $result_trees{'punctuation_abbr_acronym'} = {
             },
             {
               'contents' => [
-                {
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_before_argument'
-                },
                 {
                   'parent' => {},
                   'text' => 'expla'
                 }
               ],
+              'extra' => {
+                'spaces_before_argument' => ' '
+              },
               'parent' => {},
               'type' => 'brace_command_arg'
             }
           ],
           'cmdname' => 'acronym',
           'contents' => [],
-          'extra' => {
-            'brace_command_contents' => [
-              [
-                {}
-              ],
-              [
-                {}
-              ]
-            ]
-          },
           'line_nr' => {
             'file_name' => '',
             'line_nr' => 3,
@@ -337,63 +281,42 @@ $result_trees{'punctuation_abbr_acronym'} = {
 };
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[0]{'args'}[0];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[0];
-$result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[0]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[2]{'args'}[0];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[2];
-$result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[2]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0];
-$result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[2]{'line_nr'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[3]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[4]{'args'}[0];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[4];
-$result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[4]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[4]{'args'}[0]{'contents'}[0];
-$result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[4]{'line_nr'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[4]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[5]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[6]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[6]{'args'}[0];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[6]{'args'}[0]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[6];
-$result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[6]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[6]{'args'}[0]{'contents'}[0];
-$result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[6]{'line_nr'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[6]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[7]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[8]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[8]{'args'}[0];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[8]{'args'}[0]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[8];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[8]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[8]{'args'}[1];
-$result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[8]{'args'}[1]{'contents'}[1]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[8]{'args'}[1];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[8]{'args'}[1]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[8];
-$result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[8]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[8]{'args'}[0]{'contents'}[0];
-$result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[8]{'extra'}{'brace_command_contents'}[1][0] = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[8]{'args'}[1]{'contents'}[1];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[8]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[9]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[10]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[10]{'args'}[0];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[10]{'args'}[0]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[10];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[10]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[10]{'args'}[1];
-$result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[10]{'args'}[1]{'contents'}[1]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[10]{'args'}[1];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[10]{'args'}[1]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[10];
-$result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[10]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[10]{'args'}[0]{'contents'}[0];
-$result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[10]{'extra'}{'brace_command_contents'}[1][0] = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[10]{'args'}[1]{'contents'}[1];
-$result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[10]{'line_nr'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[8]{'line_nr'};
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[10]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[11]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[12]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[12]{'args'}[0];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[12]{'args'}[0]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[12];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[12]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[12]{'args'}[1];
-$result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[12]{'args'}[1]{'contents'}[1]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[12]{'args'}[1];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[12]{'args'}[1]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[12];
-$result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[12]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[12]{'args'}[0]{'contents'}[0];
-$result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[12]{'extra'}{'brace_command_contents'}[1][0] = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[12]{'args'}[1]{'contents'}[1];
-$result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[12]{'line_nr'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[8]{'line_nr'};
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[12]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[13]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[14]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[14]{'args'}[0];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[14]{'args'}[0]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[14];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[14]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[14]{'args'}[1];
-$result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[14]{'args'}[1]{'contents'}[1]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[14]{'args'}[1];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[14]{'args'}[1]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[14];
-$result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[14]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[14]{'args'}[0]{'contents'}[0];
-$result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[14]{'extra'}{'brace_command_contents'}[1][0] = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[14]{'args'}[1]{'contents'}[1];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[14]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'contents'}[15]{'parent'} = $result_trees{'punctuation_abbr_acronym'}{'contents'}[0];
 $result_trees{'punctuation_abbr_acronym'}{'contents'}[0]{'parent'} = $result_trees{'punctuation_abbr_acronym'};
@@ -412,6 +335,9 @@ bbb (expla). Last.
 $result_errors{'punctuation_abbr_acronym'} = [];
 
 
+$result_floats{'punctuation_abbr_acronym'} = {};
+
+
 
 $result_converted{'plaintext'}->{'punctuation_abbr_acronym'} = 'AAA.  BBB.  aaa.  bbb.  Next.  AAA (expL). BBB (explA). aaa (expl).  bbb
 (expla).  Last.
