@@ -85,7 +85,11 @@ $result_trees{'punctuation_and_code_style_commands_utf8'} = {
                   ],
                   'cmdname' => '~',
                   'contents' => [],
-                  'line_nr' => {},
+                  'line_nr' => {
+                    'file_name' => '',
+                    'line_nr' => 2,
+                    'macro' => ''
+                  },
                   'parent' => {}
                 }
               ],
@@ -95,7 +99,11 @@ $result_trees{'punctuation_and_code_style_commands_utf8'} = {
           ],
           'cmdname' => 'code',
           'contents' => [],
-          'line_nr' => {},
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 2,
+            'macro' => ''
+          },
           'parent' => {}
         },
         {
@@ -116,7 +124,11 @@ $result_trees{'punctuation_and_code_style_commands_utf8'} = {
                   ],
                   'cmdname' => 'aa',
                   'contents' => [],
-                  'line_nr' => {},
+                  'line_nr' => {
+                    'file_name' => '',
+                    'line_nr' => 2,
+                    'macro' => ''
+                  },
                   'parent' => {}
                 }
               ],
@@ -126,7 +138,11 @@ $result_trees{'punctuation_and_code_style_commands_utf8'} = {
           ],
           'cmdname' => 'samp',
           'contents' => [],
-          'line_nr' => {},
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 2,
+            'macro' => ''
+          },
           'parent' => {}
         },
         {
@@ -179,7 +195,11 @@ $result_trees{'punctuation_and_code_style_commands_utf8'} = {
                   ],
                   'cmdname' => '~',
                   'contents' => [],
-                  'line_nr' => {},
+                  'line_nr' => {
+                    'file_name' => '',
+                    'line_nr' => 3,
+                    'macro' => ''
+                  },
                   'parent' => {}
                 }
               ],
@@ -189,7 +209,11 @@ $result_trees{'punctuation_and_code_style_commands_utf8'} = {
           ],
           'cmdname' => 'code',
           'contents' => [],
-          'line_nr' => {},
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 3,
+            'macro' => ''
+          },
           'parent' => {}
         },
         {
@@ -210,7 +234,11 @@ $result_trees{'punctuation_and_code_style_commands_utf8'} = {
                   ],
                   'cmdname' => 'AA',
                   'contents' => [],
-                  'line_nr' => {},
+                  'line_nr' => {
+                    'file_name' => '',
+                    'line_nr' => 3,
+                    'macro' => ''
+                  },
                   'parent' => {}
                 }
               ],
@@ -220,7 +248,11 @@ $result_trees{'punctuation_and_code_style_commands_utf8'} = {
           ],
           'cmdname' => 'samp',
           'contents' => [],
-          'line_nr' => {},
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 3,
+            'macro' => ''
+          },
           'parent' => {}
         },
         {
@@ -277,7 +309,11 @@ $result_trees{'punctuation_and_code_style_commands_utf8'} = {
                   ],
                   'cmdname' => '~',
                   'contents' => [],
-                  'line_nr' => {},
+                  'line_nr' => {
+                    'file_name' => '',
+                    'line_nr' => 4,
+                    'macro' => ''
+                  },
                   'parent' => {}
                 }
               ],
@@ -287,7 +323,11 @@ $result_trees{'punctuation_and_code_style_commands_utf8'} = {
           ],
           'cmdname' => 'code',
           'contents' => [],
-          'line_nr' => {},
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 4,
+            'macro' => ''
+          },
           'parent' => {}
         },
         {
@@ -312,7 +352,11 @@ $result_trees{'punctuation_and_code_style_commands_utf8'} = {
                   ],
                   'cmdname' => 'AA',
                   'contents' => [],
-                  'line_nr' => {},
+                  'line_nr' => {
+                    'file_name' => '',
+                    'line_nr' => 4,
+                    'macro' => ''
+                  },
                   'parent' => {}
                 }
               ],
@@ -322,7 +366,11 @@ $result_trees{'punctuation_and_code_style_commands_utf8'} = {
           ],
           'cmdname' => 'samp',
           'contents' => [],
-          'line_nr' => {},
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 4,
+            'macro' => ''
+          },
           'parent' => {}
         },
         {
@@ -346,17 +394,13 @@ $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'conten
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1];
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'args'}[0];
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0];
-$result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'line_nr'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[0]{'line_nr'};
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[2]{'args'}[0];
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[2];
-$result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[2]{'line_nr'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[0]{'line_nr'};
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1];
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1];
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[4]{'args'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[4]{'args'}[0]{'contents'}[0];
-$result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[4]{'args'}[0]{'contents'}[0]{'line_nr'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[0]{'line_nr'};
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[4]{'args'}[0];
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[4];
-$result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[4]{'line_nr'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[0]{'line_nr'};
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[4]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1];
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[5]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1];
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[6]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[6]{'args'}[0];
@@ -365,17 +409,13 @@ $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'conten
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[7]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1];
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[8]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[8]{'args'}[0]{'contents'}[0]{'args'}[0];
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[8]{'args'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[8]{'args'}[0]{'contents'}[0];
-$result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[8]{'args'}[0]{'contents'}[0]{'line_nr'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[6]{'line_nr'};
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[8]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[8]{'args'}[0];
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[8]{'args'}[0]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[8];
-$result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[8]{'line_nr'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[6]{'line_nr'};
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[8]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1];
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[9]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1];
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[10]{'args'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[10]{'args'}[0]{'contents'}[0];
-$result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[10]{'args'}[0]{'contents'}[0]{'line_nr'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[6]{'line_nr'};
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[10]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[10]{'args'}[0];
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[10]{'args'}[0]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[10];
-$result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[10]{'line_nr'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[6]{'line_nr'};
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[10]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1];
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[11]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1];
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[12]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[12]{'args'}[0];
@@ -385,18 +425,14 @@ $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'conten
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[14]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[14]{'args'}[0];
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[14]{'args'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[14]{'args'}[0]{'contents'}[1]{'args'}[0];
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[14]{'args'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[14]{'args'}[0]{'contents'}[1];
-$result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[14]{'args'}[0]{'contents'}[1]{'line_nr'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[12]{'line_nr'};
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[14]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[14]{'args'}[0];
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[14]{'args'}[0]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[14];
-$result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[14]{'line_nr'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[12]{'line_nr'};
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[14]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1];
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[15]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1];
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[16]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[16]{'args'}[0];
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[16]{'args'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[16]{'args'}[0]{'contents'}[1];
-$result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[16]{'args'}[0]{'contents'}[1]{'line_nr'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[12]{'line_nr'};
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[16]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[16]{'args'}[0];
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[16]{'args'}[0]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[16];
-$result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[16]{'line_nr'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[12]{'line_nr'};
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[16]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1];
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'contents'}[17]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1];
 $result_trees{'punctuation_and_code_style_commands_utf8'}{'contents'}[1]{'parent'} = $result_trees{'punctuation_and_code_style_commands_utf8'};
@@ -416,6 +452,9 @@ double AAA.  double E~. double AA.  End.
 $result_errors{'punctuation_and_code_style_commands_utf8'} = [];
 
 
+$result_floats{'punctuation_and_code_style_commands_utf8'} = {};
+
+
 
 $result_converted{'plaintext'}->{'punctuation_and_code_style_commands_utf8'} = '‘aaa’.  ‘ẽ’.  ‘å’.  ‘AAA’.  ‘Ẽ’.  ‘Å’.  ‘double AAA’.  ‘double Ẽ’.
 ‘double Å’.  End.
