@@ -11,27 +11,17 @@ $result_trees{'punctuation_commands_frenchspacing'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'on'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'frenchspacing',
@@ -39,7 +29,7 @@ $result_trees{'punctuation_commands_frenchspacing'} = {
         'misc_args' => [
           'on'
         ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'line_nr' => {
         'file_name' => '',
@@ -156,7 +146,11 @@ $result_trees{'punctuation_commands_frenchspacing'} = {
           ],
           'cmdname' => 'enddots',
           'contents' => [],
-          'line_nr' => {},
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 5,
+            'macro' => ''
+          },
           'parent' => {}
         },
         {
@@ -475,12 +469,8 @@ $result_trees{'punctuation_commands_frenchspacing'} = {
   ],
   'type' => 'text_root'
 };
-$result_trees{'punctuation_commands_frenchspacing'}{'contents'}[0]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'punctuation_commands_frenchspacing'}{'contents'}[0];
 $result_trees{'punctuation_commands_frenchspacing'}{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'punctuation_commands_frenchspacing'}{'contents'}[0]{'args'}[0];
-$result_trees{'punctuation_commands_frenchspacing'}{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'punctuation_commands_frenchspacing'}{'contents'}[0]{'args'}[0];
-$result_trees{'punctuation_commands_frenchspacing'}{'contents'}[0]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'punctuation_commands_frenchspacing'}{'contents'}[0]{'args'}[0];
 $result_trees{'punctuation_commands_frenchspacing'}{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'punctuation_commands_frenchspacing'}{'contents'}[0];
-$result_trees{'punctuation_commands_frenchspacing'}{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'punctuation_commands_frenchspacing'}{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'punctuation_commands_frenchspacing'}{'contents'}[0]{'parent'} = $result_trees{'punctuation_commands_frenchspacing'};
 $result_trees{'punctuation_commands_frenchspacing'}{'contents'}[1]{'parent'} = $result_trees{'punctuation_commands_frenchspacing'};
 $result_trees{'punctuation_commands_frenchspacing'}{'contents'}[2]{'contents'}[0]{'parent'} = $result_trees{'punctuation_commands_frenchspacing'}{'contents'}[2];
@@ -503,7 +493,6 @@ $result_trees{'punctuation_commands_frenchspacing'}{'contents'}[4]{'contents'}[1
 $result_trees{'punctuation_commands_frenchspacing'}{'contents'}[4]{'contents'}[1]{'parent'} = $result_trees{'punctuation_commands_frenchspacing'}{'contents'}[4];
 $result_trees{'punctuation_commands_frenchspacing'}{'contents'}[4]{'contents'}[2]{'parent'} = $result_trees{'punctuation_commands_frenchspacing'}{'contents'}[4];
 $result_trees{'punctuation_commands_frenchspacing'}{'contents'}[4]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'punctuation_commands_frenchspacing'}{'contents'}[4]{'contents'}[3];
-$result_trees{'punctuation_commands_frenchspacing'}{'contents'}[4]{'contents'}[3]{'line_nr'} = $result_trees{'punctuation_commands_frenchspacing'}{'contents'}[4]{'contents'}[1]{'line_nr'};
 $result_trees{'punctuation_commands_frenchspacing'}{'contents'}[4]{'contents'}[3]{'parent'} = $result_trees{'punctuation_commands_frenchspacing'}{'contents'}[4];
 $result_trees{'punctuation_commands_frenchspacing'}{'contents'}[4]{'contents'}[4]{'parent'} = $result_trees{'punctuation_commands_frenchspacing'}{'contents'}[4];
 $result_trees{'punctuation_commands_frenchspacing'}{'contents'}[4]{'parent'} = $result_trees{'punctuation_commands_frenchspacing'};
@@ -633,6 +622,9 @@ End.
 $result_errors{'punctuation_commands_frenchspacing'} = [];
 
 
+$result_floats{'punctuation_commands_frenchspacing'} = {};
+
+
 
 $result_converted{'plaintext'}->{'punctuation_commands_frenchspacing'} = 'Dot. Exclam! Question? Dot. Exclam! Question? GAAA.
 
