@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
@@ -30,12 +30,12 @@ $result_trees{'settitle_and_empty_top'} = {
           'extra' => {
             'spaces_before_argument' => ' '
           },
-          'parent' => {},
-          'source_info' => {
+          'line_nr' => {
             'file_name' => '',
             'line_nr' => 1,
             'macro' => ''
-          }
+          },
+          'parent' => {}
         },
         {
           'parent' => {},
@@ -45,11 +45,12 @@ $result_trees{'settitle_and_empty_top'} = {
         }
       ],
       'parent' => {},
-      'type' => 'before_node_section'
+      'type' => 'text_root'
     },
     {
       'args' => [
         {
+          'contents' => [],
           'extra' => {
             'spaces_after_argument' => '
 '
@@ -67,12 +68,13 @@ $result_trees{'settitle_and_empty_top'} = {
           'type' => 'empty_line'
         }
       ],
-      'parent' => {},
-      'source_info' => {
+      'level' => 0,
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 3,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     }
   ],
   'type' => 'document_root'
@@ -98,20 +100,16 @@ $result_texts{'settitle_and_empty_top'} = '
 ';
 
 $result_sectioning{'settitle_and_empty_top'} = {
-  'structure' => {
-    'section_childs' => [
-      {
-        'cmdname' => 'top',
-        'structure' => {
-          'section_level' => 0,
-          'section_up' => {}
-        }
-      }
-    ],
-    'section_level' => -1
-  }
+  'level' => -1,
+  'section_childs' => [
+    {
+      'cmdname' => 'top',
+      'level' => 0,
+      'section_up' => {}
+    }
+  ]
 };
-$result_sectioning{'settitle_and_empty_top'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'settitle_and_empty_top'};
+$result_sectioning{'settitle_and_empty_top'}{'section_childs'}[0]{'section_up'} = $result_sectioning{'settitle_and_empty_top'};
 
 $result_errors{'settitle_and_empty_top'} = [];
 
