@@ -45,34 +45,23 @@ $result_trees{'empty_line'} = {
           'args' => [
             {
               'contents' => [
-                {
-                  'extra' => {
-                    'command' => {}
-                  },
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_after_command'
-                },
                 {
                   'parent' => {},
                   'text' => 'example'
-                },
-                {
-                  'parent' => {},
-                  'text' => '
-',
-                  'type' => 'spaces_at_end'
                 }
               ],
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
               'parent' => {},
-              'type' => 'misc_line_arg'
+              'type' => 'line_arg'
             }
           ],
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
             'command_argument' => 'example',
-            'spaces_after_command' => {},
+            'spaces_before_argument' => ' ',
             'text_arg' => 'example'
           },
           'line_nr' => {
@@ -84,8 +73,7 @@ $result_trees{'empty_line'} = {
         }
       ],
       'extra' => {
-        'end_command' => {},
-        'spaces_after_command' => {}
+        'end_command' => {}
       },
       'line_nr' => {
         'file_name' => '',
@@ -103,16 +91,10 @@ $result_trees{'empty_line'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent
 $result_trees{'empty_line'}{'contents'}[0]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'empty_line'}{'contents'}[0]{'contents'}[1];
 $result_trees{'empty_line'}{'contents'}[0]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'empty_line'}{'contents'}[0]{'contents'}[1];
 $result_trees{'empty_line'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'empty_line'}{'contents'}[0];
-$result_trees{'empty_line'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'empty_line'}{'contents'}[0]{'contents'}[2];
 $result_trees{'empty_line'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'empty_line'}{'contents'}[0]{'contents'}[2]{'args'}[0];
-$result_trees{'empty_line'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'empty_line'}{'contents'}[0]{'contents'}[2]{'args'}[0];
-$result_trees{'empty_line'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'empty_line'}{'contents'}[0]{'contents'}[2]{'args'}[0];
 $result_trees{'empty_line'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'empty_line'}{'contents'}[0]{'contents'}[2];
-$result_trees{'empty_line'}{'contents'}[0]{'contents'}[2]{'extra'}{'command'} = $result_trees{'empty_line'}{'contents'}[0];
-$result_trees{'empty_line'}{'contents'}[0]{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'empty_line'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'empty_line'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'empty_line'}{'contents'}[0];
 $result_trees{'empty_line'}{'contents'}[0]{'extra'}{'end_command'} = $result_trees{'empty_line'}{'contents'}[0]{'contents'}[2];
-$result_trees{'empty_line'}{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'empty_line'}{'contents'}[0]{'contents'}[0];
 $result_trees{'empty_line'}{'contents'}[0]{'parent'} = $result_trees{'empty_line'};
 
 $result_texis{'empty_line'} = '@example
@@ -131,6 +113,9 @@ after empty line
 $result_errors{'empty_line'} = [];
 
 
+$result_floats{'empty_line'} = {};
+
+
 
 $result_converted{'plaintext'}->{'empty_line'} = '     example
 
