@@ -34,13 +34,6 @@ $result_trees{'titlefont_in_example'} = {
           ],
           'cmdname' => 'titlefont',
           'contents' => [],
-          'extra' => {
-            'brace_command_contents' => [
-              [
-                {}
-              ]
-            ]
-          },
           'line_nr' => {
             'file_name' => '',
             'line_nr' => 2,
@@ -68,34 +61,23 @@ $result_trees{'titlefont_in_example'} = {
           'args' => [
             {
               'contents' => [
-                {
-                  'extra' => {
-                    'command' => {}
-                  },
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_after_command'
-                },
                 {
                   'parent' => {},
                   'text' => 'example'
-                },
-                {
-                  'parent' => {},
-                  'text' => '
-',
-                  'type' => 'spaces_at_end'
                 }
               ],
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
               'parent' => {},
-              'type' => 'misc_line_arg'
+              'type' => 'line_arg'
             }
           ],
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
             'command_argument' => 'example',
-            'spaces_after_command' => {},
+            'spaces_before_argument' => ' ',
             'text_arg' => 'example'
           },
           'line_nr' => {
@@ -107,8 +89,7 @@ $result_trees{'titlefont_in_example'} = {
         }
       ],
       'extra' => {
-        'end_command' => {},
-        'spaces_after_command' => {}
+        'end_command' => {}
       },
       'line_nr' => {
         'file_name' => '',
@@ -124,21 +105,14 @@ $result_trees{'titlefont_in_example'}{'contents'}[0]{'contents'}[0]{'extra'}{'co
 $result_trees{'titlefont_in_example'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'titlefont_in_example'}{'contents'}[0];
 $result_trees{'titlefont_in_example'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'titlefont_in_example'}{'contents'}[0]{'contents'}[1]{'args'}[0];
 $result_trees{'titlefont_in_example'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'titlefont_in_example'}{'contents'}[0]{'contents'}[1];
-$result_trees{'titlefont_in_example'}{'contents'}[0]{'contents'}[1]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'titlefont_in_example'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'titlefont_in_example'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'titlefont_in_example'}{'contents'}[0];
 $result_trees{'titlefont_in_example'}{'contents'}[0]{'contents'}[2]{'contents'}[0]{'parent'} = $result_trees{'titlefont_in_example'}{'contents'}[0]{'contents'}[2];
 $result_trees{'titlefont_in_example'}{'contents'}[0]{'contents'}[2]{'contents'}[1]{'parent'} = $result_trees{'titlefont_in_example'}{'contents'}[0]{'contents'}[2];
 $result_trees{'titlefont_in_example'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'titlefont_in_example'}{'contents'}[0];
-$result_trees{'titlefont_in_example'}{'contents'}[0]{'contents'}[3]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'titlefont_in_example'}{'contents'}[0]{'contents'}[3];
 $result_trees{'titlefont_in_example'}{'contents'}[0]{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'titlefont_in_example'}{'contents'}[0]{'contents'}[3]{'args'}[0];
-$result_trees{'titlefont_in_example'}{'contents'}[0]{'contents'}[3]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'titlefont_in_example'}{'contents'}[0]{'contents'}[3]{'args'}[0];
-$result_trees{'titlefont_in_example'}{'contents'}[0]{'contents'}[3]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'titlefont_in_example'}{'contents'}[0]{'contents'}[3]{'args'}[0];
 $result_trees{'titlefont_in_example'}{'contents'}[0]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'titlefont_in_example'}{'contents'}[0]{'contents'}[3];
-$result_trees{'titlefont_in_example'}{'contents'}[0]{'contents'}[3]{'extra'}{'command'} = $result_trees{'titlefont_in_example'}{'contents'}[0];
-$result_trees{'titlefont_in_example'}{'contents'}[0]{'contents'}[3]{'extra'}{'spaces_after_command'} = $result_trees{'titlefont_in_example'}{'contents'}[0]{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'titlefont_in_example'}{'contents'}[0]{'contents'}[3]{'parent'} = $result_trees{'titlefont_in_example'}{'contents'}[0];
 $result_trees{'titlefont_in_example'}{'contents'}[0]{'extra'}{'end_command'} = $result_trees{'titlefont_in_example'}{'contents'}[0]{'contents'}[3];
-$result_trees{'titlefont_in_example'}{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'titlefont_in_example'}{'contents'}[0]{'contents'}[0];
 $result_trees{'titlefont_in_example'}{'contents'}[0]{'parent'} = $result_trees{'titlefont_in_example'};
 
 $result_texis{'titlefont_in_example'} = '@example
@@ -155,10 +129,12 @@ Text.
 $result_errors{'titlefont_in_example'} = [];
 
 
+$result_floats{'titlefont_in_example'} = {};
+
+
 
 $result_converted{'plaintext'}->{'titlefont_in_example'} = '     Title
      *****
-
      Text.
 ';
 
