@@ -11,14 +11,6 @@ $result_trees{'quotation_beginning_and_end_on_line'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'in quotation '
@@ -34,34 +26,23 @@ $result_trees{'quotation_beginning_and_end_on_line'} = {
           'args' => [
             {
               'contents' => [
-                {
-                  'extra' => {
-                    'command' => {}
-                  },
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_after_command'
-                },
                 {
                   'parent' => {},
                   'text' => 'quotation'
-                },
-                {
-                  'parent' => {},
-                  'text' => '
-',
-                  'type' => 'spaces_at_end'
                 }
               ],
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
               'parent' => {},
-              'type' => 'misc_line_arg'
+              'type' => 'line_arg'
             }
           ],
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
             'command_argument' => 'quotation',
-            'spaces_after_command' => {},
+            'spaces_before_argument' => ' ',
             'text_arg' => 'quotation'
           },
           'line_nr' => {
@@ -74,29 +55,24 @@ $result_trees{'quotation_beginning_and_end_on_line'} = {
       ],
       'extra' => {
         'end_command' => {},
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
+      },
+      'line_nr' => {
+        'file_name' => '',
+        'line_nr' => 1,
+        'macro' => ''
       },
-      'line_nr' => {},
       'parent' => {}
     }
   ],
   'type' => 'text_root'
 };
-$result_trees{'quotation_beginning_and_end_on_line'}{'contents'}[0]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'quotation_beginning_and_end_on_line'}{'contents'}[0];
 $result_trees{'quotation_beginning_and_end_on_line'}{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'quotation_beginning_and_end_on_line'}{'contents'}[0]{'args'}[0];
-$result_trees{'quotation_beginning_and_end_on_line'}{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'quotation_beginning_and_end_on_line'}{'contents'}[0]{'args'}[0];
 $result_trees{'quotation_beginning_and_end_on_line'}{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'quotation_beginning_and_end_on_line'}{'contents'}[0];
-$result_trees{'quotation_beginning_and_end_on_line'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'quotation_beginning_and_end_on_line'}{'contents'}[0]{'contents'}[0];
 $result_trees{'quotation_beginning_and_end_on_line'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'quotation_beginning_and_end_on_line'}{'contents'}[0]{'contents'}[0]{'args'}[0];
-$result_trees{'quotation_beginning_and_end_on_line'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'quotation_beginning_and_end_on_line'}{'contents'}[0]{'contents'}[0]{'args'}[0];
-$result_trees{'quotation_beginning_and_end_on_line'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'quotation_beginning_and_end_on_line'}{'contents'}[0]{'contents'}[0]{'args'}[0];
 $result_trees{'quotation_beginning_and_end_on_line'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'quotation_beginning_and_end_on_line'}{'contents'}[0]{'contents'}[0];
-$result_trees{'quotation_beginning_and_end_on_line'}{'contents'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'quotation_beginning_and_end_on_line'}{'contents'}[0];
-$result_trees{'quotation_beginning_and_end_on_line'}{'contents'}[0]{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'quotation_beginning_and_end_on_line'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'quotation_beginning_and_end_on_line'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'quotation_beginning_and_end_on_line'}{'contents'}[0];
 $result_trees{'quotation_beginning_and_end_on_line'}{'contents'}[0]{'extra'}{'end_command'} = $result_trees{'quotation_beginning_and_end_on_line'}{'contents'}[0]{'contents'}[0];
-$result_trees{'quotation_beginning_and_end_on_line'}{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'quotation_beginning_and_end_on_line'}{'contents'}[0]{'args'}[0]{'contents'}[0];
-$result_trees{'quotation_beginning_and_end_on_line'}{'contents'}[0]{'line_nr'} = $result_trees{'quotation_beginning_and_end_on_line'}{'contents'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'quotation_beginning_and_end_on_line'}{'contents'}[0]{'parent'} = $result_trees{'quotation_beginning_and_end_on_line'};
 
 $result_texis{'quotation_beginning_and_end_on_line'} = '@quotation in quotation @end quotation
@@ -119,8 +95,11 @@ $result_errors{'quotation_beginning_and_end_on_line'} = [
 ];
 
 
+$result_floats{'quotation_beginning_and_end_on_line'} = {};
 
-$result_converted{'plaintext'}->{'quotation_beginning_and_end_on_line'} = '';
+
+
+$result_converted{'plaintext'}->{'quotation_beginning_and_end_on_line'} = '     in quotation : ';
 
 
 $result_converted{'html_text'}->{'quotation_beginning_and_end_on_line'} = '<blockquote>
