@@ -37,9 +37,11 @@ $result_trees{'braces_in_tex'} = {
               'text' => '\\chi^2 = \\sum_'
             },
             {
+              'parent' => {},
               'text' => '{i=1'
             },
             {
+              'parent' => {},
               'text' => '}^N
 '
             },
@@ -66,34 +68,23 @@ $result_trees{'braces_in_tex'} = {
           'args' => [
             {
               'contents' => [
-                {
-                  'extra' => {
-                    'command' => {}
-                  },
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_after_command'
-                },
                 {
                   'parent' => {},
                   'text' => 'tex'
-                },
-                {
-                  'parent' => {},
-                  'text' => '
-',
-                  'type' => 'spaces_at_end'
                 }
               ],
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
               'parent' => {},
-              'type' => 'misc_line_arg'
+              'type' => 'line_arg'
             }
           ],
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
             'command_argument' => 'tex',
-            'spaces_after_command' => {},
+            'spaces_before_argument' => ' ',
             'text_arg' => 'tex'
           },
           'line_nr' => {
@@ -105,8 +96,7 @@ $result_trees{'braces_in_tex'} = {
         }
       ],
       'extra' => {
-        'end_command' => {},
-        'spaces_after_command' => {}
+        'end_command' => {}
       },
       'line_nr' => {
         'file_name' => '',
@@ -165,9 +155,11 @@ $result_trees{'braces_in_tex'} = {
                       'text' => '\\chi^2 = \\sum_'
                     },
                     {
+                      'parent' => {},
                       'text' => '{i=1'
                     },
                     {
+                      'parent' => {},
                       'text' => '}^N
 '
                     },
@@ -194,34 +186,23 @@ $result_trees{'braces_in_tex'} = {
                   'args' => [
                     {
                       'contents' => [
-                        {
-                          'extra' => {
-                            'command' => {}
-                          },
-                          'parent' => {},
-                          'text' => ' ',
-                          'type' => 'empty_spaces_after_command'
-                        },
                         {
                           'parent' => {},
                           'text' => 'tex'
-                        },
-                        {
-                          'parent' => {},
-                          'text' => '
-',
-                          'type' => 'spaces_at_end'
                         }
                       ],
+                      'extra' => {
+                        'spaces_after_argument' => '
+'
+                      },
                       'parent' => {},
-                      'type' => 'misc_line_arg'
+                      'type' => 'line_arg'
                     }
                   ],
                   'cmdname' => 'end',
                   'extra' => {
-                    'command' => {},
                     'command_argument' => 'tex',
-                    'spaces_after_command' => {},
+                    'spaces_before_argument' => ' ',
                     'text_arg' => 'tex'
                   },
                   'line_nr' => {
@@ -233,8 +214,7 @@ $result_trees{'braces_in_tex'} = {
                 }
               ],
               'extra' => {
-                'end_command' => {},
-                'spaces_after_command' => {}
+                'end_command' => {}
               },
               'line_nr' => {
                 'file_name' => '',
@@ -251,34 +231,23 @@ $result_trees{'braces_in_tex'} = {
           'args' => [
             {
               'contents' => [
-                {
-                  'extra' => {
-                    'command' => {}
-                  },
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_after_command'
-                },
                 {
                   'parent' => {},
                   'text' => 'example'
-                },
-                {
-                  'parent' => {},
-                  'text' => '
-',
-                  'type' => 'spaces_at_end'
                 }
               ],
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
               'parent' => {},
-              'type' => 'misc_line_arg'
+              'type' => 'line_arg'
             }
           ],
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
             'command_argument' => 'example',
-            'spaces_after_command' => {},
+            'spaces_before_argument' => ' ',
             'text_arg' => 'example'
           },
           'line_nr' => {
@@ -290,8 +259,7 @@ $result_trees{'braces_in_tex'} = {
         }
       ],
       'extra' => {
-        'end_command' => {},
-        'spaces_after_command' => {}
+        'end_command' => {}
       },
       'line_nr' => {
         'file_name' => '',
@@ -314,20 +282,16 @@ $result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[0]{'extra'}{'command'}
 $result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[1];
 $result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[1];
 $result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[1];
+$result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[1];
+$result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[1];
 $result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[1]{'contents'}[4]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[1];
 $result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[1]{'contents'}[5]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[1];
 $result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[1]{'contents'}[6]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[1];
 $result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[1];
-$result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[2];
 $result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[2]{'args'}[0];
-$result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[2]{'args'}[0];
-$result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[2]{'args'}[0];
 $result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[2];
-$result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[2]{'extra'}{'command'} = $result_trees{'braces_in_tex'}{'contents'}[1];
-$result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[1];
 $result_trees{'braces_in_tex'}{'contents'}[1]{'extra'}{'end_command'} = $result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[2];
-$result_trees{'braces_in_tex'}{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'braces_in_tex'}{'contents'}[1]{'contents'}[0];
 $result_trees{'braces_in_tex'}{'contents'}[1]{'parent'} = $result_trees{'braces_in_tex'};
 $result_trees{'braces_in_tex'}{'contents'}[2]{'parent'} = $result_trees{'braces_in_tex'};
 $result_trees{'braces_in_tex'}{'contents'}[3]{'parent'} = $result_trees{'braces_in_tex'};
@@ -337,32 +301,22 @@ $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'con
 $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0];
 $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[1];
 $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[1];
+$result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[1];
+$result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[1];
 $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[1]{'contents'}[4]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[1];
 $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[1]{'contents'}[5]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[1];
 $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[1]{'contents'}[6]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[1];
 $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0];
-$result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[2];
 $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[2]{'args'}[0];
-$result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[2]{'args'}[0];
-$result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[2]{'args'}[0];
 $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[2];
-$result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[2]{'extra'}{'command'} = $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0];
-$result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0];
 $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'extra'}{'end_command'} = $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[2];
-$result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'contents'}[0];
 $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1];
 $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[1]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[4];
-$result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[2];
 $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[2]{'args'}[0];
-$result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[2]{'args'}[0];
-$result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[2]{'args'}[0];
 $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[2];
-$result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[2]{'extra'}{'command'} = $result_trees{'braces_in_tex'}{'contents'}[4];
-$result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[2]{'parent'} = $result_trees{'braces_in_tex'}{'contents'}[4];
 $result_trees{'braces_in_tex'}{'contents'}[4]{'extra'}{'end_command'} = $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[2];
-$result_trees{'braces_in_tex'}{'contents'}[4]{'extra'}{'spaces_after_command'} = $result_trees{'braces_in_tex'}{'contents'}[4]{'contents'}[0];
 $result_trees{'braces_in_tex'}{'contents'}[4]{'parent'} = $result_trees{'braces_in_tex'};
 $result_trees{'braces_in_tex'}{'contents'}[5]{'parent'} = $result_trees{'braces_in_tex'};
 
@@ -398,6 +352,9 @@ $result_texts{'braces_in_tex'} = '
 $result_errors{'braces_in_tex'} = [];
 
 
+$result_floats{'braces_in_tex'} = {};
+
+
 
 $result_converted{'plaintext'}->{'braces_in_tex'} = '
 ';
