@@ -12,13 +12,10 @@ $result_trees{'inline_missing_first_arg'} = {
         {
           'args' => [
             {
-              'contents' => [
-                {
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_before_argument'
-                }
-              ],
+              'contents' => [],
+              'extra' => {
+                'spaces_before_argument' => ' '
+              },
               'parent' => {},
               'type' => 'brace_command_arg'
             },
@@ -31,12 +28,7 @@ $result_trees{'inline_missing_first_arg'} = {
           'cmdname' => 'inlinefmt',
           'contents' => [],
           'extra' => {
-            'brace_command_contents' => [
-              undef,
-              undef
-            ],
-            'format' => undef,
-            'spaces_before_argument' => {}
+            'format' => undef
           },
           'line_nr' => {
             'file_name' => '',
@@ -65,13 +57,13 @@ $result_trees{'inline_missing_first_arg'} = {
           'cmdname' => 'inlineraw',
           'contents' => [],
           'extra' => {
-            'brace_command_contents' => [
-              undef,
-              undef
-            ],
             'format' => undef
           },
-          'line_nr' => {},
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 1,
+            'macro' => ''
+          },
           'parent' => {}
         },
         {
@@ -86,15 +78,12 @@ $result_trees{'inline_missing_first_arg'} = {
   ],
   'type' => 'text_root'
 };
-$result_trees{'inline_missing_first_arg'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'inline_missing_first_arg'}{'contents'}[0]{'contents'}[0]{'args'}[0];
 $result_trees{'inline_missing_first_arg'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'inline_missing_first_arg'}{'contents'}[0]{'contents'}[0];
 $result_trees{'inline_missing_first_arg'}{'contents'}[0]{'contents'}[0]{'args'}[1]{'parent'} = $result_trees{'inline_missing_first_arg'}{'contents'}[0]{'contents'}[0];
-$result_trees{'inline_missing_first_arg'}{'contents'}[0]{'contents'}[0]{'extra'}{'spaces_before_argument'} = $result_trees{'inline_missing_first_arg'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'inline_missing_first_arg'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'inline_missing_first_arg'}{'contents'}[0];
 $result_trees{'inline_missing_first_arg'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'inline_missing_first_arg'}{'contents'}[0];
 $result_trees{'inline_missing_first_arg'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'inline_missing_first_arg'}{'contents'}[0]{'contents'}[2];
 $result_trees{'inline_missing_first_arg'}{'contents'}[0]{'contents'}[2]{'args'}[1]{'parent'} = $result_trees{'inline_missing_first_arg'}{'contents'}[0]{'contents'}[2];
-$result_trees{'inline_missing_first_arg'}{'contents'}[0]{'contents'}[2]{'line_nr'} = $result_trees{'inline_missing_first_arg'}{'contents'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'inline_missing_first_arg'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'inline_missing_first_arg'}{'contents'}[0];
 $result_trees{'inline_missing_first_arg'}{'contents'}[0]{'contents'}[3]{'parent'} = $result_trees{'inline_missing_first_arg'}{'contents'}[0];
 $result_trees{'inline_missing_first_arg'}{'contents'}[0]{'parent'} = $result_trees{'inline_missing_first_arg'};
@@ -128,4 +117,7 @@ $result_errors{'inline_missing_first_arg'} = [
 ];
 
 
+$result_floats{'inline_missing_first_arg'} = {};
+
+
 1;
