@@ -27,11 +27,6 @@ $result_trees{'inlineraw'} = {
             },
             {
               'contents' => [
-                {
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_before_argument'
-                },
                 {
                   'parent' => {},
                   'text' => 'plaintext `` '
@@ -58,6 +53,9 @@ $result_trees{'inlineraw'} = {
                   'text' => ' '
                 }
               ],
+              'extra' => {
+                'spaces_before_argument' => ' '
+              },
               'parent' => {},
               'type' => 'brace_command_arg'
             }
@@ -65,20 +63,14 @@ $result_trees{'inlineraw'} = {
           'cmdname' => 'inlineraw',
           'contents' => [],
           'extra' => {
-            'brace_command_contents' => [
-              [
-                {}
-              ],
-              [
-                {},
-                {},
-                {}
-              ]
-            ],
             'expand_index' => 1,
             'format' => 'plaintext'
           },
-          'line_nr' => {},
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 1,
+            'macro' => ''
+          },
           'parent' => {}
         },
         {
@@ -100,11 +92,6 @@ $result_trees{'inlineraw'} = {
             },
             {
               'contents' => [
-                {
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_before_argument'
-                },
                 {
                   'parent' => {},
                   'text' => 'in <i>'
@@ -124,13 +111,6 @@ $result_trees{'inlineraw'} = {
                   ],
                   'cmdname' => 'acronym',
                   'contents' => [],
-                  'extra' => {
-                    'brace_command_contents' => [
-                      [
-                        {}
-                      ]
-                    ]
-                  },
                   'line_nr' => {
                     'file_name' => '',
                     'line_nr' => 2,
@@ -143,6 +123,9 @@ $result_trees{'inlineraw'} = {
                   'text' => '</i>'
                 }
               ],
+              'extra' => {
+                'spaces_before_argument' => ' '
+              },
               'parent' => {},
               'type' => 'brace_command_arg'
             }
@@ -150,20 +133,14 @@ $result_trees{'inlineraw'} = {
           'cmdname' => 'inlineraw',
           'contents' => [],
           'extra' => {
-            'brace_command_contents' => [
-              [
-                {}
-              ],
-              [
-                {},
-                {},
-                {}
-              ]
-            ],
             'expand_index' => 1,
             'format' => 'html'
           },
-          'line_nr' => {},
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 2,
+            'macro' => ''
+          },
           'parent' => {}
         },
         {
@@ -182,33 +159,20 @@ $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_tre
 $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[1]{'args'}[0];
 $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[1];
 $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[1]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[1]{'args'}[1];
+$result_trees{'inlineraw'}{'contents'}[0]{'contents'}[1]{'args'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[1]{'args'}[1]{'contents'}[1];
 $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[1]{'args'}[1]{'contents'}[1]{'parent'} = $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[1]{'args'}[1];
-$result_trees{'inlineraw'}{'contents'}[0]{'contents'}[1]{'args'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[1]{'args'}[1]{'contents'}[2];
 $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[1]{'args'}[1]{'contents'}[2]{'parent'} = $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[1]{'args'}[1];
-$result_trees{'inlineraw'}{'contents'}[0]{'contents'}[1]{'args'}[1]{'contents'}[3]{'parent'} = $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[1]{'args'}[1];
 $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[1]{'args'}[1]{'parent'} = $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[1];
-$result_trees{'inlineraw'}{'contents'}[0]{'contents'}[1]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'inlineraw'}{'contents'}[0]{'contents'}[1]{'extra'}{'brace_command_contents'}[1][0] = $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[1]{'args'}[1]{'contents'}[1];
-$result_trees{'inlineraw'}{'contents'}[0]{'contents'}[1]{'extra'}{'brace_command_contents'}[1][1] = $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[1]{'args'}[1]{'contents'}[2];
-$result_trees{'inlineraw'}{'contents'}[0]{'contents'}[1]{'extra'}{'brace_command_contents'}[1][2] = $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[1]{'args'}[1]{'contents'}[3];
-$result_trees{'inlineraw'}{'contents'}[0]{'contents'}[1]{'line_nr'} = $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[1]{'args'}[1]{'contents'}[2]{'line_nr'};
 $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'inlineraw'}{'contents'}[0];
 $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'inlineraw'}{'contents'}[0];
 $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'args'}[0];
 $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3];
 $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'args'}[1];
+$result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'args'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'args'}[1]{'contents'}[1]{'args'}[0];
+$result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'args'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'args'}[1]{'contents'}[1];
 $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'args'}[1]{'contents'}[1]{'parent'} = $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'args'}[1];
-$result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'args'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'args'}[1]{'contents'}[2]{'args'}[0];
-$result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'args'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'args'}[1]{'contents'}[2];
-$result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'args'}[1]{'contents'}[2]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'args'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'args'}[1]{'contents'}[2]{'parent'} = $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'args'}[1];
-$result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'args'}[1]{'contents'}[3]{'parent'} = $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'args'}[1];
 $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'args'}[1]{'parent'} = $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3];
-$result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'extra'}{'brace_command_contents'}[0][0] = $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'args'}[0]{'contents'}[0];
-$result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'extra'}{'brace_command_contents'}[1][0] = $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'args'}[1]{'contents'}[1];
-$result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'extra'}{'brace_command_contents'}[1][1] = $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'args'}[1]{'contents'}[2];
-$result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'extra'}{'brace_command_contents'}[1][2] = $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'args'}[1]{'contents'}[3];
-$result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'line_nr'} = $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'args'}[1]{'contents'}[2]{'line_nr'};
 $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[3]{'parent'} = $result_trees{'inlineraw'}{'contents'}[0];
 $result_trees{'inlineraw'}{'contents'}[0]{'contents'}[4]{'parent'} = $result_trees{'inlineraw'}{'contents'}[0];
 $result_trees{'inlineraw'}{'contents'}[0]{'parent'} = $result_trees{'inlineraw'};
@@ -225,6 +189,9 @@ $result_texts{'inlineraw'} = 'A  a.  Now html
 $result_errors{'inlineraw'} = [];
 
 
+$result_floats{'inlineraw'} = {};
+
+
 
 $result_converted{'plaintext'}->{'inlineraw'} = 'A plaintext `` { a.  Now html .
 ';
