@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
@@ -10,92 +10,45 @@ $result_trees{'format_in_titlepage_titlepage'} = {
     {
       'contents' => [
         {
+          'cmdname' => 'titlepage',
           'contents' => [
             {
-              'args' => [
-                {
-                  'extra' => {
-                    'spaces_after_argument' => '
-'
-                  },
-                  'parent' => {},
-                  'type' => 'block_line_arg'
-                }
-              ],
-              'cmdname' => 'titlepage',
+              'extra' => {
+                'command' => {}
+              },
+              'parent' => {},
+              'text' => '
+',
+              'type' => 'empty_line_after_command'
+            },
+            {
+              'parent' => {},
+              'text' => '
+',
+              'type' => 'empty_line'
+            },
+            {
+              'cmdname' => 'format',
               'contents' => [
                 {
+                  'extra' => {
+                    'command' => {}
+                  },
                   'parent' => {},
                   'text' => '
 ',
-                  'type' => 'empty_line'
+                  'type' => 'empty_line_after_command'
                 },
                 {
-                  'args' => [
-                    {
-                      'extra' => {
-                        'spaces_after_argument' => '
-'
-                      },
-                      'parent' => {},
-                      'type' => 'block_line_arg'
-                    }
-                  ],
-                  'cmdname' => 'format',
                   'contents' => [
                     {
-                      'contents' => [
-                        {
-                          'parent' => {},
-                          'text' => 'Published
-'
-                        }
-                      ],
                       'parent' => {},
-                      'type' => 'preformatted'
-                    },
-                    {
-                      'args' => [
-                        {
-                          'contents' => [
-                            {
-                              'parent' => {},
-                              'text' => 'format'
-                            }
-                          ],
-                          'extra' => {
-                            'spaces_after_argument' => '
+                      'text' => 'Published
 '
-                          },
-                          'parent' => {},
-                          'type' => 'line_arg'
-                        }
-                      ],
-                      'cmdname' => 'end',
-                      'extra' => {
-                        'spaces_before_argument' => ' ',
-                        'text_arg' => 'format'
-                      },
-                      'parent' => {},
-                      'source_info' => {
-                        'file_name' => '',
-                        'line_nr' => 5,
-                        'macro' => ''
-                      }
                     }
                   ],
                   'parent' => {},
-                  'source_info' => {
-                    'file_name' => '',
-                    'line_nr' => 3,
-                    'macro' => ''
-                  }
-                },
-                {
-                  'parent' => {},
-                  'text' => '
-',
-                  'type' => 'empty_line'
+                  'type' => 'preformatted'
                 },
                 {
                   'args' => [
@@ -103,7 +56,7 @@ $result_trees{'format_in_titlepage_titlepage'} = {
                       'contents' => [
                         {
                           'parent' => {},
-                          'text' => 'titlepage'
+                          'text' => 'format'
                         }
                       ],
                       'extra' => {
@@ -116,37 +69,84 @@ $result_trees{'format_in_titlepage_titlepage'} = {
                   ],
                   'cmdname' => 'end',
                   'extra' => {
+                    'command_argument' => 'format',
                     'spaces_before_argument' => ' ',
-                    'text_arg' => 'titlepage'
+                    'text_arg' => 'format'
                   },
-                  'parent' => {},
-                  'source_info' => {
+                  'line_nr' => {
                     'file_name' => '',
-                    'line_nr' => 7,
+                    'line_nr' => 5,
                     'macro' => ''
-                  }
+                  },
+                  'parent' => {}
                 }
               ],
-              'parent' => {},
-              'source_info' => {
+              'extra' => {
+                'end_command' => {}
+              },
+              'line_nr' => {
                 'file_name' => '',
-                'line_nr' => 1,
+                'line_nr' => 3,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             },
             {
               'parent' => {},
               'text' => '
 ',
               'type' => 'empty_line'
+            },
+            {
+              'args' => [
+                {
+                  'contents' => [
+                    {
+                      'parent' => {},
+                      'text' => 'titlepage'
+                    }
+                  ],
+                  'extra' => {
+                    'spaces_after_argument' => '
+'
+                  },
+                  'parent' => {},
+                  'type' => 'line_arg'
+                }
+              ],
+              'cmdname' => 'end',
+              'extra' => {
+                'command_argument' => 'titlepage',
+                'spaces_before_argument' => ' ',
+                'text_arg' => 'titlepage'
+              },
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 7,
+                'macro' => ''
+              },
+              'parent' => {}
             }
           ],
+          'extra' => {
+            'end_command' => {}
+          },
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 1,
+            'macro' => ''
+          },
+          'parent' => {}
+        },
+        {
           'parent' => {},
-          'type' => 'preamble_before_content'
+          'text' => '
+',
+          'type' => 'empty_line'
         }
       ],
       'parent' => {},
-      'type' => 'before_node_section'
+      'type' => 'text_root'
     },
     {
       'args' => [
@@ -189,32 +189,35 @@ $result_trees{'format_in_titlepage_titlepage'} = {
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 9,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     }
   ],
   'type' => 'document_root'
 };
-$result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[0];
-$result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[0];
-$result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1];
-$result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'contents'}[0];
-$result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1];
-$result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'contents'}[1]{'args'}[0];
-$result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'contents'}[1];
-$result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1];
-$result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[0];
-$result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[0];
-$result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[3]{'args'}[0];
-$result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[3];
-$result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[3]{'parent'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[0];
+$result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0];
 $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0];
 $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0];
+$result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[2]{'contents'}[0]{'extra'}{'command'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[2];
+$result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[2]{'contents'}[0]{'parent'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[2];
+$result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[2]{'contents'}[1];
+$result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[2]{'contents'}[1]{'parent'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[2];
+$result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[2]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[2]{'contents'}[2]{'args'}[0];
+$result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[2]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[2]{'contents'}[2];
+$result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[2]{'contents'}[2]{'parent'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[2];
+$result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[2]{'extra'}{'end_command'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[2]{'contents'}[2];
+$result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0];
+$result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[3]{'parent'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0];
+$result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[4]{'args'}[0];
+$result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[4];
+$result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[4]{'parent'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0];
+$result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'extra'}{'end_command'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'contents'}[4];
 $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0];
+$result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0];
 $result_trees{'format_in_titlepage_titlepage'}{'contents'}[0]{'parent'} = $result_trees{'format_in_titlepage_titlepage'};
 $result_trees{'format_in_titlepage_titlepage'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[1]{'args'}[0];
 $result_trees{'format_in_titlepage_titlepage'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'format_in_titlepage_titlepage'}{'contents'}[1];
@@ -240,17 +243,21 @@ $result_texts{'format_in_titlepage_titlepage'} = '
 
 ';
 
+$result_sectioning{'format_in_titlepage_titlepage'} = {};
+
 $result_nodes{'format_in_titlepage_titlepage'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   }
 };
 
 $result_menus{'format_in_titlepage_titlepage'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   }
 };
 
@@ -280,7 +287,7 @@ End:
 ';
 
 
-$result_converted{'html'}->{'format_in_titlepage_titlepage'} = '<!DOCTYPE html>
+$result_converted{'html'}->{'format_in_titlepage_titlepage'} = '<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
 <html>
 <!-- Created by texinfo, http://www.gnu.org/software/texinfo/ -->
 <head>
@@ -296,7 +303,21 @@ $result_converted{'html'}->{'format_in_titlepage_titlepage'} = '<!DOCTYPE html>
 <link href="#Top" rel="start" title="Top">
 <style type="text/css">
 <!--
-pre.format-preformatted {font-family: inherit}
+a.copiable-anchor {visibility: hidden; text-decoration: none; line-height: 0em}
+a.summary-letter {text-decoration: none}
+blockquote.indentedblock {margin-right: 0em}
+div.display {margin-left: 3.2em}
+div.example {margin-left: 3.2em}
+kbd {font-style: oblique}
+pre.display {font-family: inherit}
+pre.format {font-family: inherit}
+pre.menu-comment {font-family: serif}
+pre.menu-preformatted {font-family: serif}
+span.nolinebreak {white-space: nowrap}
+span.roman {font-family: initial; font-weight: normal}
+span.sansserif {font-family: sans-serif; font-weight: normal}
+span:hover a.copiable-anchor {visibility: visible}
+ul.no-bullet {list-style: none}
 -->
 </style>
 
@@ -306,14 +327,14 @@ pre.format-preformatted {font-family: inherit}
 <body lang="en">
 
 <div class="format">
-<pre class="format-preformatted">Published
+<pre class="format">Published
 </pre></div>
 
 <hr>
 
-<h1 class="node" id="Top">Top</h1>
-
+<span id="Top"></span><h1 class="node-heading">Top</h1>
 
+<hr>
 
 
 </body>
@@ -330,28 +351,4 @@ $result_converted_errors{'html'}->{'format_in_titlepage_titlepage'} = [
 ];
 
 
-
-$result_converted{'latex_text'}->{'format_in_titlepage_titlepage'} = '
-\\begin{document}
-
-\\frontmatter
-\\begin{titlepage}
-\\begingroup
-\\newskip\\titlepagetopglue \\titlepagetopglue = 1.5in
-\\newskip\\titlepagebottomglue \\titlepagebottomglue = 2pc
-\\setlength{\\parindent}{0pt}
-% Leave some space at the very top of the page.
-    \\vglue\\titlepagetopglue
-
-\\begin{Texinfopreformatted}%
-Published
-\\end{Texinfopreformatted}
-
-\\endgroup
-\\end{titlepage}
-\\pagestyle{single}%
-\\mainmatter
-\\label{anchor:Top}%
-';
-
 1;
