@@ -1,15 +1,16 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
 $result_trees{'a_comma_after_node'} = {
   'contents' => [
     {
+      'contents' => [],
       'parent' => {},
-      'type' => 'before_node_section'
+      'type' => 'text_root'
     },
     {
       'args' => [
@@ -99,12 +100,12 @@ $result_trees{'a_comma_after_node'} = {
         'normalized' => 'Commands',
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 1,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     }
   ],
   'type' => 'document_root'
@@ -135,23 +136,27 @@ $result_texts{'a_comma_after_node'} = '
 A comma in text, end.
 ';
 
+$result_sectioning{'a_comma_after_node'} = {};
+
 $result_nodes{'a_comma_after_node'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Commands'
+    'normalized' => 'Commands',
+    'spaces_before_argument' => ' '
   }
 };
 
 $result_menus{'a_comma_after_node'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Commands'
+    'normalized' => 'Commands',
+    'spaces_before_argument' => ' '
   }
 };
 
 $result_errors{'a_comma_after_node'} = [
   {
-    'error_line' => 'Next reference to nonexistent `Requirements\'
+    'error_line' => ':1: Next reference to nonexistent `Requirements\'
 ',
     'file_name' => '',
     'line_nr' => 1,
@@ -160,7 +165,7 @@ $result_errors{'a_comma_after_node'} = [
     'type' => 'error'
   },
   {
-    'error_line' => 'Prev reference to nonexistent `Nodes and Menus\'
+    'error_line' => ':1: Prev reference to nonexistent `Nodes and Menus\'
 ',
     'file_name' => '',
     'line_nr' => 1,
