@@ -17,27 +17,17 @@ $result_trees{'chapter_sections'} = [
         'args' => [
           {
             'contents' => [
-              {
-                'extra' => {
-                  'command' => {}
-                },
-                'parent' => {},
-                'text' => ' ',
-                'type' => 'empty_spaces_after_command'
-              },
               {
                 'parent' => {},
                 'text' => 'unnumbered'
-              },
-              {
-                'parent' => {},
-                'text' => '
-',
-                'type' => 'spaces_at_end'
               }
             ],
+            'extra' => {
+              'spaces_after_argument' => '
+'
+            },
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           }
         ],
         'cmdname' => 'unnumbered',
@@ -50,10 +40,7 @@ $result_trees{'chapter_sections'} = [
           }
         ],
         'extra' => {
-          'misc_content' => [
-            {}
-          ],
-          'spaces_after_command' => {}
+          'spaces_before_argument' => ' '
         },
         'level' => 1,
         'line_nr' => {
@@ -76,27 +63,17 @@ $result_trees{'chapter_sections'} = [
         'args' => [
           {
             'contents' => [
-              {
-                'extra' => {
-                  'command' => {}
-                },
-                'parent' => {},
-                'text' => ' ',
-                'type' => 'empty_spaces_after_command'
-              },
               {
                 'parent' => {},
                 'text' => 'First chapter'
-              },
-              {
-                'parent' => {},
-                'text' => '
-',
-                'type' => 'spaces_at_end'
               }
             ],
+            'extra' => {
+              'spaces_after_argument' => '
+'
+            },
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           }
         ],
         'cmdname' => 'chapter',
@@ -109,10 +86,7 @@ $result_trees{'chapter_sections'} = [
           }
         ],
         'extra' => {
-          'misc_content' => [
-            {}
-          ],
-          'spaces_after_command' => {}
+          'spaces_before_argument' => ' '
         },
         'level' => 1,
         'line_nr' => {
@@ -137,27 +111,17 @@ $result_trees{'chapter_sections'} = [
         'args' => [
           {
             'contents' => [
-              {
-                'extra' => {
-                  'command' => {}
-                },
-                'parent' => {},
-                'text' => ' ',
-                'type' => 'empty_spaces_after_command'
-              },
               {
                 'parent' => {},
                 'text' => 'second'
-              },
-              {
-                'parent' => {},
-                'text' => '
-',
-                'type' => 'spaces_at_end'
               }
             ],
+            'extra' => {
+              'spaces_after_argument' => '
+'
+            },
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           }
         ],
         'cmdname' => 'section',
@@ -170,10 +134,7 @@ $result_trees{'chapter_sections'} = [
           }
         ],
         'extra' => {
-          'misc_content' => [
-            {}
-          ],
-          'spaces_after_command' => {}
+          'spaces_before_argument' => ' '
         },
         'level' => 2,
         'line_nr' => {
@@ -198,27 +159,17 @@ $result_trees{'chapter_sections'} = [
         'args' => [
           {
             'contents' => [
-              {
-                'extra' => {
-                  'command' => {}
-                },
-                'parent' => {},
-                'text' => ' ',
-                'type' => 'empty_spaces_after_command'
-              },
               {
                 'parent' => {},
                 'text' => 'Chapter'
-              },
-              {
-                'parent' => {},
-                'text' => '
-',
-                'type' => 'spaces_at_end'
               }
             ],
+            'extra' => {
+              'spaces_after_argument' => '
+'
+            },
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           }
         ],
         'cmdname' => 'chapter',
@@ -231,10 +182,7 @@ $result_trees{'chapter_sections'} = [
           }
         ],
         'extra' => {
-          'misc_content' => [
-            {}
-          ],
-          'spaces_after_command' => {}
+          'spaces_before_argument' => ' '
         },
         'level' => 1,
         'line_nr' => {
@@ -259,27 +207,17 @@ $result_trees{'chapter_sections'} = [
         'args' => [
           {
             'contents' => [
-              {
-                'extra' => {
-                  'command' => {}
-                },
-                'parent' => {},
-                'text' => ' ',
-                'type' => 'empty_spaces_after_command'
-              },
               {
                 'parent' => {},
                 'text' => 'Section of chapter'
-              },
-              {
-                'parent' => {},
-                'text' => '
-',
-                'type' => 'spaces_at_end'
               }
             ],
+            'extra' => {
+              'spaces_after_argument' => '
+'
+            },
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           }
         ],
         'cmdname' => 'section',
@@ -292,10 +230,7 @@ $result_trees{'chapter_sections'} = [
           }
         ],
         'extra' => {
-          'misc_content' => [
-            {}
-          ],
-          'spaces_after_command' => {}
+          'spaces_before_argument' => ' '
         },
         'level' => 2,
         'line_nr' => {
@@ -320,27 +255,17 @@ $result_trees{'chapter_sections'} = [
         'args' => [
           {
             'contents' => [
-              {
-                'extra' => {
-                  'command' => {}
-                },
-                'parent' => {},
-                'text' => ' ',
-                'type' => 'empty_spaces_after_command'
-              },
               {
                 'parent' => {},
                 'text' => 'subsection 1'
-              },
-              {
-                'parent' => {},
-                'text' => '
-',
-                'type' => 'spaces_at_end'
               }
             ],
+            'extra' => {
+              'spaces_after_argument' => '
+'
+            },
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           }
         ],
         'cmdname' => 'subsection',
@@ -353,10 +278,7 @@ $result_trees{'chapter_sections'} = [
           }
         ],
         'extra' => {
-          'misc_content' => [
-            {}
-          ],
-          'spaces_after_command' => {}
+          'spaces_before_argument' => ' '
         },
         'level' => 3,
         'line_nr' => {
@@ -381,27 +303,17 @@ $result_trees{'chapter_sections'} = [
         'args' => [
           {
             'contents' => [
-              {
-                'extra' => {
-                  'command' => {}
-                },
-                'parent' => {},
-                'text' => ' ',
-                'type' => 'empty_spaces_after_command'
-              },
               {
                 'parent' => {},
                 'text' => 'subsection 2'
-              },
-              {
-                'parent' => {},
-                'text' => '
-',
-                'type' => 'spaces_at_end'
               }
             ],
+            'extra' => {
+              'spaces_after_argument' => '
+'
+            },
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           }
         ],
         'cmdname' => 'subsection',
@@ -414,10 +326,7 @@ $result_trees{'chapter_sections'} = [
           }
         ],
         'extra' => {
-          'misc_content' => [
-            {}
-          ],
-          'spaces_after_command' => {}
+          'spaces_before_argument' => ' '
         },
         'level' => 3,
         'line_nr' => {
@@ -442,36 +351,23 @@ $result_trees{'chapter_sections'} = [
         'args' => [
           {
             'contents' => [
-              {
-                'extra' => {
-                  'command' => {}
-                },
-                'parent' => {},
-                'text' => ' ',
-                'type' => 'empty_spaces_after_command'
-              },
               {
                 'parent' => {},
                 'text' => 'Chapter 2'
-              },
-              {
-                'parent' => {},
-                'text' => '
-',
-                'type' => 'spaces_at_end'
               }
             ],
+            'extra' => {
+              'spaces_after_argument' => '
+'
+            },
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           }
         ],
         'cmdname' => 'chapter',
         'contents' => [],
         'extra' => {
-          'misc_content' => [
-            {}
-          ],
-          'spaces_after_command' => {}
+          'spaces_before_argument' => ' '
         },
         'level' => 1,
         'line_nr' => {
@@ -492,96 +388,56 @@ $result_trees{'chapter_sections'} = [
   }
 ];
 $result_trees{'chapter_sections'}[0]{'contents'}[0]{'parent'} = $result_trees{'chapter_sections'}[0];
-$result_trees{'chapter_sections'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'chapter_sections'}[0]{'contents'}[1];
 $result_trees{'chapter_sections'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'chapter_sections'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'chapter_sections'}[0]{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'chapter_sections'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'chapter_sections'}[0]{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'chapter_sections'}[0]{'contents'}[1]{'args'}[0];
 $result_trees{'chapter_sections'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'chapter_sections'}[0]{'contents'}[1];
 $result_trees{'chapter_sections'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'chapter_sections'}[0]{'contents'}[1];
-$result_trees{'chapter_sections'}[0]{'contents'}[1]{'extra'}{'misc_content'}[0] = $result_trees{'chapter_sections'}[0]{'contents'}[1]{'args'}[0]{'contents'}[1];
-$result_trees{'chapter_sections'}[0]{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'chapter_sections'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'chapter_sections'}[0]{'contents'}[1]{'parent'} = $result_trees{'chapter_sections'}[0];
 $result_trees{'chapter_sections'}[0]{'extra'}{'element_command'} = $result_trees{'chapter_sections'}[0]{'contents'}[1];
 $result_trees{'chapter_sections'}[0]{'extra'}{'section'} = $result_trees{'chapter_sections'}[0]{'contents'}[1];
-$result_trees{'chapter_sections'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'chapter_sections'}[1]{'contents'}[0];
 $result_trees{'chapter_sections'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'chapter_sections'}[1]{'contents'}[0]{'args'}[0];
-$result_trees{'chapter_sections'}[1]{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'chapter_sections'}[1]{'contents'}[0]{'args'}[0];
-$result_trees{'chapter_sections'}[1]{'contents'}[0]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'chapter_sections'}[1]{'contents'}[0]{'args'}[0];
 $result_trees{'chapter_sections'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'chapter_sections'}[1]{'contents'}[0];
 $result_trees{'chapter_sections'}[1]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'chapter_sections'}[1]{'contents'}[0];
-$result_trees{'chapter_sections'}[1]{'contents'}[0]{'extra'}{'misc_content'}[0] = $result_trees{'chapter_sections'}[1]{'contents'}[0]{'args'}[0]{'contents'}[1];
-$result_trees{'chapter_sections'}[1]{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'chapter_sections'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'chapter_sections'}[1]{'contents'}[0]{'parent'} = $result_trees{'chapter_sections'}[1];
 $result_trees{'chapter_sections'}[1]{'element_prev'} = $result_trees{'chapter_sections'}[0];
 $result_trees{'chapter_sections'}[1]{'extra'}{'element_command'} = $result_trees{'chapter_sections'}[1]{'contents'}[0];
 $result_trees{'chapter_sections'}[1]{'extra'}{'section'} = $result_trees{'chapter_sections'}[1]{'contents'}[0];
-$result_trees{'chapter_sections'}[2]{'contents'}[0]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'chapter_sections'}[2]{'contents'}[0];
 $result_trees{'chapter_sections'}[2]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'chapter_sections'}[2]{'contents'}[0]{'args'}[0];
-$result_trees{'chapter_sections'}[2]{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'chapter_sections'}[2]{'contents'}[0]{'args'}[0];
-$result_trees{'chapter_sections'}[2]{'contents'}[0]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'chapter_sections'}[2]{'contents'}[0]{'args'}[0];
 $result_trees{'chapter_sections'}[2]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'chapter_sections'}[2]{'contents'}[0];
 $result_trees{'chapter_sections'}[2]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'chapter_sections'}[2]{'contents'}[0];
-$result_trees{'chapter_sections'}[2]{'contents'}[0]{'extra'}{'misc_content'}[0] = $result_trees{'chapter_sections'}[2]{'contents'}[0]{'args'}[0]{'contents'}[1];
-$result_trees{'chapter_sections'}[2]{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'chapter_sections'}[2]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'chapter_sections'}[2]{'contents'}[0]{'parent'} = $result_trees{'chapter_sections'}[2];
 $result_trees{'chapter_sections'}[2]{'element_prev'} = $result_trees{'chapter_sections'}[1];
 $result_trees{'chapter_sections'}[2]{'extra'}{'element_command'} = $result_trees{'chapter_sections'}[2]{'contents'}[0];
 $result_trees{'chapter_sections'}[2]{'extra'}{'section'} = $result_trees{'chapter_sections'}[2]{'contents'}[0];
-$result_trees{'chapter_sections'}[3]{'contents'}[0]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'chapter_sections'}[3]{'contents'}[0];
 $result_trees{'chapter_sections'}[3]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'chapter_sections'}[3]{'contents'}[0]{'args'}[0];
-$result_trees{'chapter_sections'}[3]{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'chapter_sections'}[3]{'contents'}[0]{'args'}[0];
-$result_trees{'chapter_sections'}[3]{'contents'}[0]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'chapter_sections'}[3]{'contents'}[0]{'args'}[0];
 $result_trees{'chapter_sections'}[3]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'chapter_sections'}[3]{'contents'}[0];
 $result_trees{'chapter_sections'}[3]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'chapter_sections'}[3]{'contents'}[0];
-$result_trees{'chapter_sections'}[3]{'contents'}[0]{'extra'}{'misc_content'}[0] = $result_trees{'chapter_sections'}[3]{'contents'}[0]{'args'}[0]{'contents'}[1];
-$result_trees{'chapter_sections'}[3]{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'chapter_sections'}[3]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'chapter_sections'}[3]{'contents'}[0]{'parent'} = $result_trees{'chapter_sections'}[3];
 $result_trees{'chapter_sections'}[3]{'element_prev'} = $result_trees{'chapter_sections'}[2];
 $result_trees{'chapter_sections'}[3]{'extra'}{'element_command'} = $result_trees{'chapter_sections'}[3]{'contents'}[0];
 $result_trees{'chapter_sections'}[3]{'extra'}{'section'} = $result_trees{'chapter_sections'}[3]{'contents'}[0];
-$result_trees{'chapter_sections'}[4]{'contents'}[0]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'chapter_sections'}[4]{'contents'}[0];
 $result_trees{'chapter_sections'}[4]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'chapter_sections'}[4]{'contents'}[0]{'args'}[0];
-$result_trees{'chapter_sections'}[4]{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'chapter_sections'}[4]{'contents'}[0]{'args'}[0];
-$result_trees{'chapter_sections'}[4]{'contents'}[0]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'chapter_sections'}[4]{'contents'}[0]{'args'}[0];
 $result_trees{'chapter_sections'}[4]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'chapter_sections'}[4]{'contents'}[0];
 $result_trees{'chapter_sections'}[4]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'chapter_sections'}[4]{'contents'}[0];
-$result_trees{'chapter_sections'}[4]{'contents'}[0]{'extra'}{'misc_content'}[0] = $result_trees{'chapter_sections'}[4]{'contents'}[0]{'args'}[0]{'contents'}[1];
-$result_trees{'chapter_sections'}[4]{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'chapter_sections'}[4]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'chapter_sections'}[4]{'contents'}[0]{'parent'} = $result_trees{'chapter_sections'}[4];
 $result_trees{'chapter_sections'}[4]{'element_prev'} = $result_trees{'chapter_sections'}[3];
 $result_trees{'chapter_sections'}[4]{'extra'}{'element_command'} = $result_trees{'chapter_sections'}[4]{'contents'}[0];
 $result_trees{'chapter_sections'}[4]{'extra'}{'section'} = $result_trees{'chapter_sections'}[4]{'contents'}[0];
-$result_trees{'chapter_sections'}[5]{'contents'}[0]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'chapter_sections'}[5]{'contents'}[0];
 $result_trees{'chapter_sections'}[5]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'chapter_sections'}[5]{'contents'}[0]{'args'}[0];
-$result_trees{'chapter_sections'}[5]{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'chapter_sections'}[5]{'contents'}[0]{'args'}[0];
-$result_trees{'chapter_sections'}[5]{'contents'}[0]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'chapter_sections'}[5]{'contents'}[0]{'args'}[0];
 $result_trees{'chapter_sections'}[5]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'chapter_sections'}[5]{'contents'}[0];
 $result_trees{'chapter_sections'}[5]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'chapter_sections'}[5]{'contents'}[0];
-$result_trees{'chapter_sections'}[5]{'contents'}[0]{'extra'}{'misc_content'}[0] = $result_trees{'chapter_sections'}[5]{'contents'}[0]{'args'}[0]{'contents'}[1];
-$result_trees{'chapter_sections'}[5]{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'chapter_sections'}[5]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'chapter_sections'}[5]{'contents'}[0]{'parent'} = $result_trees{'chapter_sections'}[5];
 $result_trees{'chapter_sections'}[5]{'element_prev'} = $result_trees{'chapter_sections'}[4];
 $result_trees{'chapter_sections'}[5]{'extra'}{'element_command'} = $result_trees{'chapter_sections'}[5]{'contents'}[0];
 $result_trees{'chapter_sections'}[5]{'extra'}{'section'} = $result_trees{'chapter_sections'}[5]{'contents'}[0];
-$result_trees{'chapter_sections'}[6]{'contents'}[0]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'chapter_sections'}[6]{'contents'}[0];
 $result_trees{'chapter_sections'}[6]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'chapter_sections'}[6]{'contents'}[0]{'args'}[0];
-$result_trees{'chapter_sections'}[6]{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'chapter_sections'}[6]{'contents'}[0]{'args'}[0];
-$result_trees{'chapter_sections'}[6]{'contents'}[0]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'chapter_sections'}[6]{'contents'}[0]{'args'}[0];
 $result_trees{'chapter_sections'}[6]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'chapter_sections'}[6]{'contents'}[0];
 $result_trees{'chapter_sections'}[6]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'chapter_sections'}[6]{'contents'}[0];
-$result_trees{'chapter_sections'}[6]{'contents'}[0]{'extra'}{'misc_content'}[0] = $result_trees{'chapter_sections'}[6]{'contents'}[0]{'args'}[0]{'contents'}[1];
-$result_trees{'chapter_sections'}[6]{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'chapter_sections'}[6]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'chapter_sections'}[6]{'contents'}[0]{'parent'} = $result_trees{'chapter_sections'}[6];
 $result_trees{'chapter_sections'}[6]{'element_prev'} = $result_trees{'chapter_sections'}[5];
 $result_trees{'chapter_sections'}[6]{'extra'}{'element_command'} = $result_trees{'chapter_sections'}[6]{'contents'}[0];
 $result_trees{'chapter_sections'}[6]{'extra'}{'section'} = $result_trees{'chapter_sections'}[6]{'contents'}[0];
-$result_trees{'chapter_sections'}[7]{'contents'}[0]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'chapter_sections'}[7]{'contents'}[0];
 $result_trees{'chapter_sections'}[7]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'chapter_sections'}[7]{'contents'}[0]{'args'}[0];
-$result_trees{'chapter_sections'}[7]{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'chapter_sections'}[7]{'contents'}[0]{'args'}[0];
-$result_trees{'chapter_sections'}[7]{'contents'}[0]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'chapter_sections'}[7]{'contents'}[0]{'args'}[0];
 $result_trees{'chapter_sections'}[7]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'chapter_sections'}[7]{'contents'}[0];
-$result_trees{'chapter_sections'}[7]{'contents'}[0]{'extra'}{'misc_content'}[0] = $result_trees{'chapter_sections'}[7]{'contents'}[0]{'args'}[0]{'contents'}[1];
-$result_trees{'chapter_sections'}[7]{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'chapter_sections'}[7]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'chapter_sections'}[7]{'contents'}[0]{'parent'} = $result_trees{'chapter_sections'}[7];
 $result_trees{'chapter_sections'}[7]{'element_prev'} = $result_trees{'chapter_sections'}[6];
 $result_trees{'chapter_sections'}[7]{'extra'}{'element_command'} = $result_trees{'chapter_sections'}[7]{'contents'}[0];
@@ -635,19 +491,25 @@ $result_sectioning{'chapter_sections'} = {
   'section_childs' => [
     {
       'cmdname' => 'unnumbered',
-      'extra' => {},
+      'extra' => {
+        'spaces_before_argument' => ' '
+      },
       'level' => 1,
       'section_up' => {}
     },
     {
       'cmdname' => 'chapter',
-      'extra' => {},
+      'extra' => {
+        'spaces_before_argument' => ' '
+      },
       'level' => 1,
       'number' => 1,
       'section_childs' => [
         {
           'cmdname' => 'section',
-          'extra' => {},
+          'extra' => {
+            'spaces_before_argument' => ' '
+          },
           'level' => 2,
           'number' => '1.1',
           'section_up' => {}
@@ -659,26 +521,34 @@ $result_sectioning{'chapter_sections'} = {
     },
     {
       'cmdname' => 'chapter',
-      'extra' => {},
+      'extra' => {
+        'spaces_before_argument' => ' '
+      },
       'level' => 1,
       'number' => 2,
       'section_childs' => [
         {
           'cmdname' => 'section',
-          'extra' => {},
+          'extra' => {
+            'spaces_before_argument' => ' '
+          },
           'level' => 2,
           'number' => '2.1',
           'section_childs' => [
             {
               'cmdname' => 'subsection',
-              'extra' => {},
+              'extra' => {
+                'spaces_before_argument' => ' '
+              },
               'level' => 3,
               'number' => '2.1.1',
               'section_up' => {}
             },
             {
               'cmdname' => 'subsection',
-              'extra' => {},
+              'extra' => {
+                'spaces_before_argument' => ' '
+              },
               'level' => 3,
               'number' => '2.1.2',
               'section_prev' => {},
@@ -694,7 +564,9 @@ $result_sectioning{'chapter_sections'} = {
     },
     {
       'cmdname' => 'chapter',
-      'extra' => {},
+      'extra' => {
+        'spaces_before_argument' => ' '
+      },
       'level' => 1,
       'number' => 3,
       'section_prev' => {},
@@ -722,6 +594,9 @@ $result_sectioning{'chapter_sections'}{'section_childs'}[3]{'toplevel_prev'} = $
 $result_errors{'chapter_sections'} = [];
 
 
+$result_floats{'chapter_sections'} = {};
+
+
 $result_elements{'chapter_sections'} = [
   {
     'extra' => {
@@ -746,7 +621,9 @@ $result_elements{'chapter_sections'} = [
                         },
                         'element_command' => {
                           'cmdname' => 'section',
-                          'extra' => {},
+                          'extra' => {
+                            'spaces_before_argument' => ' '
+                          },
                           'level' => 2,
                           'number' => '1.1'
                         },
@@ -776,7 +653,9 @@ $result_elements{'chapter_sections'} = [
                                           },
                                           'element_command' => {
                                             'cmdname' => 'section',
-                                            'extra' => {},
+                                            'extra' => {
+                                              'spaces_before_argument' => ' '
+                                            },
                                             'level' => 2,
                                             'number' => '2.1'
                                           },
@@ -793,7 +672,9 @@ $result_elements{'chapter_sections'} = [
                                     },
                                     'element_command' => {
                                       'cmdname' => 'subsection',
-                                      'extra' => {},
+                                      'extra' => {
+                                        'spaces_before_argument' => ' '
+                                      },
                                       'level' => 3,
                                       'number' => '2.1.1'
                                     },
@@ -810,7 +691,9 @@ $result_elements{'chapter_sections'} = [
                               },
                               'element_command' => {
                                 'cmdname' => 'subsection',
-                                'extra' => {},
+                                'extra' => {
+                                  'spaces_before_argument' => ' '
+                                },
                                 'level' => 3,
                                 'number' => '2.1.2'
                               },
@@ -824,7 +707,9 @@ $result_elements{'chapter_sections'} = [
                         },
                         'element_command' => {
                           'cmdname' => 'chapter',
-                          'extra' => {},
+                          'extra' => {
+                            'spaces_before_argument' => ' '
+                          },
                           'level' => 1,
                           'number' => 3
                         },
@@ -839,7 +724,9 @@ $result_elements{'chapter_sections'} = [
                   },
                   'element_command' => {
                     'cmdname' => 'chapter',
-                    'extra' => {},
+                    'extra' => {
+                      'spaces_before_argument' => ' '
+                    },
                     'level' => 1,
                     'number' => 2
                   },
@@ -854,7 +741,9 @@ $result_elements{'chapter_sections'} = [
             },
             'element_command' => {
               'cmdname' => 'chapter',
-              'extra' => {},
+              'extra' => {
+                'spaces_before_argument' => ' '
+              },
               'level' => 1,
               'number' => 1
             },
@@ -868,7 +757,9 @@ $result_elements{'chapter_sections'} = [
       },
       'element_command' => {
         'cmdname' => 'unnumbered',
-        'extra' => {},
+        'extra' => {
+          'spaces_before_argument' => ' '
+        },
         'level' => 1
       },
       'section' => {}
