@@ -16,27 +16,17 @@ $result_trees{'contents_in_html_text'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'top'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'top',
@@ -49,10 +39,7 @@ $result_trees{'contents_in_html_text'} = {
         }
       ],
       'extra' => {
-        'misc_content' => [
-          {}
-        ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'level' => 0,
       'line_nr' => {
@@ -66,27 +53,17 @@ $result_trees{'contents_in_html_text'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'Chap1'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'chapter',
@@ -99,10 +76,7 @@ $result_trees{'contents_in_html_text'} = {
         }
       ],
       'extra' => {
-        'misc_content' => [
-          {}
-        ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'level' => 1,
       'line_nr' => {
@@ -117,27 +91,17 @@ $result_trees{'contents_in_html_text'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'Sec 1'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'section',
@@ -150,10 +114,7 @@ $result_trees{'contents_in_html_text'} = {
         }
       ],
       'extra' => {
-        'misc_content' => [
-          {}
-        ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'level' => 2,
       'line_nr' => {
@@ -168,27 +129,17 @@ $result_trees{'contents_in_html_text'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'Chap2'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'chapter',
@@ -235,10 +186,7 @@ $result_trees{'contents_in_html_text'} = {
         }
       ],
       'extra' => {
-        'misc_content' => [
-          {}
-        ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'level' => 1,
       'line_nr' => {
@@ -253,45 +201,25 @@ $result_trees{'contents_in_html_text'} = {
   'type' => 'document_root'
 };
 $result_trees{'contents_in_html_text'}{'contents'}[0]{'parent'} = $result_trees{'contents_in_html_text'};
-$result_trees{'contents_in_html_text'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'contents_in_html_text'}{'contents'}[1];
 $result_trees{'contents_in_html_text'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'contents_in_html_text'}{'contents'}[1]{'args'}[0];
-$result_trees{'contents_in_html_text'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'contents_in_html_text'}{'contents'}[1]{'args'}[0];
-$result_trees{'contents_in_html_text'}{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'contents_in_html_text'}{'contents'}[1]{'args'}[0];
 $result_trees{'contents_in_html_text'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'contents_in_html_text'}{'contents'}[1];
 $result_trees{'contents_in_html_text'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'contents_in_html_text'}{'contents'}[1];
-$result_trees{'contents_in_html_text'}{'contents'}[1]{'extra'}{'misc_content'}[0] = $result_trees{'contents_in_html_text'}{'contents'}[1]{'args'}[0]{'contents'}[1];
-$result_trees{'contents_in_html_text'}{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'contents_in_html_text'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'contents_in_html_text'}{'contents'}[1]{'parent'} = $result_trees{'contents_in_html_text'};
-$result_trees{'contents_in_html_text'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'contents_in_html_text'}{'contents'}[2];
 $result_trees{'contents_in_html_text'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'contents_in_html_text'}{'contents'}[2]{'args'}[0];
-$result_trees{'contents_in_html_text'}{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'contents_in_html_text'}{'contents'}[2]{'args'}[0];
-$result_trees{'contents_in_html_text'}{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'contents_in_html_text'}{'contents'}[2]{'args'}[0];
 $result_trees{'contents_in_html_text'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'contents_in_html_text'}{'contents'}[2];
 $result_trees{'contents_in_html_text'}{'contents'}[2]{'contents'}[0]{'parent'} = $result_trees{'contents_in_html_text'}{'contents'}[2];
-$result_trees{'contents_in_html_text'}{'contents'}[2]{'extra'}{'misc_content'}[0] = $result_trees{'contents_in_html_text'}{'contents'}[2]{'args'}[0]{'contents'}[1];
-$result_trees{'contents_in_html_text'}{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'contents_in_html_text'}{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'contents_in_html_text'}{'contents'}[2]{'parent'} = $result_trees{'contents_in_html_text'};
-$result_trees{'contents_in_html_text'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'contents_in_html_text'}{'contents'}[3];
 $result_trees{'contents_in_html_text'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'contents_in_html_text'}{'contents'}[3]{'args'}[0];
-$result_trees{'contents_in_html_text'}{'contents'}[3]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'contents_in_html_text'}{'contents'}[3]{'args'}[0];
-$result_trees{'contents_in_html_text'}{'contents'}[3]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'contents_in_html_text'}{'contents'}[3]{'args'}[0];
 $result_trees{'contents_in_html_text'}{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'contents_in_html_text'}{'contents'}[3];
 $result_trees{'contents_in_html_text'}{'contents'}[3]{'contents'}[0]{'parent'} = $result_trees{'contents_in_html_text'}{'contents'}[3];
-$result_trees{'contents_in_html_text'}{'contents'}[3]{'extra'}{'misc_content'}[0] = $result_trees{'contents_in_html_text'}{'contents'}[3]{'args'}[0]{'contents'}[1];
-$result_trees{'contents_in_html_text'}{'contents'}[3]{'extra'}{'spaces_after_command'} = $result_trees{'contents_in_html_text'}{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'contents_in_html_text'}{'contents'}[3]{'parent'} = $result_trees{'contents_in_html_text'};
-$result_trees{'contents_in_html_text'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'contents_in_html_text'}{'contents'}[4];
 $result_trees{'contents_in_html_text'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'contents_in_html_text'}{'contents'}[4]{'args'}[0];
-$result_trees{'contents_in_html_text'}{'contents'}[4]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'contents_in_html_text'}{'contents'}[4]{'args'}[0];
-$result_trees{'contents_in_html_text'}{'contents'}[4]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'contents_in_html_text'}{'contents'}[4]{'args'}[0];
 $result_trees{'contents_in_html_text'}{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'contents_in_html_text'}{'contents'}[4];
 $result_trees{'contents_in_html_text'}{'contents'}[4]{'contents'}[0]{'parent'} = $result_trees{'contents_in_html_text'}{'contents'}[4];
 $result_trees{'contents_in_html_text'}{'contents'}[4]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'contents_in_html_text'}{'contents'}[4]{'contents'}[1];
 $result_trees{'contents_in_html_text'}{'contents'}[4]{'contents'}[1]{'parent'} = $result_trees{'contents_in_html_text'}{'contents'}[4];
 $result_trees{'contents_in_html_text'}{'contents'}[4]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'contents_in_html_text'}{'contents'}[4]{'contents'}[2];
 $result_trees{'contents_in_html_text'}{'contents'}[4]{'contents'}[2]{'parent'} = $result_trees{'contents_in_html_text'}{'contents'}[4];
-$result_trees{'contents_in_html_text'}{'contents'}[4]{'extra'}{'misc_content'}[0] = $result_trees{'contents_in_html_text'}{'contents'}[4]{'args'}[0]{'contents'}[1];
-$result_trees{'contents_in_html_text'}{'contents'}[4]{'extra'}{'spaces_after_command'} = $result_trees{'contents_in_html_text'}{'contents'}[4]{'args'}[0]{'contents'}[0];
 $result_trees{'contents_in_html_text'}{'contents'}[4]{'parent'} = $result_trees{'contents_in_html_text'};
 
 $result_texis{'contents_in_html_text'} = '@top top
@@ -326,18 +254,24 @@ $result_sectioning{'contents_in_html_text'} = {
   'section_childs' => [
     {
       'cmdname' => 'top',
-      'extra' => {},
+      'extra' => {
+        'spaces_before_argument' => ' '
+      },
       'level' => 0,
       'section_childs' => [
         {
           'cmdname' => 'chapter',
-          'extra' => {},
+          'extra' => {
+            'spaces_before_argument' => ' '
+          },
           'level' => 1,
           'number' => 1,
           'section_childs' => [
             {
               'cmdname' => 'section',
-              'extra' => {},
+              'extra' => {
+                'spaces_before_argument' => ' '
+              },
               'level' => 2,
               'number' => '1.1',
               'section_up' => {}
@@ -349,7 +283,9 @@ $result_sectioning{'contents_in_html_text'} = {
         },
         {
           'cmdname' => 'chapter',
-          'extra' => {},
+          'extra' => {
+            'spaces_before_argument' => ' '
+          },
           'level' => 1,
           'number' => 2,
           'section_prev' => {},
@@ -375,42 +311,53 @@ $result_sectioning{'contents_in_html_text'}{'section_childs'}[0]{'section_up'} =
 $result_errors{'contents_in_html_text'} = [];
 
 
+$result_floats{'contents_in_html_text'} = {};
 
-$result_converted{'html_text'}->{'contents_in_html_text'} = '<a name="top"></a>
+
+
+$result_converted{'html_text'}->{'contents_in_html_text'} = '<div class="top" id="top">
 <h1 class="top">top</h1>
 
-<a name="Chap1"></a>
+<div class="chapter" id="Chap1">
 <h2 class="chapter">1 Chap1</h2>
 
-<a name="Sec-1"></a>
+<ul class="section-toc">
+<li><a href="#Sec-1" accesskey="1">Sec 1</a></li>
+</ul>
+<div class="section" id="Sec-1">
 <h3 class="section">1.1 Sec 1</h3>
 
-<a name="Chap2"></a>
+</div>
+</div>
+<div class="chapter" id="Chap2">
 <h2 class="chapter">2 Chap2</h2>
 
+<div class="Overview_element">
 <h2 class="shortcontents-heading">Short Table of Contents</h2>
 
 <div class="shortcontents">
 <ul class="no-bullet">
-<li><a name="stoc-Chap1" href="#toc-Chap1">1 Chap1</a></li>
-<li><a name="stoc-Chap2" href="#toc-Chap2">2 Chap2</a></li>
+<li><a id="stoc-Chap1" href="#toc-Chap1">1 Chap1</a></li>
+<li><a id="stoc-Chap2" href="#toc-Chap2">2 Chap2</a></li>
 </ul>
 </div>
-
+</div>
+<div class="Contents_element">
 <h2 class="contents-heading">Table of Contents</h2>
 
 <div class="contents">
 
 <ul class="no-bullet">
-  <li><a name="toc-Chap1" href="#Chap1">1 Chap1</a>
+  <li><a id="toc-Chap1" href="#Chap1">1 Chap1</a>
   <ul class="no-bullet">
-    <li><a name="toc-Sec-1" href="#Sec-1">1.1 Sec 1</a></li>
+    <li><a id="toc-Sec-1" href="#Sec-1">1.1 Sec 1</a></li>
   </ul></li>
-  <li><a name="toc-Chap2" href="#Chap2">2 Chap2</a></li>
+  <li><a id="toc-Chap2" href="#Chap2">2 Chap2</a></li>
 </ul>
 </div>
-
-<hr>
+</div>
+<hr></div>
+</div>
 ';
 
 1;
