@@ -37,32 +37,22 @@ $result_trees{'contents_no_section'} = {
           'args' => [
             {
               'contents' => [
-                {
-                  'extra' => {
-                    'command' => {}
-                  },
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_after_command'
-                },
                 {
                   'parent' => {},
                   'text' => 'contents_no_section.info'
-                },
-                {
-                  'parent' => {},
-                  'text' => '
-',
-                  'type' => 'spaces_at_end'
                 }
               ],
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
               'parent' => {},
-              'type' => 'misc_line_arg'
+              'type' => 'line_arg'
             }
           ],
           'cmdname' => 'setfilename',
           'extra' => {
-            'spaces_after_command' => {},
+            'spaces_before_argument' => ' ',
             'text_arg' => 'contents_no_section.info'
           },
           'line_nr' => {
@@ -86,27 +76,17 @@ $result_trees{'contents_no_section'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'Top'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'node',
@@ -147,12 +127,14 @@ $result_trees{'contents_no_section'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
         'normalized' => 'Top',
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'line_nr' => {
         'file_name' => 'contents_no_section.texi',
@@ -180,27 +162,19 @@ $result_trees{'contents_no_section'}{'contents'}[0]{'contents'}[0]{'contents'}[0
 $result_trees{'contents_no_section'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'contents_no_section'}{'contents'}[0]{'contents'}[0]{'contents'}[0];
 $result_trees{'contents_no_section'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'contents_no_section'}{'contents'}[0]{'contents'}[0];
 $result_trees{'contents_no_section'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'contents_no_section'}{'contents'}[0];
-$result_trees{'contents_no_section'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'contents_no_section'}{'contents'}[0]{'contents'}[1];
 $result_trees{'contents_no_section'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'contents_no_section'}{'contents'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'contents_no_section'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'contents_no_section'}{'contents'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'contents_no_section'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'contents_no_section'}{'contents'}[0]{'contents'}[1]{'args'}[0];
 $result_trees{'contents_no_section'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'contents_no_section'}{'contents'}[0]{'contents'}[1];
-$result_trees{'contents_no_section'}{'contents'}[0]{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'contents_no_section'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'contents_no_section'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'contents_no_section'}{'contents'}[0];
 $result_trees{'contents_no_section'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'contents_no_section'}{'contents'}[0];
 $result_trees{'contents_no_section'}{'contents'}[0]{'parent'} = $result_trees{'contents_no_section'};
-$result_trees{'contents_no_section'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'contents_no_section'}{'contents'}[1];
 $result_trees{'contents_no_section'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'contents_no_section'}{'contents'}[1]{'args'}[0];
-$result_trees{'contents_no_section'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'contents_no_section'}{'contents'}[1]{'args'}[0];
-$result_trees{'contents_no_section'}{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'contents_no_section'}{'contents'}[1]{'args'}[0];
 $result_trees{'contents_no_section'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'contents_no_section'}{'contents'}[1];
 $result_trees{'contents_no_section'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'contents_no_section'}{'contents'}[1];
 $result_trees{'contents_no_section'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'contents_no_section'}{'contents'}[1]{'contents'}[1];
 $result_trees{'contents_no_section'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'contents_no_section'}{'contents'}[1];
 $result_trees{'contents_no_section'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'contents_no_section'}{'contents'}[1];
-$result_trees{'contents_no_section'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'contents_no_section'}{'contents'}[1]{'args'}[0]{'contents'}[1];
-$result_trees{'contents_no_section'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'contents_no_section'}{'contents'}[1]{'extra'}{'node_content'};
-$result_trees{'contents_no_section'}{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'contents_no_section'}{'contents'}[1]{'args'}[0]{'contents'}[0];
+$result_trees{'contents_no_section'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'contents_no_section'}{'contents'}[1]{'args'}[0]{'contents'}[0];
+$result_trees{'contents_no_section'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'contents_no_section'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'contents_no_section'}{'contents'}[1]{'parent'} = $result_trees{'contents_no_section'};
 $result_trees{'contents_no_section'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'contents_no_section'}{'contents'}[2];
 $result_trees{'contents_no_section'}{'contents'}[2]{'parent'} = $result_trees{'contents_no_section'};
@@ -227,30 +201,23 @@ $result_sectioning{'contents_no_section'} = {};
 $result_nodes{'contents_no_section'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top'
-  },
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   }
 };
-$result_nodes{'contents_no_section'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'contents_no_section'};
 
 $result_menus{'contents_no_section'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   }
 };
 
 $result_errors{'contents_no_section'} = [];
 
 
+$result_floats{'contents_no_section'} = {};
+
+
 1;
