@@ -55,7 +55,9 @@ $result_trees{'double_top'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           },
           {
@@ -201,7 +203,7 @@ $result_trees{'double_top'}{'contents'}[1]{'args'}[1]{'contents'}[0]{'parent'} =
 $result_trees{'double_top'}{'contents'}[1]{'args'}[1]{'parent'} = $result_trees{'double_top'}{'contents'}[1];
 $result_trees{'double_top'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'double_top'}{'contents'}[1];
 $result_trees{'double_top'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'double_top'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'double_top'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'double_top'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'double_top'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'double_top'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'double_top'}{'contents'}[1]{'extra'}{'nodes_manuals'}[1]{'node_content'}[0] = $result_trees{'double_top'}{'contents'}[1]{'args'}[1]{'contents'}[0];
 $result_trees{'double_top'}{'contents'}[1]{'parent'} = $result_trees{'double_top'};
 $result_trees{'double_top'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'double_top'}{'contents'}[2]{'args'}[0];
@@ -304,11 +306,14 @@ $result_errors{'double_top'} = [
 ];
 
 
+$result_floats{'double_top'} = {};
+
+
 
 $result_converted{'info'}->{'double_top'} = 'This is , produced from .
 
 
-File: ,  Node: Top,  Next: Top
+File: ,  Node: Top,  Next: Top,  Up: (dir)
 
 .
 
@@ -317,6 +322,11 @@ Tag Table:
 Node: Top27
 
 End Tag Table
+
+
+Local Variables:
+coding: utf-8
+End:
 ';
 
 
@@ -331,14 +341,16 @@ $result_converted{'html'}->{'double_top'} = '<!DOCTYPE html PUBLIC "-//W3C//DTD
 <meta name="keywords" content="Untitled Document">
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
+<meta name="viewport" content="width=device-width,initial-scale=1">
+
 <link href="#Top" rel="start" title="ToP">
 <style type="text/css">
 <!--
+a.copiable-anchor {visibility: hidden; text-decoration: none; line-height: 0em}
 a.summary-letter {text-decoration: none}
 blockquote.indentedblock {margin-right: 0em}
 div.display {margin-left: 3.2em}
 div.example {margin-left: 3.2em}
-div.lisp {margin-left: 3.2em}
 kbd {font-style: oblique}
 pre.display {font-family: inherit}
 pre.format {font-family: inherit}
@@ -347,6 +359,7 @@ pre.menu-preformatted {font-family: serif}
 span.nolinebreak {white-space: nowrap}
 span.roman {font-family: initial; font-weight: normal}
 span.sansserif {font-family: sans-serif; font-weight: normal}
+span:hover a.copiable-anchor {visibility: visible}
 ul.no-bullet {list-style: none}
 -->
 </style>
@@ -368,8 +381,7 @@ Next: <a href="#Top" accesskey="n" rel="next">ToP</a> &nbsp; </p>
 </div>
 
 <p>.
-</p><hr>
-
+</p>
 
 
 </body>
