@@ -1,19 +1,21 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
 $result_trees{'empty_node'} = {
   'contents' => [
     {
+      'contents' => [],
       'parent' => {},
-      'type' => 'before_node_section'
+      'type' => 'text_root'
     },
     {
       'args' => [
         {
+          'contents' => [],
           'extra' => {
             'spaces_after_argument' => '
 '
@@ -36,16 +38,17 @@ $result_trees{'empty_node'} = {
           undef
         ]
       },
-      'parent' => {},
-      'source_info' => {
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 1,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     },
     {
       'args' => [
         {
+          'contents' => [],
           'parent' => {},
           'type' => 'line_arg'
         },
@@ -92,6 +95,7 @@ $result_trees{'empty_node'} = {
         }
       ],
       'cmdname' => 'node',
+      'contents' => [],
       'extra' => {
         'nodes_manuals' => [
           undef,
@@ -116,12 +120,12 @@ $result_trees{'empty_node'} = {
         ],
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 3,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     }
   ],
   'type' => 'document_root'
@@ -151,9 +155,11 @@ $result_texis{'empty_node'} = '@node
 $result_texts{'empty_node'} = '
 ';
 
+$result_sectioning{'empty_node'} = {};
+
 $result_errors{'empty_node'} = [
   {
-    'error_line' => 'empty argument in @node
+    'error_line' => ':1: empty argument in @node
 ',
     'file_name' => '',
     'line_nr' => 1,
@@ -162,7 +168,7 @@ $result_errors{'empty_node'} = [
     'type' => 'error'
   },
   {
-    'error_line' => 'empty argument in @node
+    'error_line' => ':3: empty argument in @node
 ',
     'file_name' => '',
     'line_nr' => 3,
