@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
@@ -10,20 +10,24 @@ $result_trees{'empty_nodes_with_commands'} = {
     {
       'contents' => [
         {
+          'parent' => {},
           'text' => '
 ',
           'type' => 'empty_line'
         }
       ],
-      'type' => 'before_node_section'
+      'parent' => {},
+      'type' => 'text_root'
     },
     {
       'args' => [
         {
+          'contents' => [],
           'extra' => {
             'comment_at_end' => {
               'args' => [
                 {
+                  'parent' => {},
                   'text' => ' comment
 ',
                   'type' => 'misc_arg'
@@ -35,15 +39,18 @@ $result_trees{'empty_nodes_with_commands'} = {
                   ' comment
 '
                 ]
-              }
+              },
+              'parent' => {}
             }
           },
+          'parent' => {},
           'type' => 'line_arg'
         }
       ],
       'cmdname' => 'node',
       'contents' => [
         {
+          'parent' => {},
           'text' => '
 ',
           'type' => 'empty_line'
@@ -55,11 +62,12 @@ $result_trees{'empty_nodes_with_commands'} = {
         ],
         'spaces_before_argument' => ' '
       },
-      'source_info' => {
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 2,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     },
     {
       'args' => [
@@ -67,13 +75,16 @@ $result_trees{'empty_nodes_with_commands'} = {
           'contents' => [
             {
               'cmdname' => '
-'
+',
+              'parent' => {}
             }
           ],
+          'parent' => {},
           'type' => 'line_arg'
         }
       ],
       'cmdname' => 'node',
+      'contents' => [],
       'extra' => {
         'nodes_manuals' => [
           {
@@ -85,28 +96,32 @@ $result_trees{'empty_nodes_with_commands'} = {
         ],
         'spaces_before_argument' => ' '
       },
-      'source_info' => {
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 4,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     },
     {
       'args' => [
         {
           'contents' => [
             {
-              'cmdname' => ':'
+              'cmdname' => ':',
+              'parent' => {}
             }
           ],
           'extra' => {
             'spaces_after_argument' => '
 '
           },
+          'parent' => {},
           'type' => 'line_arg'
         }
       ],
       'cmdname' => 'node',
+      'contents' => [],
       'extra' => {
         'nodes_manuals' => [
           {
@@ -118,11 +133,12 @@ $result_trees{'empty_nodes_with_commands'} = {
         ],
         'spaces_before_argument' => ' '
       },
-      'source_info' => {
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 5,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     },
     {
       'args' => [
@@ -133,28 +149,34 @@ $result_trees{'empty_nodes_with_commands'} = {
                 {
                   'contents' => [
                     {
+                      'parent' => {},
                       'text' => ' '
                     }
                   ],
+                  'parent' => {},
                   'type' => 'brace_command_arg'
                 }
               ],
               'cmdname' => 'asis',
-              'source_info' => {
+              'contents' => [],
+              'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 6,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             }
           ],
           'extra' => {
             'spaces_after_argument' => '
 '
           },
+          'parent' => {},
           'type' => 'line_arg'
         }
       ],
       'cmdname' => 'node',
+      'contents' => [],
       'extra' => {
         'nodes_manuals' => [
           {
@@ -166,18 +188,37 @@ $result_trees{'empty_nodes_with_commands'} = {
         ],
         'spaces_before_argument' => ' '
       },
-      'source_info' => {
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 6,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     }
   ],
   'type' => 'document_root'
 };
+$result_trees{'empty_nodes_with_commands'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'empty_nodes_with_commands'}{'contents'}[0];
+$result_trees{'empty_nodes_with_commands'}{'contents'}[0]{'parent'} = $result_trees{'empty_nodes_with_commands'};
+$result_trees{'empty_nodes_with_commands'}{'contents'}[1]{'args'}[0]{'extra'}{'comment_at_end'}{'args'}[0]{'parent'} = $result_trees{'empty_nodes_with_commands'}{'contents'}[1]{'args'}[0]{'extra'}{'comment_at_end'};
+$result_trees{'empty_nodes_with_commands'}{'contents'}[1]{'args'}[0]{'extra'}{'comment_at_end'}{'parent'} = $result_trees{'empty_nodes_with_commands'}{'contents'}[1]{'args'}[0];
+$result_trees{'empty_nodes_with_commands'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'empty_nodes_with_commands'}{'contents'}[1];
+$result_trees{'empty_nodes_with_commands'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'empty_nodes_with_commands'}{'contents'}[1];
+$result_trees{'empty_nodes_with_commands'}{'contents'}[1]{'parent'} = $result_trees{'empty_nodes_with_commands'};
+$result_trees{'empty_nodes_with_commands'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'empty_nodes_with_commands'}{'contents'}[2]{'args'}[0];
+$result_trees{'empty_nodes_with_commands'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'empty_nodes_with_commands'}{'contents'}[2];
 $result_trees{'empty_nodes_with_commands'}{'contents'}[2]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'empty_nodes_with_commands'}{'contents'}[2]{'args'}[0]{'contents'}[0];
+$result_trees{'empty_nodes_with_commands'}{'contents'}[2]{'parent'} = $result_trees{'empty_nodes_with_commands'};
+$result_trees{'empty_nodes_with_commands'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'empty_nodes_with_commands'}{'contents'}[3]{'args'}[0];
+$result_trees{'empty_nodes_with_commands'}{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'empty_nodes_with_commands'}{'contents'}[3];
 $result_trees{'empty_nodes_with_commands'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'empty_nodes_with_commands'}{'contents'}[3]{'args'}[0]{'contents'}[0];
+$result_trees{'empty_nodes_with_commands'}{'contents'}[3]{'parent'} = $result_trees{'empty_nodes_with_commands'};
+$result_trees{'empty_nodes_with_commands'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'empty_nodes_with_commands'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'args'}[0];
+$result_trees{'empty_nodes_with_commands'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'empty_nodes_with_commands'}{'contents'}[4]{'args'}[0]{'contents'}[0];
+$result_trees{'empty_nodes_with_commands'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'empty_nodes_with_commands'}{'contents'}[4]{'args'}[0];
+$result_trees{'empty_nodes_with_commands'}{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'empty_nodes_with_commands'}{'contents'}[4];
 $result_trees{'empty_nodes_with_commands'}{'contents'}[4]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'empty_nodes_with_commands'}{'contents'}[4]{'args'}[0]{'contents'}[0];
+$result_trees{'empty_nodes_with_commands'}{'contents'}[4]{'parent'} = $result_trees{'empty_nodes_with_commands'};
 
 $result_texis{'empty_nodes_with_commands'} = '
 @node @c comment
@@ -192,9 +233,11 @@ $result_texts{'empty_nodes_with_commands'} = '
 
 ';
 
+$result_sectioning{'empty_nodes_with_commands'} = {};
+
 $result_errors{'empty_nodes_with_commands'} = [
   {
-    'error_line' => 'empty argument in @node
+    'error_line' => ':2: empty argument in @node
 ',
     'file_name' => '',
     'line_nr' => 2,
@@ -203,7 +246,7 @@ $result_errors{'empty_nodes_with_commands'} = [
     'type' => 'error'
   },
   {
-    'error_line' => 'empty node name after expansion `@
+    'error_line' => ':4: empty node name after expansion `@
 \'
 ',
     'file_name' => '',
@@ -214,7 +257,7 @@ $result_errors{'empty_nodes_with_commands'} = [
     'type' => 'error'
   },
   {
-    'error_line' => 'empty node name after expansion `@:\'
+    'error_line' => ':5: empty node name after expansion `@:\'
 ',
     'file_name' => '',
     'line_nr' => 5,
@@ -223,7 +266,7 @@ $result_errors{'empty_nodes_with_commands'} = [
     'type' => 'error'
   },
   {
-    'error_line' => 'empty node name after expansion `@asis{ }\'
+    'error_line' => ':6: empty node name after expansion `@asis{ }\'
 ',
     'file_name' => '',
     'line_nr' => 6,
