@@ -16,27 +16,17 @@ $result_trees{'no_menu'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'Top'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'node',
@@ -47,12 +37,14 @@ $result_trees{'no_menu'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
         'normalized' => 'Top',
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'line_nr' => {
         'file_name' => '',
@@ -64,19 +56,13 @@ $result_trees{'no_menu'} = {
     {
       'args' => [
         {
-          'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'empty_line_after_command'
-            }
-          ],
+          'contents' => [],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'top',
@@ -88,10 +74,7 @@ $result_trees{'no_menu'} = {
           'type' => 'empty_line'
         }
       ],
-      'extra' => {
-        'misc_content' => [],
-        'spaces_after_command' => {}
-      },
+      'extra' => {},
       'level' => 0,
       'line_nr' => {
         'file_name' => '',
@@ -104,27 +87,17 @@ $result_trees{'no_menu'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'c1'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'node',
@@ -135,12 +108,14 @@ $result_trees{'no_menu'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'c1'
           }
         ],
         'normalized' => 'c1',
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'line_nr' => {
         'file_name' => '',
@@ -153,27 +128,17 @@ $result_trees{'no_menu'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'c1'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'chapter',
@@ -186,10 +151,7 @@ $result_trees{'no_menu'} = {
         }
       ],
       'extra' => {
-        'misc_content' => [
-          {}
-        ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'level' => 1,
       'line_nr' => {
@@ -204,27 +166,17 @@ $result_trees{'no_menu'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'c2'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'node',
@@ -235,12 +187,14 @@ $result_trees{'no_menu'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'c2'
           }
         ],
         'normalized' => 'c2',
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'line_nr' => {
         'file_name' => '',
@@ -253,27 +207,17 @@ $result_trees{'no_menu'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'c2'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'chapter',
@@ -286,10 +230,7 @@ $result_trees{'no_menu'} = {
         }
       ],
       'extra' => {
-        'misc_content' => [
-          {}
-        ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'level' => 1,
       'line_nr' => {
@@ -304,27 +245,17 @@ $result_trees{'no_menu'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'c3'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'node',
@@ -335,12 +266,14 @@ $result_trees{'no_menu'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'c3'
           }
         ],
         'normalized' => 'c3',
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'line_nr' => {
         'file_name' => '',
@@ -353,36 +286,23 @@ $result_trees{'no_menu'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'c3'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'chapter',
       'contents' => [],
       'extra' => {
-        'misc_content' => [
-          {}
-        ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'level' => 1,
       'line_nr' => {
@@ -397,73 +317,39 @@ $result_trees{'no_menu'} = {
   'type' => 'document_root'
 };
 $result_trees{'no_menu'}{'contents'}[0]{'parent'} = $result_trees{'no_menu'};
-$result_trees{'no_menu'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'no_menu'}{'contents'}[1];
 $result_trees{'no_menu'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'no_menu'}{'contents'}[1]{'args'}[0];
-$result_trees{'no_menu'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'no_menu'}{'contents'}[1]{'args'}[0];
-$result_trees{'no_menu'}{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'no_menu'}{'contents'}[1]{'args'}[0];
 $result_trees{'no_menu'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'no_menu'}{'contents'}[1];
-$result_trees{'no_menu'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'no_menu'}{'contents'}[1]{'args'}[0]{'contents'}[1];
-$result_trees{'no_menu'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'no_menu'}{'contents'}[1]{'extra'}{'node_content'};
-$result_trees{'no_menu'}{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'no_menu'}{'contents'}[1]{'args'}[0]{'contents'}[0];
+$result_trees{'no_menu'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'no_menu'}{'contents'}[1]{'args'}[0]{'contents'}[0];
+$result_trees{'no_menu'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'no_menu'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'no_menu'}{'contents'}[1]{'parent'} = $result_trees{'no_menu'};
-$result_trees{'no_menu'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'no_menu'}{'contents'}[2];
-$result_trees{'no_menu'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'no_menu'}{'contents'}[2]{'args'}[0];
 $result_trees{'no_menu'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'no_menu'}{'contents'}[2];
 $result_trees{'no_menu'}{'contents'}[2]{'contents'}[0]{'parent'} = $result_trees{'no_menu'}{'contents'}[2];
-$result_trees{'no_menu'}{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'no_menu'}{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'no_menu'}{'contents'}[2]{'parent'} = $result_trees{'no_menu'};
-$result_trees{'no_menu'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'no_menu'}{'contents'}[3];
 $result_trees{'no_menu'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'no_menu'}{'contents'}[3]{'args'}[0];
-$result_trees{'no_menu'}{'contents'}[3]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'no_menu'}{'contents'}[3]{'args'}[0];
-$result_trees{'no_menu'}{'contents'}[3]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'no_menu'}{'contents'}[3]{'args'}[0];
 $result_trees{'no_menu'}{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'no_menu'}{'contents'}[3];
-$result_trees{'no_menu'}{'contents'}[3]{'extra'}{'node_content'}[0] = $result_trees{'no_menu'}{'contents'}[3]{'args'}[0]{'contents'}[1];
-$result_trees{'no_menu'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'no_menu'}{'contents'}[3]{'extra'}{'node_content'};
-$result_trees{'no_menu'}{'contents'}[3]{'extra'}{'spaces_after_command'} = $result_trees{'no_menu'}{'contents'}[3]{'args'}[0]{'contents'}[0];
+$result_trees{'no_menu'}{'contents'}[3]{'extra'}{'node_content'}[0] = $result_trees{'no_menu'}{'contents'}[3]{'args'}[0]{'contents'}[0];
+$result_trees{'no_menu'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'no_menu'}{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'no_menu'}{'contents'}[3]{'parent'} = $result_trees{'no_menu'};
-$result_trees{'no_menu'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'no_menu'}{'contents'}[4];
 $result_trees{'no_menu'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'no_menu'}{'contents'}[4]{'args'}[0];
-$result_trees{'no_menu'}{'contents'}[4]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'no_menu'}{'contents'}[4]{'args'}[0];
-$result_trees{'no_menu'}{'contents'}[4]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'no_menu'}{'contents'}[4]{'args'}[0];
 $result_trees{'no_menu'}{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'no_menu'}{'contents'}[4];
 $result_trees{'no_menu'}{'contents'}[4]{'contents'}[0]{'parent'} = $result_trees{'no_menu'}{'contents'}[4];
-$result_trees{'no_menu'}{'contents'}[4]{'extra'}{'misc_content'}[0] = $result_trees{'no_menu'}{'contents'}[4]{'args'}[0]{'contents'}[1];
-$result_trees{'no_menu'}{'contents'}[4]{'extra'}{'spaces_after_command'} = $result_trees{'no_menu'}{'contents'}[4]{'args'}[0]{'contents'}[0];
 $result_trees{'no_menu'}{'contents'}[4]{'parent'} = $result_trees{'no_menu'};
-$result_trees{'no_menu'}{'contents'}[5]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'no_menu'}{'contents'}[5];
 $result_trees{'no_menu'}{'contents'}[5]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'no_menu'}{'contents'}[5]{'args'}[0];
-$result_trees{'no_menu'}{'contents'}[5]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'no_menu'}{'contents'}[5]{'args'}[0];
-$result_trees{'no_menu'}{'contents'}[5]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'no_menu'}{'contents'}[5]{'args'}[0];
 $result_trees{'no_menu'}{'contents'}[5]{'args'}[0]{'parent'} = $result_trees{'no_menu'}{'contents'}[5];
-$result_trees{'no_menu'}{'contents'}[5]{'extra'}{'node_content'}[0] = $result_trees{'no_menu'}{'contents'}[5]{'args'}[0]{'contents'}[1];
-$result_trees{'no_menu'}{'contents'}[5]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'no_menu'}{'contents'}[5]{'extra'}{'node_content'};
-$result_trees{'no_menu'}{'contents'}[5]{'extra'}{'spaces_after_command'} = $result_trees{'no_menu'}{'contents'}[5]{'args'}[0]{'contents'}[0];
+$result_trees{'no_menu'}{'contents'}[5]{'extra'}{'node_content'}[0] = $result_trees{'no_menu'}{'contents'}[5]{'args'}[0]{'contents'}[0];
+$result_trees{'no_menu'}{'contents'}[5]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'no_menu'}{'contents'}[5]{'args'}[0]{'contents'}[0];
 $result_trees{'no_menu'}{'contents'}[5]{'parent'} = $result_trees{'no_menu'};
-$result_trees{'no_menu'}{'contents'}[6]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'no_menu'}{'contents'}[6];
 $result_trees{'no_menu'}{'contents'}[6]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'no_menu'}{'contents'}[6]{'args'}[0];
-$result_trees{'no_menu'}{'contents'}[6]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'no_menu'}{'contents'}[6]{'args'}[0];
-$result_trees{'no_menu'}{'contents'}[6]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'no_menu'}{'contents'}[6]{'args'}[0];
 $result_trees{'no_menu'}{'contents'}[6]{'args'}[0]{'parent'} = $result_trees{'no_menu'}{'contents'}[6];
 $result_trees{'no_menu'}{'contents'}[6]{'contents'}[0]{'parent'} = $result_trees{'no_menu'}{'contents'}[6];
-$result_trees{'no_menu'}{'contents'}[6]{'extra'}{'misc_content'}[0] = $result_trees{'no_menu'}{'contents'}[6]{'args'}[0]{'contents'}[1];
-$result_trees{'no_menu'}{'contents'}[6]{'extra'}{'spaces_after_command'} = $result_trees{'no_menu'}{'contents'}[6]{'args'}[0]{'contents'}[0];
 $result_trees{'no_menu'}{'contents'}[6]{'parent'} = $result_trees{'no_menu'};
-$result_trees{'no_menu'}{'contents'}[7]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'no_menu'}{'contents'}[7];
 $result_trees{'no_menu'}{'contents'}[7]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'no_menu'}{'contents'}[7]{'args'}[0];
-$result_trees{'no_menu'}{'contents'}[7]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'no_menu'}{'contents'}[7]{'args'}[0];
-$result_trees{'no_menu'}{'contents'}[7]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'no_menu'}{'contents'}[7]{'args'}[0];
 $result_trees{'no_menu'}{'contents'}[7]{'args'}[0]{'parent'} = $result_trees{'no_menu'}{'contents'}[7];
-$result_trees{'no_menu'}{'contents'}[7]{'extra'}{'node_content'}[0] = $result_trees{'no_menu'}{'contents'}[7]{'args'}[0]{'contents'}[1];
-$result_trees{'no_menu'}{'contents'}[7]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'no_menu'}{'contents'}[7]{'extra'}{'node_content'};
-$result_trees{'no_menu'}{'contents'}[7]{'extra'}{'spaces_after_command'} = $result_trees{'no_menu'}{'contents'}[7]{'args'}[0]{'contents'}[0];
+$result_trees{'no_menu'}{'contents'}[7]{'extra'}{'node_content'}[0] = $result_trees{'no_menu'}{'contents'}[7]{'args'}[0]{'contents'}[0];
+$result_trees{'no_menu'}{'contents'}[7]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'no_menu'}{'contents'}[7]{'args'}[0]{'contents'}[0];
 $result_trees{'no_menu'}{'contents'}[7]{'parent'} = $result_trees{'no_menu'};
-$result_trees{'no_menu'}{'contents'}[8]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'no_menu'}{'contents'}[8];
 $result_trees{'no_menu'}{'contents'}[8]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'no_menu'}{'contents'}[8]{'args'}[0];
-$result_trees{'no_menu'}{'contents'}[8]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'no_menu'}{'contents'}[8]{'args'}[0];
-$result_trees{'no_menu'}{'contents'}[8]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'no_menu'}{'contents'}[8]{'args'}[0];
 $result_trees{'no_menu'}{'contents'}[8]{'args'}[0]{'parent'} = $result_trees{'no_menu'}{'contents'}[8];
-$result_trees{'no_menu'}{'contents'}[8]{'extra'}{'misc_content'}[0] = $result_trees{'no_menu'}{'contents'}[8]{'args'}[0]{'contents'}[1];
-$result_trees{'no_menu'}{'contents'}[8]{'extra'}{'spaces_after_command'} = $result_trees{'no_menu'}{'contents'}[8]{'args'}[0]{'contents'}[0];
 $result_trees{'no_menu'}{'contents'}[8]{'parent'} = $result_trees{'no_menu'};
 
 $result_texis{'no_menu'} = '@node Top
@@ -500,7 +386,8 @@ $result_sectioning{'no_menu'} = {
         'associated_node' => {
           'cmdname' => 'node',
           'extra' => {
-            'normalized' => 'Top'
+            'normalized' => 'Top',
+            'spaces_before_argument' => ' '
           }
         }
       },
@@ -512,9 +399,11 @@ $result_sectioning{'no_menu'} = {
             'associated_node' => {
               'cmdname' => 'node',
               'extra' => {
-                'normalized' => 'c1'
+                'normalized' => 'c1',
+                'spaces_before_argument' => ' '
               }
-            }
+            },
+            'spaces_before_argument' => ' '
           },
           'level' => 1,
           'number' => 1,
@@ -528,9 +417,11 @@ $result_sectioning{'no_menu'} = {
             'associated_node' => {
               'cmdname' => 'node',
               'extra' => {
-                'normalized' => 'c2'
+                'normalized' => 'c2',
+                'spaces_before_argument' => ' '
               }
-            }
+            },
+            'spaces_before_argument' => ' '
           },
           'level' => 1,
           'number' => 2,
@@ -545,9 +436,11 @@ $result_sectioning{'no_menu'} = {
             'associated_node' => {
               'cmdname' => 'node',
               'extra' => {
-                'normalized' => 'c3'
+                'normalized' => 'c3',
+                'spaces_before_argument' => ' '
               }
-            }
+            },
+            'spaces_before_argument' => ' '
           },
           'level' => 1,
           'number' => 3,
@@ -582,37 +475,87 @@ $result_nodes{'no_menu'} = {
       'extra' => {},
       'level' => 0
     },
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   },
-  'node_up' => {
+  'node_next' => {
+    'cmdname' => 'node',
     'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
+      'associated_section' => {
+        'cmdname' => 'chapter',
+        'extra' => {
+          'spaces_before_argument' => ' '
+        },
+        'level' => 1,
+        'number' => 1
+      },
+      'normalized' => 'c1',
+      'spaces_before_argument' => ' '
     },
-    'type' => 'top_node_up'
+    'node_next' => {
+      'cmdname' => 'node',
+      'extra' => {
+        'associated_section' => {
+          'cmdname' => 'chapter',
+          'extra' => {
+            'spaces_before_argument' => ' '
+          },
+          'level' => 1,
+          'number' => 2
+        },
+        'normalized' => 'c2',
+        'spaces_before_argument' => ' '
+      },
+      'node_next' => {
+        'cmdname' => 'node',
+        'extra' => {
+          'associated_section' => {
+            'cmdname' => 'chapter',
+            'extra' => {
+              'spaces_before_argument' => ' '
+            },
+            'level' => 1,
+            'number' => 3
+          },
+          'normalized' => 'c3',
+          'spaces_before_argument' => ' '
+        },
+        'node_prev' => {},
+        'node_up' => {}
+      },
+      'node_prev' => {},
+      'node_up' => {}
+    },
+    'node_prev' => {},
+    'node_up' => {}
   }
 };
-$result_nodes{'no_menu'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'no_menu'};
+$result_nodes{'no_menu'}{'node_next'}{'node_next'}{'node_next'}{'node_prev'} = $result_nodes{'no_menu'}{'node_next'}{'node_next'};
+$result_nodes{'no_menu'}{'node_next'}{'node_next'}{'node_next'}{'node_up'} = $result_nodes{'no_menu'};
+$result_nodes{'no_menu'}{'node_next'}{'node_next'}{'node_prev'} = $result_nodes{'no_menu'}{'node_next'};
+$result_nodes{'no_menu'}{'node_next'}{'node_next'}{'node_up'} = $result_nodes{'no_menu'};
+$result_nodes{'no_menu'}{'node_next'}{'node_prev'} = $result_nodes{'no_menu'};
+$result_nodes{'no_menu'}{'node_next'}{'node_up'} = $result_nodes{'no_menu'};
 
 $result_menus{'no_menu'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   }
 };
 
 $result_errors{'no_menu'} = [];
 
 
+$result_floats{'no_menu'} = {};
+
+
 
 $result_converted{'info'}->{'no_menu'} = 'This is , produced from .
 
 
-File: ,  Node: Top,  Up: (dir)
+File: ,  Node: Top,  Next: c1,  Up: (dir)
 
 * Menu:
 
@@ -621,7 +564,7 @@ File: ,  Node: Top,  Up: (dir)
 * c3::
 
 
-File: ,  Node: c1,  Next: c2,  Up: Top
+File: ,  Node: c1,  Next: c2,  Prev: Top,  Up: Top
 
 1 c1
 ****
@@ -642,11 +585,16 @@ File: ,  Node: c3,  Prev: c2,  Up: Top
 
 Tag Table:
 Node: Top27
-Node: c192
-Node: c2145
-Node: c3209
+Node: c1103
+Node: c2168
+Node: c3232
 
 End Tag Table
+
+
+Local Variables:
+coding: utf-8
+End:
 ';
 
 
@@ -661,31 +609,25 @@ $result_converted{'html'}->{'no_menu'} = '<!DOCTYPE html PUBLIC "-//W3C//DTD HTM
 <meta name="keywords" content="Untitled Document">
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
+<meta name="viewport" content="width=device-width,initial-scale=1">
+
 <link href="#Top" rel="start" title="Top">
 <style type="text/css">
 <!--
+a.copiable-anchor {visibility: hidden; text-decoration: none; line-height: 0em}
 a.summary-letter {text-decoration: none}
 blockquote.indentedblock {margin-right: 0em}
-blockquote.smallindentedblock {margin-right: 0em; font-size: smaller}
-blockquote.smallquotation {font-size: smaller}
 div.display {margin-left: 3.2em}
 div.example {margin-left: 3.2em}
-div.lisp {margin-left: 3.2em}
-div.smalldisplay {margin-left: 3.2em}
-div.smallexample {margin-left: 3.2em}
-div.smalllisp {margin-left: 3.2em}
 kbd {font-style: oblique}
 pre.display {font-family: inherit}
 pre.format {font-family: inherit}
 pre.menu-comment {font-family: serif}
 pre.menu-preformatted {font-family: serif}
-pre.smalldisplay {font-family: inherit; font-size: smaller}
-pre.smallexample {font-size: smaller}
-pre.smallformat {font-family: inherit; font-size: smaller}
-pre.smalllisp {font-size: smaller}
 span.nolinebreak {white-space: nowrap}
 span.roman {font-family: initial; font-weight: normal}
 span.sansserif {font-family: sans-serif; font-weight: normal}
+span:hover a.copiable-anchor {visibility: visible}
 ul.no-bullet {list-style: none}
 -->
 </style>
@@ -694,49 +636,44 @@ ul.no-bullet {list-style: none}
 </head>
 
 <body lang="en">
-<a name="Top"></a>
+<div class="top" id="Top">
 <div class="header">
 <p>
-Up: <a href="dir.html#Top" accesskey="u" rel="up">(dir)</a> &nbsp; </p>
+Next: <a href="#c1" accesskey="n" rel="next">c1</a> &nbsp; </p>
 </div>
-<a name="SEC_Top"></a>
-
-<table class="menu" border="0" cellspacing="0">
-<tr><td align="left" valign="top">&bull; <a href="#c1" accesskey="1">c1</a>:</td><td>&nbsp;&nbsp;</td><td align="left" valign="top">
-</td></tr>
-<tr><td align="left" valign="top">&bull; <a href="#c2" accesskey="2">c2</a>:</td><td>&nbsp;&nbsp;</td><td align="left" valign="top">
-</td></tr>
-<tr><td align="left" valign="top">&bull; <a href="#c3" accesskey="3">c3</a>:</td><td>&nbsp;&nbsp;</td><td align="left" valign="top">
-</td></tr>
-</table>
-
+<span id="SEC_Top"></span>
+<ul class="section-toc">
+<li><a href="#c1" accesskey="1">c1</a></li>
+<li><a href="#c2" accesskey="2">c2</a></li>
+<li><a href="#c3" accesskey="3">c3</a></li>
+</ul>
 <hr>
-<a name="c1"></a>
+<div class="chapter" id="c1">
 <div class="header">
 <p>
-Next: <a href="#c2" accesskey="n" rel="next">c2</a>, Up: <a href="#Top" accesskey="u" rel="up">Top</a> &nbsp; </p>
+Next: <a href="#c2" accesskey="n" rel="next">c2</a> &nbsp; </p>
 </div>
-<a name="c1-1"></a>
-<h2 class="chapter">1 c1</h2>
+<span id="c1-1"></span><h2 class="chapter">1 c1</h2>
 
 <hr>
-<a name="c2"></a>
+</div>
+<div class="chapter" id="c2">
 <div class="header">
 <p>
-Next: <a href="#c3" accesskey="n" rel="next">c3</a>, Previous: <a href="#c1" accesskey="p" rel="prev">c1</a>, Up: <a href="#Top" accesskey="u" rel="up">Top</a> &nbsp; </p>
+Next: <a href="#c3" accesskey="n" rel="next">c3</a>, Previous: <a href="#c1" accesskey="p" rel="prev">c1</a> &nbsp; </p>
 </div>
-<a name="c2-1"></a>
-<h2 class="chapter">2 c2</h2>
+<span id="c2-1"></span><h2 class="chapter">2 c2</h2>
 
 <hr>
-<a name="c3"></a>
+</div>
+<div class="chapter" id="c3">
 <div class="header">
 <p>
-Previous: <a href="#c2" accesskey="p" rel="prev">c2</a>, Up: <a href="#Top" accesskey="u" rel="up">Top</a> &nbsp; </p>
+Previous: <a href="#c2" accesskey="p" rel="prev">c2</a> &nbsp; </p>
+</div>
+<span id="c3-1"></span><h2 class="chapter">3 c3</h2>
+</div>
 </div>
-<a name="c3-1"></a>
-<h2 class="chapter">3 c3</h2>
-<hr>
 
 
 
