@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
@@ -17,7 +17,7 @@ $result_trees{'node_line_arguments'} = {
         }
       ],
       'parent' => {},
-      'type' => 'before_node_section'
+      'type' => 'text_root'
     },
     {
       'args' => [
@@ -37,6 +37,7 @@ $result_trees{'node_line_arguments'} = {
         }
       ],
       'cmdname' => 'node',
+      'contents' => [],
       'extra' => {
         'node_content' => [
           {}
@@ -52,12 +53,12 @@ $result_trees{'node_line_arguments'} = {
         'normalized' => 'one-arg1',
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 2,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     },
     {
       'args' => [
@@ -88,6 +89,7 @@ $result_trees{'node_line_arguments'} = {
         }
       ],
       'cmdname' => 'node',
+      'contents' => [],
       'extra' => {
         'node_content' => [
           {}
@@ -109,12 +111,12 @@ $result_trees{'node_line_arguments'} = {
         'normalized' => 'one-arg2',
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 3,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     },
     {
       'args' => [
@@ -158,6 +160,7 @@ $result_trees{'node_line_arguments'} = {
         }
       ],
       'cmdname' => 'node',
+      'contents' => [],
       'extra' => {
         'node_content' => [
           {}
@@ -185,12 +188,12 @@ $result_trees{'node_line_arguments'} = {
         'normalized' => 'one-arg3',
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 4,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     },
     {
       'args' => [
@@ -247,6 +250,7 @@ $result_trees{'node_line_arguments'} = {
         }
       ],
       'cmdname' => 'node',
+      'contents' => [],
       'extra' => {
         'node_content' => [
           {}
@@ -280,12 +284,12 @@ $result_trees{'node_line_arguments'} = {
         'normalized' => 'one-arg4',
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 5,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     },
     {
       'args' => [
@@ -383,12 +387,12 @@ $result_trees{'node_line_arguments'} = {
         'normalized' => 'one-arg5',
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 6,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     },
     {
       'args' => [
@@ -448,12 +452,12 @@ $result_trees{'node_line_arguments'} = {
         'normalized' => 'comment',
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 8,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     },
     {
       'args' => [
@@ -466,17 +470,19 @@ $result_trees{'node_line_arguments'} = {
             {
               'args' => [
                 {
+                  'contents' => [],
                   'parent' => {},
                   'type' => 'brace_command_arg'
                 }
               ],
               'cmdname' => 'comma',
-              'parent' => {},
-              'source_info' => {
+              'contents' => [],
+              'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 10,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             },
             {
               'parent' => {},
@@ -502,12 +508,13 @@ $result_trees{'node_line_arguments'} = {
                 }
               ],
               'cmdname' => ',',
-              'parent' => {},
-              'source_info' => {
+              'contents' => [],
+              'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 10,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             },
             {
               'parent' => {},
@@ -536,12 +543,13 @@ $result_trees{'node_line_arguments'} = {
                 }
               ],
               'cmdname' => 'strong',
-              'parent' => {},
-              'source_info' => {
+              'contents' => [],
+              'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 10,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             }
           ],
           'extra' => {
@@ -571,6 +579,7 @@ $result_trees{'node_line_arguments'} = {
         }
       ],
       'cmdname' => 'node',
+      'contents' => [],
       'extra' => {
         'node_content' => [
           {},
@@ -603,12 +612,12 @@ $result_trees{'node_line_arguments'} = {
         'normalized' => 'arg1-_002c-arg2',
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 10,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     }
   ],
   'type' => 'document_root'
@@ -721,23 +730,27 @@ $result_texts{'node_line_arguments'} = '
 
 ';
 
+$result_sectioning{'node_line_arguments'} = {};
+
 $result_nodes{'node_line_arguments'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'one-arg1'
+    'normalized' => 'one-arg1',
+    'spaces_before_argument' => ' '
   }
 };
 
 $result_menus{'node_line_arguments'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'one-arg1'
+    'normalized' => 'one-arg1',
+    'spaces_before_argument' => ' '
   }
 };
 
 $result_errors{'node_line_arguments'} = [
   {
-    'error_line' => 'warning: superfluous arguments for node
+    'error_line' => ':6: warning: superfluous arguments for node
 ',
     'file_name' => '',
     'line_nr' => 6,
@@ -746,7 +759,7 @@ $result_errors{'node_line_arguments'} = [
     'type' => 'warning'
   },
   {
-    'error_line' => 'Next reference to nonexistent `two arg\'
+    'error_line' => ':3: Next reference to nonexistent `two arg\'
 ',
     'file_name' => '',
     'line_nr' => 3,
@@ -755,7 +768,7 @@ $result_errors{'node_line_arguments'} = [
     'type' => 'error'
   },
   {
-    'error_line' => 'Next reference to nonexistent `two arg\'
+    'error_line' => ':4: Next reference to nonexistent `two arg\'
 ',
     'file_name' => '',
     'line_nr' => 4,
@@ -764,7 +777,7 @@ $result_errors{'node_line_arguments'} = [
     'type' => 'error'
   },
   {
-    'error_line' => 'Prev reference to nonexistent `three arg\'
+    'error_line' => ':4: Prev reference to nonexistent `three arg\'
 ',
     'file_name' => '',
     'line_nr' => 4,
@@ -773,7 +786,7 @@ $result_errors{'node_line_arguments'} = [
     'type' => 'error'
   },
   {
-    'error_line' => 'Next reference to nonexistent `two arg\'
+    'error_line' => ':5: Next reference to nonexistent `two arg\'
 ',
     'file_name' => '',
     'line_nr' => 5,
@@ -782,7 +795,7 @@ $result_errors{'node_line_arguments'} = [
     'type' => 'error'
   },
   {
-    'error_line' => 'Prev reference to nonexistent `three arg\'
+    'error_line' => ':5: Prev reference to nonexistent `three arg\'
 ',
     'file_name' => '',
     'line_nr' => 5,
@@ -791,7 +804,7 @@ $result_errors{'node_line_arguments'} = [
     'type' => 'error'
   },
   {
-    'error_line' => 'Up reference to nonexistent `four arg\'
+    'error_line' => ':5: Up reference to nonexistent `four arg\'
 ',
     'file_name' => '',
     'line_nr' => 5,
@@ -800,7 +813,7 @@ $result_errors{'node_line_arguments'} = [
     'type' => 'error'
   },
   {
-    'error_line' => 'Next reference to nonexistent `two arg\'
+    'error_line' => ':6: Next reference to nonexistent `two arg\'
 ',
     'file_name' => '',
     'line_nr' => 6,
@@ -809,7 +822,7 @@ $result_errors{'node_line_arguments'} = [
     'type' => 'error'
   },
   {
-    'error_line' => 'Prev reference to nonexistent `three arg\'
+    'error_line' => ':6: Prev reference to nonexistent `three arg\'
 ',
     'file_name' => '',
     'line_nr' => 6,
@@ -818,7 +831,7 @@ $result_errors{'node_line_arguments'} = [
     'type' => 'error'
   },
   {
-    'error_line' => 'Up reference to nonexistent `four arg five arg\'
+    'error_line' => ':6: Up reference to nonexistent `four arg five arg\'
 ',
     'file_name' => '',
     'line_nr' => 6,
@@ -827,7 +840,7 @@ $result_errors{'node_line_arguments'} = [
     'type' => 'error'
   },
   {
-    'error_line' => 'Next reference to nonexistent `@,cedilla\'
+    'error_line' => ':10: Next reference to nonexistent `@,cedilla\'
 ',
     'file_name' => '',
     'line_nr' => 10,
@@ -836,7 +849,7 @@ $result_errors{'node_line_arguments'} = [
     'type' => 'error'
   },
   {
-    'error_line' => 'Prev reference to nonexistent `@strong{comma in strong,}\'
+    'error_line' => ':10: Prev reference to nonexistent `@strong{comma in strong,}\'
 ',
     'file_name' => '',
     'line_nr' => 10,
@@ -845,7 +858,7 @@ $result_errors{'node_line_arguments'} = [
     'type' => 'error'
   },
   {
-    'error_line' => 'warning: node `one arg2\' unreferenced
+    'error_line' => ':3: warning: node `one arg2\' unreferenced
 ',
     'file_name' => '',
     'line_nr' => 3,
@@ -854,7 +867,7 @@ $result_errors{'node_line_arguments'} = [
     'type' => 'warning'
   },
   {
-    'error_line' => 'warning: node `one arg3\' unreferenced
+    'error_line' => ':4: warning: node `one arg3\' unreferenced
 ',
     'file_name' => '',
     'line_nr' => 4,
@@ -863,7 +876,7 @@ $result_errors{'node_line_arguments'} = [
     'type' => 'warning'
   },
   {
-    'error_line' => 'warning: node `one arg4\' unreferenced
+    'error_line' => ':5: warning: node `one arg4\' unreferenced
 ',
     'file_name' => '',
     'line_nr' => 5,
@@ -872,7 +885,7 @@ $result_errors{'node_line_arguments'} = [
     'type' => 'warning'
   },
   {
-    'error_line' => 'warning: node `one arg5\' unreferenced
+    'error_line' => ':6: warning: node `one arg5\' unreferenced
 ',
     'file_name' => '',
     'line_nr' => 6,
@@ -881,7 +894,7 @@ $result_errors{'node_line_arguments'} = [
     'type' => 'warning'
   },
   {
-    'error_line' => 'warning: node `comment\' unreferenced
+    'error_line' => ':8: warning: node `comment\' unreferenced
 ',
     'file_name' => '',
     'line_nr' => 8,
@@ -890,7 +903,7 @@ $result_errors{'node_line_arguments'} = [
     'type' => 'warning'
   },
   {
-    'error_line' => 'warning: node `arg1 @comma{} arg2\' unreferenced
+    'error_line' => ':10: warning: node `arg1 @comma{} arg2\' unreferenced
 ',
     'file_name' => '',
     'line_nr' => 10,
