@@ -38,7 +38,9 @@ $result_trees{'part_chapter_after_top'} = [
           ],
           'nodes_manuals' => [
             {
-              'node_content' => [],
+              'node_content' => [
+                {}
+              ],
               'normalized' => 'Top'
             }
           ],
@@ -277,7 +279,9 @@ $result_trees{'part_chapter_after_top'} = [
           ],
           'nodes_manuals' => [
             {
-              'node_content' => [],
+              'node_content' => [
+                {}
+              ],
               'normalized' => 'chapter'
             }
           ],
@@ -337,7 +341,7 @@ $result_trees{'part_chapter_after_top'}[0]{'contents'}[0]{'parent'} = $result_tr
 $result_trees{'part_chapter_after_top'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'part_chapter_after_top'}[0]{'contents'}[1]{'args'}[0];
 $result_trees{'part_chapter_after_top'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'part_chapter_after_top'}[0]{'contents'}[1];
 $result_trees{'part_chapter_after_top'}[0]{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'part_chapter_after_top'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'part_chapter_after_top'}[0]{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'part_chapter_after_top'}[0]{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'part_chapter_after_top'}[0]{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'part_chapter_after_top'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'part_chapter_after_top'}[0]{'contents'}[1]{'parent'} = $result_trees{'part_chapter_after_top'}[0];
 $result_trees{'part_chapter_after_top'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'part_chapter_after_top'}[0]{'contents'}[2]{'args'}[0];
 $result_trees{'part_chapter_after_top'}[0]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'part_chapter_after_top'}[0]{'contents'}[2];
@@ -371,7 +375,7 @@ $result_trees{'part_chapter_after_top'}[1]{'contents'}[0]{'parent'} = $result_tr
 $result_trees{'part_chapter_after_top'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'part_chapter_after_top'}[1]{'contents'}[1]{'args'}[0];
 $result_trees{'part_chapter_after_top'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'part_chapter_after_top'}[1]{'contents'}[1];
 $result_trees{'part_chapter_after_top'}[1]{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'part_chapter_after_top'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'part_chapter_after_top'}[1]{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'part_chapter_after_top'}[1]{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'part_chapter_after_top'}[1]{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'part_chapter_after_top'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'part_chapter_after_top'}[1]{'contents'}[1]{'parent'} = $result_trees{'part_chapter_after_top'}[1];
 $result_trees{'part_chapter_after_top'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'part_chapter_after_top'}[1]{'contents'}[2]{'args'}[0];
 $result_trees{'part_chapter_after_top'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'part_chapter_after_top'}[1]{'contents'}[2];
@@ -520,23 +524,11 @@ $result_nodes{'part_chapter_after_top'} = {
       }
     }
   ],
-  'node_next' => {},
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
-  }
+  'node_next' => {}
 };
 $result_nodes{'part_chapter_after_top'}{'menu_child'}{'node_prev'} = $result_nodes{'part_chapter_after_top'};
 $result_nodes{'part_chapter_after_top'}{'menu_child'}{'node_up'} = $result_nodes{'part_chapter_after_top'};
 $result_nodes{'part_chapter_after_top'}{'node_next'} = $result_nodes{'part_chapter_after_top'}{'menu_child'};
-$result_nodes{'part_chapter_after_top'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'part_chapter_after_top'};
 
 $result_menus{'part_chapter_after_top'} = {
   'cmdname' => 'node',
@@ -561,6 +553,9 @@ $result_menus{'part_chapter_after_top'}{'menu_child'}{'menu_up'} = $result_menus
 $result_errors{'part_chapter_after_top'} = [];
 
 
+$result_floats{'part_chapter_after_top'} = {};
+
+
 $result_elements{'part_chapter_after_top'} = [
   {
     'extra' => {
@@ -616,17 +611,6 @@ $result_elements{'part_chapter_after_top'} = [
         'Next' => {},
         'NodeForward' => {},
         'NodeNext' => {},
-        'NodeUp' => {
-          'extra' => {
-            'manual_content' => [
-              {
-                'text' => 'dir'
-              }
-            ],
-            'top_node_up' => {}
-          },
-          'type' => 'external_node'
-        },
         'This' => {}
       },
       'element_command' => {
@@ -655,7 +639,6 @@ $result_elements{'part_chapter_after_top'}[0]{'extra'}{'directions'}{'Forward'}
 $result_elements{'part_chapter_after_top'}[0]{'extra'}{'directions'}{'Next'} = $result_elements{'part_chapter_after_top'}[0]{'extra'}{'directions'}{'FastForward'};
 $result_elements{'part_chapter_after_top'}[0]{'extra'}{'directions'}{'NodeForward'} = $result_elements{'part_chapter_after_top'}[0]{'extra'}{'directions'}{'FastForward'};
 $result_elements{'part_chapter_after_top'}[0]{'extra'}{'directions'}{'NodeNext'} = $result_elements{'part_chapter_after_top'}[0]{'extra'}{'directions'}{'FastForward'};
-$result_elements{'part_chapter_after_top'}[0]{'extra'}{'directions'}{'NodeUp'}{'extra'}{'top_node_up'} = $result_elements{'part_chapter_after_top'}[0]{'extra'}{'directions'}{'FastForward'}{'extra'}{'node'}{'menu_up'};
 $result_elements{'part_chapter_after_top'}[0]{'extra'}{'directions'}{'This'} = $result_elements{'part_chapter_after_top'}[0];
 $result_elements{'part_chapter_after_top'}[0]{'extra'}{'node'} = $result_elements{'part_chapter_after_top'}[0]{'extra'}{'directions'}{'FastForward'}{'extra'}{'node'}{'menu_up'};
 $result_elements{'part_chapter_after_top'}[0]{'extra'}{'section'} = $result_elements{'part_chapter_after_top'}[0]{'extra'}{'element_command'};
@@ -669,7 +652,6 @@ $result_directions_text{'part_chapter_after_top'} = 'element: @top top
   Next: @chapter chapter
   NodeForward: @chapter chapter
   NodeNext: @chapter chapter
-  NodeUp: (dir)
   This: @top top
 element: @chapter chapter
   Back: @top top
@@ -706,6 +688,11 @@ Node: Top27
 Node: chapter108
 
 End Tag Table
+
+
+Local Variables:
+coding: utf-8
+End:
 ';
 
 
@@ -720,14 +707,16 @@ $result_converted{'html'}->{'part_chapter_after_top'} = '<!DOCTYPE html PUBLIC "
 <meta name="keywords" content="top">
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
+<meta name="viewport" content="width=device-width,initial-scale=1">
+
 <link href="#Top" rel="start" title="Top">
 <style type="text/css">
 <!--
+a.copiable-anchor {visibility: hidden; text-decoration: none; line-height: 0em}
 a.summary-letter {text-decoration: none}
 blockquote.indentedblock {margin-right: 0em}
 div.display {margin-left: 3.2em}
 div.example {margin-left: 3.2em}
-div.lisp {margin-left: 3.2em}
 kbd {font-style: oblique}
 pre.display {font-family: inherit}
 pre.format {font-family: inherit}
@@ -736,6 +725,7 @@ pre.menu-preformatted {font-family: serif}
 span.nolinebreak {white-space: nowrap}
 span.roman {font-family: initial; font-weight: normal}
 span.sansserif {font-family: sans-serif; font-weight: normal}
+span:hover a.copiable-anchor {visibility: visible}
 ul.no-bullet {list-style: none}
 -->
 </style>
@@ -744,27 +734,31 @@ ul.no-bullet {list-style: none}
 </head>
 
 <body lang="en">
-<span id="Top"></span><div class="header">
+<div class="top" id="Top">
+<div class="header">
 <p>
-Next: <a href="#chapter" accesskey="n" rel="next">chapter</a>, Up: <a href="dir.html#Top" accesskey="u" rel="up">(dir)</a> &nbsp; </p>
+Next: <a href="#chapter" accesskey="n" rel="next">chapter</a> &nbsp; </p>
 </div>
 <span id="top"></span><h1 class="top">top</h1>
 
-<table class="menu" border="0" cellspacing="0">
-<tr><td align="left" valign="top">&bull; <a href="#chapter" accesskey="1">chapter</a></td><td>&nbsp;&nbsp;</td><td align="left" valign="top">
-</td></tr>
-</table>
 
 <hr>
-<span id="part"></span><div class="header">
+</div>
+<div class="part" id="part">
+<div class="header">
 <p>
-Previous: <a href="#Top" accesskey="p" rel="prev">Top</a>, Up: <a href="#Top" accesskey="u" rel="up">Top</a> &nbsp; </p>
+Previous: <a href="#Top" accesskey="p" rel="prev">top</a>, Up: <a href="#Top" accesskey="u" rel="up">top</a> &nbsp; </p>
 </div>
 <h1 class="part">part</h1>
 <hr>
 
-<span id="chapter"></span><span id="chapter-1"></span><h2 class="chapter">1 chapter</h2>
-<hr>
+<ul class="section-toc">
+<li><a href="#chapter" accesskey="1">chapter</a></li>
+</ul>
+<div class="chapter" id="chapter">
+<span id="chapter-1"></span><h2 class="chapter">1 chapter</h2>
+</div>
+</div>
 
 
 
@@ -773,7 +767,7 @@ Previous: <a href="#Top" accesskey="p" rel="prev">Top</a>, Up: <a href="#Top" ac
 ';
 
 
-$result_converted{'xml'}->{'part_chapter_after_top'} = '<node name="Top" spaces=" "><nodename>Top</nodename><nodenext automatic="on">chapter</nodenext><nodeup automatic="on">(dir)</nodeup></node>
+$result_converted{'xml'}->{'part_chapter_after_top'} = '<node name="Top" spaces=" "><nodename>Top</nodename><nodenext automatic="on">chapter</nodenext></node>
 <top spaces=" "><sectiontitle>top</sectiontitle>
 
 <menu endspaces=" ">
