@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
@@ -17,7 +17,7 @@ $result_trees{'part_chapter_appendix'} = {
         }
       ],
       'parent' => {},
-      'type' => 'before_node_section'
+      'type' => 'text_root'
     },
     {
       'args' => [
@@ -48,12 +48,13 @@ $result_trees{'part_chapter_appendix'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 0,
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 2,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     },
     {
       'args' => [
@@ -85,12 +86,14 @@ $result_trees{'part_chapter_appendix'} = {
         'associated_part' => {},
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 1,
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 4,
         'macro' => ''
-      }
+      },
+      'number' => 1,
+      'parent' => {}
     },
     {
       'args' => [
@@ -110,15 +113,18 @@ $result_trees{'part_chapter_appendix'} = {
         }
       ],
       'cmdname' => 'appendix',
+      'contents' => [],
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 1,
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 6,
         'macro' => ''
-      }
+      },
+      'number' => 'A',
+      'parent' => {}
     }
   ],
   'type' => 'document_root'
@@ -159,53 +165,49 @@ Appendix A Appendix
 ';
 
 $result_sectioning{'part_chapter_appendix'} = {
-  'structure' => {
-    'section_childs' => [
-      {
-        'cmdname' => 'part',
-        'extra' => {
-          'part_associated_section' => {
-            'cmdname' => 'chapter',
-            'extra' => {
-              'associated_part' => {}
-            },
-            'structure' => {
-              'section_level' => 1,
-              'section_number' => 1,
-              'section_up' => {}
-            }
-          }
-        },
-        'structure' => {
-          'section_childs' => [
-            {}
-          ],
-          'section_level' => 0,
+  'level' => -1,
+  'section_childs' => [
+    {
+      'cmdname' => 'part',
+      'extra' => {
+        'part_associated_section' => {
+          'cmdname' => 'chapter',
+          'extra' => {
+            'associated_part' => {},
+            'spaces_before_argument' => ' '
+          },
+          'level' => 1,
+          'number' => 1,
           'section_up' => {}
-        }
+        },
+        'spaces_before_argument' => ' '
       },
-      {
-        'cmdname' => 'appendix',
-        'extra' => {},
-        'structure' => {
-          'section_level' => 1,
-          'section_number' => 'A',
-          'section_prev' => {},
-          'section_up' => {},
-          'toplevel_prev' => {}
-        }
-      }
-    ],
-    'section_level' => -1
-  }
+      'level' => 0,
+      'section_childs' => [
+        {}
+      ],
+      'section_up' => {}
+    },
+    {
+      'cmdname' => 'appendix',
+      'extra' => {
+        'spaces_before_argument' => ' '
+      },
+      'level' => 1,
+      'number' => 'A',
+      'section_prev' => {},
+      'section_up' => {},
+      'toplevel_prev' => {}
+    }
+  ]
 };
-$result_sectioning{'part_chapter_appendix'}{'structure'}{'section_childs'}[0]{'extra'}{'part_associated_section'}{'extra'}{'associated_part'} = $result_sectioning{'part_chapter_appendix'}{'structure'}{'section_childs'}[0];
-$result_sectioning{'part_chapter_appendix'}{'structure'}{'section_childs'}[0]{'extra'}{'part_associated_section'}{'structure'}{'section_up'} = $result_sectioning{'part_chapter_appendix'}{'structure'}{'section_childs'}[0];
-$result_sectioning{'part_chapter_appendix'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0] = $result_sectioning{'part_chapter_appendix'}{'structure'}{'section_childs'}[0]{'extra'}{'part_associated_section'};
-$result_sectioning{'part_chapter_appendix'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'part_chapter_appendix'};
-$result_sectioning{'part_chapter_appendix'}{'structure'}{'section_childs'}[1]{'structure'}{'section_prev'} = $result_sectioning{'part_chapter_appendix'}{'structure'}{'section_childs'}[0];
-$result_sectioning{'part_chapter_appendix'}{'structure'}{'section_childs'}[1]{'structure'}{'section_up'} = $result_sectioning{'part_chapter_appendix'};
-$result_sectioning{'part_chapter_appendix'}{'structure'}{'section_childs'}[1]{'structure'}{'toplevel_prev'} = $result_sectioning{'part_chapter_appendix'}{'structure'}{'section_childs'}[0]{'extra'}{'part_associated_section'};
+$result_sectioning{'part_chapter_appendix'}{'section_childs'}[0]{'extra'}{'part_associated_section'}{'extra'}{'associated_part'} = $result_sectioning{'part_chapter_appendix'}{'section_childs'}[0];
+$result_sectioning{'part_chapter_appendix'}{'section_childs'}[0]{'extra'}{'part_associated_section'}{'section_up'} = $result_sectioning{'part_chapter_appendix'}{'section_childs'}[0];
+$result_sectioning{'part_chapter_appendix'}{'section_childs'}[0]{'section_childs'}[0] = $result_sectioning{'part_chapter_appendix'}{'section_childs'}[0]{'extra'}{'part_associated_section'};
+$result_sectioning{'part_chapter_appendix'}{'section_childs'}[0]{'section_up'} = $result_sectioning{'part_chapter_appendix'};
+$result_sectioning{'part_chapter_appendix'}{'section_childs'}[1]{'section_prev'} = $result_sectioning{'part_chapter_appendix'}{'section_childs'}[0];
+$result_sectioning{'part_chapter_appendix'}{'section_childs'}[1]{'section_up'} = $result_sectioning{'part_chapter_appendix'};
+$result_sectioning{'part_chapter_appendix'}{'section_childs'}[1]{'toplevel_prev'} = $result_sectioning{'part_chapter_appendix'}{'section_childs'}[0]{'extra'}{'part_associated_section'};
 
 $result_errors{'part_chapter_appendix'} = [];
 
