@@ -17,27 +17,17 @@ $result_trees{'part_node_chapter_appendix'} = [
         'args' => [
           {
             'contents' => [
-              {
-                'extra' => {
-                  'command' => {}
-                },
-                'parent' => {},
-                'text' => ' ',
-                'type' => 'empty_spaces_after_command'
-              },
               {
                 'parent' => {},
                 'text' => 'Top'
-              },
-              {
-                'parent' => {},
-                'text' => '
-',
-                'type' => 'spaces_at_end'
               }
             ],
+            'extra' => {
+              'spaces_after_argument' => '
+'
+            },
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           }
         ],
         'cmdname' => 'node',
@@ -48,12 +38,14 @@ $result_trees{'part_node_chapter_appendix'} = [
           ],
           'nodes_manuals' => [
             {
-              'node_content' => [],
+              'node_content' => [
+                {}
+              ],
               'normalized' => 'Top'
             }
           ],
           'normalized' => 'Top',
-          'spaces_after_command' => {}
+          'spaces_before_argument' => ' '
         },
         'line_nr' => {
           'file_name' => '',
@@ -66,27 +58,17 @@ $result_trees{'part_node_chapter_appendix'} = [
         'args' => [
           {
             'contents' => [
-              {
-                'extra' => {
-                  'command' => {}
-                },
-                'parent' => {},
-                'text' => ' ',
-                'type' => 'empty_spaces_after_command'
-              },
               {
                 'parent' => {},
                 'text' => 'top'
-              },
-              {
-                'parent' => {},
-                'text' => '
-',
-                'type' => 'spaces_at_end'
               }
             ],
+            'extra' => {
+              'spaces_after_argument' => '
+'
+            },
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           }
         ],
         'cmdname' => 'top',
@@ -170,34 +152,23 @@ $result_trees{'part_node_chapter_appendix'} = [
                 'args' => [
                   {
                     'contents' => [
-                      {
-                        'extra' => {
-                          'command' => {}
-                        },
-                        'parent' => {},
-                        'text' => ' ',
-                        'type' => 'empty_spaces_after_command'
-                      },
                       {
                         'parent' => {},
                         'text' => 'menu'
-                      },
-                      {
-                        'parent' => {},
-                        'text' => '
-',
-                        'type' => 'spaces_at_end'
                       }
                     ],
+                    'extra' => {
+                      'spaces_after_argument' => '
+'
+                    },
                     'parent' => {},
-                    'type' => 'misc_line_arg'
+                    'type' => 'line_arg'
                   }
                 ],
                 'cmdname' => 'end',
                 'extra' => {
-                  'command' => {},
                   'command_argument' => 'menu',
-                  'spaces_after_command' => {},
+                  'spaces_before_argument' => ' ',
                   'text_arg' => 'menu'
                 },
                 'line_nr' => {
@@ -209,8 +180,7 @@ $result_trees{'part_node_chapter_appendix'} = [
               }
             ],
             'extra' => {
-              'end_command' => {},
-              'spaces_after_command' => {}
+              'end_command' => {}
             },
             'line_nr' => {
               'file_name' => '',
@@ -227,10 +197,7 @@ $result_trees{'part_node_chapter_appendix'} = [
           }
         ],
         'extra' => {
-          'misc_content' => [
-            {}
-          ],
-          'spaces_after_command' => {}
+          'spaces_before_argument' => ' '
         },
         'level' => 0,
         'line_nr' => {
@@ -254,27 +221,17 @@ $result_trees{'part_node_chapter_appendix'} = [
         'args' => [
           {
             'contents' => [
-              {
-                'extra' => {
-                  'command' => {}
-                },
-                'parent' => {},
-                'text' => ' ',
-                'type' => 'empty_spaces_after_command'
-              },
               {
                 'parent' => {},
                 'text' => 'Part 1'
-              },
-              {
-                'parent' => {},
-                'text' => '
-',
-                'type' => 'spaces_at_end'
               }
             ],
+            'extra' => {
+              'spaces_after_argument' => '
+'
+            },
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           }
         ],
         'cmdname' => 'part',
@@ -287,10 +244,7 @@ $result_trees{'part_node_chapter_appendix'} = [
           }
         ],
         'extra' => {
-          'misc_content' => [
-            {}
-          ],
-          'spaces_after_command' => {}
+          'spaces_before_argument' => ' '
         },
         'level' => 0,
         'line_nr' => {
@@ -304,27 +258,17 @@ $result_trees{'part_node_chapter_appendix'} = [
         'args' => [
           {
             'contents' => [
-              {
-                'extra' => {
-                  'command' => {}
-                },
-                'parent' => {},
-                'text' => ' ',
-                'type' => 'empty_spaces_after_command'
-              },
               {
                 'parent' => {},
                 'text' => 'chapter node'
-              },
-              {
-                'parent' => {},
-                'text' => '
-',
-                'type' => 'spaces_at_end'
               }
             ],
+            'extra' => {
+              'spaces_after_argument' => '
+'
+            },
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           }
         ],
         'cmdname' => 'node',
@@ -335,12 +279,14 @@ $result_trees{'part_node_chapter_appendix'} = [
           ],
           'nodes_manuals' => [
             {
-              'node_content' => [],
+              'node_content' => [
+                {}
+              ],
               'normalized' => 'chapter-node'
             }
           ],
           'normalized' => 'chapter-node',
-          'spaces_after_command' => {}
+          'spaces_before_argument' => ' '
         },
         'line_nr' => {
           'file_name' => '',
@@ -353,27 +299,17 @@ $result_trees{'part_node_chapter_appendix'} = [
         'args' => [
           {
             'contents' => [
-              {
-                'extra' => {
-                  'command' => {}
-                },
-                'parent' => {},
-                'text' => ' ',
-                'type' => 'empty_spaces_after_command'
-              },
               {
                 'parent' => {},
                 'text' => 'chapter'
-              },
-              {
-                'parent' => {},
-                'text' => '
-',
-                'type' => 'spaces_at_end'
               }
             ],
+            'extra' => {
+              'spaces_after_argument' => '
+'
+            },
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           }
         ],
         'cmdname' => 'chapter',
@@ -387,10 +323,7 @@ $result_trees{'part_node_chapter_appendix'} = [
         ],
         'extra' => {
           'associated_part' => {},
-          'misc_content' => [
-            {}
-          ],
-          'spaces_after_command' => {}
+          'spaces_before_argument' => ' '
         },
         'level' => 1,
         'line_nr' => {
@@ -416,36 +349,23 @@ $result_trees{'part_node_chapter_appendix'} = [
         'args' => [
           {
             'contents' => [
-              {
-                'extra' => {
-                  'command' => {}
-                },
-                'parent' => {},
-                'text' => ' ',
-                'type' => 'empty_spaces_after_command'
-              },
               {
                 'parent' => {},
                 'text' => 'Appendix'
-              },
-              {
-                'parent' => {},
-                'text' => '
-',
-                'type' => 'spaces_at_end'
               }
             ],
+            'extra' => {
+              'spaces_after_argument' => '
+'
+            },
             'parent' => {},
-            'type' => 'misc_line_arg'
+            'type' => 'line_arg'
           }
         ],
         'cmdname' => 'appendix',
         'contents' => [],
         'extra' => {
-          'misc_content' => [
-            {}
-          ],
-          'spaces_after_command' => {}
+          'spaces_before_argument' => ' '
         },
         'level' => 1,
         'line_nr' => {
@@ -466,19 +386,12 @@ $result_trees{'part_node_chapter_appendix'} = [
   }
 ];
 $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[0]{'parent'} = $result_trees{'part_node_chapter_appendix'}[0];
-$result_trees{'part_node_chapter_appendix'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[1];
 $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'part_node_chapter_appendix'}[0]{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'part_node_chapter_appendix'}[0]{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[1]{'args'}[0];
 $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[1];
-$result_trees{'part_node_chapter_appendix'}[0]{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[1]{'args'}[0]{'contents'}[1];
-$result_trees{'part_node_chapter_appendix'}[0]{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[1]{'extra'}{'node_content'};
-$result_trees{'part_node_chapter_appendix'}[0]{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0];
+$result_trees{'part_node_chapter_appendix'}[0]{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0];
+$result_trees{'part_node_chapter_appendix'}[0]{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[1]{'parent'} = $result_trees{'part_node_chapter_appendix'}[0];
-$result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2];
 $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'args'}[0];
-$result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'args'}[0];
-$result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'args'}[0];
 $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2];
 $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'contents'}[0]{'parent'} = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2];
 $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[0]{'extra'}{'command'} = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'contents'}[1];
@@ -493,63 +406,36 @@ $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'contents'}[1]{'co
 $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[1]{'extra'}{'menu_entry_description'} = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[1]{'args'}[3];
 $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[1]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[1]{'args'}[1]{'contents'}[0];
 $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'contents'}[1];
-$result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[2];
 $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[0];
-$result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[0];
-$result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[0];
 $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[2];
-$result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[2]{'extra'}{'command'} = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'contents'}[1];
-$result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'contents'}[1];
 $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'contents'}[1]{'extra'}{'end_command'} = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[2];
-$result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'contents'}[1]{'contents'}[0];
 $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'contents'}[1]{'parent'} = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2];
 $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'contents'}[2]{'parent'} = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2];
-$result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'extra'}{'misc_content'}[0] = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'args'}[0]{'contents'}[1];
-$result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2]{'parent'} = $result_trees{'part_node_chapter_appendix'}[0];
 $result_trees{'part_node_chapter_appendix'}[0]{'extra'}{'element_command'} = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2];
 $result_trees{'part_node_chapter_appendix'}[0]{'extra'}{'node'} = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[1];
 $result_trees{'part_node_chapter_appendix'}[0]{'extra'}{'section'} = $result_trees{'part_node_chapter_appendix'}[0]{'contents'}[2];
-$result_trees{'part_node_chapter_appendix'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[0];
 $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[0]{'args'}[0];
-$result_trees{'part_node_chapter_appendix'}[1]{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[0]{'args'}[0];
-$result_trees{'part_node_chapter_appendix'}[1]{'contents'}[0]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[0]{'args'}[0];
 $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[0];
 $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[0];
-$result_trees{'part_node_chapter_appendix'}[1]{'contents'}[0]{'extra'}{'misc_content'}[0] = $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[0]{'args'}[0]{'contents'}[1];
-$result_trees{'part_node_chapter_appendix'}[1]{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[0]{'parent'} = $result_trees{'part_node_chapter_appendix'}[1];
-$result_trees{'part_node_chapter_appendix'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[1];
 $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[1]{'args'}[0];
-$result_trees{'part_node_chapter_appendix'}[1]{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[1]{'args'}[0];
-$result_trees{'part_node_chapter_appendix'}[1]{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[1]{'args'}[0];
 $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[1];
-$result_trees{'part_node_chapter_appendix'}[1]{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[1]{'args'}[0]{'contents'}[1];
-$result_trees{'part_node_chapter_appendix'}[1]{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[1]{'extra'}{'node_content'};
-$result_trees{'part_node_chapter_appendix'}[1]{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0];
+$result_trees{'part_node_chapter_appendix'}[1]{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0];
+$result_trees{'part_node_chapter_appendix'}[1]{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[1]{'parent'} = $result_trees{'part_node_chapter_appendix'}[1];
-$result_trees{'part_node_chapter_appendix'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[2];
 $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[2]{'args'}[0];
-$result_trees{'part_node_chapter_appendix'}[1]{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[2]{'args'}[0];
-$result_trees{'part_node_chapter_appendix'}[1]{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[2]{'args'}[0];
 $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[2];
 $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[2]{'contents'}[0]{'parent'} = $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[2];
 $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[2]{'extra'}{'associated_part'} = $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[0];
-$result_trees{'part_node_chapter_appendix'}[1]{'contents'}[2]{'extra'}{'misc_content'}[0] = $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[2]{'args'}[0]{'contents'}[1];
-$result_trees{'part_node_chapter_appendix'}[1]{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[2]{'parent'} = $result_trees{'part_node_chapter_appendix'}[1];
 $result_trees{'part_node_chapter_appendix'}[1]{'element_prev'} = $result_trees{'part_node_chapter_appendix'}[0];
 $result_trees{'part_node_chapter_appendix'}[1]{'extra'}{'element_command'} = $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[2];
 $result_trees{'part_node_chapter_appendix'}[1]{'extra'}{'node'} = $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[1];
 $result_trees{'part_node_chapter_appendix'}[1]{'extra'}{'section'} = $result_trees{'part_node_chapter_appendix'}[1]{'contents'}[2];
-$result_trees{'part_node_chapter_appendix'}[2]{'contents'}[0]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'part_node_chapter_appendix'}[2]{'contents'}[0];
 $result_trees{'part_node_chapter_appendix'}[2]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'part_node_chapter_appendix'}[2]{'contents'}[0]{'args'}[0];
-$result_trees{'part_node_chapter_appendix'}[2]{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'part_node_chapter_appendix'}[2]{'contents'}[0]{'args'}[0];
-$result_trees{'part_node_chapter_appendix'}[2]{'contents'}[0]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'part_node_chapter_appendix'}[2]{'contents'}[0]{'args'}[0];
 $result_trees{'part_node_chapter_appendix'}[2]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'part_node_chapter_appendix'}[2]{'contents'}[0];
-$result_trees{'part_node_chapter_appendix'}[2]{'contents'}[0]{'extra'}{'misc_content'}[0] = $result_trees{'part_node_chapter_appendix'}[2]{'contents'}[0]{'args'}[0]{'contents'}[1];
-$result_trees{'part_node_chapter_appendix'}[2]{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'part_node_chapter_appendix'}[2]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'part_node_chapter_appendix'}[2]{'contents'}[0]{'parent'} = $result_trees{'part_node_chapter_appendix'}[2];
 $result_trees{'part_node_chapter_appendix'}[2]{'element_prev'} = $result_trees{'part_node_chapter_appendix'}[1];
 $result_trees{'part_node_chapter_appendix'}[2]{'extra'}{'element_command'} = $result_trees{'part_node_chapter_appendix'}[2]{'contents'}[0];
@@ -595,9 +481,11 @@ $result_sectioning{'part_node_chapter_appendix'} = {
         'associated_node' => {
           'cmdname' => 'node',
           'extra' => {
-            'normalized' => 'Top'
+            'normalized' => 'Top',
+            'spaces_before_argument' => ' '
           }
-        }
+        },
+        'spaces_before_argument' => ' '
       },
       'level' => 0,
       'section_up' => {}
@@ -611,17 +499,20 @@ $result_sectioning{'part_node_chapter_appendix'} = {
             'associated_node' => {
               'cmdname' => 'node',
               'extra' => {
-                'normalized' => 'chapter-node'
+                'normalized' => 'chapter-node',
+                'spaces_before_argument' => ' '
               }
             },
-            'associated_part' => {}
+            'associated_part' => {},
+            'spaces_before_argument' => ' '
           },
           'level' => 1,
           'number' => 1,
           'section_up' => {},
           'toplevel_prev' => {},
           'toplevel_up' => {}
-        }
+        },
+        'spaces_before_argument' => ' '
       },
       'level' => 0,
       'section_childs' => [
@@ -632,7 +523,9 @@ $result_sectioning{'part_node_chapter_appendix'} = {
     },
     {
       'cmdname' => 'appendix',
-      'extra' => {},
+      'extra' => {
+        'spaces_before_argument' => ' '
+      },
       'level' => 1,
       'number' => 'A',
       'section_prev' => {},
@@ -660,10 +553,13 @@ $result_nodes{'part_node_chapter_appendix'} = {
   'extra' => {
     'associated_section' => {
       'cmdname' => 'top',
-      'extra' => {},
+      'extra' => {
+        'spaces_before_argument' => ' '
+      },
       'level' => 0
     },
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   },
   'menu_child' => {
     'cmdname' => 'node',
@@ -673,14 +569,18 @@ $result_nodes{'part_node_chapter_appendix'} = {
         'extra' => {
           'associated_part' => {
             'cmdname' => 'part',
-            'extra' => {},
+            'extra' => {
+              'spaces_before_argument' => ' '
+            },
             'level' => 0
-          }
+          },
+          'spaces_before_argument' => ' '
         },
         'level' => 1,
         'number' => 1
       },
-      'normalized' => 'chapter-node'
+      'normalized' => 'chapter-node',
+      'spaces_before_argument' => ' '
     },
     'node_prev' => {},
     'node_up' => {}
@@ -692,42 +592,31 @@ $result_nodes{'part_node_chapter_appendix'} = {
         'end_command' => {
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
             'command_argument' => 'menu',
+            'spaces_before_argument' => ' ',
             'text_arg' => 'menu'
           }
         }
       }
     }
   ],
-  'node_next' => {},
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
-  }
+  'node_next' => {}
 };
 $result_nodes{'part_node_chapter_appendix'}{'menu_child'}{'node_prev'} = $result_nodes{'part_node_chapter_appendix'};
 $result_nodes{'part_node_chapter_appendix'}{'menu_child'}{'node_up'} = $result_nodes{'part_node_chapter_appendix'};
-$result_nodes{'part_node_chapter_appendix'}{'menus'}[0]{'extra'}{'end_command'}{'extra'}{'command'} = $result_nodes{'part_node_chapter_appendix'}{'menus'}[0];
 $result_nodes{'part_node_chapter_appendix'}{'node_next'} = $result_nodes{'part_node_chapter_appendix'}{'menu_child'};
-$result_nodes{'part_node_chapter_appendix'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'part_node_chapter_appendix'};
 
 $result_menus{'part_node_chapter_appendix'} = {
   'cmdname' => 'node',
   'extra' => {
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   },
   'menu_child' => {
     'cmdname' => 'node',
     'extra' => {
-      'normalized' => 'chapter-node'
+      'normalized' => 'chapter-node',
+      'spaces_before_argument' => ' '
     },
     'menu_up' => {},
     'menu_up_hash' => {
@@ -740,6 +629,9 @@ $result_menus{'part_node_chapter_appendix'}{'menu_child'}{'menu_up'} = $result_m
 $result_errors{'part_node_chapter_appendix'} = [];
 
 
+$result_floats{'part_node_chapter_appendix'} = {};
+
+
 $result_elements{'part_node_chapter_appendix'} = [
   {
     'extra' => {
@@ -759,7 +651,9 @@ $result_elements{'part_node_chapter_appendix'} = [
                   },
                   'element_command' => {
                     'cmdname' => 'appendix',
-                    'extra' => {},
+                    'extra' => {
+                      'spaces_before_argument' => ' '
+                    },
                     'level' => 1,
                     'number' => 'A'
                   },
@@ -778,9 +672,12 @@ $result_elements{'part_node_chapter_appendix'} = [
               'extra' => {
                 'associated_part' => {
                   'cmdname' => 'part',
-                  'extra' => {},
+                  'extra' => {
+                    'spaces_before_argument' => ' '
+                  },
                   'level' => 0
-                }
+                },
+                'spaces_before_argument' => ' '
               },
               'level' => 1,
               'number' => 1
@@ -788,12 +685,14 @@ $result_elements{'part_node_chapter_appendix'} = [
             'node' => {
               'cmdname' => 'node',
               'extra' => {
-                'normalized' => 'chapter-node'
+                'normalized' => 'chapter-node',
+                'spaces_before_argument' => ' '
               },
               'menu_up' => {
                 'cmdname' => 'node',
                 'extra' => {
-                  'normalized' => 'Top'
+                  'normalized' => 'Top',
+                  'spaces_before_argument' => ' '
                 },
                 'menu_child' => {}
               },
@@ -809,22 +708,13 @@ $result_elements{'part_node_chapter_appendix'} = [
         'Next' => {},
         'NodeForward' => {},
         'NodeNext' => {},
-        'NodeUp' => {
-          'extra' => {
-            'manual_content' => [
-              {
-                'text' => 'dir'
-              }
-            ],
-            'top_node_up' => {}
-          },
-          'type' => 'external_node'
-        },
         'This' => {}
       },
       'element_command' => {
         'cmdname' => 'top',
-        'extra' => {},
+        'extra' => {
+          'spaces_before_argument' => ' '
+        },
         'level' => 0
       },
       'node' => {},
@@ -853,7 +743,6 @@ $result_elements{'part_node_chapter_appendix'}[0]{'extra'}{'directions'}{'Forwar
 $result_elements{'part_node_chapter_appendix'}[0]{'extra'}{'directions'}{'Next'} = $result_elements{'part_node_chapter_appendix'}[0]{'extra'}{'directions'}{'FastForward'};
 $result_elements{'part_node_chapter_appendix'}[0]{'extra'}{'directions'}{'NodeForward'} = $result_elements{'part_node_chapter_appendix'}[0]{'extra'}{'directions'}{'FastForward'};
 $result_elements{'part_node_chapter_appendix'}[0]{'extra'}{'directions'}{'NodeNext'} = $result_elements{'part_node_chapter_appendix'}[0]{'extra'}{'directions'}{'FastForward'};
-$result_elements{'part_node_chapter_appendix'}[0]{'extra'}{'directions'}{'NodeUp'}{'extra'}{'top_node_up'} = $result_elements{'part_node_chapter_appendix'}[0]{'extra'}{'directions'}{'FastForward'}{'extra'}{'node'}{'menu_up'};
 $result_elements{'part_node_chapter_appendix'}[0]{'extra'}{'directions'}{'This'} = $result_elements{'part_node_chapter_appendix'}[0];
 $result_elements{'part_node_chapter_appendix'}[0]{'extra'}{'node'} = $result_elements{'part_node_chapter_appendix'}[0]{'extra'}{'directions'}{'FastForward'}{'extra'}{'node'}{'menu_up'};
 $result_elements{'part_node_chapter_appendix'}[0]{'extra'}{'section'} = $result_elements{'part_node_chapter_appendix'}[0]{'extra'}{'element_command'};
@@ -868,7 +757,6 @@ $result_directions_text{'part_node_chapter_appendix'} = 'element: @top top
   Next: @chapter chapter
   NodeForward: @chapter chapter
   NodeNext: @chapter chapter
-  NodeUp: (dir)
   This: @top top
 element: @chapter chapter
   Back: @top top
@@ -915,6 +803,11 @@ Node: Top27
 Node: chapter node118
 
 End Tag Table
+
+
+Local Variables:
+coding: utf-8
+End:
 ';
 
 
@@ -929,31 +822,25 @@ $result_converted{'html'}->{'part_node_chapter_appendix'} = '<!DOCTYPE html PUBL
 <meta name="keywords" content="top">
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
+<meta name="viewport" content="width=device-width,initial-scale=1">
+
 <link href="#Top" rel="start" title="Top">
 <style type="text/css">
 <!--
+a.copiable-anchor {visibility: hidden; text-decoration: none; line-height: 0em}
 a.summary-letter {text-decoration: none}
 blockquote.indentedblock {margin-right: 0em}
-blockquote.smallindentedblock {margin-right: 0em; font-size: smaller}
-blockquote.smallquotation {font-size: smaller}
 div.display {margin-left: 3.2em}
 div.example {margin-left: 3.2em}
-div.lisp {margin-left: 3.2em}
-div.smalldisplay {margin-left: 3.2em}
-div.smallexample {margin-left: 3.2em}
-div.smalllisp {margin-left: 3.2em}
 kbd {font-style: oblique}
 pre.display {font-family: inherit}
 pre.format {font-family: inherit}
 pre.menu-comment {font-family: serif}
 pre.menu-preformatted {font-family: serif}
-pre.smalldisplay {font-family: inherit; font-size: smaller}
-pre.smallexample {font-size: smaller}
-pre.smallformat {font-family: inherit; font-size: smaller}
-pre.smalllisp {font-size: smaller}
 span.nolinebreak {white-space: nowrap}
 span.roman {font-family: initial; font-weight: normal}
 span.sansserif {font-family: sans-serif; font-weight: normal}
+span:hover a.copiable-anchor {visibility: visible}
 ul.no-bullet {list-style: none}
 -->
 </style>
@@ -962,35 +849,35 @@ ul.no-bullet {list-style: none}
 </head>
 
 <body lang="en">
-<a name="Top"></a>
+<div class="top" id="Top">
 <div class="header">
 <p>
-Next: <a href="#chapter-node" accesskey="n" rel="next">chapter node</a>, Up: <a href="dir.html#Top" accesskey="u" rel="up">(dir)</a> &nbsp; </p>
+Next: <a href="#chapter-node" accesskey="n" rel="next">chapter</a> &nbsp; </p>
 </div>
-<a name="top"></a>
-<h1 class="top">top</h1>
+<span id="top"></span><h1 class="top">top</h1>
 
-<table class="menu" border="0" cellspacing="0">
-<tr><td align="left" valign="top">&bull; <a href="#chapter-node" accesskey="1">chapter node</a>:</td><td>&nbsp;&nbsp;</td><td align="left" valign="top">
-</td></tr>
-</table>
 
 <hr>
-<a name="Part-1"></a>
+</div>
+<div class="part" id="Part-1">
 <div class="header">
 <p>
-Previous: <a href="#Top" accesskey="p" rel="prev">Top</a>, Up: <a href="#Top" accesskey="u" rel="up">Top</a> &nbsp; </p>
+Previous: <a href="#Top" accesskey="p" rel="prev">top</a>, Up: <a href="#Top" accesskey="u" rel="up">top</a> &nbsp; </p>
 </div>
 <h1 class="part">Part 1</h1>
 <hr>
 
-<a name="chapter-node"></a>
-<a name="chapter"></a>
-<h2 class="chapter">1 chapter</h2>
+<ul class="section-toc">
+<li><a href="#chapter-node" accesskey="1">chapter</a></li>
+</ul>
+<div class="chapter" id="chapter-node">
+<span id="chapter"></span><h2 class="chapter">1 chapter</h2>
 
-<a name="Appendix"></a>
+</div>
+<div class="appendix" id="Appendix">
 <h2 class="appendix">Appendix A Appendix</h2>
-<hr>
+</div>
+</div>
 
 
 
@@ -999,7 +886,7 @@ Previous: <a href="#Top" accesskey="p" rel="prev">Top</a>, Up: <a href="#Top" ac
 ';
 
 
-$result_converted{'xml'}->{'part_node_chapter_appendix'} = '<node name="Top" spaces=" "><nodename>Top</nodename><nodenext automatic="on">chapter node</nodenext><nodeup automatic="on">(dir)</nodeup></node>
+$result_converted{'xml'}->{'part_node_chapter_appendix'} = '<node name="Top" spaces=" "><nodename>Top</nodename><nodenext automatic="on">chapter node</nodenext></node>
 <top spaces=" "><sectiontitle>top</sectiontitle>
 
 <menu endspaces=" ">
