@@ -38,7 +38,9 @@ $result_trees{'part_node_part_node_appendix'} = [
           ],
           'nodes_manuals' => [
             {
-              'node_content' => [],
+              'node_content' => [
+                {}
+              ],
               'normalized' => 'Top'
             }
           ],
@@ -334,7 +336,9 @@ $result_trees{'part_node_part_node_appendix'} = [
           ],
           'nodes_manuals' => [
             {
-              'node_content' => [],
+              'node_content' => [
+                {}
+              ],
               'normalized' => 'chapter-node'
             }
           ],
@@ -460,7 +464,9 @@ $result_trees{'part_node_part_node_appendix'} = [
           ],
           'nodes_manuals' => [
             {
-              'node_content' => [],
+              'node_content' => [
+                {}
+              ],
               'normalized' => 'appendix-node'
             }
           ],
@@ -520,7 +526,7 @@ $result_trees{'part_node_part_node_appendix'}[0]{'contents'}[0]{'parent'} = $res
 $result_trees{'part_node_part_node_appendix'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'part_node_part_node_appendix'}[0]{'contents'}[1]{'args'}[0];
 $result_trees{'part_node_part_node_appendix'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'part_node_part_node_appendix'}[0]{'contents'}[1];
 $result_trees{'part_node_part_node_appendix'}[0]{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'part_node_part_node_appendix'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'part_node_part_node_appendix'}[0]{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'part_node_part_node_appendix'}[0]{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'part_node_part_node_appendix'}[0]{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'part_node_part_node_appendix'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'part_node_part_node_appendix'}[0]{'contents'}[1]{'parent'} = $result_trees{'part_node_part_node_appendix'}[0];
 $result_trees{'part_node_part_node_appendix'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'part_node_part_node_appendix'}[0]{'contents'}[2]{'args'}[0];
 $result_trees{'part_node_part_node_appendix'}[0]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'part_node_part_node_appendix'}[0]{'contents'}[2];
@@ -564,7 +570,7 @@ $result_trees{'part_node_part_node_appendix'}[1]{'contents'}[0]{'parent'} = $res
 $result_trees{'part_node_part_node_appendix'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'part_node_part_node_appendix'}[1]{'contents'}[1]{'args'}[0];
 $result_trees{'part_node_part_node_appendix'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'part_node_part_node_appendix'}[1]{'contents'}[1];
 $result_trees{'part_node_part_node_appendix'}[1]{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'part_node_part_node_appendix'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'part_node_part_node_appendix'}[1]{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'part_node_part_node_appendix'}[1]{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'part_node_part_node_appendix'}[1]{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'part_node_part_node_appendix'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'part_node_part_node_appendix'}[1]{'contents'}[1]{'parent'} = $result_trees{'part_node_part_node_appendix'}[1];
 $result_trees{'part_node_part_node_appendix'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'part_node_part_node_appendix'}[1]{'contents'}[2]{'args'}[0];
 $result_trees{'part_node_part_node_appendix'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'part_node_part_node_appendix'}[1]{'contents'}[2];
@@ -582,7 +588,7 @@ $result_trees{'part_node_part_node_appendix'}[2]{'contents'}[0]{'parent'} = $res
 $result_trees{'part_node_part_node_appendix'}[2]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'part_node_part_node_appendix'}[2]{'contents'}[1]{'args'}[0];
 $result_trees{'part_node_part_node_appendix'}[2]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'part_node_part_node_appendix'}[2]{'contents'}[1];
 $result_trees{'part_node_part_node_appendix'}[2]{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'part_node_part_node_appendix'}[2]{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'part_node_part_node_appendix'}[2]{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'part_node_part_node_appendix'}[2]{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'part_node_part_node_appendix'}[2]{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'part_node_part_node_appendix'}[2]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'part_node_part_node_appendix'}[2]{'contents'}[1]{'parent'} = $result_trees{'part_node_part_node_appendix'}[2];
 $result_trees{'part_node_part_node_appendix'}[2]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'part_node_part_node_appendix'}[2]{'contents'}[2]{'args'}[0];
 $result_trees{'part_node_part_node_appendix'}[2]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'part_node_part_node_appendix'}[2]{'contents'}[2];
@@ -806,25 +812,13 @@ $result_nodes{'part_node_part_node_appendix'} = {
       }
     }
   ],
-  'node_next' => {},
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
-  }
+  'node_next' => {}
 };
 $result_nodes{'part_node_part_node_appendix'}{'menu_child'}{'node_next'}{'node_prev'} = $result_nodes{'part_node_part_node_appendix'}{'menu_child'};
 $result_nodes{'part_node_part_node_appendix'}{'menu_child'}{'node_next'}{'node_up'} = $result_nodes{'part_node_part_node_appendix'};
 $result_nodes{'part_node_part_node_appendix'}{'menu_child'}{'node_prev'} = $result_nodes{'part_node_part_node_appendix'};
 $result_nodes{'part_node_part_node_appendix'}{'menu_child'}{'node_up'} = $result_nodes{'part_node_part_node_appendix'};
 $result_nodes{'part_node_part_node_appendix'}{'node_next'} = $result_nodes{'part_node_part_node_appendix'}{'menu_child'};
-$result_nodes{'part_node_part_node_appendix'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'part_node_part_node_appendix'};
 
 $result_menus{'part_node_part_node_appendix'} = {
   'cmdname' => 'node',
@@ -863,6 +857,9 @@ $result_menus{'part_node_part_node_appendix'}{'menu_child'}{'menu_up'} = $result
 $result_errors{'part_node_part_node_appendix'} = [];
 
 
+$result_floats{'part_node_part_node_appendix'} = {};
+
+
 $result_elements{'part_node_part_node_appendix'} = [
   {
     'extra' => {
@@ -963,17 +960,6 @@ $result_elements{'part_node_part_node_appendix'} = [
         'Next' => {},
         'NodeForward' => {},
         'NodeNext' => {},
-        'NodeUp' => {
-          'extra' => {
-            'manual_content' => [
-              {
-                'text' => 'dir'
-              }
-            ],
-            'top_node_up' => {}
-          },
-          'type' => 'external_node'
-        },
         'This' => {}
       },
       'element_command' => {
@@ -1016,7 +1002,6 @@ $result_elements{'part_node_part_node_appendix'}[0]{'extra'}{'directions'}{'Forw
 $result_elements{'part_node_part_node_appendix'}[0]{'extra'}{'directions'}{'Next'} = $result_elements{'part_node_part_node_appendix'}[0]{'extra'}{'directions'}{'FastForward'};
 $result_elements{'part_node_part_node_appendix'}[0]{'extra'}{'directions'}{'NodeForward'} = $result_elements{'part_node_part_node_appendix'}[0]{'extra'}{'directions'}{'FastForward'};
 $result_elements{'part_node_part_node_appendix'}[0]{'extra'}{'directions'}{'NodeNext'} = $result_elements{'part_node_part_node_appendix'}[0]{'extra'}{'directions'}{'FastForward'};
-$result_elements{'part_node_part_node_appendix'}[0]{'extra'}{'directions'}{'NodeUp'}{'extra'}{'top_node_up'} = $result_elements{'part_node_part_node_appendix'}[0]{'extra'}{'directions'}{'FastForward'}{'extra'}{'directions'}{'FastForward'}{'extra'}{'node'}{'menu_prev'}{'menu_up'};
 $result_elements{'part_node_part_node_appendix'}[0]{'extra'}{'directions'}{'This'} = $result_elements{'part_node_part_node_appendix'}[0];
 $result_elements{'part_node_part_node_appendix'}[0]{'extra'}{'node'} = $result_elements{'part_node_part_node_appendix'}[0]{'extra'}{'directions'}{'FastForward'}{'extra'}{'directions'}{'FastForward'}{'extra'}{'node'}{'menu_prev'}{'menu_up'};
 $result_elements{'part_node_part_node_appendix'}[0]{'extra'}{'section'} = $result_elements{'part_node_part_node_appendix'}[0]{'extra'}{'element_command'};
@@ -1031,7 +1016,6 @@ $result_directions_text{'part_node_part_node_appendix'} = 'element: @top top
   Next: @chapter chapter
   NodeForward: @chapter chapter
   NodeNext: @chapter chapter
-  NodeUp: (dir)
   This: @top top
 element: @chapter chapter
   Back: @top top
@@ -1087,6 +1071,11 @@ Node: chapter node136
 Node: appendix node232
 
 End Tag Table
+
+
+Local Variables:
+coding: utf-8
+End:
 ';
 
 
@@ -1101,14 +1090,16 @@ $result_converted{'html'}->{'part_node_part_node_appendix'} = '<!DOCTYPE html PU
 <meta name="keywords" content="top">
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
+<meta name="viewport" content="width=device-width,initial-scale=1">
+
 <link href="#Top" rel="start" title="Top">
 <style type="text/css">
 <!--
+a.copiable-anchor {visibility: hidden; text-decoration: none; line-height: 0em}
 a.summary-letter {text-decoration: none}
 blockquote.indentedblock {margin-right: 0em}
 div.display {margin-left: 3.2em}
 div.example {margin-left: 3.2em}
-div.lisp {margin-left: 3.2em}
 kbd {font-style: oblique}
 pre.display {font-family: inherit}
 pre.format {font-family: inherit}
@@ -1117,6 +1108,7 @@ pre.menu-preformatted {font-family: serif}
 span.nolinebreak {white-space: nowrap}
 span.roman {font-family: initial; font-weight: normal}
 span.sansserif {font-family: sans-serif; font-weight: normal}
+span:hover a.copiable-anchor {visibility: visible}
 ul.no-bullet {list-style: none}
 -->
 </style>
@@ -1125,39 +1117,48 @@ ul.no-bullet {list-style: none}
 </head>
 
 <body lang="en">
-<span id="Top"></span><div class="header">
+<div class="top" id="Top">
+<div class="header">
 <p>
-Next: <a href="#chapter-node" accesskey="n" rel="next">chapter node</a>, Up: <a href="dir.html#Top" accesskey="u" rel="up">(dir)</a> &nbsp; </p>
+Next: <a href="#chapter-node" accesskey="n" rel="next">chapter</a> &nbsp; </p>
 </div>
 <span id="top"></span><h1 class="top">top</h1>
 
-<table class="menu" border="0" cellspacing="0">
-<tr><td align="left" valign="top">&bull; <a href="#chapter-node" accesskey="1">chapter node</a></td><td>&nbsp;&nbsp;</td><td align="left" valign="top">
-</td></tr>
-<tr><td align="left" valign="top">&bull; <a href="#appendix-node" accesskey="2">appendix node</a></td><td>&nbsp;&nbsp;</td><td align="left" valign="top">
-</td></tr>
-</table>
 
 <hr>
-<span id="Part-1"></span><div class="header">
+</div>
+<div class="part" id="Part-1">
+<div class="header">
 <p>
-Next: <a href="#appendix-node" accesskey="n" rel="next">appendix node</a>, Previous: <a href="#Top" accesskey="p" rel="prev">Top</a>, Up: <a href="#Top" accesskey="u" rel="up">Top</a> &nbsp; </p>
+Next: <a href="#appendix-node" accesskey="n" rel="next">Appendix</a>, Previous: <a href="#Top" accesskey="p" rel="prev">top</a>, Up: <a href="#Top" accesskey="u" rel="up">top</a> &nbsp; </p>
 </div>
 <h1 class="part">Part 1</h1>
 <hr>
 
-<span id="chapter-node"></span><span id="chapter"></span><h2 class="chapter">1 chapter</h2>
+<ul class="section-toc">
+<li><a href="#chapter-node" accesskey="1">chapter</a></li>
+</ul>
+<div class="chapter" id="chapter-node">
+<span id="chapter"></span><h2 class="chapter">1 chapter</h2>
 
 <hr>
-<span id="Part-Appendix"></span><div class="header">
+</div>
+</div>
+<div class="part" id="Part-Appendix">
+<div class="header">
 <p>
-Previous: <a href="#chapter-node" accesskey="p" rel="prev">chapter node</a>, Up: <a href="#Top" accesskey="u" rel="up">Top</a> &nbsp; </p>
+Previous: <a href="#chapter-node" accesskey="p" rel="prev">chapter</a>, Up: <a href="#Top" accesskey="u" rel="up">top</a> &nbsp; </p>
 </div>
 <h1 class="part">Part Appendix</h1>
 <hr>
 
-<span id="appendix-node"></span><span id="Appendix"></span><h2 class="appendix">Appendix A Appendix</h2>
-<hr>
+<ul class="section-toc">
+<li><a href="#appendix-node" accesskey="1">Appendix</a></li>
+</ul>
+<div class="appendix" id="appendix-node">
+<span id="Appendix"></span><h2 class="appendix">Appendix A Appendix</h2>
+</div>
+</div>
 
 
 
@@ -1166,7 +1167,7 @@ Previous: <a href="#chapter-node" accesskey="p" rel="prev">chapter node</a>, Up:
 ';
 
 
-$result_converted{'xml'}->{'part_node_part_node_appendix'} = '<node name="Top" spaces=" "><nodename>Top</nodename><nodenext automatic="on">chapter node</nodenext><nodeup automatic="on">(dir)</nodeup></node>
+$result_converted{'xml'}->{'part_node_part_node_appendix'} = '<node name="Top" spaces=" "><nodename>Top</nodename><nodenext automatic="on">chapter node</nodenext></node>
 <top spaces=" "><sectiontitle>top</sectiontitle>
 
 <menu endspaces=" ">
