@@ -16,27 +16,17 @@ $result_trees{'section_before_chapter'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'section'
-            },
-            {
-              'parent' => {},
-              'text' => ' 
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => ' 
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'section',
@@ -49,10 +39,7 @@ $result_trees{'section_before_chapter'} = {
         }
       ],
       'extra' => {
-        'misc_content' => [
-          {}
-        ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'level' => 2,
       'line_nr' => {
@@ -67,36 +54,23 @@ $result_trees{'section_before_chapter'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'chapter'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'chapter',
       'contents' => [],
       'extra' => {
-        'misc_content' => [
-          {}
-        ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'level' => 2,
       'line_nr' => {
@@ -111,22 +85,12 @@ $result_trees{'section_before_chapter'} = {
   'type' => 'document_root'
 };
 $result_trees{'section_before_chapter'}{'contents'}[0]{'parent'} = $result_trees{'section_before_chapter'};
-$result_trees{'section_before_chapter'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'section_before_chapter'}{'contents'}[1];
 $result_trees{'section_before_chapter'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'section_before_chapter'}{'contents'}[1]{'args'}[0];
-$result_trees{'section_before_chapter'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'section_before_chapter'}{'contents'}[1]{'args'}[0];
-$result_trees{'section_before_chapter'}{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'section_before_chapter'}{'contents'}[1]{'args'}[0];
 $result_trees{'section_before_chapter'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'section_before_chapter'}{'contents'}[1];
 $result_trees{'section_before_chapter'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'section_before_chapter'}{'contents'}[1];
-$result_trees{'section_before_chapter'}{'contents'}[1]{'extra'}{'misc_content'}[0] = $result_trees{'section_before_chapter'}{'contents'}[1]{'args'}[0]{'contents'}[1];
-$result_trees{'section_before_chapter'}{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'section_before_chapter'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'section_before_chapter'}{'contents'}[1]{'parent'} = $result_trees{'section_before_chapter'};
-$result_trees{'section_before_chapter'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'section_before_chapter'}{'contents'}[2];
 $result_trees{'section_before_chapter'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'section_before_chapter'}{'contents'}[2]{'args'}[0];
-$result_trees{'section_before_chapter'}{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'section_before_chapter'}{'contents'}[2]{'args'}[0];
-$result_trees{'section_before_chapter'}{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'section_before_chapter'}{'contents'}[2]{'args'}[0];
 $result_trees{'section_before_chapter'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'section_before_chapter'}{'contents'}[2];
-$result_trees{'section_before_chapter'}{'contents'}[2]{'extra'}{'misc_content'}[0] = $result_trees{'section_before_chapter'}{'contents'}[2]{'args'}[0]{'contents'}[1];
-$result_trees{'section_before_chapter'}{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'section_before_chapter'}{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'section_before_chapter'}{'contents'}[2]{'parent'} = $result_trees{'section_before_chapter'};
 
 $result_texis{'section_before_chapter'} = '@section section 
@@ -147,14 +111,18 @@ $result_sectioning{'section_before_chapter'} = {
   'section_childs' => [
     {
       'cmdname' => 'section',
-      'extra' => {},
+      'extra' => {
+        'spaces_before_argument' => ' '
+      },
       'level' => 2,
       'number' => 1,
       'section_up' => {}
     },
     {
       'cmdname' => 'chapter',
-      'extra' => {},
+      'extra' => {
+        'spaces_before_argument' => ' '
+      },
       'level' => 2,
       'number' => 2,
       'section_prev' => {},
@@ -181,6 +149,9 @@ $result_errors{'section_before_chapter'} = [
 ];
 
 
+$result_floats{'section_before_chapter'} = {};
+
+
 
 $result_converted{'xml'}->{'section_before_chapter'} = '<section spaces=" "><sectiontitle>section </sectiontitle>
 
