@@ -191,6 +191,9 @@ $result_errors{'section_before_part'} = [
 ];
 
 
+$result_floats{'section_before_part'} = {};
+
+
 
 $result_converted{'plaintext'}->{'section_before_part'} = '1 section
 =========
@@ -211,14 +214,16 @@ $result_converted{'html'}->{'section_before_part'} = '<!DOCTYPE html PUBLIC "-//
 <meta name="keywords" content="Untitled Document">
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
+<meta name="viewport" content="width=device-width,initial-scale=1">
+
 <link href="#SEC_Contents" rel="contents" title="Table of Contents">
 <style type="text/css">
 <!--
+a.copiable-anchor {visibility: hidden; text-decoration: none; line-height: 0em}
 a.summary-letter {text-decoration: none}
 blockquote.indentedblock {margin-right: 0em}
 div.display {margin-left: 3.2em}
 div.example {margin-left: 3.2em}
-div.lisp {margin-left: 3.2em}
 kbd {font-style: oblique}
 pre.display {font-family: inherit}
 pre.format {font-family: inherit}
@@ -227,6 +232,7 @@ pre.menu-preformatted {font-family: serif}
 span.nolinebreak {white-space: nowrap}
 span.roman {font-family: initial; font-weight: normal}
 span.sansserif {font-family: sans-serif; font-weight: normal}
+span:hover a.copiable-anchor {visibility: visible}
 ul.no-bullet {list-style: none}
 -->
 </style>
@@ -235,12 +241,15 @@ ul.no-bullet {list-style: none}
 </head>
 
 <body lang="en">
-<span id="section"></span><h3 class="section">1 section</h3>
+<div class="section" id="section">
+<h3 class="section">1 section</h3>
 
-<span id="part"></span><h1 class="part">part</h1>
+</div>
+<div class="part" id="part">
+<h1 class="part">part</h1>
 <hr>
 
-<span id="SEC_Contents"></span>
+<div class="Contents_element" id="SEC_Contents">
 <h2 class="contents-heading">Table of Contents</h2>
 
 <div class="contents">
@@ -250,8 +259,8 @@ ul.no-bullet {list-style: none}
 
 </ul>
 </div>
-
-<hr>
+</div>
+<hr></div>
 
 
 
