@@ -1,22 +1,16 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
 $result_trees{'sections_test_no_use_nodes'} = {
   'contents' => [
     {
-      'contents' => [
-        {
-          'contents' => [],
-          'parent' => {},
-          'type' => 'preamble_before_content'
-        }
-      ],
+      'contents' => [],
       'parent' => {},
-      'type' => 'before_node_section'
+      'type' => 'text_root'
     },
     {
       'args' => [
@@ -47,12 +41,13 @@ $result_trees{'sections_test_no_use_nodes'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 0,
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 1,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     },
     {
       'args' => [
@@ -83,12 +78,14 @@ $result_trees{'sections_test_no_use_nodes'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 1,
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 3,
         'macro' => ''
-      }
+      },
+      'number' => 1,
+      'parent' => {}
     },
     {
       'args' => [
@@ -119,12 +116,14 @@ $result_trees{'sections_test_no_use_nodes'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 2,
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 5,
         'macro' => ''
-      }
+      },
+      'number' => '1.1',
+      'parent' => {}
     },
     {
       'args' => [
@@ -155,12 +154,14 @@ $result_trees{'sections_test_no_use_nodes'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 3,
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 7,
         'macro' => ''
-      }
+      },
+      'number' => '1.1.1',
+      'parent' => {}
     },
     {
       'args' => [
@@ -191,12 +192,14 @@ $result_trees{'sections_test_no_use_nodes'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 4,
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 9,
         'macro' => ''
-      }
+      },
+      'number' => '1.1.1.1',
+      'parent' => {}
     },
     {
       'args' => [
@@ -227,12 +230,13 @@ $result_trees{'sections_test_no_use_nodes'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 0,
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 11,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     },
     {
       'args' => [
@@ -264,12 +268,14 @@ $result_trees{'sections_test_no_use_nodes'} = {
         'associated_part' => {},
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 1,
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 13,
         'macro' => ''
-      }
+      },
+      'number' => 2,
+      'parent' => {}
     },
     {
       'args' => [
@@ -300,12 +306,14 @@ $result_trees{'sections_test_no_use_nodes'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 1,
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 15,
         'macro' => ''
-      }
+      },
+      'number' => 3,
+      'parent' => {}
     },
     {
       'args' => [
@@ -336,12 +344,13 @@ $result_trees{'sections_test_no_use_nodes'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 1,
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 17,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     },
     {
       'args' => [
@@ -372,12 +381,14 @@ $result_trees{'sections_test_no_use_nodes'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 1,
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 19,
         'macro' => ''
-      }
+      },
+      'number' => 'A',
+      'parent' => {}
     },
     {
       'args' => [
@@ -397,20 +408,22 @@ $result_trees{'sections_test_no_use_nodes'} = {
         }
       ],
       'cmdname' => 'appendixsec',
+      'contents' => [],
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'level' => 2,
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 21,
         'macro' => ''
-      }
+      },
+      'number' => 'A.1',
+      'parent' => {}
     }
   ],
   'type' => 'document_root'
 };
-$result_trees{'sections_test_no_use_nodes'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'sections_test_no_use_nodes'}{'contents'}[0];
 $result_trees{'sections_test_no_use_nodes'}{'contents'}[0]{'parent'} = $result_trees{'sections_test_no_use_nodes'};
 $result_trees{'sections_test_no_use_nodes'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'sections_test_no_use_nodes'}{'contents'}[1]{'args'}[0];
 $result_trees{'sections_test_no_use_nodes'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'sections_test_no_use_nodes'}{'contents'}[1];
@@ -516,165 +529,161 @@ A.1 appendixsec
 ';
 
 $result_sectioning{'sections_test_no_use_nodes'} = {
-  'structure' => {
-    'section_childs' => [
-      {
-        'cmdname' => 'top',
-        'extra' => {},
-        'structure' => {
+  'level' => -1,
+  'section_childs' => [
+    {
+      'cmdname' => 'top',
+      'extra' => {
+        'spaces_before_argument' => ' '
+      },
+      'level' => 0,
+      'section_childs' => [
+        {
+          'cmdname' => 'chapter',
+          'extra' => {
+            'spaces_before_argument' => ' '
+          },
+          'level' => 1,
+          'number' => 1,
           'section_childs' => [
             {
-              'cmdname' => 'chapter',
-              'extra' => {},
-              'structure' => {
-                'section_childs' => [
-                  {
-                    'cmdname' => 'section',
-                    'extra' => {},
-                    'structure' => {
-                      'section_childs' => [
-                        {
-                          'cmdname' => 'subsection',
-                          'extra' => {},
-                          'structure' => {
-                            'section_childs' => [
-                              {
-                                'cmdname' => 'subsubsection',
-                                'extra' => {},
-                                'structure' => {
-                                  'section_level' => 4,
-                                  'section_number' => '1.1.1.1',
-                                  'section_up' => {}
-                                }
-                              }
-                            ],
-                            'section_level' => 3,
-                            'section_number' => '1.1.1',
-                            'section_up' => {}
-                          }
-                        }
-                      ],
-                      'section_level' => 2,
-                      'section_number' => '1.1',
+              'cmdname' => 'section',
+              'extra' => {
+                'spaces_before_argument' => ' '
+              },
+              'level' => 2,
+              'number' => '1.1',
+              'section_childs' => [
+                {
+                  'cmdname' => 'subsection',
+                  'extra' => {
+                    'spaces_before_argument' => ' '
+                  },
+                  'level' => 3,
+                  'number' => '1.1.1',
+                  'section_childs' => [
+                    {
+                      'cmdname' => 'subsubsection',
+                      'extra' => {
+                        'spaces_before_argument' => ' '
+                      },
+                      'level' => 4,
+                      'number' => '1.1.1.1',
                       'section_up' => {}
                     }
-                  }
-                ],
-                'section_level' => 1,
-                'section_number' => 1,
-                'section_up' => {},
-                'toplevel_prev' => {},
-                'toplevel_up' => {}
-              }
+                  ],
+                  'section_up' => {}
+                }
+              ],
+              'section_up' => {}
             }
           ],
-          'section_level' => 0,
-          'section_up' => {}
+          'section_up' => {},
+          'toplevel_prev' => {},
+          'toplevel_up' => {}
         }
-      },
-      {
-        'cmdname' => 'part',
-        'extra' => {
-          'part_associated_section' => {
-            'cmdname' => 'chapter',
-            'extra' => {
-              'associated_part' => {}
-            },
-            'structure' => {
-              'section_level' => 1,
-              'section_number' => 2,
-              'section_up' => {},
-              'toplevel_prev' => {},
-              'toplevel_up' => {}
-            }
-          }
+      ],
+      'section_up' => {}
+    },
+    {
+      'cmdname' => 'part',
+      'extra' => {
+        'part_associated_section' => {
+          'cmdname' => 'chapter',
+          'extra' => {
+            'associated_part' => {},
+            'spaces_before_argument' => ' '
+          },
+          'level' => 1,
+          'number' => 2,
+          'section_up' => {},
+          'toplevel_prev' => {},
+          'toplevel_up' => {}
         },
-        'structure' => {
-          'section_childs' => [
-            {},
-            {
-              'cmdname' => 'chapter',
-              'extra' => {},
-              'structure' => {
-                'section_level' => 1,
-                'section_number' => 3,
-                'section_prev' => {},
-                'section_up' => {},
-                'toplevel_prev' => {},
-                'toplevel_up' => {}
-              }
-            },
-            {
-              'cmdname' => 'unnumbered',
-              'extra' => {},
-              'structure' => {
-                'section_level' => 1,
-                'section_prev' => {},
-                'section_up' => {},
-                'toplevel_prev' => {},
-                'toplevel_up' => {}
-              }
-            }
-          ],
-          'section_level' => 0,
-          'section_prev' => {},
-          'section_up' => {}
-        }
+        'spaces_before_argument' => ' '
       },
-      {
-        'cmdname' => 'appendix',
-        'extra' => {},
-        'structure' => {
-          'section_childs' => [
-            {
-              'cmdname' => 'appendixsec',
-              'extra' => {},
-              'structure' => {
-                'section_level' => 2,
-                'section_number' => 'A.1',
-                'section_up' => {}
-              }
-            }
-          ],
-          'section_level' => 1,
-          'section_number' => 'A',
+      'level' => 0,
+      'section_childs' => [
+        {},
+        {
+          'cmdname' => 'chapter',
+          'extra' => {
+            'spaces_before_argument' => ' '
+          },
+          'level' => 1,
+          'number' => 3,
+          'section_prev' => {},
+          'section_up' => {},
+          'toplevel_prev' => {},
+          'toplevel_up' => {}
+        },
+        {
+          'cmdname' => 'unnumbered',
+          'extra' => {
+            'spaces_before_argument' => ' '
+          },
+          'level' => 1,
           'section_prev' => {},
           'section_up' => {},
           'toplevel_prev' => {},
           'toplevel_up' => {}
         }
-      }
-    ],
-    'section_level' => -1
-  }
+      ],
+      'section_prev' => {},
+      'section_up' => {}
+    },
+    {
+      'cmdname' => 'appendix',
+      'extra' => {
+        'spaces_before_argument' => ' '
+      },
+      'level' => 1,
+      'number' => 'A',
+      'section_childs' => [
+        {
+          'cmdname' => 'appendixsec',
+          'extra' => {
+            'spaces_before_argument' => ' '
+          },
+          'level' => 2,
+          'number' => 'A.1',
+          'section_up' => {}
+        }
+      ],
+      'section_prev' => {},
+      'section_up' => {},
+      'toplevel_prev' => {},
+      'toplevel_up' => {}
+    }
+  ]
 };
-$result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0];
-$result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0];
-$result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0];
-$result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[0];
-$result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'toplevel_prev'} = $result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[0];
-$result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0]{'structure'}{'toplevel_up'} = $result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[0];
-$result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'sections_test_no_use_nodes'};
-$result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[1]{'extra'}{'part_associated_section'}{'extra'}{'associated_part'} = $result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[1];
-$result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[1]{'extra'}{'part_associated_section'}{'structure'}{'section_up'} = $result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[1];
-$result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[1]{'extra'}{'part_associated_section'}{'structure'}{'toplevel_prev'} = $result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[0]{'structure'}{'section_childs'}[0];
-$result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[1]{'extra'}{'part_associated_section'}{'structure'}{'toplevel_up'} = $result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[0];
-$result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[1]{'structure'}{'section_childs'}[0] = $result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[1]{'extra'}{'part_associated_section'};
-$result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[1]{'structure'}{'section_childs'}[1]{'structure'}{'section_prev'} = $result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[1]{'extra'}{'part_associated_section'};
-$result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[1]{'structure'}{'section_childs'}[1]{'structure'}{'section_up'} = $result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[1];
-$result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[1]{'structure'}{'section_childs'}[1]{'structure'}{'toplevel_prev'} = $result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[1]{'extra'}{'part_associated_section'};
-$result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[1]{'structure'}{'section_childs'}[1]{'structure'}{'toplevel_up'} = $result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[0];
-$result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[1]{'structure'}{'section_childs'}[2]{'structure'}{'section_prev'} = $result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[1]{'structure'}{'section_childs'}[1];
-$result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[1]{'structure'}{'section_childs'}[2]{'structure'}{'section_up'} = $result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[1];
-$result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[1]{'structure'}{'section_childs'}[2]{'structure'}{'toplevel_prev'} = $result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[1]{'structure'}{'section_childs'}[1];
-$result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[1]{'structure'}{'section_childs'}[2]{'structure'}{'toplevel_up'} = $result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[0];
-$result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[1]{'structure'}{'section_prev'} = $result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[0];
-$result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[1]{'structure'}{'section_up'} = $result_sectioning{'sections_test_no_use_nodes'};
-$result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[2]{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[2];
-$result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[2]{'structure'}{'section_prev'} = $result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[1];
-$result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[2]{'structure'}{'section_up'} = $result_sectioning{'sections_test_no_use_nodes'};
-$result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[2]{'structure'}{'toplevel_prev'} = $result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[1]{'structure'}{'section_childs'}[2];
-$result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[2]{'structure'}{'toplevel_up'} = $result_sectioning{'sections_test_no_use_nodes'}{'structure'}{'section_childs'}[0];
+$result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[0]{'section_up'} = $result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[0];
+$result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[0]{'section_up'} = $result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[0];
+$result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[0]{'section_childs'}[0]{'section_childs'}[0]{'section_up'} = $result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[0]{'section_childs'}[0];
+$result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[0]{'section_childs'}[0]{'section_up'} = $result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[0];
+$result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[0]{'section_childs'}[0]{'toplevel_prev'} = $result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[0];
+$result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[0]{'section_childs'}[0]{'toplevel_up'} = $result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[0];
+$result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[0]{'section_up'} = $result_sectioning{'sections_test_no_use_nodes'};
+$result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[1]{'extra'}{'part_associated_section'}{'extra'}{'associated_part'} = $result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[1];
+$result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[1]{'extra'}{'part_associated_section'}{'section_up'} = $result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[1];
+$result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[1]{'extra'}{'part_associated_section'}{'toplevel_prev'} = $result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[0]{'section_childs'}[0];
+$result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[1]{'extra'}{'part_associated_section'}{'toplevel_up'} = $result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[0];
+$result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[1]{'section_childs'}[0] = $result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[1]{'extra'}{'part_associated_section'};
+$result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[1]{'section_childs'}[1]{'section_prev'} = $result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[1]{'extra'}{'part_associated_section'};
+$result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[1]{'section_childs'}[1]{'section_up'} = $result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[1];
+$result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[1]{'section_childs'}[1]{'toplevel_prev'} = $result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[1]{'extra'}{'part_associated_section'};
+$result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[1]{'section_childs'}[1]{'toplevel_up'} = $result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[0];
+$result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[1]{'section_childs'}[2]{'section_prev'} = $result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[1]{'section_childs'}[1];
+$result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[1]{'section_childs'}[2]{'section_up'} = $result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[1];
+$result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[1]{'section_childs'}[2]{'toplevel_prev'} = $result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[1]{'section_childs'}[1];
+$result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[1]{'section_childs'}[2]{'toplevel_up'} = $result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[0];
+$result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[1]{'section_prev'} = $result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[0];
+$result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[1]{'section_up'} = $result_sectioning{'sections_test_no_use_nodes'};
+$result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[2]{'section_childs'}[0]{'section_up'} = $result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[2];
+$result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[2]{'section_prev'} = $result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[1];
+$result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[2]{'section_up'} = $result_sectioning{'sections_test_no_use_nodes'};
+$result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[2]{'toplevel_prev'} = $result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[1]{'section_childs'}[2];
+$result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[2]{'toplevel_up'} = $result_sectioning{'sections_test_no_use_nodes'}{'section_childs'}[0];
 
 $result_errors{'sections_test_no_use_nodes'} = [];
 
@@ -716,7 +725,7 @@ A.1 appendixsec
 ';
 
 
-$result_converted{'html'}->{'sections_test_no_use_nodes'} = '<!DOCTYPE html>
+$result_converted{'html'}->{'sections_test_no_use_nodes'} = '<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
 <html>
 <!-- Created by texinfo, http://www.gnu.org/software/texinfo/ -->
 <head>
@@ -730,57 +739,76 @@ $result_converted{'html'}->{'sections_test_no_use_nodes'} = '<!DOCTYPE html>
 <meta name="viewport" content="width=device-width,initial-scale=1">
 
 <link href="#top" rel="start" title="top">
+<style type="text/css">
+<!--
+a.copiable-anchor {visibility: hidden; text-decoration: none; line-height: 0em}
+a.summary-letter {text-decoration: none}
+blockquote.indentedblock {margin-right: 0em}
+div.display {margin-left: 3.2em}
+div.example {margin-left: 3.2em}
+kbd {font-style: oblique}
+pre.display {font-family: inherit}
+pre.format {font-family: inherit}
+pre.menu-comment {font-family: serif}
+pre.menu-preformatted {font-family: serif}
+span.nolinebreak {white-space: nowrap}
+span.roman {font-family: initial; font-weight: normal}
+span.sansserif {font-family: sans-serif; font-weight: normal}
+span:hover a.copiable-anchor {visibility: visible}
+ul.no-bullet {list-style: none}
+-->
+</style>
 
 
 </head>
 
 <body lang="en">
-<div class="top-level-extent" id="top">
-<div class="nav-panel">
+<div class="top" id="top">
+<div class="header">
 <p>
 Next: <a href="#chapter-in-part" accesskey="n" rel="next">chapter in part</a> &nbsp; </p>
 </div>
 <h1 class="top">top</h1>
 
-<ul class="mini-toc">
+<ul class="section-toc">
 <li><a href="#chapter" accesskey="1">chapter</a></li>
 </ul>
 <hr>
-<div class="chapter-level-extent" id="chapter">
-<div class="nav-panel">
+<div class="chapter" id="chapter">
+<div class="header">
 <p>
  Up : <a href="#top" accesskey="u" rel="up">top</a> &nbsp; </p>
 </div>
 <h2 class="chapter">1 chapter</h2>
 
-<ul class="mini-toc">
+<ul class="section-toc">
 <li><a href="#section" accesskey="1">section</a></li>
 </ul>
 <hr>
-<div class="section-level-extent" id="section">
-<div class="nav-panel">
+<div class="section" id="section">
+<div class="header">
 <p>
  Up : <a href="#chapter" accesskey="u" rel="up">chapter</a> &nbsp; </p>
 </div>
 <h3 class="section">1.1 section</h3>
 
-<ul class="mini-toc">
+<ul class="section-toc">
 <li><a href="#subsection" accesskey="1">subsection</a></li>
 </ul>
 <hr>
-<div class="subsection-level-extent" id="subsection">
-<div class="nav-panel">
+<div class="subsection" id="subsection">
+<div class="header">
 <p>
  Up : <a href="#section" accesskey="u" rel="up">section</a> &nbsp; </p>
 </div>
 <h4 class="subsection">1.1.1 subsection</h4>
 
-<ul class="mini-toc">
+<ul class="section-toc">
 <li><a href="#subsubsection" accesskey="1">subsubsection</a></li>
 </ul>
 <hr>
-<div class="subsubsection-level-extent" id="subsubsection">
-<div class="nav-panel">
+<div class="subsubsection" id="subsubsection">
+<div class="header">
 <p>
  Up : <a href="#subsection" accesskey="u" rel="up">subsection</a> &nbsp; </p>
 </div>
@@ -792,26 +820,26 @@ Next: <a href="#chapter-in-part" accesskey="n" rel="next">chapter in part</a> &n
 </div>
 </div>
 </div>
-<div class="part-level-extent" id="part">
-<div class="nav-panel">
+<div class="part" id="part">
+<div class="header">
 <p>
 Next: <a href="#second-chapter-in-part" accesskey="n" rel="next">second chapter in part</a> &nbsp; </p>
 </div>
 <h1 class="part">part</h1>
 <hr>
 
-<ul class="mini-toc">
+<ul class="section-toc">
 <li><a href="#chapter-in-part" accesskey="1">chapter in part</a></li>
 <li><a href="#second-chapter-in-part" accesskey="2">second chapter in part</a></li>
 <li><a href="#unnumbered" accesskey="3">unnumbered</a></li>
 </ul>
-<div class="chapter-level-extent" id="chapter-in-part">
+<div class="chapter" id="chapter-in-part">
 <h2 class="chapter">2 chapter in part</h2>
 
 <hr>
 </div>
-<div class="chapter-level-extent" id="second-chapter-in-part">
-<div class="nav-panel">
+<div class="chapter" id="second-chapter-in-part">
+<div class="header">
 <p>
 Next: <a href="#unnumbered" accesskey="n" rel="next">unnumbered</a>, Prev: <a href="#chapter-in-part" accesskey="p" rel="prev">chapter in part</a>,  Up : <a href="#chapter-in-part" accesskey="u" rel="up">chapter in part</a> &nbsp; </p>
 </div>
@@ -819,8 +847,8 @@ Next: <a href="#unnumbered" accesskey="n" rel="next">unnumbered</a>, Prev: <a hr
 
 <hr>
 </div>
-<div class="unnumbered-level-extent" id="unnumbered">
-<div class="nav-panel">
+<div class="unnumbered" id="unnumbered">
+<div class="header">
 <p>
 Prev: <a href="#second-chapter-in-part" accesskey="p" rel="prev">second chapter in part</a>,  Up : <a href="#chapter-in-part" accesskey="u" rel="up">chapter in part</a> &nbsp; </p>
 </div>
@@ -828,19 +856,19 @@ Prev: <a href="#second-chapter-in-part" accesskey="p" rel="prev">second chapter
 
 <hr>
 </div>
-<div class="appendix-level-extent" id="appendix">
-<div class="nav-panel">
+<div class="appendix" id="appendix">
+<div class="header">
 <p>
 Prev: <a href="#chapter-in-part" accesskey="p" rel="prev">chapter in part</a> &nbsp; </p>
 </div>
 <h2 class="appendix">Appendix A appendix</h2>
 
-<ul class="mini-toc">
+<ul class="section-toc">
 <li><a href="#appendixsec" accesskey="1">appendixsec</a></li>
 </ul>
 <hr>
-<div class="appendixsec-level-extent" id="appendixsec">
-<div class="nav-panel">
+<div class="appendixsec" id="appendixsec">
+<div class="header">
 <p>
  Up : <a href="#appendix" accesskey="u" rel="up">appendix</a> &nbsp; </p>
 </div>
