@@ -16,27 +16,17 @@ $result_trees{'shortcontents'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'top'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'top',
@@ -49,10 +39,7 @@ $result_trees{'shortcontents'} = {
         }
       ],
       'extra' => {
-        'misc_content' => [
-          {}
-        ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'level' => 0,
       'line_nr' => {
@@ -66,27 +53,17 @@ $result_trees{'shortcontents'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'chapter'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'chapter',
@@ -99,10 +76,7 @@ $result_trees{'shortcontents'} = {
         }
       ],
       'extra' => {
-        'misc_content' => [
-          {}
-        ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'level' => 1,
       'line_nr' => {
@@ -117,27 +91,17 @@ $result_trees{'shortcontents'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'section'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'section',
@@ -150,10 +114,7 @@ $result_trees{'shortcontents'} = {
         }
       ],
       'extra' => {
-        'misc_content' => [
-          {}
-        ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'level' => 2,
       'line_nr' => {
@@ -168,27 +129,17 @@ $result_trees{'shortcontents'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'subsection'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'subsection',
@@ -201,10 +152,7 @@ $result_trees{'shortcontents'} = {
         }
       ],
       'extra' => {
-        'misc_content' => [
-          {}
-        ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'level' => 3,
       'line_nr' => {
@@ -219,27 +167,17 @@ $result_trees{'shortcontents'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'subsubsection'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'subsubsection',
@@ -252,10 +190,7 @@ $result_trees{'shortcontents'} = {
         }
       ],
       'extra' => {
-        'misc_content' => [
-          {}
-        ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'level' => 4,
       'line_nr' => {
@@ -270,27 +205,17 @@ $result_trees{'shortcontents'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'part'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'part',
@@ -303,10 +228,7 @@ $result_trees{'shortcontents'} = {
         }
       ],
       'extra' => {
-        'misc_content' => [
-          {}
-        ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'level' => 0,
       'line_nr' => {
@@ -320,27 +242,17 @@ $result_trees{'shortcontents'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'chapter in part'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'chapter',
@@ -354,10 +266,7 @@ $result_trees{'shortcontents'} = {
       ],
       'extra' => {
         'associated_part' => {},
-        'misc_content' => [
-          {}
-        ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'level' => 1,
       'line_nr' => {
@@ -372,27 +281,17 @@ $result_trees{'shortcontents'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'second chapter in part'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'chapter',
@@ -405,10 +304,7 @@ $result_trees{'shortcontents'} = {
         }
       ],
       'extra' => {
-        'misc_content' => [
-          {}
-        ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'level' => 1,
       'line_nr' => {
@@ -423,27 +319,17 @@ $result_trees{'shortcontents'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'unnumbered'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'unnumbered',
@@ -456,10 +342,7 @@ $result_trees{'shortcontents'} = {
         }
       ],
       'extra' => {
-        'misc_content' => [
-          {}
-        ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'level' => 1,
       'line_nr' => {
@@ -473,27 +356,17 @@ $result_trees{'shortcontents'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'appendix'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'appendix',
@@ -506,10 +379,7 @@ $result_trees{'shortcontents'} = {
         }
       ],
       'extra' => {
-        'misc_content' => [
-          {}
-        ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'level' => 1,
       'line_nr' => {
@@ -524,27 +394,17 @@ $result_trees{'shortcontents'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'parent' => {},
               'text' => 'appendixsec'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'spaces_at_end'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
-          'type' => 'misc_line_arg'
+          'type' => 'line_arg'
         }
       ],
       'cmdname' => 'appendixsec',
@@ -574,10 +434,7 @@ $result_trees{'shortcontents'} = {
         }
       ],
       'extra' => {
-        'misc_content' => [
-          {}
-        ],
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
       },
       'level' => 2,
       'line_nr' => {
@@ -592,107 +449,52 @@ $result_trees{'shortcontents'} = {
   'type' => 'document_root'
 };
 $result_trees{'shortcontents'}{'contents'}[0]{'parent'} = $result_trees{'shortcontents'};
-$result_trees{'shortcontents'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'shortcontents'}{'contents'}[1];
 $result_trees{'shortcontents'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[1]{'args'}[0];
-$result_trees{'shortcontents'}{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'shortcontents'}{'contents'}[1]{'args'}[0];
-$result_trees{'shortcontents'}{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'shortcontents'}{'contents'}[1]{'args'}[0];
 $result_trees{'shortcontents'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[1];
 $result_trees{'shortcontents'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[1];
-$result_trees{'shortcontents'}{'contents'}[1]{'extra'}{'misc_content'}[0] = $result_trees{'shortcontents'}{'contents'}[1]{'args'}[0]{'contents'}[1];
-$result_trees{'shortcontents'}{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'shortcontents'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'shortcontents'}{'contents'}[1]{'parent'} = $result_trees{'shortcontents'};
-$result_trees{'shortcontents'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'shortcontents'}{'contents'}[2];
 $result_trees{'shortcontents'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[2]{'args'}[0];
-$result_trees{'shortcontents'}{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'shortcontents'}{'contents'}[2]{'args'}[0];
-$result_trees{'shortcontents'}{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'shortcontents'}{'contents'}[2]{'args'}[0];
 $result_trees{'shortcontents'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[2];
 $result_trees{'shortcontents'}{'contents'}[2]{'contents'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[2];
-$result_trees{'shortcontents'}{'contents'}[2]{'extra'}{'misc_content'}[0] = $result_trees{'shortcontents'}{'contents'}[2]{'args'}[0]{'contents'}[1];
-$result_trees{'shortcontents'}{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'shortcontents'}{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'shortcontents'}{'contents'}[2]{'parent'} = $result_trees{'shortcontents'};
-$result_trees{'shortcontents'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'shortcontents'}{'contents'}[3];
 $result_trees{'shortcontents'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[3]{'args'}[0];
-$result_trees{'shortcontents'}{'contents'}[3]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'shortcontents'}{'contents'}[3]{'args'}[0];
-$result_trees{'shortcontents'}{'contents'}[3]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'shortcontents'}{'contents'}[3]{'args'}[0];
 $result_trees{'shortcontents'}{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[3];
 $result_trees{'shortcontents'}{'contents'}[3]{'contents'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[3];
-$result_trees{'shortcontents'}{'contents'}[3]{'extra'}{'misc_content'}[0] = $result_trees{'shortcontents'}{'contents'}[3]{'args'}[0]{'contents'}[1];
-$result_trees{'shortcontents'}{'contents'}[3]{'extra'}{'spaces_after_command'} = $result_trees{'shortcontents'}{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'shortcontents'}{'contents'}[3]{'parent'} = $result_trees{'shortcontents'};
-$result_trees{'shortcontents'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'shortcontents'}{'contents'}[4];
 $result_trees{'shortcontents'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[4]{'args'}[0];
-$result_trees{'shortcontents'}{'contents'}[4]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'shortcontents'}{'contents'}[4]{'args'}[0];
-$result_trees{'shortcontents'}{'contents'}[4]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'shortcontents'}{'contents'}[4]{'args'}[0];
 $result_trees{'shortcontents'}{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[4];
 $result_trees{'shortcontents'}{'contents'}[4]{'contents'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[4];
-$result_trees{'shortcontents'}{'contents'}[4]{'extra'}{'misc_content'}[0] = $result_trees{'shortcontents'}{'contents'}[4]{'args'}[0]{'contents'}[1];
-$result_trees{'shortcontents'}{'contents'}[4]{'extra'}{'spaces_after_command'} = $result_trees{'shortcontents'}{'contents'}[4]{'args'}[0]{'contents'}[0];
 $result_trees{'shortcontents'}{'contents'}[4]{'parent'} = $result_trees{'shortcontents'};
-$result_trees{'shortcontents'}{'contents'}[5]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'shortcontents'}{'contents'}[5];
 $result_trees{'shortcontents'}{'contents'}[5]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[5]{'args'}[0];
-$result_trees{'shortcontents'}{'contents'}[5]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'shortcontents'}{'contents'}[5]{'args'}[0];
-$result_trees{'shortcontents'}{'contents'}[5]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'shortcontents'}{'contents'}[5]{'args'}[0];
 $result_trees{'shortcontents'}{'contents'}[5]{'args'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[5];
 $result_trees{'shortcontents'}{'contents'}[5]{'contents'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[5];
-$result_trees{'shortcontents'}{'contents'}[5]{'extra'}{'misc_content'}[0] = $result_trees{'shortcontents'}{'contents'}[5]{'args'}[0]{'contents'}[1];
-$result_trees{'shortcontents'}{'contents'}[5]{'extra'}{'spaces_after_command'} = $result_trees{'shortcontents'}{'contents'}[5]{'args'}[0]{'contents'}[0];
 $result_trees{'shortcontents'}{'contents'}[5]{'parent'} = $result_trees{'shortcontents'};
-$result_trees{'shortcontents'}{'contents'}[6]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'shortcontents'}{'contents'}[6];
 $result_trees{'shortcontents'}{'contents'}[6]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[6]{'args'}[0];
-$result_trees{'shortcontents'}{'contents'}[6]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'shortcontents'}{'contents'}[6]{'args'}[0];
-$result_trees{'shortcontents'}{'contents'}[6]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'shortcontents'}{'contents'}[6]{'args'}[0];
 $result_trees{'shortcontents'}{'contents'}[6]{'args'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[6];
 $result_trees{'shortcontents'}{'contents'}[6]{'contents'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[6];
-$result_trees{'shortcontents'}{'contents'}[6]{'extra'}{'misc_content'}[0] = $result_trees{'shortcontents'}{'contents'}[6]{'args'}[0]{'contents'}[1];
-$result_trees{'shortcontents'}{'contents'}[6]{'extra'}{'spaces_after_command'} = $result_trees{'shortcontents'}{'contents'}[6]{'args'}[0]{'contents'}[0];
 $result_trees{'shortcontents'}{'contents'}[6]{'parent'} = $result_trees{'shortcontents'};
-$result_trees{'shortcontents'}{'contents'}[7]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'shortcontents'}{'contents'}[7];
 $result_trees{'shortcontents'}{'contents'}[7]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[7]{'args'}[0];
-$result_trees{'shortcontents'}{'contents'}[7]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'shortcontents'}{'contents'}[7]{'args'}[0];
-$result_trees{'shortcontents'}{'contents'}[7]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'shortcontents'}{'contents'}[7]{'args'}[0];
 $result_trees{'shortcontents'}{'contents'}[7]{'args'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[7];
 $result_trees{'shortcontents'}{'contents'}[7]{'contents'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[7];
 $result_trees{'shortcontents'}{'contents'}[7]{'extra'}{'associated_part'} = $result_trees{'shortcontents'}{'contents'}[6];
-$result_trees{'shortcontents'}{'contents'}[7]{'extra'}{'misc_content'}[0] = $result_trees{'shortcontents'}{'contents'}[7]{'args'}[0]{'contents'}[1];
-$result_trees{'shortcontents'}{'contents'}[7]{'extra'}{'spaces_after_command'} = $result_trees{'shortcontents'}{'contents'}[7]{'args'}[0]{'contents'}[0];
 $result_trees{'shortcontents'}{'contents'}[7]{'parent'} = $result_trees{'shortcontents'};
-$result_trees{'shortcontents'}{'contents'}[8]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'shortcontents'}{'contents'}[8];
 $result_trees{'shortcontents'}{'contents'}[8]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[8]{'args'}[0];
-$result_trees{'shortcontents'}{'contents'}[8]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'shortcontents'}{'contents'}[8]{'args'}[0];
-$result_trees{'shortcontents'}{'contents'}[8]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'shortcontents'}{'contents'}[8]{'args'}[0];
 $result_trees{'shortcontents'}{'contents'}[8]{'args'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[8];
 $result_trees{'shortcontents'}{'contents'}[8]{'contents'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[8];
-$result_trees{'shortcontents'}{'contents'}[8]{'extra'}{'misc_content'}[0] = $result_trees{'shortcontents'}{'contents'}[8]{'args'}[0]{'contents'}[1];
-$result_trees{'shortcontents'}{'contents'}[8]{'extra'}{'spaces_after_command'} = $result_trees{'shortcontents'}{'contents'}[8]{'args'}[0]{'contents'}[0];
 $result_trees{'shortcontents'}{'contents'}[8]{'parent'} = $result_trees{'shortcontents'};
-$result_trees{'shortcontents'}{'contents'}[9]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'shortcontents'}{'contents'}[9];
 $result_trees{'shortcontents'}{'contents'}[9]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[9]{'args'}[0];
-$result_trees{'shortcontents'}{'contents'}[9]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'shortcontents'}{'contents'}[9]{'args'}[0];
-$result_trees{'shortcontents'}{'contents'}[9]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'shortcontents'}{'contents'}[9]{'args'}[0];
 $result_trees{'shortcontents'}{'contents'}[9]{'args'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[9];
 $result_trees{'shortcontents'}{'contents'}[9]{'contents'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[9];
-$result_trees{'shortcontents'}{'contents'}[9]{'extra'}{'misc_content'}[0] = $result_trees{'shortcontents'}{'contents'}[9]{'args'}[0]{'contents'}[1];
-$result_trees{'shortcontents'}{'contents'}[9]{'extra'}{'spaces_after_command'} = $result_trees{'shortcontents'}{'contents'}[9]{'args'}[0]{'contents'}[0];
 $result_trees{'shortcontents'}{'contents'}[9]{'parent'} = $result_trees{'shortcontents'};
-$result_trees{'shortcontents'}{'contents'}[10]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'shortcontents'}{'contents'}[10];
 $result_trees{'shortcontents'}{'contents'}[10]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[10]{'args'}[0];
-$result_trees{'shortcontents'}{'contents'}[10]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'shortcontents'}{'contents'}[10]{'args'}[0];
-$result_trees{'shortcontents'}{'contents'}[10]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'shortcontents'}{'contents'}[10]{'args'}[0];
 $result_trees{'shortcontents'}{'contents'}[10]{'args'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[10];
 $result_trees{'shortcontents'}{'contents'}[10]{'contents'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[10];
-$result_trees{'shortcontents'}{'contents'}[10]{'extra'}{'misc_content'}[0] = $result_trees{'shortcontents'}{'contents'}[10]{'args'}[0]{'contents'}[1];
-$result_trees{'shortcontents'}{'contents'}[10]{'extra'}{'spaces_after_command'} = $result_trees{'shortcontents'}{'contents'}[10]{'args'}[0]{'contents'}[0];
 $result_trees{'shortcontents'}{'contents'}[10]{'parent'} = $result_trees{'shortcontents'};
-$result_trees{'shortcontents'}{'contents'}[11]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'shortcontents'}{'contents'}[11];
 $result_trees{'shortcontents'}{'contents'}[11]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[11]{'args'}[0];
-$result_trees{'shortcontents'}{'contents'}[11]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'shortcontents'}{'contents'}[11]{'args'}[0];
-$result_trees{'shortcontents'}{'contents'}[11]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'shortcontents'}{'contents'}[11]{'args'}[0];
 $result_trees{'shortcontents'}{'contents'}[11]{'args'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[11];
 $result_trees{'shortcontents'}{'contents'}[11]{'contents'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[11];
 $result_trees{'shortcontents'}{'contents'}[11]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'shortcontents'}{'contents'}[11]{'contents'}[1];
 $result_trees{'shortcontents'}{'contents'}[11]{'contents'}[1]{'parent'} = $result_trees{'shortcontents'}{'contents'}[11];
-$result_trees{'shortcontents'}{'contents'}[11]{'extra'}{'misc_content'}[0] = $result_trees{'shortcontents'}{'contents'}[11]{'args'}[0]{'contents'}[1];
-$result_trees{'shortcontents'}{'contents'}[11]{'extra'}{'spaces_after_command'} = $result_trees{'shortcontents'}{'contents'}[11]{'args'}[0]{'contents'}[0];
 $result_trees{'shortcontents'}{'contents'}[11]{'parent'} = $result_trees{'shortcontents'};
 
 $result_texis{'shortcontents'} = '@top top
@@ -761,30 +563,40 @@ $result_sectioning{'shortcontents'} = {
   'section_childs' => [
     {
       'cmdname' => 'top',
-      'extra' => {},
+      'extra' => {
+        'spaces_before_argument' => ' '
+      },
       'level' => 0,
       'section_childs' => [
         {
           'cmdname' => 'chapter',
-          'extra' => {},
+          'extra' => {
+            'spaces_before_argument' => ' '
+          },
           'level' => 1,
           'number' => 1,
           'section_childs' => [
             {
               'cmdname' => 'section',
-              'extra' => {},
+              'extra' => {
+                'spaces_before_argument' => ' '
+              },
               'level' => 2,
               'number' => '1.1',
               'section_childs' => [
                 {
                   'cmdname' => 'subsection',
-                  'extra' => {},
+                  'extra' => {
+                    'spaces_before_argument' => ' '
+                  },
                   'level' => 3,
                   'number' => '1.1.1',
                   'section_childs' => [
                     {
                       'cmdname' => 'subsubsection',
-                      'extra' => {},
+                      'extra' => {
+                        'spaces_before_argument' => ' '
+                      },
                       'level' => 4,
                       'number' => '1.1.1.1',
                       'section_up' => {}
@@ -809,21 +621,25 @@ $result_sectioning{'shortcontents'} = {
         'part_associated_section' => {
           'cmdname' => 'chapter',
           'extra' => {
-            'associated_part' => {}
+            'associated_part' => {},
+            'spaces_before_argument' => ' '
           },
           'level' => 1,
           'number' => 2,
           'section_up' => {},
           'toplevel_prev' => {},
           'toplevel_up' => {}
-        }
+        },
+        'spaces_before_argument' => ' '
       },
       'level' => 0,
       'section_childs' => [
         {},
         {
           'cmdname' => 'chapter',
-          'extra' => {},
+          'extra' => {
+            'spaces_before_argument' => ' '
+          },
           'level' => 1,
           'number' => 3,
           'section_prev' => {},
@@ -833,7 +649,9 @@ $result_sectioning{'shortcontents'} = {
         },
         {
           'cmdname' => 'unnumbered',
-          'extra' => {},
+          'extra' => {
+            'spaces_before_argument' => ' '
+          },
           'level' => 1,
           'section_prev' => {},
           'section_up' => {},
@@ -846,13 +664,17 @@ $result_sectioning{'shortcontents'} = {
     },
     {
       'cmdname' => 'appendix',
-      'extra' => {},
+      'extra' => {
+        'spaces_before_argument' => ' '
+      },
       'level' => 1,
       'number' => 'A',
       'section_childs' => [
         {
           'cmdname' => 'appendixsec',
-          'extra' => {},
+          'extra' => {
+            'spaces_before_argument' => ' '
+          },
           'level' => 2,
           'number' => 'A.1',
           'section_up' => {}
@@ -896,6 +718,9 @@ $result_sectioning{'shortcontents'}{'section_childs'}[2]{'toplevel_up'} = $resul
 $result_errors{'shortcontents'} = [];
 
 
+$result_floats{'shortcontents'} = {};
+
+
 
 $result_converted{'plaintext'}->{'shortcontents'} = 'top
 ***
@@ -948,30 +773,24 @@ $result_converted{'html'}->{'shortcontents'} = '<!DOCTYPE html PUBLIC "-//W3C//D
 <meta name="keywords" content="top">
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
+<meta name="viewport" content="width=device-width,initial-scale=1">
+
 <style type="text/css">
 <!--
+a.copiable-anchor {visibility: hidden; text-decoration: none; line-height: 0em}
 a.summary-letter {text-decoration: none}
 blockquote.indentedblock {margin-right: 0em}
-blockquote.smallindentedblock {margin-right: 0em; font-size: smaller}
-blockquote.smallquotation {font-size: smaller}
 div.display {margin-left: 3.2em}
 div.example {margin-left: 3.2em}
-div.lisp {margin-left: 3.2em}
-div.smalldisplay {margin-left: 3.2em}
-div.smallexample {margin-left: 3.2em}
-div.smalllisp {margin-left: 3.2em}
 kbd {font-style: oblique}
 pre.display {font-family: inherit}
 pre.format {font-family: inherit}
 pre.menu-comment {font-family: serif}
 pre.menu-preformatted {font-family: serif}
-pre.smalldisplay {font-family: inherit; font-size: smaller}
-pre.smallexample {font-size: smaller}
-pre.smallformat {font-family: inherit; font-size: smaller}
-pre.smalllisp {font-size: smaller}
 span.nolinebreak {white-space: nowrap}
 span.roman {font-family: initial; font-weight: normal}
 span.sansserif {font-family: sans-serif; font-weight: normal}
+span:hover a.copiable-anchor {visibility: visible}
 ul.no-bullet {list-style: none}
 -->
 </style>
@@ -980,60 +799,87 @@ ul.no-bullet {list-style: none}
 </head>
 
 <body lang="en">
-<a name="top"></a>
+<div class="top" id="top">
 <h1 class="top">top</h1>
 
-<a name="chapter"></a>
-<h2 class="chapter">1 chapter</h2>
-
-<a name="section"></a>
-<h3 class="section">1.1 section</h3>
-
-<a name="subsection"></a>
-<h4 class="subsection">1.1.1 subsection</h4>
-
-<a name="subsubsection"></a>
-<h4 class="subsubsection">1.1.1.1 subsubsection</h4>
-
-<a name="part"></a>
-<h1 class="part">part</h1>
-<hr>
-
-<a name="chapter-in-part"></a>
-<h2 class="chapter">2 chapter in part</h2>
-
-<a name="second-chapter-in-part"></a>
-<h2 class="chapter">3 second chapter in part</h2>
-
-<a name="unnumbered"></a>
-<h2 class="unnumbered">unnumbered</h2>
-
-<a name="appendix"></a>
-<h2 class="appendix">Appendix A appendix</h2>
-
-<a name="appendixsec"></a>
-<h3 class="appendixsec">A.1 appendixsec</h3>
-
-<a name="SEC_Overview"></a>
+<div class="Overview_element" id="SEC_Overview">
 <h2 class="shortcontents-heading">Short Table of Contents</h2>
 
 <div class="shortcontents">
 <ul class="no-bullet">
 <li><ul class="no-bullet">
-<li><a name="stoc-chapter" href="#toc-chapter">1 chapter</a></li>
+<li><a id="stoc-chapter" href="#toc-chapter">1 chapter</a></li>
 </ul></li>
-<li><a name="stoc-part" href="#toc-part">part</a><ul class="no-bullet">
-<li><a name="stoc-chapter-in-part" href="#toc-chapter-in-part">2 chapter in part</a></li>
-<li><a name="stoc-second-chapter-in-part" href="#toc-second-chapter-in-part">3 second chapter in part</a></li>
-<li><a name="stoc-unnumbered" href="#toc-unnumbered">unnumbered</a></li>
+<li><a id="stoc-part" href="#toc-part">part</a><ul class="no-bullet">
+<li><a id="stoc-chapter-in-part" href="#toc-chapter-in-part">2 chapter in part</a></li>
+<li><a id="stoc-second-chapter-in-part" href="#toc-second-chapter-in-part">3 second chapter in part</a></li>
+<li><a id="stoc-unnumbered" href="#toc-unnumbered">unnumbered</a></li>
 </ul></li>
-<li><a name="stoc-appendix" href="#toc-appendix">Appendix A appendix</a></li>
+<li><a id="stoc-appendix" href="#toc-appendix">Appendix A appendix</a></li>
 
 </ul>
 </div>
+</div>
+<div class="chapter" id="chapter">
+<h2 class="chapter">1 chapter</h2>
 
+<ul class="section-toc">
+<li><a href="#section" accesskey="1">section</a></li>
+</ul>
+<div class="section" id="section">
+<h3 class="section">1.1 section</h3>
+
+<ul class="section-toc">
+<li><a href="#subsection" accesskey="1">subsection</a></li>
+</ul>
+<div class="subsection" id="subsection">
+<h4 class="subsection">1.1.1 subsection</h4>
+
+<ul class="section-toc">
+<li><a href="#subsubsection" accesskey="1">subsubsection</a></li>
+</ul>
+<div class="subsubsection" id="subsubsection">
+<h4 class="subsubsection">1.1.1.1 subsubsection</h4>
+
+</div>
+</div>
+</div>
+</div>
+</div>
+<div class="part" id="part">
+<h1 class="part">part</h1>
 <hr>
 
+<ul class="section-toc">
+<li><a href="#chapter-in-part" accesskey="1">chapter in part</a></li>
+<li><a href="#second-chapter-in-part" accesskey="2">second chapter in part</a></li>
+<li><a href="#unnumbered" accesskey="3">unnumbered</a></li>
+</ul>
+<div class="chapter" id="chapter-in-part">
+<h2 class="chapter">2 chapter in part</h2>
+
+</div>
+<div class="chapter" id="second-chapter-in-part">
+<h2 class="chapter">3 second chapter in part</h2>
+
+</div>
+<div class="unnumbered" id="unnumbered">
+<h2 class="unnumbered">unnumbered</h2>
+
+</div>
+<div class="appendix" id="appendix">
+<h2 class="appendix">Appendix A appendix</h2>
+
+<ul class="section-toc">
+<li><a href="#appendixsec" accesskey="1">appendixsec</a></li>
+</ul>
+<div class="appendixsec" id="appendixsec">
+<h3 class="appendixsec">A.1 appendixsec</h3>
+
+<hr></div>
+</div>
+</div>
+
 
 
 </body>
