@@ -278,7 +278,11 @@ $result_trees{'set_on_item_line'} = {
         'end_command' => {},
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {},
+      'line_nr' => {
+        'file_name' => '',
+        'line_nr' => 1,
+        'macro' => ''
+      },
       'parent' => {}
     },
     {
@@ -564,7 +568,11 @@ $result_trees{'set_on_item_line'} = {
         'end_command' => {},
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {},
+      'line_nr' => {
+        'file_name' => '',
+        'line_nr' => 10,
+        'macro' => ''
+      },
       'parent' => {}
     }
   ],
@@ -605,7 +613,6 @@ $result_trees{'set_on_item_line'}{'contents'}[0]{'contents'}[3]{'args'}[0]{'pare
 $result_trees{'set_on_item_line'}{'contents'}[0]{'contents'}[3]{'parent'} = $result_trees{'set_on_item_line'}{'contents'}[0];
 $result_trees{'set_on_item_line'}{'contents'}[0]{'extra'}{'command_as_argument'} = $result_trees{'set_on_item_line'}{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'set_on_item_line'}{'contents'}[0]{'extra'}{'end_command'} = $result_trees{'set_on_item_line'}{'contents'}[0]{'contents'}[3];
-$result_trees{'set_on_item_line'}{'contents'}[0]{'line_nr'} = $result_trees{'set_on_item_line'}{'contents'}[0]{'args'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'set_on_item_line'}{'contents'}[0]{'parent'} = $result_trees{'set_on_item_line'};
 $result_trees{'set_on_item_line'}{'contents'}[1]{'parent'} = $result_trees{'set_on_item_line'};
 $result_trees{'set_on_item_line'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'set_on_item_line'}{'contents'}[2]{'args'}[0];
@@ -645,7 +652,6 @@ $result_trees{'set_on_item_line'}{'contents'}[2]{'contents'}[3]{'args'}[0]{'pare
 $result_trees{'set_on_item_line'}{'contents'}[2]{'contents'}[3]{'parent'} = $result_trees{'set_on_item_line'}{'contents'}[2];
 $result_trees{'set_on_item_line'}{'contents'}[2]{'extra'}{'command_as_argument'} = $result_trees{'set_on_item_line'}{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'set_on_item_line'}{'contents'}[2]{'extra'}{'end_command'} = $result_trees{'set_on_item_line'}{'contents'}[2]{'contents'}[3];
-$result_trees{'set_on_item_line'}{'contents'}[2]{'line_nr'} = $result_trees{'set_on_item_line'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'set_on_item_line'}{'contents'}[2]{'parent'} = $result_trees{'set_on_item_line'};
 
 $result_texis{'set_on_item_line'} = '@table @code
@@ -684,4 +690,7 @@ vvv
 $result_errors{'set_on_item_line'} = [];
 
 
+$result_floats{'set_on_item_line'} = {};
+
+
 1;
