@@ -1,7 +1,7 @@
 use vars qw(%result_texis %result_texts %result_trees %result_errors 
    %result_indices %result_sectioning %result_nodes %result_menus
    %result_floats %result_converted %result_converted_errors 
-   %result_elements %result_directions_text %result_indices_sort_strings);
+   %result_elements %result_directions_text);
 
 use utf8;
 
@@ -112,12 +112,12 @@ $result_trees{'value_in_index_commands'} = {
             ],
             'spaces_before_argument' => ' '
           },
-          'parent' => {},
-          'source_info' => {
+          'line_nr' => {
             'file_name' => '',
             'line_nr' => 5,
             'macro' => ''
-          }
+          },
+          'parent' => {}
         },
         {
           'args' => [
@@ -144,12 +144,12 @@ $result_trees{'value_in_index_commands'} = {
             ],
             'spaces_before_argument' => ' '
           },
-          'parent' => {},
-          'source_info' => {
+          'line_nr' => {
             'file_name' => '',
             'line_nr' => 6,
             'macro' => ''
-          }
+          },
+          'parent' => {}
         },
         {
           'parent' => {},
@@ -218,12 +218,12 @@ $result_trees{'value_in_index_commands'} = {
                 ],
                 'spaces_before_argument' => ' '
               },
-              'parent' => {},
-              'source_info' => {
+              'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 11,
                 'macro' => ''
-              }
+              },
+              'parent' => {}
             },
             {
               'parent' => {},
@@ -324,12 +324,12 @@ $result_trees{'value_in_index_commands'} = {
             ],
             'spaces_before_argument' => ' '
           },
-          'parent' => {},
-          'source_info' => {
+          'line_nr' => {
             'file_name' => '',
             'line_nr' => 18,
             'macro' => ''
-          }
+          },
+          'parent' => {}
         },
         {
           'parent' => {},
@@ -369,7 +369,7 @@ $result_trees{'value_in_index_commands'} = {
         }
       ],
       'parent' => {},
-      'type' => 'before_node_section'
+      'type' => 'text_root'
     },
     {
       'args' => [
@@ -416,25 +416,25 @@ $result_trees{'value_in_index_commands'} = {
           'cmdname' => 'trucindex',
           'extra' => {
             'index_entry' => {
+              'command' => {},
+              'content' => [],
               'content_normalized' => [],
-              'entry_content' => [],
-              'entry_element' => {},
-              'entry_node' => {},
-              'entry_number' => 1,
               'in_code' => 0,
               'index_at_command' => 'trucindex',
-              'index_ignore_chars' => {},
               'index_name' => 'truc',
-              'index_type_command' => 'trucindex'
+              'index_type_command' => 'trucindex',
+              'key' => 'index truc',
+              'node' => {},
+              'number' => 1
             },
             'spaces_before_argument' => ' '
           },
-          'parent' => {},
-          'source_info' => {
+          'line_nr' => {
             'file_name' => '',
             'line_nr' => 24,
             'macro' => ''
           },
+          'parent' => {},
           'type' => 'index_entry_command'
         },
         {
@@ -465,12 +465,13 @@ $result_trees{'value_in_index_commands'} = {
                     }
                   ],
                   'cmdname' => 'var',
-                  'parent' => {},
-                  'source_info' => {
+                  'contents' => [],
+                  'line_nr' => {
                     'file_name' => '',
                     'line_nr' => 26,
                     'macro' => ''
-                  }
+                  },
+                  'parent' => {}
                 },
                 {
                   'parent' => {},
@@ -490,12 +491,13 @@ $result_trees{'value_in_index_commands'} = {
                     }
                   ],
                   'cmdname' => '\'',
-                  'parent' => {},
-                  'source_info' => {
+                  'contents' => [],
+                  'line_nr' => {
                     'file_name' => '',
                     'line_nr' => 26,
                     'macro' => ''
-                  }
+                  },
+                  'parent' => {}
                 },
                 {
                   'parent' => {},
@@ -519,12 +521,13 @@ $result_trees{'value_in_index_commands'} = {
                             }
                           ],
                           'cmdname' => 'dotless',
-                          'parent' => {},
-                          'source_info' => {
+                          'contents' => [],
+                          'line_nr' => {
                             'file_name' => '',
                             'line_nr' => 26,
                             'macro' => ''
-                          }
+                          },
+                          'parent' => {}
                         }
                       ],
                       'parent' => {},
@@ -532,12 +535,13 @@ $result_trees{'value_in_index_commands'} = {
                     }
                   ],
                   'cmdname' => '^',
-                  'parent' => {},
-                  'source_info' => {
+                  'contents' => [],
+                  'line_nr' => {
                     'file_name' => '',
                     'line_nr' => 26,
                     'macro' => ''
-                  }
+                  },
+                  'parent' => {}
                 }
               ],
               'extra' => {
@@ -551,25 +555,25 @@ $result_trees{'value_in_index_commands'} = {
           'cmdname' => 'codeidxindex',
           'extra' => {
             'index_entry' => {
+              'command' => {},
+              'content' => [],
               'content_normalized' => [],
-              'entry_content' => [],
-              'entry_element' => {},
-              'entry_node' => {},
-              'entry_number' => 1,
               'in_code' => 1,
               'index_at_command' => 'codeidxindex',
-              'index_ignore_chars' => {},
               'index_name' => 'codeidx',
-              'index_type_command' => 'codeidxindex'
+              'index_type_command' => 'codeidxindex',
+              'key' => "a index entry t\x{e9} \x{ee}",
+              'node' => {},
+              'number' => 1
             },
             'spaces_before_argument' => ' '
           },
-          'parent' => {},
-          'source_info' => {
+          'line_nr' => {
             'file_name' => '',
             'line_nr' => 26,
             'macro' => ''
           },
+          'parent' => {},
           'type' => 'index_entry_command'
         },
         {
@@ -598,25 +602,25 @@ $result_trees{'value_in_index_commands'} = {
           'cmdname' => 'kindex',
           'extra' => {
             'index_entry' => {
+              'command' => {},
+              'content' => [],
               'content_normalized' => [],
-              'entry_content' => [],
-              'entry_element' => {},
-              'entry_node' => {},
-              'entry_number' => 1,
               'in_code' => 1,
               'index_at_command' => 'kindex',
-              'index_ignore_chars' => {},
               'index_name' => 'ky',
-              'index_type_command' => 'kindex'
+              'index_type_command' => 'kindex',
+              'key' => 'truc kindex',
+              'node' => {},
+              'number' => 1
             },
             'spaces_before_argument' => ' '
           },
-          'parent' => {},
-          'source_info' => {
+          'line_nr' => {
             'file_name' => '',
             'line_nr' => 28,
             'macro' => ''
           },
+          'parent' => {},
           'type' => 'index_entry_command'
         },
         {
@@ -639,25 +643,25 @@ $result_trees{'value_in_index_commands'} = {
           'cmdname' => 'pindex',
           'extra' => {
             'index_entry' => {
+              'command' => {},
+              'content' => [],
               'content_normalized' => [],
-              'entry_content' => [],
-              'entry_element' => {},
-              'entry_node' => {},
-              'entry_number' => 1,
               'in_code' => 1,
               'index_at_command' => 'pindex',
-              'index_ignore_chars' => {},
               'index_name' => 'pg',
-              'index_type_command' => 'pindex'
+              'index_type_command' => 'pindex',
+              'key' => 'pindex codeidx',
+              'node' => {},
+              'number' => 1
             },
             'spaces_before_argument' => ' '
           },
-          'parent' => {},
-          'source_info' => {
+          'line_nr' => {
             'file_name' => '',
             'line_nr' => 29,
             'macro' => ''
           },
+          'parent' => {},
           'type' => 'index_entry_command'
         },
         {
@@ -701,12 +705,12 @@ $result_trees{'value_in_index_commands'} = {
             ],
             'spaces_before_argument' => ' '
           },
-          'parent' => {},
-          'source_info' => {
+          'line_nr' => {
             'file_name' => '',
             'line_nr' => 32,
             'macro' => ''
-          }
+          },
+          'parent' => {}
         },
         {
           'parent' => {},
@@ -749,12 +753,12 @@ $result_trees{'value_in_index_commands'} = {
             ],
             'spaces_before_argument' => ' '
           },
-          'parent' => {},
-          'source_info' => {
+          'line_nr' => {
             'file_name' => '',
             'line_nr' => 35,
             'macro' => ''
-          }
+          },
+          'parent' => {}
         }
       ],
       'extra' => {
@@ -773,12 +777,12 @@ $result_trees{'value_in_index_commands'} = {
         'normalized' => 'Top',
         'spaces_before_argument' => ' '
       },
-      'parent' => {},
-      'source_info' => {
+      'line_nr' => {
         'file_name' => '',
         'line_nr' => 22,
         'macro' => ''
-      }
+      },
+      'parent' => {}
     }
   ],
   'type' => 'document_root'
@@ -833,10 +837,10 @@ $result_trees{'value_in_index_commands'}{'contents'}[1]{'args'}[0]{'parent'} = $
 $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'value_in_index_commands'}{'contents'}[1];
 $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[1]{'args'}[0];
 $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[1];
+$result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[1]{'extra'}{'index_entry'}{'command'} = $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[1];
+$result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[1]{'extra'}{'index_entry'}{'content'} = $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'};
 $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[1]{'extra'}{'index_entry'}{'content_normalized'} = $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'};
-$result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[1]{'extra'}{'index_entry'}{'entry_content'} = $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'contents'};
-$result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[1]{'extra'}{'index_entry'}{'entry_element'} = $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[1];
-$result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[1]{'extra'}{'index_entry'}{'entry_node'} = $result_trees{'value_in_index_commands'}{'contents'}[1];
+$result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[1]{'extra'}{'index_entry'}{'node'} = $result_trees{'value_in_index_commands'}{'contents'}[1];
 $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'value_in_index_commands'}{'contents'}[1];
 $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'value_in_index_commands'}{'contents'}[1];
 $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[3]{'args'}[0];
@@ -854,25 +858,25 @@ $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[3]{'args'}[0
 $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[5]{'args'}[0]{'parent'} = $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[5];
 $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'}[5]{'parent'} = $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[3]{'args'}[0];
 $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[3];
+$result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[3]{'extra'}{'index_entry'}{'command'} = $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[3];
+$result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[3]{'extra'}{'index_entry'}{'content'} = $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'};
 $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[3]{'extra'}{'index_entry'}{'content_normalized'} = $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'};
-$result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[3]{'extra'}{'index_entry'}{'entry_content'} = $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[3]{'args'}[0]{'contents'};
-$result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[3]{'extra'}{'index_entry'}{'entry_element'} = $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[3];
-$result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[3]{'extra'}{'index_entry'}{'entry_node'} = $result_trees{'value_in_index_commands'}{'contents'}[1];
+$result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[3]{'extra'}{'index_entry'}{'node'} = $result_trees{'value_in_index_commands'}{'contents'}[1];
 $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'value_in_index_commands'}{'contents'}[1];
 $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[4]{'parent'} = $result_trees{'value_in_index_commands'}{'contents'}[1];
 $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[5]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[5]{'args'}[0];
 $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[5]{'args'}[0]{'parent'} = $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[5];
+$result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[5]{'extra'}{'index_entry'}{'command'} = $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[5];
+$result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[5]{'extra'}{'index_entry'}{'content'} = $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[5]{'args'}[0]{'contents'};
 $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[5]{'extra'}{'index_entry'}{'content_normalized'} = $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[5]{'args'}[0]{'contents'};
-$result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[5]{'extra'}{'index_entry'}{'entry_content'} = $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[5]{'args'}[0]{'contents'};
-$result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[5]{'extra'}{'index_entry'}{'entry_element'} = $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[5];
-$result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[5]{'extra'}{'index_entry'}{'entry_node'} = $result_trees{'value_in_index_commands'}{'contents'}[1];
+$result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[5]{'extra'}{'index_entry'}{'node'} = $result_trees{'value_in_index_commands'}{'contents'}[1];
 $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[5]{'parent'} = $result_trees{'value_in_index_commands'}{'contents'}[1];
 $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[6]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[6]{'args'}[0];
 $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[6]{'args'}[0]{'parent'} = $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[6];
+$result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[6]{'extra'}{'index_entry'}{'command'} = $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[6];
+$result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[6]{'extra'}{'index_entry'}{'content'} = $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[6]{'args'}[0]{'contents'};
 $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[6]{'extra'}{'index_entry'}{'content_normalized'} = $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[6]{'args'}[0]{'contents'};
-$result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[6]{'extra'}{'index_entry'}{'entry_content'} = $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[6]{'args'}[0]{'contents'};
-$result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[6]{'extra'}{'index_entry'}{'entry_element'} = $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[6];
-$result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[6]{'extra'}{'index_entry'}{'entry_node'} = $result_trees{'value_in_index_commands'}{'contents'}[1];
+$result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[6]{'extra'}{'index_entry'}{'node'} = $result_trees{'value_in_index_commands'}{'contents'}[1];
 $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[6]{'parent'} = $result_trees{'value_in_index_commands'}{'contents'}[1];
 $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[7]{'parent'} = $result_trees{'value_in_index_commands'}{'contents'}[1];
 $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[8]{'contents'}[0]{'parent'} = $result_trees{'value_in_index_commands'}{'contents'}[1]{'contents'}[8];
@@ -947,11 +951,14 @@ value truc
 value cp
 ';
 
+$result_sectioning{'value_in_index_commands'} = {};
+
 $result_nodes{'value_in_index_commands'} = {
   'cmdname' => 'node',
   'extra' => {
     'isindex' => 1,
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   }
 };
 
@@ -959,13 +966,14 @@ $result_menus{'value_in_index_commands'} = {
   'cmdname' => 'node',
   'extra' => {
     'isindex' => 1,
-    'normalized' => 'Top'
+    'normalized' => 'Top',
+    'spaces_before_argument' => ' '
   }
 };
 
 $result_errors{'value_in_index_commands'} = [
   {
-    'error_line' => 'warning: printing an index `cp\' merged in another one, `fn\'
+    'error_line' => ':35: warning: printing an index `cp\' merged in another one, `fn\'
 ',
     'file_name' => '',
     'line_nr' => 35,
@@ -1040,20 +1048,4 @@ $result_indices{'value_in_index_commands'} = {
 $result_floats{'value_in_index_commands'} = {};
 
 
-$result_indices_sort_strings{'value_in_index_commands'} = {
-  'codeidx' => [
-    'a index entry te\' i^'
-  ],
-  'ky' => [
-    'truc kindex'
-  ],
-  'pg' => [
-    'pindex codeidx'
-  ],
-  'truc' => [
-    'index truc'
-  ]
-};
-
-
 1;
