@@ -33,13 +33,15 @@ $result_trees{'nested'} = {
                   ],
                   'cmdname' => 'verb',
                   'contents' => [],
+                  'extra' => {
+                    'delimiter' => '/'
+                  },
                   'line_nr' => {
                     'file_name' => '',
                     'line_nr' => 1,
                     'macro' => ''
                   },
-                  'parent' => {},
-                  'type' => '/'
+                  'parent' => {}
                 },
                 {
                   'parent' => {},
@@ -52,7 +54,11 @@ $result_trees{'nested'} = {
           ],
           'cmdname' => 'b',
           'contents' => [],
-          'line_nr' => {},
+          'line_nr' => {
+            'file_name' => '',
+            'line_nr' => 1,
+            'macro' => ''
+          },
           'parent' => {}
         }
       ],
@@ -68,7 +74,6 @@ $result_trees{'nested'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[1]{
 $result_trees{'nested'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'nested'}{'contents'}[0]{'contents'}[0]{'args'}[0];
 $result_trees{'nested'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'nested'}{'contents'}[0]{'contents'}[0]{'args'}[0];
 $result_trees{'nested'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'nested'}{'contents'}[0]{'contents'}[0];
-$result_trees{'nested'}{'contents'}[0]{'contents'}[0]{'line_nr'} = $result_trees{'nested'}{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'nested'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'nested'}{'contents'}[0];
 $result_trees{'nested'}{'contents'}[0]{'parent'} = $result_trees{'nested'};
 
@@ -80,4 +85,7 @@ $result_texts{'nested'} = 'in b  in verb { }  in b end';
 $result_errors{'nested'} = [];
 
 
+$result_floats{'nested'} = {};
+
+
 1;
