@@ -37,7 +37,9 @@ $result_trees{'node_no_section'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -58,7 +60,7 @@ $result_trees{'node_no_section'}{'contents'}[0]{'parent'} = $result_trees{'node_
 $result_trees{'node_no_section'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'node_no_section'}{'contents'}[1]{'args'}[0];
 $result_trees{'node_no_section'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'node_no_section'}{'contents'}[1];
 $result_trees{'node_no_section'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'node_no_section'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'node_no_section'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'node_no_section'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'node_no_section'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'node_no_section'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'node_no_section'}{'contents'}[1]{'parent'} = $result_trees{'node_no_section'};
 
 $result_texis{'node_no_section'} = '@node Top
@@ -74,20 +76,8 @@ $result_nodes{'node_no_section'} = {
   'extra' => {
     'normalized' => 'Top',
     'spaces_before_argument' => ' '
-  },
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
   }
 };
-$result_nodes{'node_no_section'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'node_no_section'};
 
 $result_menus{'node_no_section'} = {
   'cmdname' => 'node',
@@ -100,8 +90,11 @@ $result_menus{'node_no_section'} = {
 $result_errors{'node_no_section'} = [];
 
 
+$result_floats{'node_no_section'} = {};
 
-$result_converted{'xml'}->{'node_no_section'} = '<node name="Top" spaces=" "><nodename>Top</nodename><nodeup automatic="on">(dir)</nodeup></node>
+
+
+$result_converted{'xml'}->{'node_no_section'} = '<node name="Top" spaces=" "><nodename>Top</nodename></node>
 ';
 
 1;
