@@ -12,35 +12,25 @@ $result_trees{'spaces_info_lost'} = {
         {
           'contents' => [
             {
-              'extra' => {
-                'command' => {}
-              },
               'parent' => {},
-              'text' => '  ',
-              'type' => 'empty_spaces_after_command'
-            },
-            {
-              'parent' => {},
-              'text' => 'text on example line'
-            },
-            {
-              'parent' => {},
-              'text' => ' 
-',
-              'type' => 'space_at_end_block_command'
+              'text' => 'text on display line'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => ' 
+'
+          },
           'parent' => {},
           'type' => 'block_line_arg'
         }
       ],
-      'cmdname' => 'example',
+      'cmdname' => 'display',
       'contents' => [
         {
           'contents' => [
             {
               'parent' => {},
-              'text' => 'in bad example
+              'text' => 'in bad display
 '
             }
           ],
@@ -52,34 +42,23 @@ $result_trees{'spaces_info_lost'} = {
             {
               'contents' => [
                 {
-                  'extra' => {
-                    'command' => {}
-                  },
                   'parent' => {},
-                  'text' => '  ',
-                  'type' => 'empty_spaces_after_command'
-                },
-                {
-                  'parent' => {},
-                  'text' => 'example'
-                },
-                {
-                  'parent' => {},
-                  'text' => ' 
-',
-                  'type' => 'spaces_at_end'
+                  'text' => 'display'
                 }
               ],
+              'extra' => {
+                'spaces_after_argument' => ' 
+'
+              },
               'parent' => {},
-              'type' => 'misc_line_arg'
+              'type' => 'line_arg'
             }
           ],
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
-            'command_argument' => 'example',
-            'spaces_after_command' => {},
-            'text_arg' => 'example'
+            'command_argument' => 'display',
+            'spaces_before_argument' => '  ',
+            'text_arg' => 'display'
           },
           'line_nr' => {
             'file_name' => '',
@@ -90,13 +69,8 @@ $result_trees{'spaces_info_lost'} = {
         }
       ],
       'extra' => {
-        'block_command_line_contents' => [
-          [
-            {}
-          ]
-        ],
         'end_command' => {},
-        'spaces_after_command' => {}
+        'spaces_before_argument' => '  '
       },
       'line_nr' => {
         'file_name' => '',
@@ -130,9 +104,7 @@ $result_trees{'spaces_info_lost'} = {
           'type' => 'raw'
         }
       ],
-      'extra' => {
-        'spaces_after_command' => {}
-      },
+      'extra' => {},
       'line_nr' => {
         'file_name' => '',
         'line_nr' => 5,
@@ -141,9 +113,6 @@ $result_trees{'spaces_info_lost'} = {
       'parent' => {}
     },
     {
-      'extra' => {
-        'command' => {}
-      },
       'parent' => {},
       'text' => ' 
 ',
@@ -152,37 +121,25 @@ $result_trees{'spaces_info_lost'} = {
   ],
   'type' => 'text_root'
 };
-$result_trees{'spaces_info_lost'}{'contents'}[0]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'spaces_info_lost'}{'contents'}[0];
 $result_trees{'spaces_info_lost'}{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'spaces_info_lost'}{'contents'}[0]{'args'}[0];
-$result_trees{'spaces_info_lost'}{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'spaces_info_lost'}{'contents'}[0]{'args'}[0];
-$result_trees{'spaces_info_lost'}{'contents'}[0]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'spaces_info_lost'}{'contents'}[0]{'args'}[0];
 $result_trees{'spaces_info_lost'}{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'spaces_info_lost'}{'contents'}[0];
 $result_trees{'spaces_info_lost'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'spaces_info_lost'}{'contents'}[0]{'contents'}[0];
 $result_trees{'spaces_info_lost'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'spaces_info_lost'}{'contents'}[0];
-$result_trees{'spaces_info_lost'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'spaces_info_lost'}{'contents'}[0]{'contents'}[1];
 $result_trees{'spaces_info_lost'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'spaces_info_lost'}{'contents'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'spaces_info_lost'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'spaces_info_lost'}{'contents'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'spaces_info_lost'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'spaces_info_lost'}{'contents'}[0]{'contents'}[1]{'args'}[0];
 $result_trees{'spaces_info_lost'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'spaces_info_lost'}{'contents'}[0]{'contents'}[1];
-$result_trees{'spaces_info_lost'}{'contents'}[0]{'contents'}[1]{'extra'}{'command'} = $result_trees{'spaces_info_lost'}{'contents'}[0];
-$result_trees{'spaces_info_lost'}{'contents'}[0]{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'spaces_info_lost'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'spaces_info_lost'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'spaces_info_lost'}{'contents'}[0];
-$result_trees{'spaces_info_lost'}{'contents'}[0]{'extra'}{'block_command_line_contents'}[0][0] = $result_trees{'spaces_info_lost'}{'contents'}[0]{'args'}[0]{'contents'}[1];
 $result_trees{'spaces_info_lost'}{'contents'}[0]{'extra'}{'end_command'} = $result_trees{'spaces_info_lost'}{'contents'}[0]{'contents'}[1];
-$result_trees{'spaces_info_lost'}{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'spaces_info_lost'}{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'spaces_info_lost'}{'contents'}[0]{'parent'} = $result_trees{'spaces_info_lost'};
 $result_trees{'spaces_info_lost'}{'contents'}[1]{'parent'} = $result_trees{'spaces_info_lost'};
 $result_trees{'spaces_info_lost'}{'contents'}[2]{'contents'}[0]{'extra'}{'command'} = $result_trees{'spaces_info_lost'}{'contents'}[2];
 $result_trees{'spaces_info_lost'}{'contents'}[2]{'contents'}[0]{'parent'} = $result_trees{'spaces_info_lost'}{'contents'}[2];
 $result_trees{'spaces_info_lost'}{'contents'}[2]{'contents'}[1]{'parent'} = $result_trees{'spaces_info_lost'}{'contents'}[2];
-$result_trees{'spaces_info_lost'}{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'spaces_info_lost'}{'contents'}[2]{'contents'}[0];
 $result_trees{'spaces_info_lost'}{'contents'}[2]{'parent'} = $result_trees{'spaces_info_lost'};
-$result_trees{'spaces_info_lost'}{'contents'}[3]{'extra'}{'command'} = $result_trees{'spaces_info_lost'}{'contents'}[2];
 $result_trees{'spaces_info_lost'}{'contents'}[3]{'parent'} = $result_trees{'spaces_info_lost'};
 
-$result_texis{'spaces_info_lost'} = '@example  text on example line 
-in bad example
-@end  example 
+$result_texis{'spaces_info_lost'} = '@display  text on display line 
+in bad display
+@end  display 
 
 @verbatim  
 in verbatim @g 
@@ -190,7 +147,7 @@ in verbatim @g
 ';
 
 
-$result_texts{'spaces_info_lost'} = 'in bad example
+$result_texts{'spaces_info_lost'} = 'in bad display
 
 in verbatim @g 
 ';
@@ -198,10 +155,13 @@ in verbatim @g
 $result_errors{'spaces_info_lost'} = [];
 
 
+$result_floats{'spaces_info_lost'} = {};
 
-$result_converted{'xml'}->{'spaces_info_lost'} = '<example spaces="  " endspaces="  "> 
-<pre xml:space="preserve">in bad example
-</pre></example> 
+
+
+$result_converted{'xml'}->{'spaces_info_lost'} = '<display spaces="  " endspaces="  "> 
+<pre xml:space="preserve">in bad display
+</pre></display> 
 
 <verbatim xml:space="preserve">  
 in verbatim @g 
