@@ -126,7 +126,11 @@ $result_trees{'accent_on_table_line'} = {
                   'extra' => {
                     'spaces_before_argument' => ' '
                   },
-                  'line_nr' => {},
+                  'line_nr' => {
+                    'file_name' => '',
+                    'line_nr' => 3,
+                    'macro' => ''
+                  },
                   'parent' => {}
                 }
               ],
@@ -173,7 +177,11 @@ $result_trees{'accent_on_table_line'} = {
         'end_command' => {},
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {},
+      'line_nr' => {
+        'file_name' => '',
+        'line_nr' => 1,
+        'macro' => ''
+      },
       'parent' => {}
     }
   ],
@@ -192,7 +200,6 @@ $result_trees{'accent_on_table_line'}{'contents'}[0]{'contents'}[1]{'contents'}[
 $result_trees{'accent_on_table_line'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'accent_on_table_line'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[1];
 $result_trees{'accent_on_table_line'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'accent_on_table_line'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'args'}[0];
 $result_trees{'accent_on_table_line'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'accent_on_table_line'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'contents'}[0];
-$result_trees{'accent_on_table_line'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'line_nr'} = $result_trees{'accent_on_table_line'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'accent_on_table_line'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'accent_on_table_line'}{'contents'}[0]{'contents'}[1]{'contents'}[0];
 $result_trees{'accent_on_table_line'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'accent_on_table_line'}{'contents'}[0]{'contents'}[1];
 $result_trees{'accent_on_table_line'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'accent_on_table_line'}{'contents'}[0];
@@ -201,7 +208,6 @@ $result_trees{'accent_on_table_line'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'
 $result_trees{'accent_on_table_line'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'accent_on_table_line'}{'contents'}[0];
 $result_trees{'accent_on_table_line'}{'contents'}[0]{'extra'}{'command_as_argument'} = $result_trees{'accent_on_table_line'}{'contents'}[0]{'args'}[0];
 $result_trees{'accent_on_table_line'}{'contents'}[0]{'extra'}{'end_command'} = $result_trees{'accent_on_table_line'}{'contents'}[0]{'contents'}[2];
-$result_trees{'accent_on_table_line'}{'contents'}[0]{'line_nr'} = $result_trees{'accent_on_table_line'}{'contents'}[0]{'args'}[1]{'contents'}[0]{'line_nr'};
 $result_trees{'accent_on_table_line'}{'contents'}[0]{'parent'} = $result_trees{'accent_on_table_line'};
 
 $result_texis{'accent_on_table_line'} = '@table @~
@@ -228,6 +234,9 @@ $result_errors{'accent_on_table_line'} = [
 ];
 
 
+$result_floats{'accent_on_table_line'} = {};
+
+
 
 $result_converted{'plaintext'}->{'accent_on_table_line'} = 'first item
 no at-command \'code\'
@@ -235,8 +244,8 @@ no at-command \'code\'
 
 
 $result_converted{'html_text'}->{'accent_on_table_line'} = '<dl compact="compact">
-<dt>first item</dt>
-<dt>no at-command <code>code</code></dt>
+<dt><span>first item</span></dt>
+<dt><span>no at-command <code>code</code></span></dt>
 </dl>
 ';
 
