@@ -11,14 +11,6 @@ $result_trees{'comment_and_itemx_before_item'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'cmdname' => 'code',
               'contents' => [],
@@ -29,14 +21,12 @@ $result_trees{'comment_and_itemx_before_item'} = {
               },
               'parent' => {},
               'type' => 'command_as_argument'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'space_at_end_block_command'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
           'type' => 'block_line_arg'
         }
@@ -75,35 +65,22 @@ $result_trees{'comment_and_itemx_before_item'} = {
                   'args' => [
                     {
                       'contents' => [
-                        {
-                          'extra' => {
-                            'command' => {}
-                          },
-                          'parent' => {},
-                          'text' => ' ',
-                          'type' => 'empty_spaces_after_command'
-                        },
                         {
                           'parent' => {},
                           'text' => 'in itemx'
-                        },
-                        {
-                          'parent' => {},
-                          'text' => '
-',
-                          'type' => 'spaces_at_end'
                         }
                       ],
+                      'extra' => {
+                        'spaces_after_argument' => '
+'
+                      },
                       'parent' => {},
-                      'type' => 'misc_line_arg'
+                      'type' => 'line_arg'
                     }
                   ],
                   'cmdname' => 'itemx',
                   'extra' => {
-                    'misc_content' => [
-                      {}
-                    ],
-                    'spaces_after_command' => {}
+                    'spaces_before_argument' => ' '
                   },
                   'line_nr' => {
                     'file_name' => '',
@@ -124,34 +101,23 @@ $result_trees{'comment_and_itemx_before_item'} = {
           'args' => [
             {
               'contents' => [
-                {
-                  'extra' => {
-                    'command' => {}
-                  },
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_after_command'
-                },
                 {
                   'parent' => {},
                   'text' => 'table'
-                },
-                {
-                  'parent' => {},
-                  'text' => '
-',
-                  'type' => 'spaces_at_end'
                 }
               ],
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
               'parent' => {},
-              'type' => 'misc_line_arg'
+              'type' => 'line_arg'
             }
           ],
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
             'command_argument' => 'table',
-            'spaces_after_command' => {},
+            'spaces_before_argument' => ' ',
             'text_arg' => 'table'
           },
           'line_nr' => {
@@ -163,52 +129,35 @@ $result_trees{'comment_and_itemx_before_item'} = {
         }
       ],
       'extra' => {
-        'block_command_line_contents' => [
-          [
-            {}
-          ]
-        ],
         'command_as_argument' => {},
         'end_command' => {},
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
+      },
+      'line_nr' => {
+        'file_name' => '',
+        'line_nr' => 1,
+        'macro' => ''
       },
-      'line_nr' => {},
       'parent' => {}
     }
   ],
   'type' => 'text_root'
 };
-$result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'comment_and_itemx_before_item'}{'contents'}[0];
 $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'args'}[0];
-$result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'args'}[0];
-$result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'args'}[0];
 $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'comment_and_itemx_before_item'}{'contents'}[0];
 $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[0]{'contents'}[0];
 $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[0];
 $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'comment_and_itemx_before_item'}{'contents'}[0];
-$result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'contents'}[0];
 $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'args'}[0];
-$result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'args'}[0];
-$result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'args'}[0];
 $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'contents'}[0];
-$result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'extra'}{'misc_content'}[0] = $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[1];
-$result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[1]{'contents'}[0];
 $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[1];
 $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'comment_and_itemx_before_item'}{'contents'}[0];
-$result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[2];
 $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[2]{'args'}[0];
-$result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[2]{'args'}[0];
-$result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[2]{'args'}[0];
 $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[2];
-$result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[2]{'extra'}{'command'} = $result_trees{'comment_and_itemx_before_item'}{'contents'}[0];
-$result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[2]{'extra'}{'spaces_after_command'} = $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'comment_and_itemx_before_item'}{'contents'}[0];
-$result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'extra'}{'block_command_line_contents'}[0][0] = $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'args'}[0]{'contents'}[1];
-$result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'extra'}{'command_as_argument'} = $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'args'}[0]{'contents'}[1];
+$result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'extra'}{'command_as_argument'} = $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'extra'}{'end_command'} = $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'contents'}[2];
-$result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'args'}[0]{'contents'}[0];
-$result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'line_nr'} = $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'comment_and_itemx_before_item'}{'contents'}[0]{'parent'} = $result_trees{'comment_and_itemx_before_item'};
 
 $result_texis{'comment_and_itemx_before_item'} = '@table @code
@@ -234,13 +183,16 @@ $result_errors{'comment_and_itemx_before_item'} = [
 ];
 
 
+$result_floats{'comment_and_itemx_before_item'} = {};
+
+
 
 $result_converted{'plaintext'}->{'comment_and_itemx_before_item'} = '\'in itemx\'
 ';
 
 
 $result_converted{'html_text'}->{'comment_and_itemx_before_item'} = '<dl compact="compact">
-<dt><code>in itemx</code></dt>
+<dt><span><code>in itemx</code></span></dt>
 </dl>
 ';
 
