@@ -11,14 +11,6 @@ $result_trees{'invalid_command_and_brace_in_table'} = {
       'args' => [
         {
           'contents' => [
-            {
-              'extra' => {
-                'command' => {}
-              },
-              'parent' => {},
-              'text' => ' ',
-              'type' => 'empty_spaces_after_command'
-            },
             {
               'cmdname' => 'asis',
               'contents' => [],
@@ -29,14 +21,12 @@ $result_trees{'invalid_command_and_brace_in_table'} = {
               },
               'parent' => {},
               'type' => 'command_as_argument'
-            },
-            {
-              'parent' => {},
-              'text' => '
-',
-              'type' => 'space_at_end_block_command'
             }
           ],
+          'extra' => {
+            'spaces_after_argument' => '
+'
+          },
           'parent' => {},
           'type' => 'block_line_arg'
         }
@@ -78,34 +68,23 @@ $result_trees{'invalid_command_and_brace_in_table'} = {
           'args' => [
             {
               'contents' => [
-                {
-                  'extra' => {
-                    'command' => {}
-                  },
-                  'parent' => {},
-                  'text' => ' ',
-                  'type' => 'empty_spaces_after_command'
-                },
                 {
                   'parent' => {},
                   'text' => 'table'
-                },
-                {
-                  'parent' => {},
-                  'text' => '
-',
-                  'type' => 'spaces_at_end'
                 }
               ],
+              'extra' => {
+                'spaces_after_argument' => '
+'
+              },
               'parent' => {},
-              'type' => 'misc_line_arg'
+              'type' => 'line_arg'
             }
           ],
           'cmdname' => 'end',
           'extra' => {
-            'command' => {},
             'command_argument' => 'table',
-            'spaces_after_command' => {},
+            'spaces_before_argument' => ' ',
             'text_arg' => 'table'
           },
           'line_nr' => {
@@ -117,25 +96,21 @@ $result_trees{'invalid_command_and_brace_in_table'} = {
         }
       ],
       'extra' => {
-        'block_command_line_contents' => [
-          [
-            {}
-          ]
-        ],
         'command_as_argument' => {},
         'end_command' => {},
-        'spaces_after_command' => {}
+        'spaces_before_argument' => ' '
+      },
+      'line_nr' => {
+        'file_name' => '',
+        'line_nr' => 1,
+        'macro' => ''
       },
-      'line_nr' => {},
       'parent' => {}
     }
   ],
   'type' => 'text_root'
 };
-$result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0];
 $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'args'}[0];
-$result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'args'}[0];
-$result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'args'}[0];
 $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0];
 $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'contents'}[0];
 $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'contents'}[0]{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'contents'}[0]{'contents'}[1];
@@ -143,19 +118,11 @@ $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'contents'}[0
 $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'contents'}[0]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'contents'}[0]{'contents'}[1];
 $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'contents'}[0];
 $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0];
-$result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'extra'}{'command'} = $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'contents'}[1];
 $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'contents'}[1]{'args'}[0];
-$result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'contents'}[1]{'args'}[0];
 $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'contents'}[1];
-$result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'contents'}[1]{'extra'}{'command'} = $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0];
-$result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'contents'}[1]{'extra'}{'spaces_after_command'} = $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0];
-$result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'extra'}{'block_command_line_contents'}[0][0] = $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'args'}[0]{'contents'}[1];
-$result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'extra'}{'command_as_argument'} = $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'args'}[0]{'contents'}[1];
+$result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'extra'}{'command_as_argument'} = $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'extra'}{'end_command'} = $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'contents'}[1];
-$result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'extra'}{'spaces_after_command'} = $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'args'}[0]{'contents'}[0];
-$result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'line_nr'} = $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'invalid_command_and_brace_in_table'}{'contents'}[0]{'parent'} = $result_trees{'invalid_command_and_brace_in_table'};
 
 $result_texis{'invalid_command_and_brace_in_table'} = '@table @asis
@@ -211,4 +178,7 @@ $result_errors{'invalid_command_and_brace_in_table'} = [
 ];
 
 
+$result_floats{'invalid_command_and_brace_in_table'} = {};
+
+
 1;
