@@ -109,7 +109,11 @@ $result_trees{'itemx_before_item'} = {
         'end_command' => {},
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {},
+      'line_nr' => {
+        'file_name' => '',
+        'line_nr' => 1,
+        'macro' => ''
+      },
       'parent' => {}
     }
   ],
@@ -127,7 +131,6 @@ $result_trees{'itemx_before_item'}{'contents'}[0]{'contents'}[1]{'args'}[0]{'par
 $result_trees{'itemx_before_item'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'itemx_before_item'}{'contents'}[0];
 $result_trees{'itemx_before_item'}{'contents'}[0]{'extra'}{'command_as_argument'} = $result_trees{'itemx_before_item'}{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'itemx_before_item'}{'contents'}[0]{'extra'}{'end_command'} = $result_trees{'itemx_before_item'}{'contents'}[0]{'contents'}[1];
-$result_trees{'itemx_before_item'}{'contents'}[0]{'line_nr'} = $result_trees{'itemx_before_item'}{'contents'}[0]{'args'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'itemx_before_item'}{'contents'}[0]{'parent'} = $result_trees{'itemx_before_item'};
 
 $result_texis{'itemx_before_item'} = '@table @emph
@@ -152,4 +155,7 @@ $result_errors{'itemx_before_item'} = [
 ];
 
 
+$result_floats{'itemx_before_item'} = {};
+
+
 1;
