@@ -1,8 +1,6 @@
-# $Id: test_utils.pl 7235 2016-06-25 20:20:46Z gavin $
 # t/* test support for the Perl modules.
 #
-# Copyright 2010, 2011, 2012, 2013, 2014, 2015
-# Free Software Foundation, Inc.
+# Copyright 2010-2019 Free Software Foundation, Inc.
 # 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,21 +21,13 @@ use strict;
 
 use 5.006;
 
-use File::Basename;
-use File::Spec;
-
 BEGIN {
 
-if (!$ENV{'top_srcdir'}) {
-  my ($real_command_name, $command_directory, $command_suffix) 
-     = fileparse($0, '.pl');
-  my $updir = File::Spec->updir();
-
-  # tp/t -> tp/t/../..
-  $ENV{'top_srcdir'} = File::Spec->catdir($command_directory, $updir, $updir);
-}
 require Texinfo::ModulePath;
-Texinfo::ModulePath::init();
+Texinfo::ModulePath::init(undef, undef, 'updirs' => 2);
+
+# For consistent test results, use the C locale
+$ENV{LC_ALL} = 'C';
 
 } # end BEGIN
 
@@ -52,7 +42,6 @@ use Texinfo::Convert::Info;
 use Texinfo::Convert::HTML;
 use Texinfo::Convert::TexinfoXML;
 use Texinfo::Convert::DocBook;
-use DebugTexinfo::DebugCount;
 use File::Basename;
 use File::Copy;
 use File::Compare; # standard since 5.004
@@ -96,7 +85,9 @@ foreach my $dir ("LocaleData", "$locales_srcdir/LocaleData") {
 if (! defined($localesdir)) {
   warn "No locales directory found, some tests will fail\n";
 }
+
 Locale::Messages::bindtextdomain ('texinfo_document', $localesdir);
+Locale::Messages::bindtextdomain ('texinfo', $localesdir);
 
 my $generated_texis_dir = 't_texis';
 
@@ -113,22 +104,6 @@ foreach my $dir ('t', 't/results', $output_files_dir) {
   }
 }
 
-my $include_reference_dir = 't/include_reference';
-my $include_dir = 't/include_dir';
-if (! -d $include_dir) {
-  mkdir $include_dir or die "mkdir $include_dir: $!\n";
-  if (opendir DIR, $include_reference_dir) {
-    my @files = grep {-f "$include_reference_dir/$_"} readdir DIR;
-    closedir DIR;
-    foreach my $file (@files) {
-      copy ("$include_reference_dir/$file", "$include_dir/$file")
-        or die "Copy $include_reference_dir/$file $include_dir/$file failed: $!\n";
-    }
-  } else {
-    die "Opendir $include_reference_dir failed: $!\n";
-  }
-}
-
 ok(1);
 
 our %formats = (
@@ -143,12 +118,10 @@ our %formats = (
   'file_xml' => \&convert_to_xml,
   'docbook' => \&convert_to_docbook,
   'file_docbook' => \&convert_to_docbook,
-  'debugcount' => \&debugcount,
 );
 
 our %extensions = (
   'plaintext' => 'txt',
-  'debugcount' => 'txt',
   'html_text' => 'html',
   'xml' => 'xml',
   'docbook' => 'dbk',
@@ -366,6 +339,74 @@ sub remove_keys($$;$)
   return $root;
 }
 
+sub duplicate_key_array($$)
+{
+  my $element = shift;
+  my $key = shift;
+
+  if (defined($element) and exists($element->{$key})
+      and defined($element->{$key})) {
+    my $new_content = [];
+    foreach my $array_item (@{$element->{$key}}) {
+      push @$new_content, $array_item;
+    }
+    $element->{$key} = $new_content;
+  }
+}
+
+# used to have a similar output as the XS parser
+# when using the pure perl parser.
+sub _duplicate_element_keys($$$)
+{
+  my $self = shift;
+  my $type = shift;
+  my $current = shift;
+
+  if (exists($current->{'line_nr'})) {
+    # cannot use dclone as dclone changes integers to strings
+    #$current->{'line_nr'} = dclone($current->{'line_nr'});
+    my $new_line_nr = {};
+    foreach my $key(keys(%{$current->{'line_nr'}})) {
+      $new_line_nr->{$key} = $current->{'line_nr'}->{$key};
+    }
+    $current->{'line_nr'} = $new_line_nr;
+  }
+
+  if (exists($current->{'extra'})) {
+    if (exists($current->{'extra'}->{'nodes_manuals'})
+        and defined($current->{'extra'}->{'nodes_manuals'})) {
+      foreach my $node_manual (@{$current->{'extra'}->{'nodes_manuals'}}) {
+        duplicate_key_array($node_manual, 'node_content');
+      }
+    }
+    if (exists($current->{'extra'}->{'type'})) {
+      duplicate_key_array($current->{'extra'}->{'type'}, 'content');
+    }
+    # only need to duplicate for @def* index entries
+    # in that case they are not duplicated in the XS parser output
+    if (exists($current->{'extra'}->{'index_entry'})
+        and exists($current->{'extra'}->{'def_command'})) {
+      duplicate_key_array($current->{'extra'}->{'index_entry'},
+        'content_normalized');
+    }
+    if (exists($current->{'extra'}->{'prototypes'})
+        and (defined($current->{'extra'}->{'prototypes'}))) {
+      foreach my $prototype (@{$current->{'extra'}->{'prototypes'}}) {
+        duplicate_key_array($prototype, 'contents');
+      }
+    }
+  }
+
+  return ($current);
+}
+
+sub duplicate_tree_element_keys($$)
+{
+  my $self = shift;
+  my $tree = shift;
+  return Texinfo::Common::modify_tree($self, $tree, \&_duplicate_element_keys);
+}
+
 sub cmp_trimmed($$$$)
 {
   my $compared = shift;
@@ -387,7 +428,7 @@ sub new_test($;$$$)
               'DEBUG' => $debug, 'test_formats' => $test_formats};
   
   if ($generate) {
-    mkdir "t/results/$name" if (! -d "t/results/$name");
+    mkdir $srcdir."t/results/$name" if (! -d $srcdir."t/results/$name");
   }
   bless $test;
   return $test;
@@ -645,26 +686,6 @@ sub convert_to_docbook($$$$$$;$)
   return ($errors, $result);
 }
 
-sub debugcount($$$$$$;$)
-{
-  my $self = shift;
-  my $test_name = shift;
-  my $format = shift;
-  my $tree = shift;
-  my $parser = shift;
-  my $parser_options = shift;
-  my $converter_options = shift;
-  $converter_options = {} if (!defined($converter_options));
-  my $converter =
-     DebugTexinfo::DebugCount->converter({'DEBUG' => $self->{'DEBUG'},
-                                         'parser' => $parser,
-                                         'output_format' => 'info',
-                                          %$converter_options });
-  my $result = $converter->convert($tree);
-  my ($errors, $error_nrs) = $converter->errors();
-  return ($errors, $result);
-}
-
 # Run a single test case.  Each test case is an array
 # [TEST_NAME, TEST_TEXT, PARSER_OPTIONS, CONVERTER_OPTIONS]
 sub test($$) 
@@ -711,6 +732,14 @@ sub test($$)
     }
     delete $parser_options->{'test_split'};
   }
+
+  if (!$self->{'generate'}) {
+    mkdir "t/results/$self->{'name'}" if (! -d "t/results/$self->{'name'}");
+  } else {
+    mkdir $srcdir."t/results/$self->{'name'}"
+      if (! -d $srcdir."t/results/$self->{'name'}");
+  }
+
   my %todos;
   if ($parser_options->{'todo'}) {
     %todos = %{$parser_options->{'todo'}};
@@ -726,23 +755,17 @@ sub test($$)
   if ($parser_options and $parser_options->{'test_formats'}) {
     push @tested_formats, @{$parser_options->{'test_formats'}};
     delete $parser_options->{'test_formats'};
-  #} elsif ($self->{'test_formats'}) {
-  #  push @tested_formats, @{$self->{'test_formats'}};
   }
 
-  my $parser = Texinfo::Parser->parser({'TEST' => 1,
-                                        'include_directories' => [
-                                          't/include_dir/',
-                                          't/include/',
+  my $parser = Texinfo::Parser::parser({'include_directories' => [
                                           $srcdir.'t/include/'],
                                         'DEBUG' => $self->{'DEBUG'},
                                        %$parser_options});
+
   # take the initial values to record only if there is something new
-  my ($initial_index_names, $initial_merged_indices) 
-    = $parser->indices_information();
+  my $initial_index_names = $parser->indices_information();
   # do a copy to compare the values and not the references
   $initial_index_names = dclone($initial_index_names);
-  $initial_merged_indices = { %{$initial_merged_indices} };
   print STDERR "  TEST $test_name\n" if ($self->{'DEBUG'});
   my $result;
   if (!$test_file) {
@@ -763,11 +786,13 @@ sub test($$)
 
   Texinfo::Structuring::number_floats($floats);
 
+  Texinfo::Structuring::set_menus_node_directions($parser);
   my $top_node = Texinfo::Structuring::nodes_tree($parser);
 
+  Texinfo::Structuring::complete_node_tree_with_menus($parser, $top_node);
+
   my ($errors, $error_nrs) = $parser->errors();
-  my ($index_names, $merged_indices) 
-       = $parser->indices_information();
+  my $index_names = $parser->indices_information();
   # FIXME maybe it would be good to compare $merged_index_entries?
   my $merged_index_entries 
      = Texinfo::Structuring::merge_indices($index_names);
@@ -778,8 +803,6 @@ sub test($$)
   my $trimmed_index_names = remove_keys($index_names, ['index_entries']);
   $indices->{'index_names'} = $trimmed_index_names
     unless (Data::Compare::Compare($trimmed_index_names, $initial_index_names));
-  $indices->{'merged_indices'} = $merged_indices
-    unless (Data::Compare::Compare($merged_indices, $initial_merged_indices));
 
   my $sorted_index_entries;
   if ($merged_index_entries) {
@@ -789,7 +812,9 @@ sub test($$)
                                                      $index_names);
   }
   if ($parser_options->{'SIMPLE_MENU'}) {
-    $parser->Texinfo::Structuring::set_menus_to_simple_menu();
+    # require instead of use for speed when this module is not needed
+    require Texinfo::Transformations;
+    $parser->Texinfo::Transformations::set_menus_to_simple_menu();
   }
 
   my $converted_text = Texinfo::Convert::Text::convert($result, {'TEST' => 1});
@@ -807,37 +832,36 @@ sub test($$)
         my $base = "t/results/$self->{'name'}/$test_name/";
         my $test_out_dir;
         if ($self->{'generate'}) {
-          $test_out_dir = 'res_'.$format_type;
-          if (-d $base."$test_out_dir/") {
-             unlink_dir_files("t/results/$self->{'name'}/$test_name/$test_out_dir/");
+          $base = $srcdir.$base;
+          $test_out_dir = $base.'res_'.$format_type;
+          if (-d $test_out_dir) {
+            unlink_dir_files($test_out_dir);
           }
         } else {
-          $test_out_dir = 'out_'.$format_type;
+          $test_out_dir = $base.'out_'.$format_type;
         }
         if (!defined($format_converter_options->{'SUBDIR'})) {
           mkdir ($base) 
             if (! -d $base);
-          if (! -d $base."$test_out_dir/") {
-            mkdir ($base."$test_out_dir/"); 
+          if (! -d $test_out_dir) {
+            mkdir ($test_out_dir); 
           } else {
             # remove any files from previous runs
-            unlink glob ($base."$test_out_dir/*"); 
+            unlink glob ("$test_out_dir/*"); 
           }
-          $format_converter_options->{'SUBDIR'} 
-             = $base."$test_out_dir/";
+          $format_converter_options->{'SUBDIR'} = "$test_out_dir/";
         }
       } elsif (!defined($format_converter_options->{'OUTFILE'})) {
         $format_converter_options->{'OUTFILE'} = '';
       }
+      $format_converter_options->{'TEST'} = 1;
+      $format_converter_options->{'include_directories'} = [
+                                          $srcdir.'t/include/'];
       ($converted_errors{$format}, $converted{$format})
            = &{$formats{$format}}($self, $test_name, $format_type, 
                                   $result, $parser, 
                                   $parser_options, $format_converter_options);
       $converted_errors{$format} = undef if (!@{$converted_errors{$format}});
-      if (defined($converted{$format}) and $format =~ /^file_/) {
-        warn "Warning: output generated for $format by $test_name\n";
-      }
-      #print STDERR "$format: \n$converted{$format}";
 
       # output converted result and errors in files if $arg_output is set
       if ($arg_output) {
@@ -915,18 +939,24 @@ sub test($$)
   my $split_result;
   if ($elements) {
     $split_result = $elements;
+    foreach my $element (@$elements) {
+      duplicate_tree_element_keys($parser, $element);
+    }
   } else {
     $split_result = $result;
+    duplicate_tree_element_keys($parser, $result);
   }
 
   {
     local $Data::Dumper::Purity = 1;
     local $Data::Dumper::Indent = 1;
 
-    my $out_file = $new_file;
-    $out_file = $file if ($self->{'generate'});
-
-    mkdir "t/results/$self->{'name'}" if (! -d "t/results/$self->{'name'}");
+    my $out_file;
+    if (!$self->{'generate'}) {
+      $out_file = $new_file;
+    } else {
+      $out_file = $srcdir.$file;
+    }
     open (OUT, ">$out_file") or die "Open $out_file: $!\n";
     binmode (OUT, ":encoding(utf8)");
     print OUT 'use vars qw(%result_texis %result_texts %result_trees %result_errors '."\n".
@@ -982,25 +1012,17 @@ sub test($$)
       if (defined($converted{$format})) {
         $out_result .= "\n".'$result_converted{\''.$format.'\'}->{\''
           .$test_name.'\'} = \''.protect_perl_string($converted{$format})."';\n\n";
-      #print STDERR "$format: \n$converted{$format}";
       }
       if (defined($converted_errors{$format})) {
         local $Data::Dumper::Sortkeys = 1;
         $out_result .= Data::Dumper->Dump([$converted_errors{$format}], 
                  ['$result_converted_errors{\''.$format.'\'}->{\''.$test_name.'\'}']) ."\n\n";
-        #print STDERR "".Data::Dumper->Dump([$converted_errors{$format}]);
       }
     }
 
     $out_result .= "1;\n";
     print OUT $out_result;
     close (OUT);
-    #if (ref($test_case) ne 'ARRAY') {
-    #  my $out_texi_file = "t/results/$self->{'name'}/$test_name.texi";
-    #  open (OUT, ">$out_texi_file") or die "Open $out_texi_file: $!\n";
-    #  print OUT $texi_string_result;
-    #  close (OUT);
-    #}
     
     print STDERR "--> $test_name\n".Texinfo::Convert::Texinfo::convert($result)."\n" 
             if ($self->{'generate'});
@@ -1025,8 +1047,6 @@ sub test($$)
     ok (Texinfo::Convert::Texinfo::convert($result) eq $result_texis{$test_name}, 
          $test_name.' texi');
     if ($todos{'text'}) {
-      #TODO: {
-        #local $TODO = $todos{'text'};
       SKIP: {
         skip $todos{'text'}, 1;
         ok ($converted_text eq $result_texts{$test_name}, $test_name.' text');
@@ -1056,8 +1076,6 @@ sub test($$)
             $tests_count += 1;
             my $errors = compare_dirs_files($reference_dir, $results_dir);
             if ($todos{$format}) {
-              #TODO: {
-              #  local $TODO = $todos{$format};
               SKIP: {
                 skip $todos{$format}, 1;
                 ok (!defined($errors), $test_name.' converted '.$format)
@@ -1082,8 +1100,8 @@ sub test($$)
           $reference_exists = 1;
           $tests_count += 1;
           if ($todos{$format}) {
-            TODO: {
-              local $TODO = $todos{$format};
+            SKIP: {
+              skip $todos{$format}, 1;
               ok ($converted{$format} 
                               eq $result_converted{$format}->{$test_name},
                    $test_name.' converted '.$format);
@@ -1100,12 +1118,9 @@ sub test($$)
                $result_converted_errors{$format}->{$test_name}),
                $test_name.' errors '.$format);
         }
-      #print STDERR "$format: \n$converted{$format}";
       }
     }
-    #is (Texinfo::Convert::Texinfo::convert($result), $result_texis{$test_name}, $test_name.' text');
   }
-  #exit;
   return $tests_count;
 }
 
